local addonName,addonTable = ...
local DA = LibStub("AceAddon-3.0"):GetAddon("Skillet") -- for DebugAids.lua
--[[
Skillet: A tradeskill window replacement.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
]]--

local isRetail = WOW_PROJECT_ID == WOW_PROJECT_MAINLINE
local isClassic = WOW_PROJECT_ID == WOW_PROJECT_CLASSIC
local isBCC = WOW_PROJECT_ID == WOW_PROJECT_BURNING_CRUSADE_CLASSIC
local isWrath = WOW_PROJECT_ID == WOW_PROJECT_WRATH_CLASSIC
local isCata = WOW_PROJECT_ID == WOW_PROJECT_CATACLYSM_CLASSIC

local PT = LibStub("LibPeriodicTable-3.1")

local skillColors = {
	["unknown"]			= { r = 1.00, g = 0.00, b = 0.00, level = 5, alttext="???", cstring = "|cffff0000"},
	["optimal"]			= { r = 1.00, g = 0.50, b = 0.25, level = 4, alttext="+++", cstring = "|cffff8040"},
	["medium"]			= { r = 1.00, g = 1.00, b = 0.00, level = 3, alttext="++",	cstring = "|cffffff00"},
	["easy"]			= { r = 0.25, g = 0.75, b = 0.25, level = 2, alttext="+",	cstring = "|cff40c000"},
	["trivial"]			= { r = 0.60, g = 0.60, b = 0.60, level = 1, alttext="",	cstring = "|cff909090"},
	["header"]			= { r = 1.00, g = 0.82, b = 0,	  level = 0, alttext="",	cstring = "|cffffc800"},
	["unavailable"]		= { r = 0.3, g = 0.3, b = 0.3,	  level = 6, alttext="",	cstring = "|cff606060"},
}

--
-- function InitializeSkillLevels (which loads Skillet.db.global.SkillLevels) is 
-- at the end of this file.
--
-- Skillet-Classic table was scraped from https://wotlk.wowhead.com/, Skillet from https://www.wowhead.com/
-- using ScrapeWowhead.js (follow instructions in file)
-- provided and maintained by Matthew Hively, https://github.com/matthewhively, matthewhively@viz.com
--

--
-- Table of racial bonuses (including retail)
--
local racialList = {
	[4036]  = {["Gnome"] = 15,				-- engineering
			   ["KulTiran"] = 5},
	[7411]  = {["BloodElf"] = 10,			-- enchanting
			   ["KulTiran"] = 5},
	[25229] = {["Draenei"] = 5,				-- jewelcrafting
			   ["KulTiran"] = 5},
	[2259]  = {["Goblin"] = 15,				-- alchemy
			   ["KulTiran"] = 5},
	[2018]  = {["LightforgedDraenei"] = 15,	-- blacksmithing
			   ["DarkIronDwarf"] = 5,
			   ["KulTiran"] = 5},
	[45357] = {["Nightborne"] = 15,			-- inscription
			   ["KulTiran"] = 5},
	[2550]  = {["Pandaren"] = 15},			-- cooking
}

--
-- local function returns any racial bonus that may apply
--
local function getRacialBonus()
	local player = Skillet.currentPlayer
	local trade = Skillet.currentTrade
	local race = Skillet.db.realm.race[player]
	--DA.DEBUG(0,"getRacialBonus: trade = "..tostring(trade).." ("..tostring(GetSpellInfo(trade)).."), race= "..tostring(race))
	if racialList[trade] then
		for r, bonus in pairs(racialList[trade]) do
			--DA.DEBUG(1,"getRacialBonus: r = "..tostring(r)..", bonus= "..tostring(bonus))
			if r == race then
			DA.DEBUG(1,"getRacialBonus: bonus = "..tostring(bonus))
				return bonus
			end
		end
	end
	return 0
end

--
-- Get TradeSkill Difficulty Levels
--
-- Note: MainFrame.lua uses both inputs, other calls just use itemID.
--   Old MainFrame.lua call: GetTradeSkillLevels((recipe.itemID>0 and recipe.itemID) or -recipe.spellID)
--
function Skillet:GetTradeSkillLevels(itemID, spellID)
	DA.DEBUG(0,"GetTradeSkillLevels("..tostring(itemID)..", "..tostring(spellID)..")")
	local a,b,c,d,e,f,g,h
	local rb = getRacialBonus()
	local skillLevels = Skillet.db.global.SkillLevels
	local levels
	local skillLevelsEra = Skillet.db.global.SkillLineAbility_era
	local levelsE
	local skillLevelsClassic = Skillet.db.global.SkillLineAbility_cata
	local levelsC
	local skillLevelsRetail = Skillet.db.global.SkillLineAbility_retail
	local levelsR
	local possibleRecipes, recipeID, levelsByRecipe
	if itemID then 
		if tonumber(itemID) ~= nil and itemID ~= 0 then
			if self.isCraft or self.currentTrade == 7411 then  -- isCraft for Classic and BCC, Enchanting TradeID for Wrath
				DA.DEBUG(1,"GetTradeSkillLevels: itemID= "..tostring(itemID)..", spellID= "..tostring(spellID)..")")
				itemID = -itemID
			end
			self.indexTradeSkillLevel = itemID
--
-- The CraftInfoAnywhere (https://www.curseforge.com/wow/addons/craft-info-anywhere) API
-- is used to get the recipeID that produces this itemID
--
-- (for now, use the last value returned)
--
			if CraftInfoAnywhere and CraftInfoAnywhere.API then
				possibleRecipes = CraftInfoAnywhere.API.GetRecipesForItem(itemID)
				if possibleRecipes ~= nil then
					recipeID = possibleRecipes[#possibleRecipes]
				end
--
-- Use the appropriate table to find the data
--
				if is_Classic then
					levelsByRecipe = skillLevelsEra[recipeID]
				else
					levelsByRecipe = skillLevelsClassic[recipeID]
				end
			end
--
-- If there is an entry in our own table(s), use it
--
			if skillLevels and skillLevels[itemID] or levelsByRecipe then
--
-- The data from Wowhead is not specific to the game version
--
				if skillLevels and skillLevels[itemID] then
					levels = skillLevels[itemID]
					if type(levels) == 'table' then
						if spellID then
							if isRetail then
								levels = skillLevels[itemID][spellID]
							else
								for spell, strng in pairs(levels) do
									name = GetSpellInfo(spell)
									DA.DEBUG(1,"GetTradeSkillLevels: name= "..tostring(name))
									if name == spellID then
										levels = strng
										break
									end
								end
							end
						end
					end
				end
--
-- Compare the sources
--				
				DA.DEBUG(1,"GetTradeSkillLevels: levelsWowhead= "..tostring(levels))
				DA.DEBUG(1,"GetTradeSkillLevels: levelsByRecipe= "..tostring(levelsByRecipe))
				if levels and type(levels) == 'string' then
					a,b,c,d = string.split("/", levels)
					a = (tonumber(a) or 0) + rb
					b = (tonumber(b) or 0) + rb
					c = (tonumber(c) or 0) + rb
					d = (tonumber(d) or 0) + rb
					self.sourceTradeSkillLevel = 1
				end
				if levelsByRecipe and type(levelsByRecipe) == 'string' then
					e,f,g,h = string.split("/", levelsByRecipe)
					e = (tonumber(e) or 0) + rb
					f = (tonumber(f) or 0) + rb
					g = (tonumber(g) or 0) + rb
					h = (tonumber(h) or 0) + rb
				end
--
-- For debugging, report the differences
--
				local diff = false
				if a ~= e then
					DA.DEBUG(1,"GetTradeSkillLevels: a= "..tostring(a)..", e= "..tostring(e))
				end
				if b ~= f then
					DA.DEBUG(1,"GetTradeSkillLevels: b= "..tostring(b)..", f= "..tostring(f))
					diff = true
				end
				if c ~= g then
					DA.DEBUG(1,"GetTradeSkillLevels: c= "..tostring(c)..", g= "..tostring(g))
					diff = true
				end
				if d ~= h then
					DA.DEBUG(1,"GetTradeSkillLevels: d= "..tostring(b)..", h= "..tostring(h))
					diff = true
				end
--
-- Choose the best value(s)
-- (levelsByRecipe will be nil if CraftInfoAnywhere is not loaded or the Wago Tools table(s) have no data)
--
--				if levelsByRecipe and self.db.profile.altskilllevels then
				if levelsByRecipe then
					if self.db.profile.baseskilllevel then
						a = e
					end
					b = f
					c = g
					d = h
					DA.DEBUG(1,"GetTradeSkillLevels: levelsReturned= "..tostring(a).."/"..tostring(b).."/"..tostring(c).."/"..tostring(d))
					if diff then
						self.sourceTradeSkillLevel = 2
					end
				end
				return a, b, c, d
			end
--
-- The TradeskillInfo addon seems to be more accurate than LibPeriodicTable-3.1
--
			if isRetail and TradeskillInfo then
				local recipeSource = Skillet.db.global.itemRecipeSource[itemID]
				if not recipeSource then
					--DA.DEBUG(1,"GetTradeSkillLevels: itemID= "..tostring(itemID)..", recipeSource= "..tostring(recipeSource))
					recipeSource = Skillet.db.global.itemRecipeSource[-itemID]
				end
				if type(recipeSource) == 'table' then
					--DA.DEBUG(1,"GetTradeSkillLevels: itemID= "..tostring(itemID)..", recipeSource= "..DA.DUMP1(recipeSource))
					for recipeID in pairs(recipeSource) do
						--DA.DEBUG(2,"GetTradeSkillLevels: recipeID= "..tostring(recipeID))
						local TSILevels = TradeskillInfo:GetCombineDifficulty(recipeID)
						if type(TSILevels) == 'table' then
							--DA.DEBUG(2,"GetTradeSkillLevels: TSILevels="..DA.DUMP1(TSILevels))
							a = (tonumber(TSILevels[1]) or 0) + rb
							b = (tonumber(TSILevels[2]) or 0) + rb
							c = (tonumber(TSILevels[3]) or 0) + rb
							d = (tonumber(TSILevels[4]) or 0) + rb
							self.sourceTradeSkillLevel = 2
							return a, b, c, d
						end
					end
				else
					--DA.DEBUG(1,"GetTradeSkillLevels: itemID= "..tostring(itemID)..", recipeSource= "..tostring(recipeSource))
				end
			end

--
-- Check LibPeriodicTable
-- Note: The itemID for Enchants is negative
--
			if PT then
				local levels = PT:ItemInSet(itemID,"TradeskillLevels")
				--DA.DEBUG(1,"GetTradeSkillLevels (PT): itemID= "..tostring(itemID)..", levels= "..tostring(levels))
				if not levels then
					itemID = -itemID
					levels = PT:ItemInSet(itemID,"TradeskillLevels")
					--DA.DEBUG(1,"GetTradeSkillLevels (PT): itemID= "..tostring(itemID)..", levels= "..tostring(levels))
				end
				if levels then
					a,b,c,d = string.split("/",levels)
					a = (tonumber(a) or 0) + rb
					b = (tonumber(b) or 0) + rb
					c = (tonumber(c) or 0) + rb
					d = (tonumber(d) or 0) + rb
					self.sourceTradeSkillLevel = 3
					return a, b, c, d
				end
			end
		elseif tonumber(itemID) == nil then
			DA.DEBUG(0,"GetTradeSkillLevels: "..tostring(itemID).." is not a number")
			self.sourceTradeSkillLevel = 4
			self.indexTradeSkillLevel = nil
			return 0, 0, 0, 0 
		end
	else
		DA.DEBUG(0,"GetTradeSkillLevels: itemID is missing")
		self.sourceTradeSkillLevel = 5
		self.indexTradeSkillLevel = nil
		return 0, 0, 0, 0 
	end
	if not self.db.global.MissingSkillLevels then
		self.db.global.MissingSkillLevels = {}
	end
	self.db.global.MissingSkillLevels[itemID] = "0/0/0/0"
	self.sourceTradeSkillLevel = 6
	return 0, 0, 0, 0 
end

function Skillet:GetTradeSkillLevelColor(itemID, rank)
	--DA.DEBUG(0,"GetTradeSkillLevelColor("..tostring(itemID)..", "..tostring(rank)")")
	if itemID then
		local orange, yellow, green, gray = self:GetTradeSkillLevels(itemID)
		if rank >= gray then return skillColors["trivial"] end
		if rank >= green then return skillColors["easy"] end
		if rank >= yellow then return skillColors["moderate"] end
		if rank >= orange then return skillColors["optimal"] end
	end
	return skillColors["unknown"]
end

function Skillet:AddTradeSkillLevels(itemID, orange, yellow, green, gray, spellID)
	DA.DEBUG(0,"AddTradeSkillLevels("..tostring(itemID)..", "..tostring(orange)..", "..tostring(yellow)..", "..tostring(green)..", "..tostring(gray)..", "..tostring(spellID)..")")
	local skillLevels = Skillet.db.global.SkillLevels
--
-- We should add some sanity checking
--
	if itemID and spellID then
		if not skillLevels[itemID] then 
			skillLevels[itemID] = {}
		end
		skillLevels[itemID][spellID] = tostring(orange).."/"..tostring(yellow).."/"..tostring(green).."/"..tostring(gray)
	elseif itemID then
		skillLevels[itemID] = tostring(orange).."/"..tostring(yellow).."/"..tostring(green).."/"..tostring(gray)
	end
end

function Skillet:DelTradeSkillLevels(itemID)
	DA.DEBUG(0,"DelTradeSkillLevels("..tostring(itemID)..")")
	local skillLevels = Skillet.db.global.SkillLevels
	if itemID then
--
-- We could add some additional checking
--
		skillLevels[itemID] = nil
	end
end

local function tablelength(T)
  local count = 0
  for _ in pairs(T) do count = count + 1 end
  return count
end
--
-- Print the TradeSkillLevels(itemID) result including the actual index and the source.
--
-- index will be itemID or if the current profession is Enchanting, -itemID
--
-- source will be:
--    1 if from Skillet.db.global.SkillLevels
--    2 if from SkillLineAbility_era or SkillLineAbility_cata
--    3 if from TradeskillInfo
--    4 if from LibPeriodicTable
--    5 if itemID was missing or not a number
--    6 if it wasn't found (and was added to Skillet.db.global.MissingSkillLevels)
--
function Skillet:PrintTradeSkillLevels(itemID, spellID)
	--DA.DEBUG(0,"PrintTradeSkillLevels("..tostring(itemID)..", "..tostring(spellID)..")")
	DA.MARK3("PrintTradeSkillLevels: altskilllevels= "..tostring(self.db.profile.altskilllevels))
	DA.MARK3("PrintTradeSkillLevels: baseskilllevel= "..tostring(self.db.profile.baseskilllevel))
	DA.MARK3("PrintTradeSkillLevels: #SkillLevels= "..tostring(tablelength(self.db.global.SkillLevels)))
	DA.MARK3("PrintTradeSkillLevels: #SkillLineAbility_era= "..tostring(tablelength(self.db.global.SkillLineAbility_era)))
	DA.MARK3("PrintTradeSkillLevels: #SkillLineAbility_cata= "..tostring(tablelength(self.db.global.SkillLineAbility_cata)))
	DA.MARK3("PrintTradeSkillLevels: #SkillLineAbility_retail= "..tostring(tablelength(self.db.global.SkillLineAbility_retail)))
	if CraftInfoAnywhere then
		DA.MARK3("PrintTradeSkillLevels: #ItemsToRecipes= "..tostring(tablelength(CraftInfoAnywhere.Data.ItemsToRecipes)))
	end
	if itemID then
		local orange, yellow, green, gray = self:GetTradeSkillLevels(itemID, spellID)
		DA.MARK3("PrintTradeSkillLevels: itemID= "..tostring(itemID)..", spellID= "..tostring(spellID))
		DA.MARK3("PrintTradeSkillLevels: index= "..tostring(self.indexTradeSkillLevel)..", source= "..tostring(self.sourceTradeSkillLevel))
		DA.MARK3("PrintTradeSkillLevels: levels= "..tostring(orange).."/"..tostring(yellow).."/"..tostring(green).."/"..tostring(gray))
	end
end

--
-- Our own tables of skill levels:
--    Skillet.db.global.SkillLevels
--    Skillet.db.global.SkillLineAbility_era
--    Skillet.db.global.SkillLineAbility_cata
--
-- SkillLevels index is itemID
-- SkillLineAbility_era and SkillLineAbility_cata index is recipeID
--
-- Contents can be generated by:
--    1)	  
--      Scrape from Wowhead: Follow instructions in ScrapeWowhead.js
--		Use https://wago.tools/: Follow the instructions in SkillLevelsConverter.py
--
--    2) can be maintained with an external addon (using AddTradeSkillLevels, DelTradeSkillLevels)
--
-- Each entry is either [itemID] = "orange/yellow/green/gray" or 
--   a table of recipeIDs with the same format
--   [itemID] = {[recipeID1] = "orange/yellow/green/gray", [recipeID2] = "orange/yellow/green/gray"},
--
--   itemID is the item made by the recipe or the recipeID of the Enchant
--   recipeID(s) are the numeric id(s) of each recipe that produces the itemID
--   orange is the (numeric) skill level below which recipe is orange
--   yellow is the (numeric) skill level below which the recipe is yellow
--   green  is the (numeric) skill level below which the recipe is green
--   gray   is the (numeric) skill level above which the recipe is gray
--
-- A global table, Skillet.db.global.MissingSkillLevels, is added to when
-- no other entry is found. The format of this table is the same as
-- the table Skillet.db.global.SkillLevels to facilitate adding to this table.
--
-- InitializeSkillLevels is only called if the table does not exist.
--
-- Force refresh with '/skillet initskilllevels'
-- or '/run Skillet:InitializeSkillLevels()'
-- or '/run Skillet.db.global.SkillLevels = nil'
--
function Skillet:InitializeSkillLevels()
Skillet.db.global.SkillLevels = {
		[0] = "orange/yellow/green/gray",
-- alchemy
[118] = "1/55/75/95",
[858] = "1/85/105/125",
[929] = "1/135/155/175",
[1710] = "1/175/195/215",
[2454] = "1/55/75/95",
[2455] = "1/65/85/105",
[2456] = "1/70/90/110",
[2457] = "1/80/100/120",
[2458] = "1/80/100/120",
[2459] = "1/90/110/130",
[3382] = "1/60/80/100",
[3383] = "1/120/140/160",
[3385] = "1/145/165/185",
[3386] = "1/145/165/185",
[3387] = "1/275/287/300",
[3388] = "1/150/170/190",
[3389] = "1/155/175/195",
[3390] = "1/165/185/205",
[3391] = "1/175/195/215",
[3577] = "1/240/260/280",
[3823] = "1/185/205/225",
[3824] = "1/190/210/230",
[3825] = "1/195/215/235",
[3826] = "1/200/220/240",
[3827] = "1/180/200/220",
[3828] = "1/215/235/255",
[3829] = "1/220/240/260",
[3928] = "1/230/250/270",
[4596] = "1/80/100/120",
[4623] = "1/230/250/270",
[5631] = "1/90/110/130",
[5633] = "1/195/215/235",
[5634] = "1/175/195/215",
[5996] = "1/120/140/160",
[5997] = "1/55/75/95",
[6037] = "1/240/260/280",
[6048] = "1/160/180/200",
[6049] = "1/210/230/250",
[6050] = "1/205/225/245",
[6051] = "1/130/150/170",
[6052] = "1/210/230/250",
[6149] = "1/220/240/260",
[6370] = "1/80/90/100",
[6371] = "1/150/160/170",
[6372] = "1/130/150/170",
[6373] = "1/165/185/205",
[6452] = "1/80/115/150",
[6453] = "1/130/165/200",
[6662] = "1/120/140/160",
[7068] = "1/300/300/300",
[7076] = {[17560] = "1/275/282/290", [17565] = "1/275/282/290"},
[7078] = "1/275/282/290",
[7080] = {[17561] = "1/275/282/290", [17563] = "1/275/282/290"},
[7082] = "1/275/282/290",
[8827] = "1/40/47/55",
[8949] = "1/205/225/245",
[8951] = "1/215/235/255",
[8956] = "1/220/240/260",
[9030] = "1/225/245/265",
[9061] = "1/225/245/265",
[9088] = "1/255/275/295",
[9144] = "1/240/260/280",
[9149] = "1/240/260/280",
[9154] = "1/245/265/285",
[9155] = "1/250/270/290",
[9172] = "1/250/270/290",
[9179] = "1/250/270/290",
[9187] = "1/255/275/295",
[9197] = "1/255/275/295",
[9206] = "1/260/280/300",
[9210] = "1/260/280/300",
[9224] = "1/265/282/300",
[9233] = "1/265/282/300",
[9264] = "1/265/282/300",
[10592] = "1/220/240/260",
[12190] = "1/245/265/285",
[12360] = "1/275/282/290",
[12803] = "1/275/282/290",
[12808] = "1/275/282/290",
[13423] = "1/250/255/260",
[13442] = "1/270/285/300",
[13443] = "1/275/287/300",
[13444] = "1/300/300/300",
[13445] = "1/280/290/300",
[13446] = "1/290/295/300",
[13447] = "1/285/292/300",
[13452] = "1/295/297/300",
[13453] = "275/290/295/300",
[13454] = "1/300/300/300",
[13455] = "1/295/297/300",
[13456] = "1/300/300/300",
[13457] = "1/300/300/300",
[13458] = "1/300/300/300",
[13459] = "1/300/300/300",
[13461] = "1/300/300/300",
[13462] = "1/300/300/300",
[13503] = "1/1/25/50",
[13506] = "1/300/300/300",
[13510] = "1/300/300/300",
[13511] = "1/300/300/300",
[13512] = "1/300/300/300",
[17708] = "1/210/230/250",
[18253] = "1/300/300/300",
[18294] = "1/230/250/270",
[19440] = "1/300/300/300",
[19931] = "1/300/300/300",
[20002] = "1/290/295/300",
[20004] = "1/300/300/300",
[20007] = "1/290/295/300",
[20008] = "1/300/300/300",
[21546] = "1/265/282/300",
[21884] = {[28566] = "1/65/70/75", [28582] = "1/75/75/75"},
[21885] = {[28567] = "1/65/70/75", [28580] = "1/75/75/75"},
[21886] = "1/75/75/75",
[22451] = "1/65/70/75",
[22452] = {[28568] = "1/65/70/75", [28584] = "1/75/75/75"},
[22456] = "1/75/75/75",
[22457] = "1/75/75/75",
[22823] = "1/20/27/35",
[22824] = "1/20/27/35",
[22825] = "1/25/32/40",
[22826] = "1/30/37/45",
[22827] = "1/35/42/50",
[22828] = "1/35/42/50",
[22829] = "1/40/47/55",
[22830] = "1/40/47/55",
[22831] = "1/45/52/60",
[22832] = "1/55/62/70",
[22833] = "1/60/67/75",
[22834] = "1/60/67/75",
[22835] = "1/65/70/75",
[22836] = "1/65/70/75",
[22837] = "1/65/70/75",
[22838] = "1/65/70/75",
[22839] = "1/65/70/75",
[22840] = "1/70/72/75",
[22841] = "1/75/75/75",
[22842] = "1/75/75/75",
[22844] = "1/75/75/75",
[22845] = "1/75/75/75",
[22846] = "1/75/75/75",
[22847] = "1/75/75/75",
[22848] = "1/75/75/75",
[22849] = "1/75/75/75",
[22850] = "1/75/75/75",
[22851] = "1/75/75/75",
[22853] = "1/75/75/75",
[22854] = "1/75/75/75",
[22861] = "1/75/75/75",
[22866] = "1/75/75/75",
[22871] = "1/50/57/65",
[23571] = "1/65/70/75",
[25867] = "1/65/70/75",
[25868] = "1/65/70/75",
[28100] = "1/15/22/30",
[28101] = "1/25/32/40",
[28102] = "1/15/22/30",
[28103] = "1/15/22/30",
[28104] = "1/30/37/45",
[31080] = "1/40/47/55",
[31676] = "1/60/67/75",
[31677] = "1/75/75/75",
[31679] = "1/50/57/65",
[32062] = "1/25/32/40",
[32063] = "1/35/42/50",
[32067] = "1/35/42/50",
[32068] = "1/45/52/60",
[32839] = "1/60/67/75",
[32849] = "1/60/67/75",
[32850] = "1/60/67/75",
[32851] = "1/60/67/75",
[32852] = "1/60/67/75",
[33447] = "1/35/42/50",
[33448] = "1/40/47/55",
[34440] = "1/35/42/50",
[35622] = {[53774] = "1/30/40/50", [53776] = "1/30/40/50"},
[35623] = {[53781] = "1/30/40/50", [53783] = "1/30/40/50"},
[35624] = {[53777] = "1/30/40/50", [53779] = "1/30/40/50"},
[35625] = {[53775] = "1/30/40/50", [53780] = "1/30/40/50"},
[35627] = {[53771] = "1/30/40/50", [53782] = "1/30/40/50"},
[35748] = "1/75/75/75",
[35749] = "1/75/75/75",
[35750] = "1/75/75/75",
[35751] = "1/75/75/75",
[36860] = {[53773] = "1/30/40/50", [53784] = "1/30/40/50"},
[36919] = "1/65/70/75",
[36922] = "1/65/70/75",
[36925] = "1/65/70/75",
[36928] = "1/65/70/75",
[36931] = "1/65/70/75",
[36934] = "1/65/70/75",
[39666] = "1/25/32/40",
[39671] = "1/1/3/5",
[40067] = "1/1/5/10",
[40068] = "1/1/5/10",
[40070] = "1/1/8/15",
[40072] = "1/15/20/25",
[40073] = "1/15/20/25",
[40076] = "1/5/10/15",
[40077] = "1/40/47/55",
[40078] = "1/20/25/30",
[40079] = "1/5/10/15",
[40081] = "1/10/15/20",
[40087] = "1/40/47/55",
[40093] = "1/40/47/55",
[40097] = "1/40/47/55",
[40109] = "1/40/47/55",
[40195] = "1/5/10/15",
[40211] = "1/40/47/55",
[40212] = "1/40/47/55",
[40213] = "1/35/40/45",
[40214] = "1/35/40/45",
[40215] = "1/35/40/45",
[40216] = "1/35/40/45",
[40217] = "1/400/400/400",
[41163] = "1/45/55/65",
[41266] = "1/65/70/75",
[41334] = "1/60/65/70",
[43569] = "1/35/37/40",
[43570] = "1/40/42/45",
[44322] = "1/45/50/55",
[44323] = "1/45/50/55",
[44324] = "1/45/50/55",
[44325] = "1/40/47/55",
[44327] = "1/40/47/55",
[44328] = "1/40/47/55",
[44329] = "1/40/47/55",
[44330] = "1/40/47/55",
[44331] = "1/40/47/55",
[44332] = "1/25/32/40",
[44958] = "1/5/10/15",
[45621] = "1/160/180/200",
[46376] = "1/75/75/75",
[46377] = "1/75/75/75",
[46378] = "1/75/75/75",
[46379] = "1/75/75/75",
[51950] = "1/75/75/75",
[52190] = "1/75/75/75",
[52191] = "1/70/72/75",
[52192] = "1/60/65/70",
[52193] = "1/65/70/75",
[52194] = "1/70/72/75",
[52195] = "1/75/75/75",
[52303] = "1/75/75/75",
[54464] = "1/60/65/70",
[56850] = "1/25/30/35",
[57099] = "1/25/30/35",
[57191] = "1/50/55/60",
[57192] = "1/40/45/50",
[57193] = "1/30/35/40",
[57194] = "1/20/25/30",
[58084] = "1/5/10/15",
[58085] = "1/55/60/65",
[58086] = "1/60/65/70",
[58087] = "1/65/70/75",
[58088] = "1/65/70/75",
[58089] = "1/10/15/20",
[58090] = "1/5/10/15",
[58091] = "1/15/20/25",
[58092] = "1/20/25/30",
[58093] = "1/30/35/40",
[58094] = "1/35/40/45",
[58142] = "1/10/15/20",
[58143] = "1/35/40/45",
[58144] = "1/45/50/55",
[58145] = "1/40/45/50",
[58146] = "1/45/50/55",
[58148] = "1/50/55/60",
[58480] = "1/75/75/75",
[58483] = "1/60/62/65",
[58487] = "1/75/75/75",
[58488] = "1/75/75/75",
[58489] = "1/20/25/30",
[62288] = "1/75/75/75",
[65460] = "1/75/75/75",
[65891] = "1/75/75/75",
[67415] = "1/1/5/10",
[67438] = "1/55/60/65",
[68775] = "1/60/62/65",
[68776] = "1/60/62/65",
[68777] = "1/60/62/65",
[72095] = "1/75/75/75",
[72104] = {[114780] = "1/75/75/75", [130326] = "1/75/75/75"},
[75274] = "1/1/5/10",
[75525] = "1/300/300/300",
[76075] = "1/15/27/40",
[76076] = "1/15/27/40",
[76077] = "1/15/27/40",
[76078] = "1/40/52/65",
[76079] = "1/40/52/65",
[76080] = "1/40/52/65",
[76081] = "1/40/52/65",
[76083] = "1/15/27/40",
[76084] = "1/75/75/75",
[76085] = "1/75/75/75",
[76086] = "1/75/75/75",
[76087] = "1/75/75/75",
[76088] = "1/75/75/75",
[76089] = "1/40/52/65",
[76090] = "1/15/27/40",
[76092] = "1/40/52/65",
[76093] = "1/15/27/40",
[76094] = "1/1/5/10",
[76095] = "1/40/52/65",
[76096] = "1/40/52/65",
[76097] = "1/1/5/10",
[76098] = "1/75/75/75",
[76131] = "1/75/75/75",
[76132] = "1/75/75/75",
[76138] = "1/75/75/75",
[76139] = "1/75/75/75",
[76140] = "1/75/75/75",
[76141] = "1/75/75/75",
[76142] = "1/75/75/75",
[87872] = "1/15/27/40",
[93351] = "1/75/75/75",
[108996] = "1/1/50/100",
[109123] = "1/50/55/60",
[109145] = "1/100/100/100",
[109147] = "1/100/100/100",
[109148] = "1/100/100/100",
[109152] = "1/100/100/100",
[109153] = "1/100/100/100",
[109155] = "1/100/100/100",
[109156] = "1/100/100/100",
[109160] = "1/100/100/100",
[109217] = "1/50/55/60",
[109218] = "1/50/55/60",
[109219] = "1/50/55/60",
[109220] = "1/50/55/60",
[109221] = "1/50/55/60",
[109222] = "1/50/55/60",
[109223] = "1/1/25/50",
[109226] = "1/50/55/60",
[109262] = "1/100/100/100",
[112090] = "1/50/55/60",
[113261] = {[181632] = "1/100/100/100", [181633] = "1/100/100/100", [181634] = "1/100/100/100"},
[113262] = {[181628] = "1/100/100/100", [181635] = "1/100/100/100", [181636] = "1/100/100/100"},
[113263] = {[181625] = "1/100/100/100", [181629] = "1/100/100/100", [181637] = "1/1/3/5"},
[113264] = {[181627] = "1/100/100/100", [181630] = "1/100/100/100", [181631] = "1/100/100/100"},
[115460] = "1/40/47/55",
[116266] = "1/50/55/60",
[116268] = "1/50/55/60",
[116271] = "1/50/55/60",
[116276] = "1/50/55/60",
[116979] = "1/50/75/100",
[116981] = "1/75/87/100",
[118472] = "1/5/7/10",
[118700] = "1/1/50/100",
[118704] = "1/50/55/60",
[118711] = "1/50/55/60",
[122601] = "1/1/3/5",
[122602] = "1/2/3/5",
[122603] = "1/3/4/5",
[122604] = "1/4/4/5",
[124124] = "1/20/50/80",
[127834] = {[188297] = "1/20/30/40", [188299] = "1/40/50/60", [188300] = "1/60/70/80"},
[127835] = {[188301] = "1/20/30/40", [188302] = "1/40/50/60", [188303] = "1/60/70/80"},
[127836] = {[188304] = "1/20/30/40", [188305] = "1/40/50/60", [188306] = "1/60/70/80"},
[127837] = {[188307] = "1/20/30/40", [188308] = "1/40/50/60", [188309] = "1/60/70/80"},
[127838] = {[188310] = "1/20/30/40", [188311] = "1/40/50/60", [188312] = "1/60/70/80"},
[127839] = {[188313] = "1/20/30/40", [188314] = "1/40/50/60", [188315] = "1/60/70/80"},
[127840] = {[188316] = "1/20/30/40", [188317] = "1/40/50/60", [188318] = "1/60/70/80"},
[127841] = {[188319] = "1/20/30/40", [188320] = "1/40/50/60", [188321] = "1/60/70/80"},
[127842] = {[188322] = "1/40/50/60", [188323] = "1/60/70/80", [188324] = "1/80/90/100"},
[127843] = {[188325] = "1/40/50/60", [188326] = "1/60/70/80", [188327] = "1/80/90/100"},
[127844] = {[188328] = "1/40/50/60", [188329] = "1/60/70/80", [188330] = "1/80/90/100"},
[127845] = {[188331] = "1/40/50/60", [188332] = "1/60/70/80", [188333] = "1/80/90/100"},
[127846] = {[188334] = "1/40/50/60", [188335] = "1/60/70/80", [188336] = "1/80/90/100"},
[127847] = {[188337] = "1/60/70/80", [188338] = "1/80/90/100", [188339] = "1/100/100/100"},
[127848] = {[188340] = "1/60/70/80", [188341] = "1/80/90/100", [188342] = "1/100/100/100"},
[127849] = {[188343] = "1/60/70/80", [188344] = "1/80/90/100", [188345] = "1/100/100/100"},
[127850] = {[188346] = "1/60/70/80", [188347] = "1/80/90/100", [188348] = "1/100/100/100"},
[127851] = {[188349] = "1/60/70/80", [188350] = "1/80/90/100", [188351] = "1/100/100/100"},
[136653] = "1/40/50/60",
[137590] = "1/20/50/80",
[137591] = "1/20/50/80",
[137592] = "1/20/50/80",
[137593] = {[213251] = "1/20/50/80", [213252] = "1/20/50/80", [213253] = "1/20/50/80"},
[137594] = "1/20/50/80",
[137599] = "1/20/50/80",
[137600] = "1/20/50/80",
[141323] = {[188800] = "1/20/50/80", [188801] = "1/20/50/80", [188802] = "1/20/50/80"},
[142117] = {[229217] = "1/60/70/80", [229218] = "1/80/90/100", [229220] = "1/100/100/100"},
[151568] = "1/20/50/80",
[151607] = {[247694] = "1/90/95/100", [247695] = "1/90/95/100", [247696] = "1/90/95/100"},
[151608] = {[247619] = "1/80/90/100", [247620] = "1/80/90/100", [247622] = "1/80/90/100"},
[151609] = {[247688] = "1/80/90/100", [247690] = "1/80/90/100", [247691] = "1/80/90/100"},
[152494] = {[252382] = "1/25/37/50", [252383] = "1/50/62/75", [252384] = "1/75/87/100"},
[152495] = {[252385] = "1/25/37/50", [252386] = "1/50/62/75", [252387] = "1/75/87/100"},
[152496] = {[252391] = "1/50/62/75", [252392] = "1/65/82/100", [252393] = "1/85/105/125"},
[152497] = {[252394] = "1/50/62/75", [252395] = "1/65/82/100", [252396] = "1/85/105/125"},
[152503] = {[252400] = "1/50/62/75", [252401] = "1/65/82/100", [252402] = "1/85/105/125"},
[152550] = {[252397] = "1/50/62/75", [252398] = "1/65/82/100", [252399] = "1/85/105/125"},
[152557] = {[252334] = "1/60/72/85", [252335] = "1/75/95/115", [252336] = "1/100/117/135"},
[152559] = {[252344] = "1/60/72/85", [252345] = "1/75/95/115", [252346] = "1/100/117/135"},
[152560] = {[252341] = "1/60/72/85", [252342] = "1/75/95/115", [252343] = "1/100/117/135"},
[152561] = {[252337] = "1/60/72/85", [252339] = "1/75/95/115", [252340] = "1/100/117/135"},
[152578] = "1/30/90/150",
[152580] = {[251306] = "1/30/90/150", [251310] = "1/30/90/150"},
[152581] = {[251311] = "1/30/90/150", [251822] = "1/30/90/150"},
[152582] = "1/30/90/150",
[152615] = {[251646] = "1/40/50/60", [251651] = "1/60/70/80", [251658] = "1/80/90/100"},
[152632] = {[252379] = "1/95/110/125", [252380] = "1/110/130/150", [252381] = "1/150/150/150"},
[152634] = {[252361] = "1/50/62/75", [252362] = "1/80/102/125", [252363] = "1/90/110/130"},
[152636] = {[252376] = "1/95/110/125", [252377] = "1/110/130/150", [252378] = "1/150/150/150"},
[152637] = {[252368] = "1/50/62/75", [252369] = "1/80/102/125", [252370] = "1/90/110/130"},
[152638] = {[252348] = "1/105/115/125", [252349] = "1/140/145/150", [252350] = "1/150/150/150"},
[152639] = {[252351] = "1/105/115/125", [252352] = "1/140/145/150", [252353] = "1/150/150/150"},
[152640] = {[252354] = "1/105/115/125", [252355] = "1/140/145/150", [252356] = "1/150/150/150"},
[152641] = {[252357] = "1/105/115/125", [252358] = "1/140/145/150", [252359] = "1/150/150/150"},
[152668] = "1/90/120/150",
[156631] = "1/150/150/150",
[160322] = "1/30/90/150",
[160325] = "1/30/90/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[162519] = {[276975] = "1/150/150/150", [276976] = "1/150/150/150", [276977] = "1/150/150/150"},
[163082] = {[252388] = "1/25/37/50", [252389] = "1/50/62/75", [252390] = "1/75/87/100"},
[163222] = {[279162] = "1/75/100/125", [279163] = "1/95/112/130", [279164] = "1/100/117/135"},
[163223] = {[279159] = "1/75/100/125", [279160] = "1/95/112/130", [279161] = "1/100/117/135"},
[163224] = {[279168] = "1/75/100/125", [279169] = "1/95/112/130", [279170] = "1/100/117/135"},
[163225] = {[279165] = "1/75/100/125", [279166] = "1/95/112/130", [279167] = "1/100/117/135"},
[165721] = "1/95/110/125",
[165744] = "1/95/110/125",
[165851] = "1/30/90/150",
[165926] = "1/150/150/150",
[165927] = "1/150/150/150",
[165928] = "1/150/150/150",
[166270] = {[287447] = "1/50/62/75", [287448] = "1/65/82/100", [287449] = "1/85/105/125"},
[166974] = "1/125/137/150",
[166975] = "1/130/140/150",
[166976] = "1/135/142/150",
[168489] = {[298729] = "1/165/170/175", [298730] = "1/170/172/175", [298731] = "1/175/175/175"},
[168498] = {[298741] = "1/165/170/175", [298742] = "1/170/172/175", [298743] = "1/175/175/175"},
[168499] = {[298747] = "1/165/170/175", [298748] = "1/170/172/175", [298749] = "1/175/175/175"},
[168500] = {[298750] = "1/165/170/175", [298751] = "1/170/172/175", [298752] = "1/175/175/175"},
[168501] = {[298734] = "1/165/170/175", [298735] = "1/170/172/175", [298736] = "1/175/175/175"},
[168506] = {[298744] = "1/165/170/175", [298745] = "1/170/172/175", [298746] = "1/175/175/175"},
[168529] = {[298726] = "1/165/170/175", [298727] = "1/170/172/175", [298728] = "1/175/175/175"},
[168651] = {[298842] = "1/170/172/175", [298843] = "1/175/175/175", [298845] = "1/175/175/175"},
[168652] = {[298846] = "1/170/172/175", [298847] = "1/175/175/175", [298848] = "1/175/175/175"},
[168653] = {[298850] = "1/170/172/175", [298851] = "1/175/175/175", [298852] = "1/175/175/175"},
[168654] = {[298853] = "1/170/172/175", [298854] = "1/175/175/175", [298855] = "1/175/175/175"},
[168656] = {[298862] = "1/175/175/175", [298863] = "1/175/175/175", [298864] = "1/175/175/175"},
[168674] = "1/175/175/175",
[168675] = "1/175/175/175",
[168676] = "1/175/175/175",
[169299] = {[300749] = "1/165/170/175", [300750] = "1/170/172/175", [300751] = "1/175/175/175"},
[169300] = {[300752] = "1/165/170/175", [300753] = "1/170/172/175", [300754] = "1/175/175/175"},
[169451] = {[301310] = "1/165/170/175", [301311] = "1/170/172/175", [301312] = "1/175/175/175"},
[171085] = "1/175/175/175",
[171087] = "1/175/175/175",
[171088] = "1/175/175/175",
[171263] = "1/60/77/95",
[171264] = "1/55/67/80",
[171266] = "1/45/57/70",
[171267] = "1/10/15/20",
[171268] = "1/10/15/20",
[171269] = "1/15/22/30",
[171270] = "1/165/170/175",
[171271] = "1/110/127/145",
[171272] = "1/110/127/145",
[171273] = "1/165/170/175",
[171274] = "1/165/170/175",
[171275] = "1/165/170/175",
[171276] = "1/170/172/175",
[171278] = "1/170/172/175",
[171284] = "1/175/175/175",
[171285] = "1/20/35/50",
[171286] = "1/20/35/50",
[171287] = "1/25/32/40",
[171288] = "1/90/97/105",
[171289] = "1/115/122/130",
[171290] = "1/55/62/70",
[171291] = "1/25/37/50",
[171292] = "1/70/77/85",
[171301] = "1/15/22/30",
[171320] = "1/200/200/200",
[171323] = "1/175/175/175",
[171349] = "1/135/152/170",
[171350] = "1/135/152/170",
[171351] = "1/145/160/175",
[171352] = "1/145/160/175",
[171370] = "1/70/87/105",
[171428] = "1/175/175/175",
[173381] = "1/155/157/160",
[173382] = "1/175/177/180",
[173383] = "1/190/192/195",
[173384] = "1/200/200/200",
[176811] = "1/120/137/155",
[180457] = "1/175/175/175",
[180751] = "1/10/15/20",
[183823] = "1/60/77/95",
[183942] = "1/130/132/135",
[184090] = "1/100/117/135",
[186694] = "1/175/175/175",
[186697] = "1/100/112/125",
[186698] = "1/100/112/125",
[186699] = "1/100/112/125",
[186700] = "1/100/112/125",
[186701] = "1/100/112/125",
-- Invalid recipe: Shadowlands Alchemy (59) - Potion of Hibernal Rest (338190)
-- Invalid recipe: Shadowlands Alchemy (59) - Liquid Sleep (338191)
-- Invalid recipe: Shadowlands Alchemy (59) - Powdered Dreamroot (338192)
-- Invalid recipe: Shadowlands Alchemy (59) - Flask of Measured Discipline (338194)
-- Invalid recipe: Shadowlands Alchemy (59) - Distilled Resolve (338195)
-- Invalid recipe: Shadowlands Alchemy (59) - Pulverized Breezebloom (338196)
-- Invalid recipe: Shadowlands Alchemy (59) - Draught of Grotesque Strength (338198)
-- Invalid recipe: Shadowlands Alchemy (59) - Brutal Oil (338199)
-- Invalid recipe: Shadowlands Alchemy (59) - Crushed Bones (338200)
-- Invalid recipe: Shadowlands Alchemy (59) - Elixir of Humility (338202)
-- Invalid recipe: Shadowlands Alchemy (59) - Refined Submission (338203)
-- Invalid recipe: Shadowlands Alchemy (59) - Bramblethorn Juice (338204)



-- blacksmithing
[2844] = "1/55/75/95",
[2845] = "1/60/80/100",
[2847] = "1/65/85/105",
[2848] = "1/140/155/170",
[2849] = "1/145/160/175",
[2850] = "1/150/165/180",
[2851] = "1/75/95/115",
[2852] = "1/50/70/90",
[2853] = "1/20/40/60",
[2854] = "1/115/127/140",
[2857] = "1/110/130/150",
[2862] = "1/15/35/55",
[2863] = "1/65/72/80",
[2864] = "1/120/140/160",
[2865] = "1/145/160/175",
[2866] = "1/145/160/175",
[2868] = "1/150/165/180",
[2869] = "1/160/175/190",
[2870] = "1/175/190/205",
[2871] = "1/125/132/140",
[3239] = "1/15/35/55",
[3240] = "1/65/72/80",
[3241] = "1/125/132/140",
[3469] = "1/60/80/100",
[3470] = "1/45/65/85",
[3471] = "1/75/95/115",
[3472] = "1/80/100/120",
[3473] = "1/85/105/125",
[3474] = "1/100/120/140",
[3478] = "1/75/87/100",
[3480] = "1/140/155/170",
[3481] = "1/155/170/185",
[3482] = "1/160/175/190",
[3483] = "1/165/180/195",
[3484] = "1/175/190/205",
[3485] = "1/180/195/210",
[3486] = "1/125/137/150",
[3487] = "1/135/155/175",
[3488] = "1/75/95/115",
[3489] = "1/110/130/150",
[3490] = "1/155/170/185",
[3491] = "1/160/175/190",
[3492] = "1/175/190/205",
[3835] = "1/190/202/215",
[3836] = "1/195/207/220",
[3837] = "1/215/227/240",
[3840] = "1/185/197/210",
[3841] = "1/200/212/225",
[3842] = "1/180/192/205",
[3843] = "1/195/207/220",
[3844] = "1/205/217/230",
[3845] = "1/220/232/245",
[3846] = "1/210/222/235",
[3847] = "1/225/237/250",
[3848] = "1/135/150/165",
[3849] = "1/185/197/210",
[3850] = "1/200/212/225",
[3851] = "1/180/192/205",
[3852] = "1/195/207/220",
[3853] = "1/205/217/230",
[3854] = "1/225/237/250",
[3855] = "1/210/222/235",
[3856] = "1/225/237/250",
[5540] = "1/140/155/170",
[5541] = "1/170/185/200",
[6040] = "1/210/222/235",
[6041] = "1/215/227/240",
[6042] = "1/180/195/210",
[6043] = "1/190/202/215",
[6214] = "1/105/125/145",
[6350] = "1/125/140/155",
[6731] = "1/140/160/180",
[7071] = "1/150/152/155",
[7166] = "1/70/90/110",
[7913] = "1/185/197/210",
[7914] = "1/185/197/210",
[7915] = "1/200/212/225",
[7916] = "1/205/217/230",
[7917] = "1/210/222/235",
[7918] = "1/225/235/245",
[7919] = "1/225/235/245",
[7920] = "1/230/240/250",
[7921] = "1/230/240/250",
[7922] = "1/235/245/255",
[7924] = "1/235/245/255",
[7926] = "1/240/250/260",
[7927] = "1/240/250/260",
[7928] = "1/245/255/265",
[7929] = "1/250/260/270",
[7930] = "1/250/260/270",
[7931] = "1/250/260/270",
[7932] = "1/255/265/275",
[7933] = "1/255/265/275",
[7934] = "1/255/265/275",
[7935] = "1/260/270/280",
[7936] = "1/265/275/285",
[7937] = "1/265/275/285",
[7938] = "1/245/255/265",
[7939] = "1/265/275/285",
[7941] = "1/235/247/260",
[7942] = "1/245/257/270",
[7943] = "1/250/262/275",
[7944] = "1/265/277/290",
[7945] = "1/255/267/280",
[7946] = "1/270/282/295",
[7947] = "1/280/290/300",
[7954] = "1/260/272/285",
[7955] = "1/70/90/110",
[7956] = "1/155/170/185",
[7957] = "1/160/175/190",
[7958] = "1/165/180/195",
[7959] = "1/275/287/300",
[7960] = "1/285/292/300",
[7961] = "1/270/282/295",
[7963] = "1/225/237/250",
[7964] = "1/200/205/210",
[7965] = "1/200/205/210",
[7966] = "1/200/205/210",
[7967] = "1/235/245/255",
[7969] = "1/255/265/275",
[9060] = "1/225/237/250",
[9366] = "1/225/235/245",
[10421] = "1/15/35/55",
[10423] = "1/180/192/205",
[11604] = "1/300/300/300",
[11605] = "1/300/300/300",
[11606] = "1/290/295/300",
[11607] = "1/295/297/300",
[11608] = "1/285/292/300",
[12259] = "1/205/217/230",
[12260] = "1/215/227/240",
[12404] = "1/255/257/260",
[12405] = "1/270/280/290",
[12406] = "1/270/280/290",
[12408] = "1/275/285/295",
[12409] = "1/300/300/300",
[12410] = "1/300/300/300",
[12414] = "1/300/300/300",
[12415] = "1/290/295/300",
[12416] = "1/280/290/300",
[12417] = "1/300/300/300",
[12418] = "1/300/300/300",
[12419] = "1/300/300/300",
[12420] = "1/300/300/300",
[12422] = "1/300/300/300",
[12424] = "1/285/292/300",
[12425] = "1/290/295/300",
[12426] = "1/300/300/300",
[12427] = "1/300/300/300",
[12428] = "1/285/292/300",
[12429] = "1/300/300/300",
[12610] = "1/300/300/300",
[12611] = "1/300/300/300",
[12612] = "1/300/300/300",
[12613] = "1/300/300/300",
[12614] = "1/300/300/300",
[12618] = "1/300/300/300",
[12619] = "1/300/300/300",
[12620] = "1/300/300/300",
[12624] = "1/290/295/300",
[12625] = "1/300/300/300",
[12628] = "1/300/300/300",
[12631] = "1/300/300/300",
[12632] = "1/300/300/300",
[12633] = "1/300/300/300",
[12636] = "1/300/300/300",
[12639] = "1/300/300/300",
[12640] = "1/300/300/300",
[12641] = "1/300/300/300",
[12643] = "1/255/257/260",
[12644] = "1/255/257/260",
[12645] = "1/295/297/300",
[12773] = "1/300/300/300",
[12774] = "1/300/300/300",
[12775] = "1/300/300/300",
[12776] = "1/300/300/300",
[12777] = "1/300/300/300",
[12781] = "1/300/300/300",
[12782] = "1/300/300/300",
[12783] = "1/300/300/300",
[12784] = "1/300/300/300",
[12790] = "1/300/300/300",
[12792] = "1/300/300/300",
[12794] = "1/300/300/300",
[12796] = "1/300/300/300",
[12797] = "1/300/300/300",
[12798] = "1/300/300/300",
[15869] = "1/100/110/120",
[15870] = "1/150/160/170",
[15871] = "1/200/210/220",
[15872] = "1/275/280/285",
[16988] = "1/300/300/300",
[16989] = "1/300/300/300",
[17013] = "1/300/300/300",
[17014] = "1/300/300/300",
[17015] = "1/300/300/300",
[17016] = "1/300/300/300",
[17193] = "1/300/300/300",
[17704] = "1/215/227/240",
[18262] = "1/300/300/300",
[19043] = "1/300/300/300",
[19048] = "1/300/300/300",
[19051] = "1/300/300/300",
[19057] = "1/300/300/300",
[19148] = "1/300/300/300",
[19164] = "1/300/300/300",
[19166] = "1/300/300/300",
[19167] = "1/300/300/300",
[19168] = "1/300/300/300",
[19169] = "1/300/300/300",
[19170] = "1/300/300/300",
[19690] = "1/300/300/300",
[19691] = "1/300/300/300",
[19692] = "1/300/300/300",
[19693] = "1/300/300/300",
[19694] = "1/300/300/300",
[19695] = "1/300/300/300",
[20039] = "1/300/300/300",
[20549] = "1/300/300/300",
[20550] = "1/300/300/300",
[20551] = "1/300/300/300",
[22191] = "1/300/300/300",
[22194] = "1/300/300/300",
[22195] = "1/300/300/300",
[22196] = "1/300/300/300",
[22197] = "1/300/300/300",
[22198] = "1/300/300/300",
[22383] = "1/300/300/300",
[22384] = "1/300/300/300",
[22385] = "1/300/300/300",
[22669] = "1/300/300/300",
[22670] = "1/300/300/300",
[22671] = "1/300/300/300",
[22762] = "1/300/300/300",
[22763] = "1/300/300/300",
[22764] = "1/300/300/300",
[23482] = "1/10/20/30",
[23484] = "1/15/25/35",
[23487] = "1/25/35/45",
[23488] = "1/25/35/45",
[23489] = "1/35/45/55",
[23490] = "1/30/40/50",
[23491] = "1/20/30/40",
[23493] = "1/10/20/30",
[23494] = "1/25/35/45",
[23497] = "1/20/30/40",
[23498] = "1/25/35/45",
[23499] = "1/30/40/50",
[23502] = "1/35/45/55",
[23503] = "1/40/50/60",
[23504] = "1/40/50/60",
[23505] = "1/45/55/65",
[23506] = "1/45/55/65",
[23507] = "1/50/60/70",
[23508] = "1/45/55/65",
[23509] = "1/70/72/75",
[23510] = "1/65/67/70",
[23511] = "1/65/67/70",
[23512] = "1/70/72/75",
[23513] = "1/70/72/75",
[23514] = "1/70/72/75",
[23515] = "1/60/65/70",
[23516] = "1/65/67/70",
[23517] = "1/70/72/75",
[23518] = "1/70/72/75",
[23519] = "1/70/72/75",
[23520] = "1/70/72/75",
[23521] = "1/70/72/75",
[23522] = "1/70/72/75",
[23523] = "1/70/72/75",
[23524] = "1/70/72/75",
[23525] = "1/70/72/75",
[23526] = "1/70/72/75",
[23527] = "1/70/72/75",
[23528] = "1/1/5/10",
[23529] = "1/50/55/60",
[23530] = "1/70/72/75",
[23531] = "1/70/72/75",
[23532] = "1/70/72/75",
[23533] = "1/70/72/75",
[23534] = "1/70/72/75",
[23535] = "1/70/72/75",
[23536] = "1/70/72/75",
[23537] = "1/70/72/75",
[23538] = "1/70/72/75",
[23539] = "1/70/72/75",
[23540] = "1/70/72/75",
[23541] = "1/70/72/75",
[23542] = "1/70/72/75",
[23543] = "1/70/72/75",
[23544] = "1/70/72/75",
[23546] = "1/70/72/75",
[23554] = "1/70/72/75",
[23555] = "1/70/72/75",
[23556] = "1/70/72/75",
[23559] = "1/25/30/35",
[23563] = "1/60/65/70",
[23564] = "1/70/72/75",
[23565] = "1/70/72/75",
[23575] = "1/40/45/50",
[23576] = "1/70/72/75",
[25521] = "1/50/55/60",
[28420] = "1/1/5/10",
[28421] = "1/50/55/60",
[28425] = "1/60/65/70",
[28426] = "1/70/72/75",
[28427] = "1/70/72/75",
[28428] = "1/60/65/70",
[28429] = "1/70/72/75",
[28430] = "1/70/72/75",
[28431] = "1/60/65/70",
[28432] = "1/70/72/75",
[28433] = "1/70/72/75",
[28434] = "1/60/65/70",
[28435] = "1/70/72/75",
[28436] = "1/70/72/75",
[28437] = "1/60/65/70",
[28438] = "1/70/72/75",
[28439] = "1/70/72/75",
[28440] = "1/60/65/70",
[28441] = "1/70/72/75",
[28442] = "1/70/72/75",
[28483] = "1/60/65/70",
[28484] = "1/70/72/75",
[28485] = "1/70/72/75",
[30031] = "1/70/72/75",
[30032] = "1/70/72/75",
[30033] = "1/70/72/75",
[30034] = "1/70/72/75",
[30069] = "1/1/3/5",
[30070] = "1/1/3/5",
[30071] = "1/300/300/300",
[30072] = "1/1/3/5",
[30073] = "1/1/3/5",
[30074] = "1/40/50/60",
[30076] = "1/40/50/60",
[30077] = "1/40/50/60",
[30086] = "1/40/50/60",
[30087] = "1/40/50/60",
[30088] = "1/40/50/60",
[30089] = "1/40/50/60",
[30093] = "1/40/50/60",
[31364] = "1/70/72/75",
[31367] = "1/70/72/75",
[31368] = "1/70/72/75",
[31369] = "1/70/72/75",
[31370] = "1/70/72/75",
[31371] = "1/70/72/75",
[32401] = "1/70/72/75",
[32402] = "1/70/72/75",
[32403] = "1/70/72/75",
[32404] = "1/70/72/75",
[32568] = "1/375/375/375",
[32570] = "1/70/72/75",
[32571] = "1/375/375/375",
[32573] = "1/70/72/75",
[32854] = "1/70/72/75",
[33173] = "1/70/72/75",
[33185] = "1/45/50/55",
[33791] = "1/75/95/115",
[34377] = "1/365/365/365",
[34378] = "1/365/365/365",
[34379] = "1/70/72/75",
[34380] = "1/365/365/365",
[39083] = "1/1/3/5",
[39084] = "1/1/5/10",
[39085] = "1/5/10/15",
[39086] = "1/1/5/10",
[39087] = "1/1/3/5",
[39088] = "1/1/3/5",
[40668] = "1/1/3/5",
[40669] = "1/25/30/35",
[40670] = "1/20/25/30",
[40671] = "1/30/35/40",
[40672] = "1/30/35/40",
[40673] = "1/35/40/45",
[40674] = "1/25/30/35",
[40675] = "1/35/40/45",
[40942] = "1/5/10/15",
[40943] = "1/25/30/35",
[40949] = "1/10/15/20",
[40950] = "1/15/20/25",
[40951] = "1/15/20/25",
[40952] = "1/20/25/30",
[40953] = "1/25/30/35",
[40954] = "1/30/35/40",
[40955] = "1/30/35/40",
[40956] = "1/20/25/30",
[40957] = "1/30/35/40",
[40958] = "1/35/40/45",
[40959] = "1/40/45/50",
[41113] = "1/40/45/50",
[41114] = "1/45/50/55",
[41116] = "1/40/45/50",
[41117] = "1/20/25/30",
[41126] = "1/25/30/35",
[41127] = "1/30/35/40",
[41128] = "1/35/40/45",
[41129] = "1/45/50/55",
[41181] = "1/20/25/30",
[41182] = "1/25/30/35",
[41183] = "1/30/35/40",
[41184] = "1/35/40/45",
[41185] = "1/40/45/50",
[41186] = "1/45/50/55",
[41187] = "1/45/50/55",
[41188] = "1/45/50/55",
[41189] = "1/45/50/55",
[41190] = "1/45/50/55",
[41239] = "1/10/15/20",
[41240] = "1/10/15/20",
[41242] = "1/15/20/25",
[41243] = "1/20/25/30",
[41245] = "1/40/45/50",
[41257] = "1/75/75/75",
[41344] = "1/60/70/80",
[41345] = "1/60/70/80",
[41346] = "1/60/70/80",
[41347] = "1/60/70/80",
[41348] = "1/55/65/75",
[41349] = "1/55/65/75",
[41350] = "1/60/70/80",
[41351] = "1/55/65/75",
[41352] = "1/55/65/75",
[41353] = "1/60/70/80",
[41354] = "1/50/55/60",
[41355] = "1/50/55/60",
[41356] = "1/55/65/75",
[41357] = "1/55/65/75",
[41383] = "1/75/75/75",
[41384] = "1/75/75/75",
[41386] = "1/75/75/75",
[41387] = "1/75/75/75",
[41388] = "1/75/75/75",
[41391] = "1/75/75/75",
[41392] = "1/75/75/75",
[41394] = "1/75/75/75",
[41611] = "1/45/50/55",
[41974] = "1/1/3/5",
[41975] = "1/5/10/15",
[41976] = "1/50/55/60",
[42435] = "1/75/75/75",
[42443] = "1/40/45/50",
[42500] = "1/50/55/60",
[42508] = "1/75/75/75",
[42723] = "1/50/55/60",
[42724] = "1/55/65/75",
[42725] = "1/60/70/80",
[42726] = "1/60/70/80",
[42727] = "1/55/65/75",
[42728] = "1/60/70/80",
[42729] = "1/55/65/75",
[42730] = "1/55/65/75",
[43586] = "1/60/70/80",
[43587] = "1/55/65/75",
[43588] = "1/55/65/75",
[43853] = "1/60/65/70",
[43854] = "1/1/3/5",
[43860] = "1/25/30/35",
[43864] = "1/30/35/40",
[43865] = "1/35/40/45",
[43870] = "1/45/50/55",
[43871] = "1/40/45/50",
[44936] = "1/75/75/75",
[45085] = "1/75/75/75",
[45550] = "1/75/75/75",
[45551] = "1/75/75/75",
[45552] = "1/75/75/75",
[45559] = "1/75/75/75",
[45560] = "1/75/75/75",
[45561] = "1/75/75/75",
[47570] = "1/75/75/75",
[47571] = "1/75/75/75",
[47572] = "1/75/75/75",
[47573] = "1/75/75/75",
[47574] = "1/75/75/75",
[47575] = "1/75/75/75",
[47589] = "1/75/75/75",
[47590] = "1/75/75/75",
[47591] = "1/75/75/75",
[47592] = "1/75/75/75",
[47593] = "1/75/75/75",
[47594] = "1/75/75/75",
[49902] = "1/100/100/100",
[49903] = "1/100/100/100",
[49904] = "1/100/100/100",
[49905] = "1/100/100/100",
[49906] = "1/100/100/100",
[49907] = "1/100/100/100",
[54850] = "1/10/12/15",
[54852] = "1/425/425/425",
[54853] = "1/425/425/425",
[54854] = "1/425/425/425",
[54876] = "1/425/425/425",
[55022] = "1/425/425/425",
[55023] = "1/425/425/425",
[55024] = "1/425/425/425",
[55025] = "1/425/425/425",
[55026] = "1/425/425/425",
[55027] = "1/425/425/425",
[55028] = "1/425/425/425",
[55029] = "1/425/425/425",
[55030] = "1/425/425/425",
[55031] = "1/425/425/425",
[55032] = "1/425/425/425",
[55033] = "1/425/425/425",
[55034] = "1/425/425/425",
[55035] = "1/425/425/425",
[55036] = "1/425/425/425",
[55037] = "1/425/425/425",
[55038] = "1/425/425/425",
[55039] = "1/425/425/425",
[55040] = "1/425/425/425",
[55041] = "1/425/425/425",
[55042] = "1/425/425/425",
[55043] = "1/425/425/425",
[55044] = "1/425/425/425",
[55045] = "1/425/425/425",
[55046] = "1/425/425/425",
[55052] = "1/425/425/425",
[55053] = "1/425/425/425",
[55054] = "1/75/75/75",
[55055] = "1/425/425/425",
[55056] = "1/75/75/75",
[55057] = "1/55/60/65",
[55058] = "1/75/75/75",
[55059] = "1/70/72/75",
[55060] = "1/75/75/75",
[55061] = "1/70/72/75",
[55062] = "1/75/75/75",
[55063] = "1/70/72/75",
[55064] = "1/75/75/75",
[55065] = "1/75/75/75",
[55066] = "1/75/75/75",
[55067] = "1/75/75/75",
[55068] = "1/75/75/75",
[55069] = "1/75/75/75",
[55070] = "1/75/75/75",
[55246] = "1/425/425/425",
[65365] = "1/1/3/5",
[67602] = "1/75/75/75",
[67605] = "1/75/75/75",
[69936] = "1/75/75/75",
[69937] = "1/75/75/75",
[69938] = "1/75/75/75",
[69946] = "1/75/75/75",
[69947] = "1/75/75/75",
[69948] = "1/75/75/75",
[70155] = "1/75/75/75",
[70156] = "1/75/75/75",
[70157] = "1/75/75/75",
[70158] = "1/75/75/75",
[70162] = "1/75/75/75",
[70163] = "1/75/75/75",
[70164] = "1/75/75/75",
[70165] = "1/75/75/75",
[71982] = "1/75/75/75",
[71983] = "1/75/75/75",
[71984] = "1/75/75/75",
[71991] = "1/75/75/75",
[71992] = "1/75/75/75",
[71993] = "1/75/75/75",
[75118] = "1/70/72/75",
[75119] = "1/80/82/85",
[75120] = "1/75/75/75",
[75121] = "1/65/67/70",
[75122] = "1/65/67/70",
[75123] = "1/70/72/75",
[75124] = "1/60/62/65",
[75125] = "1/60/62/65",
[75126] = "1/75/75/75",
[75128] = "1/75/75/75",
[75129] = "1/75/75/75",
[75132] = "1/75/75/75",
[75133] = "1/75/75/75",
[75134] = "1/80/82/85",
[75135] = "1/75/75/75",
[75136] = "1/75/75/75",
[82903] = "1/40/57/75",
[82904] = "1/25/50/75",
[82905] = "1/40/57/75",
[82906] = "1/15/45/75",
[82907] = "1/20/47/75",
[82908] = "1/1/38/75",
[82909] = "1/20/47/75",
[82910] = "1/15/45/75",
[82919] = "1/75/75/75",
[82920] = "1/75/75/75",
[82921] = "1/75/75/75",
[82922] = "1/75/75/75",
[82923] = "1/75/75/75",
[82924] = "1/75/75/75",
[82925] = "1/75/75/75",
[82926] = "1/75/75/75",
[82943] = "1/75/75/75",
[82944] = "1/75/75/75",
[82945] = "1/75/75/75",
[82946] = "1/75/75/75",
[82947] = "1/75/75/75",
[82948] = "1/75/75/75",
[82949] = "1/75/75/75",
[82950] = "1/75/75/75",
[82951] = "1/75/75/75",
[82952] = "1/75/75/75",
[82953] = "1/75/75/75",
[82954] = "1/75/75/75",
[82955] = "1/75/75/75",
[82956] = "1/75/75/75",
[82957] = "1/75/75/75",
[82958] = "1/75/75/75",
[82960] = "1/1/3/5",
[82961] = "1/25/50/75",
[82962] = "1/30/52/75",
[82963] = "1/35/55/75",
[82964] = "1/40/57/75",
[82965] = "1/45/60/75",
[82966] = "1/50/62/75",
[82967] = "1/50/62/75",
[82968] = "1/75/75/75",
[82969] = "1/75/75/75",
[82970] = "1/75/75/75",
[82971] = "1/75/75/75",
[82972] = "1/75/75/75",
[82973] = "1/75/75/75",
[82974] = "1/75/75/75",
[82975] = "1/75/75/75",
[82976] = "1/75/75/75",
[82977] = "1/75/75/75",
[82978] = "1/75/75/75",
[82979] = "1/75/75/75",
[82980] = "1/75/75/75",
[86597] = "1/75/75/75",
[86599] = "1/25/32/40",
[87402] = "1/75/75/75",
[87403] = "1/75/75/75",
[87404] = "1/75/75/75",
[87405] = "1/75/75/75",
[87406] = "1/75/75/75",
[87407] = "1/75/75/75",
[90046] = "1/75/75/75",
[93453] = "1/75/75/75",
[93454] = "1/75/75/75",
[93455] = "1/75/75/75",
[93456] = "1/75/75/75",
[93457] = "1/75/75/75",
[93527] = "1/75/75/75",
[93528] = "1/75/75/75",
[93529] = "1/75/75/75",
[93530] = "1/75/75/75",
[93531] = "1/75/75/75",
[93532] = "1/75/75/75",
[93533] = "1/75/75/75",
[93534] = "1/75/75/75",
[93535] = "1/75/75/75",
[93536] = "1/75/75/75",
[93537] = "1/75/75/75",
[93538] = "1/75/75/75",
[93539] = "1/75/75/75",
[93540] = "1/75/75/75",
[93541] = "1/75/75/75",
[93542] = "1/75/75/75",
[93543] = "1/75/75/75",
[93544] = "1/75/75/75",
[93545] = "1/75/75/75",
[93546] = "1/75/75/75",
[93547] = "1/75/75/75",
[93548] = "1/75/75/75",
[93620] = "1/75/75/75",
[93621] = "1/75/75/75",
[93622] = "1/75/75/75",
[93623] = "1/75/75/75",
[93624] = "1/75/75/75",
[94111] = "1/75/75/75",
[94263] = "1/75/75/75",
[94264] = "1/75/75/75",
[94265] = "1/75/75/75",
[94266] = "1/75/75/75",
[94267] = "1/75/75/75",
[94268] = "1/75/75/75",
[94575] = "1/75/75/75",
[94576] = "1/75/75/75",
[94577] = "1/75/75/75",
[94578] = "1/75/75/75",
[94579] = "1/75/75/75",
[94580] = "1/75/75/75",
[94581] = "1/75/75/75",
[94582] = "1/75/75/75",
[94583] = "1/75/75/75",
[94584] = "1/75/75/75",
[94585] = "1/75/75/75",
[94586] = "1/75/75/75",
[94587] = "1/75/75/75",
[94588] = "1/75/75/75",
[94589] = "1/75/75/75",
[94590] = "1/75/75/75",
[94591] = "1/75/75/75",
[94592] = "1/75/75/75",
[98602] = "1/75/75/75",
[98606] = "1/75/75/75",
[98607] = "1/75/75/75",
[98611] = "1/75/75/75",
[98615] = "1/75/75/75",
[98616] = "1/75/75/75",
[98717] = {[143255] = "1/75/75/75", [146921] = "1/75/75/75"},
[98776] = "1/75/75/75",
[98784] = "1/75/75/75",
[98785] = "1/75/75/75",
[98786] = "1/75/75/75",
[98787] = "1/75/75/75",
[98788] = "1/75/75/75",
[98810] = "1/75/75/75",
[98843] = "1/75/75/75",
[98844] = "1/75/75/75",
[98845] = "1/75/75/75",
[98846] = "1/75/75/75",
[98847] = "1/75/75/75",
[98848] = "1/75/75/75",
[98849] = "1/75/75/75",
[98850] = "1/75/75/75",
[98851] = "1/75/75/75",
[98852] = "1/75/75/75",
[98853] = "1/75/75/75",
[98854] = "1/75/75/75",
[98855] = "1/75/75/75",
[98856] = "1/75/75/75",
[98857] = "1/75/75/75",
[98858] = "1/75/75/75",
[98859] = "1/75/75/75",
[98860] = "1/75/75/75",
[98861] = "1/75/75/75",
[98862] = "1/75/75/75",
[98863] = "1/75/75/75",
[98864] = "1/75/75/75",
[98920] = "1/75/75/75",
[98926] = "1/75/75/75",
[98927] = "1/75/75/75",
[98928] = "1/75/75/75",
[98929] = "1/75/75/75",
[98930] = "1/75/75/75",
[108257] = {[171690] = "1/1/50/100", [182116] = "1/100/100/100"},
[114230] = "1/100/100/101",
[114231] = "1/100/100/101",
[114232] = "1/100/100/101",
[114233] = "1/100/100/101",
[114234] = "1/100/100/101",
[114235] = "1/100/100/101",
[114236] = "1/100/100/101",
[114237] = "1/100/100/101",
[116425] = "1/50/55/60",
[116426] = "1/50/55/60",
[116427] = "1/50/55/60",
[116428] = "1/100/100/100",
[116453] = "1/100/100/100",
[116454] = "1/100/100/100",
[116644] = "1/100/100/100",
[116646] = "1/100/100/100",
[116647] = "1/100/100/100",
[116654] = "1/100/100/100",
[118720] = "1/1/50/100",
[119328] = "1/100/100/100",
[120259] = "1/100/100/100",
[120261] = "1/100/100/100",
[123891] = {[182935] = "1/20/30/40", [182969] = "1/40/50/60", [182973] = "1/60/70/80"},
[123892] = {[182934] = "1/20/30/40", [182968] = "1/40/50/60", [191928] = "1/60/70/80"},
[123893] = {[182933] = "1/20/30/40", [182967] = "1/40/50/60", [191930] = "1/60/70/80"},
[123894] = {[182932] = "1/20/30/40", [182966] = "1/40/50/60", [191929] = "1/60/70/80"},
[123895] = {[182931] = "1/20/30/40", [182965] = "1/40/50/60", [191931] = "1/60/70/80"},
[123896] = {[182930] = "1/20/30/40", [182964] = "1/40/50/60", [182972] = "1/60/70/80"},
[123897] = {[182929] = "1/20/30/40", [182963] = "1/40/50/60", [182971] = "1/60/70/80"},
[123898] = {[182928] = "1/20/30/40", [182962] = "1/40/50/60", [182970] = "1/60/70/80"},
[123910] = {[182951] = "1/60/70/80", [182981] = "1/80/90/100", [182989] = "1/100/100/100"},
[123911] = {[182950] = "1/60/70/80", [182980] = "1/80/90/100", [182988] = "1/100/100/100"},
[123912] = {[182949] = "1/60/70/80", [182979] = "1/80/90/100", [182987] = "1/100/100/100"},
[123913] = {[182948] = "1/60/70/80", [182978] = "1/80/90/100", [182986] = "1/100/100/100"},
[123914] = {[182947] = "1/60/70/80", [182977] = "1/80/90/100", [182985] = "1/100/100/100"},
[123915] = {[182946] = "1/60/70/80", [182976] = "1/80/90/100", [182984] = "1/100/100/100"},
[123916] = {[182945] = "1/60/70/80", [182975] = "1/80/90/100", [182983] = "1/100/100/100"},
[123917] = {[182944] = "1/60/70/80", [182974] = "1/80/90/100", [182982] = "1/100/100/100"},
[123956] = "1/20/32/45",
[124006] = "1/1/1/1",
[124007] = "1/1/1/1",
[124009] = "1/1/1/1",
[124010] = "1/1/1/1",
[124049] = "1/1/1/1",
[124393] = "1/1/1/1",
[124394] = "1/1/1/1",
[124395] = "1/1/1/1",
[124396] = "1/1/1/1",
[124397] = "1/1/1/1",
[124405] = "1/1/1/1",
[124406] = "1/1/1/1",
[124407] = "1/1/1/1",
[124408] = "1/1/1/1",
[124409] = "1/1/1/1",
[124410] = "1/1/1/1",
[124411] = "1/1/1/1",
[124418] = "1/1/1/1",
[124419] = "1/1/1/1",
[124420] = "1/1/1/1",
[124421] = "1/1/1/1",
[124422] = "1/1/1/1",
[124423] = "1/1/1/1",
[124424] = "1/1/1/1",
[124426] = "1/1/1/1",
[124427] = "1/1/1/1",
[124428] = "1/1/1/1",
[124429] = "1/1/1/1",
[124430] = "1/1/1/1",
[124431] = "1/1/1/1",
[124432] = "1/1/1/1",
[124433] = "1/1/1/1",
[124434] = "1/1/1/1",
[124435] = "1/1/1/1",
[124450] = "1/1/1/1",
[124452] = "1/1/1/1",
[124453] = "1/1/1/1",
[124454] = "1/1/1/1",
[124455] = "1/1/1/1",
[124461] = "1/60/67/75",
[128777] = "1/1/1/1",
[136683] = "1/20/45/70",
[136684] = "1/20/45/70",
[136685] = "1/20/45/70",
[136686] = "1/20/45/70",
[136708] = "1/20/32/45",
[137686] = "1/100/105/110",
[146667] = "1/100/100/100",
[151239] = "1/20/32/45",
[151576] = {[247710] = "1/90/95/100", [247713] = "1/90/95/100", [247714] = "1/90/95/100"},
[151872] = "1/1/1/1",
[151923] = "1/1/1/1",
[151924] = "1/1/1/1",
[151925] = "1/1/1/1",
[152802] = "1/80/90/100",
[152803] = "1/25/37/50",
[152804] = "1/15/32/50",
[152805] = "1/30/47/65",
[152806] = "1/45/72/100",
[152807] = "1/50/70/90",
[152808] = "1/25/37/50",
[152809] = "1/10/17/25",
[152812] = {[253110] = "1/80/90/100", [286015] = "1/100/105/110", [286016] = "1/110/115/120"},
[152813] = "1/80/90/100",
[152818] = "1/30/47/65",
[152819] = {[253116] = "1/110/130/150", [253117] = "1/125/137/150", [253118] = "1/135/142/150"},
[152827] = "1/15/32/50",
[152828] = "1/45/72/100",
[152831] = "1/45/72/100",
[152832] = "1/15/32/50",
[152833] = "1/45/72/100",
[152834] = {[253159] = "1/110/130/150", [253160] = "1/125/137/150", [253161] = "1/135/142/150"},
[152835] = {[253156] = "1/110/130/150", [253157] = "1/125/137/150", [253158] = "1/135/142/150"},
[152839] = "1/150/150/150",
[158887] = "1/165/170/175",
[159826] = "1/20/60/100",
[159851] = {[269458] = "1/110/130/150", [269459] = "1/120/135/150", [269460] = "1/130/140/150"},
[159853] = {[269464] = "1/100/110/120", [269465] = "1/110/122/135", [269466] = "1/120/132/145"},
[159855] = {[269470] = "1/115/132/150", [269471] = "1/125/137/150", [269472] = "1/135/142/150"},
[159857] = {[269476] = "1/100/110/120", [269477] = "1/110/122/135", [269478] = "1/120/132/145"},
[159858] = {[269479] = "1/115/132/150", [269480] = "1/125/137/150", [269481] = "1/135/142/150"},
[159860] = {[269424] = "1/110/130/150", [269425] = "1/120/135/150", [269426] = "1/130/140/150"},
[159861] = {[269421] = "1/100/110/120", [269422] = "1/110/122/135", [269423] = "1/120/132/145"},
[159863] = {[269444] = "1/115/132/150", [269446] = "1/125/137/150", [269447] = "1/135/142/150"},
[159865] = {[269448] = "1/110/130/150", [269449] = "1/120/135/150", [269450] = "1/130/140/150"},
[159866] = {[269451] = "1/100/110/120", [269452] = "1/110/122/135", [269453] = "1/120/132/145"},
[161888] = "1/150/150/150",
[161889] = "1/150/150/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[162464] = "1/150/150/150",
[162466] = "1/150/150/150",
[162491] = "1/150/150/150",
[162492] = "1/150/150/150",
[162652] = {[253144] = "1/120/132/145", [253149] = "1/110/122/135", [256786] = "1/100/110/120"},
[162655] = {[278131] = "1/110/130/150", [278132] = "1/125/137/150", [278133] = "1/135/142/150"},
[164648] = {[282876] = "1/135/142/150", [282878] = "1/140/145/150", [282879] = "1/145/147/150"},
[164649] = {[282871] = "1/135/142/150", [282872] = "1/140/145/150", [282873] = "1/145/147/150"},
[164650] = {[282868] = "1/135/142/150", [282869] = "1/140/145/150", [282870] = "1/145/147/150"},
[164651] = {[282862] = "1/135/142/150", [282863] = "1/140/145/150", [282864] = "1/145/147/150"},
[164652] = {[282859] = "1/135/142/150", [282860] = "1/140/145/150", [282861] = "1/145/147/150"},
[164653] = {[283249] = "1/135/142/150", [283250] = "1/140/145/150", [283251] = "1/145/147/150"},
[164654] = {[283245] = "1/135/142/150", [283247] = "1/140/145/150", [283248] = "1/145/147/150"},
[164655] = {[283242] = "1/135/142/150", [283243] = "1/140/145/150", [283244] = "1/145/147/150"},
[164656] = {[283239] = "1/135/142/150", [283240] = "1/140/145/150", [283241] = "1/145/147/150"},
[164657] = {[282889] = "1/135/142/150", [283237] = "1/140/145/150", [283238] = "1/145/147/150"},
[164719] = {[282865] = "1/135/142/150", [282866] = "1/140/145/150", [282867] = "1/145/147/150"},
[165379] = "1/150/150/150",
[165389] = "1/150/150/150",
[165397] = "1/150/150/150",
[165406] = "1/150/150/150",
[165414] = "1/150/150/150",
[165422] = "1/150/150/150",
[165740] = "1/95/110/125",
[165746] = "1/95/110/125",
[165748] = "1/95/110/125",
[167937] = {[294766] = "1/165/170/175", [294767] = "1/170/172/175", [294768] = "1/175/175/175"},
[167939] = {[294769] = "1/165/170/175", [294770] = "1/170/172/175", [294771] = "1/175/175/175"},
[167965] = {[294763] = "1/165/170/175", [294764] = "1/170/172/175", [294765] = "1/175/175/175"},
[167967] = {[294748] = "1/165/170/175", [294749] = "1/170/172/175", [294750] = "1/175/175/175"},
[167969] = {[294751] = "1/165/170/175", [294752] = "1/170/172/175", [294753] = "1/175/175/175"},
[167971] = {[294754] = "1/165/170/175", [294755] = "1/170/172/175", [294756] = "1/175/175/175"},
[167973] = {[294760] = "1/165/170/175", [294761] = "1/170/172/175", [294762] = "1/175/175/175"},
[167975] = {[294778] = "1/165/170/175", [294779] = "1/170/172/175", [294780] = "1/175/175/175"},
[167989] = {[294775] = "1/165/170/175", [294776] = "1/170/172/175", [294777] = "1/175/175/175"},
[167991] = {[294757] = "1/165/170/175", [294758] = "1/170/172/175", [294759] = "1/175/175/175"},
[167995] = {[294772] = "1/165/170/175", [294773] = "1/170/172/175", [294774] = "1/175/175/175"},
[168417] = "1/165/170/175",
[168677] = "1/175/175/175",
[168678] = "1/175/175/175",
[168679] = "1/175/175/175",
[168680] = "1/175/175/175",
[168681] = "1/175/175/175",
[168682] = "1/175/175/175",
[170285] = {[304307] = "1/165/170/175", [306086] = "1/165/170/175", [306087] = "1/165/170/175"},
[170286] = {[304308] = "1/165/170/175", [306084] = "1/165/170/175", [306085] = "1/165/170/175"},
[170287] = {[304312] = "1/165/170/175", [306082] = "1/165/170/175", [306083] = "1/165/170/175"},
[170288] = {[304315] = "1/165/170/175", [306080] = "1/165/170/175", [306081] = "1/165/170/175"},
[170289] = {[304317] = "1/165/170/175", [306078] = "1/165/170/175", [306079] = "1/165/170/175"},
[170290] = {[304324] = "1/165/170/175", [305844] = "1/165/170/175", [305845] = "1/165/170/175"},
[170291] = {[304323] = "1/165/170/175", [305846] = "1/165/170/175", [305847] = "1/165/170/175"},
[170292] = {[304322] = "1/165/170/175", [305848] = "1/165/170/175", [305849] = "1/165/170/175"},
[170293] = {[304320] = "1/165/170/175", [305850] = "1/165/170/175", [305851] = "1/165/170/175"},
[170294] = {[304318] = "1/165/170/175", [305852] = "1/165/170/175", [305853] = "1/165/170/175"},
[170364] = {[304314] = "1/165/170/175", [306310] = "1/165/170/175", [306312] = "1/165/170/175"},
[170386] = "1/175/175/175",
[170387] = "1/175/175/175",
[170388] = "1/175/175/175",
[170389] = "1/175/175/175",
[170390] = "1/175/175/175",
[170391] = "1/175/175/175",
[171320] = "1/200/200/200",
[171374] = "1/25/30/35",
[171375] = "1/5/10/15",
[171376] = "1/15/20/25",
[171377] = "1/30/35/40",
[171378] = "1/35/40/45",
[171379] = "1/40/45/50",
[171380] = "1/10/15/20",
[171381] = "1/5/10/15",
[171382] = "1/15/20/25",
[171383] = "1/30/35/40",
[171384] = "1/10/15/20",
[171385] = "1/5/10/15",
[171386] = "1/20/25/30",
[171387] = "1/25/30/35",
[171388] = "1/30/35/40",
[171389] = "1/20/25/30",
[171390] = "1/40/45/50",
[171391] = "1/20/25/30",
[171392] = "1/35/40/45",
[171412] = {[307712] = "1/100/100/100", [332013] = "1/100/100/100", [332048] = "1/100/100/100", [338968] = "1/100/100/100"},
[171413] = {[307711] = "1/100/100/100", [332012] = "1/100/100/100", [332047] = "1/100/100/100", [338969] = "1/100/100/100"},
[171414] = {[307710] = "1/100/100/100", [332011] = "1/100/100/100", [332046] = "1/100/100/100", [338970] = "1/100/100/100"},
[171415] = {[307709] = "1/100/100/100", [332010] = "1/100/100/100", [332045] = "1/100/100/100", [338971] = "1/100/100/100"},
[171416] = {[307708] = "1/100/100/100", [332009] = "1/100/100/100", [332044] = "1/100/100/100", [338972] = "1/100/100/100"},
[171417] = {[307707] = "1/100/100/100", [332008] = "1/100/100/100", [332043] = "1/100/100/100", [338974] = "1/100/100/100"},
[171418] = {[307706] = "1/100/100/100", [332007] = "1/100/100/100", [332042] = "1/100/100/100", [338975] = "1/100/100/100"},
[171419] = {[307705] = "1/100/100/100", [332006] = "1/100/100/100", [332041] = "1/100/100/100", [338976] = "1/100/100/100"},
[171428] = "1/57/58/60",
[171436] = "1/5/7/10",
[171437] = "1/55/57/60",
[171438] = "1/5/7/10",
[171439] = "1/60/62/65",
[171441] = "1/17/18/20",
[171442] = "1/90/95/100",
[171443] = "1/65/70/75",
[171444] = "1/75/80/85",
[171445] = "1/85/90/95",
[171446] = "1/100/100/100",
[171447] = "1/100/100/100",
[171448] = "1/70/75/80",
[171449] = "1/60/65/70",
[173381] = "1/55/60/65",
[173382] = "1/75/80/85",
[173383] = "1/90/92/95",
[173384] = "1/200/200/200",
[180055] = {[330134] = "1/1/10/20", [330144] = "1/1/10/20", [330149] = "1/1/10/20", [330154] = "1/1/10/20", [330159] = "1/1/10/20", [330164] = "1/1/10/20", [330169] = "1/1/10/20", [330174] = "1/1/10/20"},
[180057] = {[330140] = "1/1/10/20", [330145] = "1/1/10/20", [330150] = "1/1/10/20", [330155] = "1/1/10/20", [330160] = "1/1/10/20", [330165] = "1/1/10/20", [330170] = "1/1/10/20", [330175] = "1/1/10/20"},
[180058] = {[330141] = "1/1/10/20", [330146] = "1/1/10/20", [330151] = "1/1/10/20", [330156] = "1/1/10/20", [330161] = "1/1/10/20", [330166] = "1/1/10/20", [330171] = "1/1/10/20", [330176] = "1/1/10/20"},
[180059] = {[330142] = "1/1/10/20", [330147] = "1/1/10/20", [330152] = "1/1/10/20", [330157] = "1/1/10/20", [330162] = "1/1/10/20", [330167] = "1/1/10/20", [330172] = "1/1/10/20", [330177] = "1/1/10/20"},
[180060] = {[330143] = "1/1/10/20", [330148] = "1/1/10/20", [330153] = "1/1/10/20", [330158] = "1/1/10/20", [330163] = "1/1/10/20", [330168] = "1/1/10/20", [330173] = "1/1/10/20", [330178] = "1/1/10/20"},
[181378] = "1/1/1/1",
[181784] = "1/1/1/1",
[181787] = "1/1/1/1",
[181788] = "1/1/1/1",
[181790] = "1/1/1/1",
[181791] = "1/1/1/1",
[181792] = "1/1/1/1",
[181862] = "1/1/1/1",
[182086] = "1/1/1/1",
[182087] = "1/1/1/1",
[182090] = "1/1/1/1",
[182092] = "1/1/1/1",
[182093] = "1/1/1/1",
[183942] = "1/50/55/60",
[185960] = "1/100/100/100",



-- enchanting
[-7418] = "1/70/90/110",
[-7420] = "1/70/90/110",
[-7421] = "1/5/7/10",
[-7426] = "1/90/110/130",
[-7428] = "1/80/100/120",
[-7443] = "1/80/100/120",
[-7457] = "1/100/120/140",
[-7745] = "1/130/150/170",
[-7748] = "1/105/125/145",
[-7766] = "1/105/125/145",
[-7771] = "1/110/130/150",
[-7776] = "1/115/135/155",
[-7779] = "1/115/135/155",
[-7782] = "1/115/135/155",
[-7786] = "1/120/140/160",
[-7788] = "1/120/140/160",
[-7793] = "1/130/150/170",
[-7857] = "1/145/165/185",
[-7859] = "1/145/165/185",
[-7863] = "1/150/170/190",
[-7867] = "1/425/425/425",
[-13378] = "1/130/150/170",
[-13380] = "1/135/155/175",
[-13419] = "1/135/155/175",
[-13421] = "1/140/160/180",
[-13464] = "1/140/160/180",
[-13485] = "1/155/175/195",
[-13501] = "1/155/175/195",
[-13503] = "1/165/185/205",
[-13529] = "1/170/190/210",
[-13536] = "1/165/185/205",
[-13538] = "1/165/185/205",
[-13607] = "1/170/190/210",
[-13612] = "1/170/190/210",
[-13617] = "1/170/190/210",
[-13620] = "1/170/190/210",
[-13622] = "1/175/195/215",
[-13626] = "1/175/195/215",
[-13631] = "1/175/195/215",
[-13635] = "1/175/195/215",
[-13637] = "1/180/200/220",
[-13640] = "1/180/200/220",
[-13642] = "1/185/205/225",
[-13644] = "1/190/210/230",
[-13646] = "1/190/210/230",
[-13648] = "1/190/210/230",
[-13653] = "1/195/215/235",
[-13655] = "1/195/215/235",
[-13659] = "1/200/220/240",
[-13661] = "1/200/220/240",
[-13663] = "1/205/225/245",
[-13687] = "1/210/230/250",
[-13689] = "1/215/235/255",
[-13693] = "1/215/235/255",
[-13695] = "1/220/240/260",
[-13698] = "1/220/240/260",
[-13700] = "1/220/240/260",
[-13746] = "1/225/245/265",
[-13815] = "1/230/250/270",
[-13817] = "1/230/250/270",
[-13822] = "1/230/250/270",
[-13836] = "1/235/255/275",
[-13841] = "1/235/255/275",
[-13846] = "1/240/260/280",
[-13858] = "1/240/260/280",
[-13868] = "1/245/265/285",
[-13882] = "1/245/265/285",
[-13887] = "1/245/265/285",
[-13890] = "1/245/265/285",
[-13898] = "1/285/292/300",
[-13905] = "1/250/270/290",
[-13915] = "1/250/270/290",
[-13917] = "1/250/270/290",
[-13931] = "1/255/275/295",
[-13935] = "1/255/275/295",
[-13937] = "1/260/280/300",
[-13939] = "1/260/280/300",
[-13941] = "1/265/282/300",
[-13943] = "1/265/282/300",
[-13945] = "1/265/282/300",
[-13947] = "1/270/285/300",
[-13948] = "1/270/285/300",
[-14293] = "1/75/95/115",
[-14807] = "1/110/130/150",
[-14809] = "1/175/195/215",
[-14810] = "1/195/215/235",
[-15596] = "1/285/292/300",
[-17180] = "1/250/255/260",
[-17181] = "1/250/255/260",
[-20008] = "1/275/287/300",
[-20009] = "1/290/295/300",
[-20010] = "1/300/300/300",
[-20011] = "1/300/300/300",
[-20012] = "1/290/295/300",
[-20013] = "1/300/300/300",
[-20015] = "1/300/300/300",
[-20016] = "1/300/300/300",
[-20017] = "1/285/292/300",
[-20020] = "1/280/290/300",
[-20023] = "1/300/300/300",
[-20024] = "1/295/297/300",
[-20025] = "1/300/300/300",
[-20026] = "1/295/297/300",
[-20028] = "1/300/300/300",
[-20029] = "1/300/300/300",
[-20030] = "1/300/300/300",
[-20031] = "1/300/300/300",
[-20032] = "1/300/300/300",
[-20033] = "1/300/300/300",
[-20034] = "1/300/300/300",
[-20035] = "1/300/300/300",
[-20036] = "1/300/300/300",
[-21931] = "1/210/230/250",
[-22749] = "1/300/300/300",
[-22750] = "1/300/300/300",
[-23799] = "1/300/300/300",
[-23800] = "1/300/300/300",
[-23801] = "1/300/300/300",
[-23802] = "1/300/300/300",
[-23803] = "1/300/300/300",
[-23804] = "1/300/300/300",
[-25072] = "1/1/25/50",
[-25073] = "1/300/300/300",
[-25074] = "1/300/300/300",
[-25078] = "1/300/300/300",
[-25079] = "1/300/300/300",
[-25080] = "1/1/25/50",
[-25083] = "1/1/25/50",
[-25084] = "1/1/25/50",
[-25086] = "1/1/25/50",
[-25124] = "1/55/65/75",
[-25125] = "1/160/170/180",
[-25126] = "1/210/220/230",
[-25127] = "1/260/270/280",
[-25128] = "1/285/292/300",
[-25129] = "1/300/300/300",
[-25130] = "1/300/300/300",
[-27837] = "1/300/300/300",
[-27899] = "1/15/30/45",
[-27905] = "1/25/40/55",
[-27906] = "1/30/45/60",
[-27911] = "1/35/50/65",
[-27913] = "1/45/55/65",
[-27914] = "1/70/72/75",
[-27917] = "1/70/72/75",
[-27944] = "1/20/35/50",
[-27945] = "1/35/50/65",
[-27946] = "1/50/62/75",
[-27948] = "1/15/30/45",
[-27950] = "1/30/45/60",
[-27951] = "1/50/62/75",
[-27954] = "1/75/75/75",
[-27957] = "1/25/40/55",
[-27958] = "1/1/5/10",
[-27960] = "1/55/65/75",
[-27961] = "1/20/35/50",
[-27967] = "1/50/62/75",
[-27968] = "1/50/62/75",
[-27971] = "1/70/72/75",
[-27972] = "1/70/72/75",
[-27975] = "1/70/72/75",
[-27977] = "1/70/72/75",
[-27981] = "1/75/75/75",
[-27982] = "1/75/75/75",
[-27984] = "1/75/75/75",
[-28003] = "1/70/72/75",
[-28004] = "1/70/72/75",
[-28016] = "1/10/20/30",
[-28019] = "1/40/50/60",
[-28022] = "1/1/3/5",
[-28027] = "1/25/30/35",
[-28028] = "1/70/72/75",
[-33990] = "1/30/45/60",
[-33991] = "1/10/25/40",
[-33992] = "1/55/65/75",
[-33993] = "1/15/30/45",
[-33994] = "1/70/72/75",
[-33995] = "1/50/62/75",
[-33996] = "1/20/35/50",
[-33997] = "1/70/72/75",
[-33999] = "1/70/72/75",
[-34001] = "1/15/30/45",
[-34002] = "1/10/25/40",
[-34003] = "1/35/50/65",
[-34004] = "1/20/35/50",
[-34007] = "1/70/72/75",
[-34008] = "1/70/72/75",
[-34009] = "1/35/50/65",
[-34010] = "1/70/72/75",
[-42615] = "1/15/25/35",
[-42620] = "1/60/67/75",
[-42974] = "1/375/375/375",
[-44383] = "1/40/52/65",
[-44484] = "1/40/50/60",
[-44488] = "1/50/57/65",
[-44489] = "1/55/65/75",
[-44492] = "1/30/40/50",
[-44500] = "1/30/40/50",
[-44506] = "1/15/20/25",
[-44508] = "1/50/57/65",
[-44509] = "1/55/65/75",
[-44510] = "1/50/57/65",
[-44513] = "1/30/40/50",
[-44524] = "1/60/67/75",
[-44528] = "1/25/30/35",
[-44529] = "1/50/60/70",
[-44555] = "1/10/17/25",
[-44575] = "1/65/70/75",
[-44576] = "1/60/67/75",
[-44582] = "1/20/27/35",
[-44584] = "1/40/50/60",
[-44588] = "1/60/67/75",
[-44589] = "1/50/60/70",
[-44591] = "1/70/72/75",
[-44592] = "1/1/5/10",
[-44593] = "1/55/65/75",
[-44595] = "1/65/70/75",
[-44598] = "1/50/60/70",
[-44616] = "1/35/45/55",
[-44621] = "1/65/70/75",
[-44623] = "1/5/15/25",
[-44625] = "1/70/72/75",
[-44629] = "1/30/40/50",
[-44630] = "1/25/35/45",
[-44631] = "1/75/75/75",
[-44633] = "1/50/57/65",
[-44635] = "1/30/40/50",
[-45765] = "1/60/62/65",
[-46578] = "1/50/57/65",
[-46594] = "1/70/72/75",
[-47051] = "1/75/75/75",
[-47672] = "1/65/70/75",
[-47766] = "1/35/45/55",
[-47898] = "1/65/70/75",
[-47899] = "1/75/75/75",
[-47900] = "1/60/67/75",
[-47901] = "1/75/75/75",
[-59619] = "1/75/75/75",
[-59621] = "1/75/75/75",
[-59625] = "1/75/75/75",
[-60606] = "1/10/20/30",
[-60609] = "1/1/5/10",
[-60616] = "1/1/5/10",
[-60621] = "1/15/25/35",
[-60623] = "1/20/30/40",
[-60653] = "1/30/40/50",
[-60663] = "1/55/65/75",
[-60668] = "1/60/67/75",
[-60691] = "1/65/70/75",
[-60692] = "1/75/75/75",
[-60707] = "1/70/72/75",
[-60714] = "1/70/72/75",
[-60763] = "1/75/75/75",
[-60767] = "1/75/75/75",
[-62256] = "1/75/75/75",
[-62948] = "1/75/75/75",
[-62959] = "1/20/30/40",
[-63746] = "1/245/265/285",
[-64441] = "1/75/75/75",
[-64579] = "1/75/75/75",
[-69412] = "1/25/30/35",
[-71692] = "1/1/13/25",
[-74132] = "1/1/5/10",
[-74189] = "1/1/5/10",
[-74191] = "1/1/5/10",
[-74192] = "1/1/10/20",
[-74193] = "1/1/10/20",
[-74195] = "1/10/12/15",
[-74197] = "1/10/12/15",
[-74198] = "1/15/25/35",
[-74199] = "1/15/25/35",
[-74200] = "1/20/30/40",
[-74201] = "1/20/30/40",
[-74202] = "1/25/35/45",
[-74207] = "1/25/35/45",
[-74211] = "1/30/40/50",
[-74212] = "1/30/40/50",
[-74213] = "1/35/45/55",
[-74214] = "1/35/45/55",
[-74220] = "1/40/50/60",
[-74223] = "1/40/50/60",
[-74225] = "1/45/55/65",
[-74226] = "1/45/55/65",
[-74229] = "1/50/60/70",
[-74230] = "1/50/60/70",
[-74231] = "1/55/65/75",
[-74232] = "1/55/65/75",
[-74234] = "1/60/67/75",
[-74235] = "1/60/67/75",
[-74236] = "1/60/62/65",
[-74237] = "1/65/70/75",
[-74238] = "1/70/72/75",
[-74239] = "1/70/72/75",
[-74240] = "1/70/72/75",
[-74242] = "1/75/75/75",
[-74244] = "1/75/75/75",
[-74246] = "1/75/75/75",
[-74247] = "1/75/75/75",
[-74248] = "1/75/75/75",
[-74250] = "1/75/75/75",
[-74251] = "1/75/75/75",
[-74252] = "1/75/75/75",
[-74253] = "1/75/75/75",
[-74254] = "1/75/75/75",
[-74255] = "1/75/75/75",
[-74256] = "1/75/75/75",
[-93841] = "1/75/75/75",
[-93843] = "1/75/75/75",
[-95471] = "1/30/40/50",
[-96261] = "1/75/75/75",
[-96262] = "1/75/75/75",
[-96264] = "1/75/75/75",
[-104338] = "1/1/5/10",
[-104385] = "1/25/42/60",
[-104389] = "1/75/75/75",
[-104390] = "1/75/75/75",
[-104391] = "1/75/75/75",
[-104392] = "1/25/42/60",
[-104393] = "1/25/42/60",
[-104395] = "1/75/75/75",
[-104397] = "1/50/62/75",
[-104398] = "1/50/62/75",
[-104401] = "1/75/75/75",
[-104403] = "1/25/42/60",
[-104404] = "1/1/5/10",
[-104407] = "1/50/62/75",
[-104408] = "1/25/42/60",
[-104409] = "1/50/62/75",
[-104414] = "1/75/75/75",
[-104416] = "1/25/42/60",
[-104417] = "1/50/62/75",
[-104419] = "1/75/75/75",
[-104420] = "1/75/75/75",
[-104425] = "1/50/62/75",
[-104427] = "1/75/75/75",
[-104430] = "1/25/42/60",
[-104434] = "1/75/75/75",
[-104440] = "1/75/75/75",
[-104442] = "1/75/75/75",
[-104445] = "1/75/75/75",
[-104698] = "1/15/32/50",
[-116497] = "1/1/3/5",
[-116498] = "1/1/3/5",
[-116499] = "1/1/3/5",
[-118237] = "1/1/3/5",
[-118238] = "1/1/3/5",
[-118239] = "1/1/3/5",
[-130758] = "1/75/75/75",
[-158877] = "1/25/27/30",
[-158878] = "1/25/27/30",
[-158879] = "1/25/27/30",
[-158881] = "1/25/27/30",
[-158884] = "1/100/100/100",
[-158885] = "1/100/100/100",
[-158886] = "1/100/100/100",
[-158889] = "1/100/100/100",
[-158892] = "1/25/27/30",
[-158893] = "1/25/27/30",
[-158894] = "1/25/27/30",
[-158896] = "1/25/27/30",
[-158899] = "1/100/100/100",
[-158900] = "1/100/100/100",
[-158901] = "1/100/100/100",
[-158903] = "1/100/100/100",
[-158907] = "1/25/27/30",
[-158908] = "1/25/27/30",
[-158909] = "1/25/27/30",
[-158911] = "1/25/27/30",
[-158914] = "1/100/100/100",
[-158915] = "1/100/100/100",
[-158916] = "1/100/100/100",
[-158918] = "1/100/100/100",
[-159235] = "1/100/100/100",
[-159236] = "1/100/100/100",
[-159671] = "1/100/100/100",
[-159672] = "1/100/100/100",
[-159673] = "1/100/100/100",
[-159674] = "1/100/100/100",
[-162948] = "1/50/75/100",
[-169091] = "1/25/27/30",
[-169092] = "1/1/50/100",
[-173323] = "1/100/100/100",
[-177043] = "1/1/50/100",
[-182129] = "1/100/100/100",
[-190866] = "1/20/30/40",
[-190867] = "1/20/30/40",
[-190868] = "1/20/30/40",
[-190869] = "1/20/30/40",
[-190870] = "1/60/70/80",
[-190871] = "1/60/70/80",
[-190872] = "1/60/70/80",
[-190873] = "1/60/70/80",
[-190874] = "1/20/30/40",
[-190875] = "1/20/30/40",
[-190876] = "1/20/30/40",
[-190877] = "1/60/70/80",
[-190878] = "1/60/70/80",
[-190879] = "1/60/70/80",
[-190892] = "1/40/50/60",
[-190893] = "1/40/50/60",
[-190894] = "1/40/50/60",
[-190954] = "1/20/40/60",
[-190988] = "1/20/45/70",
[-190989] = "1/20/45/70",
[-190990] = "1/20/45/70",
[-190991] = "1/20/45/70",
[-190992] = "1/40/50/60",
[-190993] = "1/40/50/60",
[-190994] = "1/40/50/60",
[-190995] = "1/40/50/60",
[-190996] = "1/80/90/100",
[-190997] = "1/80/90/100",
[-190998] = "1/80/90/100",
[-190999] = "1/80/90/100",
[-191000] = "1/40/50/60",
[-191001] = "1/40/50/60",
[-191002] = "1/40/50/60",
[-191003] = "1/80/90/100",
[-191004] = "1/80/90/100",
[-191005] = "1/80/90/100",
[-191006] = "1/60/70/80",
[-191007] = "1/60/70/80",
[-191008] = "1/60/70/80",
[-191009] = "1/60/70/80",
[-191010] = "1/60/70/80",
[-191011] = "1/60/70/80",
[-191012] = "1/60/70/80",
[-191013] = "1/100/100/100",
[-191014] = "1/100/100/100",
[-191015] = "1/100/100/100",
[-191016] = "1/100/100/100",
[-191017] = "1/60/70/80",
[-191018] = "1/60/70/80",
[-191019] = "1/60/70/80",
[-191020] = "1/100/100/100",
[-191021] = "1/100/100/100",
[-191022] = "1/100/100/100",
[-191023] = "1/80/90/100",
[-191024] = "1/80/90/100",
[-191025] = "1/80/90/100",
[-191074] = "1/20/40/60",
[-191075] = "1/20/40/60",
[-191076] = "1/20/40/60",
[-191078] = "1/20/40/60",
[-209507] = "1/20/45/70",
[-209509] = "1/20/45/70",
[-217637] = "1/290/295/300",
[-217641] = "1/70/72/75",
[-217644] = "1/70/72/75",
[-217645] = "1/70/72/75",
[-217649] = "1/70/72/75",
[-217650] = "1/70/72/75",
[-217651] = "1/70/72/75",
[-217655] = "1/90/95/100",
[-224199] = "1/1/3/5",
[-228402] = "1/40/50/60",
[-228403] = "1/60/70/80",
[-228404] = "1/80/90/100",
[-228405] = "1/40/50/60",
[-228406] = "1/60/70/80",
[-228407] = "1/80/90/100",
[-228408] = "1/40/50/60",
[-228409] = "1/60/70/80",
[-228410] = "1/80/90/100",
[-235695] = "1/40/50/60",
[-235696] = "1/40/50/60",
[-235697] = "1/40/50/60",
[-235698] = "1/40/50/60",
[-235699] = "1/50/60/70",
[-235700] = "1/50/60/70",
[-235701] = "1/50/60/70",
[-235702] = "1/50/60/70",
[-235703] = "1/60/70/80",
[-235704] = "1/60/70/80",
[-235705] = "1/60/70/80",
[-235706] = "1/60/70/80",
[-252106] = "1/60/70/80",
[-255035] = "1/10/30/50",
[-255040] = "1/10/30/50",
[-255065] = "1/10/30/50",
[-255066] = "1/10/30/50",
[-255068] = "1/35/55/75",
[-255070] = "1/10/30/50",
[-255071] = "1/25/37/50",
[-255072] = "1/25/37/50",
[-255073] = "1/25/37/50",
[-255074] = "1/25/37/50",
[-255075] = "1/100/117/135",
[-255076] = "1/100/117/135",
[-255077] = "1/100/117/135",
[-255078] = "1/100/117/135",
[-255086] = "1/40/57/75",
[-255087] = "1/40/57/75",
[-255088] = "1/40/57/75",
[-255089] = "1/40/57/75",
[-255090] = "1/120/135/150",
[-255091] = "1/120/135/150",
[-255092] = "1/120/135/150",
[-255093] = "1/120/135/150",
[-255094] = "1/75/87/100",
[-255095] = "1/75/87/100",
[-255096] = "1/75/87/100",
[-255097] = "1/75/87/100",
[-255098] = "1/115/132/150",
[-255099] = "1/115/132/150",
[-255100] = "1/115/132/150",
[-255101] = "1/115/132/150",
[-255103] = "1/75/87/100",
[-255104] = "1/105/120/135",
[-255105] = "1/115/130/145",
[-255110] = "1/75/87/100",
[-255111] = "1/105/120/135",
[-255112] = "1/115/130/145",
[-255129] = "1/75/87/100",
[-255130] = "1/105/120/135",
[-255131] = "1/115/130/145",
[-255141] = "1/75/87/100",
[-255142] = "1/105/120/135",
[-255143] = "1/115/130/145",
[-265105] = "1/30/40/50",
[-265106] = "1/50/75/100",
[-265110] = "1/100/125/150",
[-265111] = "1/125/137/150",
[-265112] = "1/125/137/150",
[-267458] = "1/10/30/50",
[-267482] = "1/10/30/50",
[-267486] = "1/10/30/50",
[-267490] = "1/10/30/50",
[-267495] = "1/35/55/75",
[-267498] = "1/10/30/50",
[-268852] = "1/75/95/115",
[-268878] = "1/150/150/150",
[-268879] = "1/150/150/150",
[-268894] = "1/75/95/115",
[-268895] = "1/150/150/150",
[-268897] = "1/150/150/150",
[-268901] = "1/75/95/115",
[-268902] = "1/150/150/150",
[-268903] = "1/150/150/150",
[-268907] = "1/75/95/115",
[-268908] = "1/150/150/150",
[-268909] = "1/150/150/150",
[-268913] = "1/75/95/115",
[-268914] = "1/150/150/150",
[-268915] = "1/150/150/150",
[-269715] = "1/100/117/135",
[-269716] = "1/110/127/145",
[-269719] = "1/115/132/150",
[-271366] = "1/35/55/75",
[-271433] = "1/35/55/75",
[-278418] = "1/95/110/125",
[-282851] = "1/135/142/150",
[-282855] = "1/140/145/150",
[-282857] = "1/145/147/150",
[-285644] = "1/140/145/150",
[-286644] = "1/1/25/50",
[-286665] = "1/100/100/100",
[-287270] = "1/1/25/50",
[-287494] = "1/150/150/150",
[-290360] = "1/1/50/100",
[-290361] = "1/1/75/150",
[-294781] = "1/165/170/175",
[-294782] = "1/170/172/175",
[-294783] = "1/175/175/175",
[-297989] = "1/165/170/175",
[-297991] = "1/170/172/175",
[-297993] = "1/165/170/175",
[-297994] = "1/170/172/175",
[-297995] = "1/165/170/175",
[-297999] = "1/175/175/175",
[-298001] = "1/170/172/175",
[-298002] = "1/175/175/175",
[-298009] = "1/165/170/175",
[-298010] = "1/170/172/175",
[-298011] = "1/175/175/175",
[-298016] = "1/175/175/175",
[-298433] = "1/175/175/175",
[-298437] = "1/175/175/175",
[-298438] = "1/175/175/175",
[-298439] = "1/175/175/175",
[-298440] = "1/175/175/175",
[-298441] = "1/175/175/175",
[-298442] = "1/175/175/175",
[-298515] = "1/175/175/175",
[-300769] = "1/175/175/175",
[-300770] = "1/175/175/175",
[-300788] = "1/175/175/175",
[-300789] = "1/175/175/175",
[-301412] = "1/165/170/175",
[-305936] = "1/165/170/175",
[-305937] = "1/165/170/175",
[-305938] = "1/165/170/175",
[-309524] = "1/10/17/25",
[-309525] = "1/20/25/30",
[-309526] = "1/85/90/95",
[-309528] = "1/35/42/50",
[-309530] = "1/35/42/50",
[-309531] = "1/35/42/50",
[-309532] = "1/20/25/30",
[-309534] = "1/85/90/95",
[-309535] = "1/70/75/80",
[-309608] = "1/20/25/30",
[-309609] = "1/85/90/95",
[-309610] = "1/10/17/25",
[-309612] = "1/45/55/65",
[-309613] = "1/50/60/70",
[-309614] = "1/55/65/75",
[-309615] = "1/60/65/70",
[-309616] = "1/90/95/100",
[-309617] = "1/90/95/100",
[-309618] = "1/90/95/100",
[-309619] = "1/90/95/100",
[-309620] = "1/110/130/150",
[-309621] = "1/110/130/150",
[-309622] = "1/110/130/150",
[-309623] = "1/110/130/150",
[-309627] = "1/35/42/50",
[-309636] = "1/115/132/150",
[-309637] = "1/115/132/150",
[-309638] = "1/115/132/150",
[-309644] = "1/1/1/1",
[-309645] = "1/1/1/1",
[-323609] = "1/10/17/25",
[-323755] = "1/65/70/75",
[-323760] = "1/105/127/150",
[-323761] = "1/105/127/150",
[-323762] = "1/40/50/60",
[-324773] = "1/100/125/150",
[-342316] = "1/70/75/80",
[-343680] = "1/45/47/50",
[-343683] = "1/70/72/75",
[-343684] = "1/50/52/55",
[-355184] = "1/50/62/75",
-- Invalid recipe: Shadowlands Enchanting (46) - True Aim Spear (338121)
-- Invalid recipe: Shadowlands Enchanting (46) - Unbreakable Crystal (338123)
-- Invalid recipe: Shadowlands Enchanting (46) - Everburning Brand (338125)
-- Invalid recipe: Shadowlands Enchanting (46) - Boundless Basket (346026)



-- engineering
[4357] = "1/20/30/40",
[4358] = "1/30/45/60",
[4359] = "1/45/52/60",
[4360] = "1/60/75/90",
[4362] = "1/80/95/110",
[4364] = "1/85/90/95",
[4365] = "1/95/100/105",
[4366] = "1/115/130/145",
[4367] = "1/130/145/160",
[4368] = "1/130/145/160",
[4369] = "1/130/142/155",
[4370] = "1/125/140/155",
[4371] = "1/115/135/155",
[4372] = "1/145/157/170",
[4373] = "1/145/157/170",
[4374] = "1/120/145/170",
[4375] = "1/125/150/175",
[4376] = "1/125/150/175",
[4377] = "1/125/135/145",
[4378] = "1/125/135/145",
[4379] = "1/155/167/180",
[4380] = "1/140/165/190",
[4381] = "1/165/177/190",
[4382] = "1/145/170/195",
[4383] = "1/170/182/195",
[4384] = "1/175/187/200",
[4385] = "1/175/187/200",
[4386] = "1/175/185/195",
[4387] = "1/160/170/180",
[4388] = "1/180/190/200",
[4389] = "1/170/190/210",
[4390] = "1/175/195/215",
[4391] = "1/175/195/215",
[4392] = "1/185/205/225",
[4393] = "1/205/215/225",
[4394] = "1/190/210/230",
[4395] = "1/215/225/235",
[4396] = "1/220/230/240",
[4397] = "1/220/230/240",
[4398] = "1/200/220/240",
[4401] = "1/105/120/135",
[4403] = "1/185/195/205",
[4404] = "1/110/125/140",
[4405] = "1/90/105/120",
[4406] = "1/135/147/160",
[4407] = "1/200/210/220",
[4852] = "1/185/205/225",
[5507] = "1/160/172/185",
[6219] = "1/70/80/90",
[6533] = "1/150/160/170",
[6712] = "1/125/125/125",
[6714] = "1/115/122/130",
[7148] = "1/160/180/200",
[7189] = "1/245/255/265",
[7191] = "1/275/280/285",
[7506] = "1/150/162/175",
[9312] = "1/150/162/175",
[9313] = "1/150/162/175",
[9318] = "1/150/162/175",
[10498] = "1/175/195/215",
[10499] = "1/195/205/215",
[10500] = "1/225/235/245",
[10501] = "1/240/250/260",
[10502] = "1/245/255/265",
[10503] = "1/250/260/270",
[10504] = "1/265/275/285",
[10505] = "1/175/185/195",
[10506] = "1/250/260/270",
[10507] = "1/175/185/195",
[10508] = "1/225/235/245",
[10510] = "1/240/250/260",
[10514] = "1/215/235/255",
[10518] = "1/245/255/265",
[10542] = "1/225/235/245",
[10543] = "1/225/235/245",
[10545] = "1/230/240/250",
[10546] = "1/230/240/250",
[10548] = "1/260/270/280",
[10558] = "1/150/170/190",
[10559] = "1/195/215/235",
[10560] = "1/200/220/240",
[10561] = "1/215/235/255",
[10562] = "1/235/255/275",
[10576] = "1/270/280/290",
[10577] = "1/225/235/245",
[10586] = "1/235/255/275",
[10587] = "1/230/250/270",
[10588] = "1/265/275/285",
[10644] = "1/205/205/205",
[10645] = "1/260/270/280",
[10646] = "1/205/225/245",
[10713] = "1/195/195/195",
[10716] = "1/225/235/245",
[10720] = "1/230/240/250",
[10721] = "1/235/245/255",
[10724] = "1/245/255/265",
[10725] = "1/250/260/270",
[10726] = "1/255/265/275",
[10727] = "1/260/270/280",
[11590] = "1/200/220/240",
[11825] = "1/205/205/205",
[11826] = "1/205/205/205",
[15992] = "1/250/255/260",
[15993] = "1/280/290/300",
[15994] = "1/280/290/300",
[15995] = "1/280/290/300",
[15996] = "1/285/292/300",
[15999] = "1/290/295/300",
[16000] = "1/295/297/300",
[16004] = "1/295/297/300",
[16005] = "1/300/300/300",
[16006] = "1/300/300/300",
[16007] = "1/300/300/300",
[16008] = "1/300/300/300",
[16009] = "1/300/300/300",
[16022] = "1/300/300/300",
[16023] = "1/295/297/300",
[16040] = "1/300/300/300",
[17716] = "1/190/210/230",
[18168] = "1/300/300/300",
[18232] = "1/300/300/300",
[18282] = "1/300/300/300",
[18283] = "1/300/300/300",
[18587] = "1/285/292/300",
[18588] = "1/200/210/220",
[18594] = "1/275/285/295",
[18631] = "1/270/275/280",
[18634] = "1/280/290/300",
[18637] = "1/285/290/295",
[18638] = "1/300/300/300",
[18639] = "1/300/300/300",
[18641] = "1/250/260/270",
[18645] = "1/275/280/285",
[18660] = "1/260/265/270",
[18984] = "1/285/292/300",
[18986] = "1/285/292/300",
[19026] = "1/250/260/270",
[19998] = "1/300/300/300",
[19999] = "1/300/300/300",
[21277] = "1/300/300/300",
[21557] = "1/125/137/150",
[21558] = "1/125/137/150",
[21559] = "1/125/137/150",
[21569] = "1/245/255/265",
[21570] = "1/295/297/300",
[21571] = "1/225/237/250",
[21574] = "1/225/237/250",
[21576] = "1/225/237/250",
[21589] = "1/175/187/200",
[21590] = "1/175/187/200",
[21592] = "1/175/187/200",
[21714] = "1/275/280/285",
[21716] = "1/275/280/285",
[21718] = "1/275/280/285",
[22728] = "1/275/280/285",
[23736] = "1/20/30/40",
[23737] = "1/35/45/55",
[23742] = "1/30/40/50",
[23746] = "1/60/65/70",
[23747] = "1/70/72/75",
[23748] = "1/75/75/75",
[23758] = "1/50/60/70",
[23761] = "1/50/60/70",
[23762] = "1/60/65/70",
[23763] = "1/70/72/75",
[23764] = "1/45/55/65",
[23765] = "1/70/72/75",
[23766] = "1/75/75/75",
[23767] = "1/35/45/55",
[23768] = "1/35/45/55",
[23771] = "1/35/45/55",
[23774] = "1/25/35/45",
[23775] = "1/50/57/65",
[23781] = "1/1/10/20",
[23782] = "1/1/10/20",
[23783] = "1/1/5/10",
[23784] = "1/25/30/35",
[23785] = "1/50/60/70",
[23786] = "1/50/60/70",
[23787] = "1/50/60/70",
[23819] = "1/50/55/60",
[23821] = "1/5/15/25",
[23824] = "1/65/67/70",
[23825] = "1/60/65/70",
[23826] = "1/25/35/45",
[23827] = "1/40/50/60",
[23828] = "1/75/75/75",
[23829] = "1/75/75/75",
[23835] = "1/60/65/70",
[23836] = "1/60/65/70",
[23838] = "1/75/75/75",
[23839] = "1/75/75/75",
[23841] = "1/35/45/55",
[25886] = "1/35/45/55",
[30542] = "1/50/60/70",
[30544] = "1/50/60/70",
[32413] = "1/45/55/65",
[32423] = "1/35/40/45",
[32461] = "1/70/72/75",
[32472] = "1/70/72/75",
[32473] = "1/70/72/75",
[32474] = "1/70/72/75",
[32475] = "1/70/72/75",
[32476] = "1/70/72/75",
[32478] = "1/70/72/75",
[32479] = "1/70/72/75",
[32480] = "1/70/72/75",
[32494] = "1/70/72/75",
[32495] = "1/70/72/75",
[32756] = "1/75/75/75",
[33092] = "1/30/40/50",
[33093] = "1/45/55/65",
[34060] = "1/1/38/75",
[34061] = "1/75/75/75",
[34113] = "1/70/72/75",
[34353] = "1/75/75/75",
[34354] = "1/75/75/75",
[34355] = "1/75/75/75",
[34356] = "1/15/35/55",
[34357] = "1/75/75/75",
[34847] = "1/75/75/75",
[35181] = "1/75/75/75",
[35182] = "1/75/75/75",
[35183] = "1/75/75/75",
[35184] = "1/75/75/75",
[35185] = "1/75/75/75",
[35581] = "1/65/67/70",
[37567] = "1/40/45/50",
[39681] = "1/1/3/5",
[39682] = "1/5/10/15",
[39683] = "1/20/25/30",
[39688] = "1/30/35/40",
[39690] = "1/1/5/10",
[40536] = "1/10/15/20",
[40727] = "1/75/75/75",
[40767] = "1/60/65/70",
[40768] = "1/55/57/60",
[40769] = "1/40/42/45",
[40771] = "1/1/8/15",
[40772] = "1/65/70/75",
[40865] = "1/60/65/70",
[40892] = "1/5/10/15",
[40893] = "1/5/10/15",
[40895] = "1/55/60/65",
[41112] = "1/50/57/65",
[41121] = "1/55/60/65",
[41146] = "1/55/57/60",
[41167] = "1/60/67/75",
[41168] = "1/75/75/75",
[41508] = "1/75/75/75",
[42546] = "1/45/50/55",
[42549] = "1/75/75/75",
[42550] = "1/75/75/75",
[42551] = "1/75/75/75",
[42552] = "1/75/75/75",
[42553] = "1/75/75/75",
[42554] = "1/75/75/75",
[42555] = "1/75/75/75",
[42641] = "1/50/55/60",
[44413] = "1/75/75/75",
[44504] = "1/75/75/75",
[44739] = "1/25/32/40",
[44740] = "1/50/57/65",
[44741] = "1/50/57/65",
[44742] = "1/50/57/65",
[44949] = "1/75/75/75",
[44951] = "1/35/40/45",
[45631] = "1/270/280/290",
[47828] = "1/40/45/50",
[48933] = "1/75/75/75",
[49040] = "1/75/75/75",
[59359] = "1/75/75/75",
[59364] = "1/75/75/75",
[59367] = "1/75/75/75",
[59448] = "1/75/75/75",
[59449] = "1/75/75/75",
[59453] = "1/75/75/75",
[59455] = "1/75/75/75",
[59456] = "1/75/75/75",
[59458] = "1/75/75/75",
[59594] = "1/75/75/75",
[59595] = "1/45/47/50",
[59596] = "1/45/47/50",
[59597] = "1/70/72/75",
[59598] = "1/75/75/75",
[59599] = "1/75/75/75",
[60216] = "1/70/72/75",
[60217] = "1/70/72/75",
[60218] = "1/65/67/70",
[60222] = "1/30/32/35",
[60223] = "1/55/55/55",
[60224] = "1/10/17/25",
[60403] = "1/75/75/75",
[60853] = "1/35/42/50",
[60854] = "1/70/72/75",
[60858] = "1/65/70/75",
[63396] = "1/75/75/75",
[67494] = "1/25/27/30",
[67749] = "1/30/35/40",
[68049] = "1/75/75/75",
[70139] = "1/75/75/75",
[71077] = "1/75/75/75",
[77467] = "1/1/13/25",
[77468] = "1/1/13/25",
[77527] = "1/40/45/50",
[77528] = "1/75/75/75",
[77529] = "1/75/75/75",
[77530] = "1/50/62/75",
[77531] = "1/50/62/75",
[77532] = "1/1/3/5",
[77533] = "1/75/75/75",
[77534] = "1/75/75/75",
[77535] = "1/75/75/75",
[77536] = "1/75/75/75",
[77537] = "1/75/75/75",
[77538] = "1/75/75/75",
[77539] = "1/75/75/75",
[77540] = "1/10/22/35",
[77541] = "1/10/22/35",
[77542] = "1/10/22/35",
[77543] = "1/10/22/35",
[77544] = "1/10/22/35",
[77545] = "1/10/22/35",
[77546] = "1/10/22/35",
[77547] = "1/10/22/35",
[77589] = "1/25/37/50",
[86607] = "1/40/45/50",
[87213] = "1/75/75/75",
[87214] = "1/75/75/75",
[87215] = "1/75/75/75",
[87216] = "1/50/62/75",
[87250] = "1/75/75/75",
[87251] = "1/75/75/75",
[87526] = "1/75/75/75",
[87764] = "1/1/13/25",
[88491] = "1/1/13/25",
[88493] = "1/1/13/25",
[89888] = "1/1/13/25",
[89893] = "1/1/13/25",
[89991] = "1/1/13/25",
[90146] = "1/50/55/60",
[92747] = "1/600/600/600",
[94113] = "1/600/600/600",
[94903] = "1/600/600/600",
[95416] = "1/600/600/600",
[100905] = "1/600/600/600",
[108745] = "1/100/100/100",
[109076] = "1/25/27/30",
[109120] = "1/100/100/100",
[109122] = "1/100/100/100",
[109167] = "1/100/100/100",
[109168] = "1/100/100/100",
[109171] = "1/100/100/100",
[109172] = "1/100/100/100",
[109173] = "1/100/100/100",
[109174] = "1/100/100/100",
[109183] = "1/100/100/100",
[109184] = "1/25/27/30",
[109253] = "1/100/100/100",
[111366] = {[169080] = "1/1/50/100", [182120] = "1/100/100/100"},
[111402] = "1/100/100/100",
[111820] = "1/100/100/100",
[111821] = "1/100/100/100",
[112057] = "1/100/100/100",
[112059] = "1/100/100/100",
[114056] = "1/100/100/100",
[114943] = "1/100/100/100",
[116147] = "1/1/3/5",
[116148] = "1/1/3/5",
[116149] = "1/1/3/5",
[118006] = "1/25/27/30",
[118007] = "1/25/27/30",
[118008] = "1/100/100/100",
[118741] = "1/100/100/100",
[119299] = "1/1/50/100",
[132500] = {[198939] = "1/20/30/40", [198991] = "1/40/50/60", [199005] = "1/60/70/80"},
[132501] = {[198965] = "1/20/30/40", [198992] = "1/40/50/60", [199006] = "1/60/70/80"},
[132502] = {[198966] = "1/20/30/40", [198993] = "1/40/50/60", [199007] = "1/60/70/80"},
[132503] = {[198967] = "1/20/30/40", [198994] = "1/40/50/60", [199008] = "1/60/70/80"},
[132504] = {[198968] = "1/60/70/80", [198995] = "1/100/100/100", [199009] = "1/90/95/100"},
[132505] = {[198969] = "1/60/70/80", [198996] = "1/100/100/100", [199010] = "1/90/95/100"},
[132506] = {[198970] = "1/60/70/80", [198997] = "1/100/100/100", [199011] = "1/90/95/100"},
[132507] = {[198971] = "1/60/70/80", [198998] = "1/100/100/100", [199012] = "1/90/95/100"},
[132509] = {[198972] = "1/40/50/60", [198999] = "1/60/70/80", [199013] = "1/80/90/100"},
[132510] = {[198973] = "1/40/50/60", [199000] = "1/60/70/80", [199014] = "1/80/90/100"},
[132511] = {[198974] = "1/40/50/60", [199001] = "1/60/70/80", [199015] = "1/80/90/100"},
[132513] = {[198975] = "1/40/50/60", [199002] = "1/60/70/80", [199016] = "1/80/90/100"},
[132514] = {[198976] = "1/40/50/60", [199003] = "1/60/70/80", [199017] = "1/80/90/100"},
[132515] = {[198977] = "1/40/50/60", [199004] = "1/60/70/80", [199018] = "1/80/90/100"},
[132516] = "1/20/40/60",
[132517] = "1/20/40/60",
[132518] = "1/80/90/100",
[132519] = "1/90/95/100",
[132523] = "1/20/30/40",
[132524] = "1/20/40/60",
[132525] = "1/20/40/60",
[132526] = "1/20/40/60",
[132528] = "1/20/40/60",
[132529] = "1/20/40/60",
[132530] = "1/20/40/60",
[132531] = "1/20/40/60",
[132982] = "1/20/40/60",
[134125] = "1/20/40/60",
[136606] = "1/20/40/60",
[136687] = "1/20/45/70",
[136688] = "1/20/45/70",
[144331] = "1/100/100/100",
[144332] = "1/100/100/100",
[144333] = "1/100/100/100",
[144334] = "1/100/100/100",
[144341] = "1/60/70/80",
[151651] = "1/20/40/60",
[151652] = "1/75/87/100",
[152830] = "1/25/60/95",
[152837] = {[253150] = "1/125/137/150", [253151] = "1/135/142/150", [253152] = "1/145/147/150"},
[153487] = {[255407] = "1/25/37/50", [255408] = "1/50/67/85", [255409] = "1/75/87/100"},
[153490] = {[255392] = "1/25/37/50", [255393] = "1/50/67/85", [255394] = "1/75/87/100"},
[153494] = {[255395] = "1/25/37/50", [255396] = "1/50/67/85", [255397] = "1/75/87/100"},
[153506] = {[255457] = "1/125/137/150", [255458] = "1/135/142/150", [255459] = "1/145/147/150"},
[153510] = {[256080] = "1/35/67/100", [256082] = "1/80/97/115", [256084] = "1/95/110/125"},
[153512] = {[256073] = "1/35/67/100", [256074] = "1/80/97/115", [256075] = "1/95/110/125"},
[153573] = {[256070] = "1/35/67/100", [256071] = "1/80/97/115", [256072] = "1/95/110/125"},
[153597] = {[256154] = "1/35/67/100", [256155] = "1/80/97/115", [256156] = "1/95/110/125"},
[158203] = {[265097] = "1/50/75/100", [265098] = "1/100/112/125", [265099] = "1/115/125/135"},
[158212] = {[264960] = "1/50/82/115", [264961] = "1/100/112/125", [264962] = "1/115/125/135"},
[158327] = {[264964] = "1/50/82/115", [264966] = "1/100/112/125", [264967] = "1/115/125/135"},
[158377] = {[265100] = "1/50/75/100", [265101] = "1/100/112/125", [265102] = "1/115/125/135"},
[158379] = {[283914] = "1/100/125/150", [283915] = "1/125/137/150", [283916] = "1/145/147/150"},
[158886] = "1/170/172/175",
[159936] = {[269727] = "1/125/137/150", [269728] = "1/125/137/150", [269729] = "1/135/142/150"},
[159937] = {[269724] = "1/125/137/150", [269725] = "1/125/137/150", [269726] = "1/135/142/150"},
[160488] = {[272056] = "1/130/140/150", [272057] = "1/140/145/150", [272058] = "1/150/150/150"},
[160489] = {[272059] = "1/130/140/150", [272060] = "1/140/145/150", [272061] = "1/150/150/150"},
[160490] = {[272062] = "1/130/140/150", [272063] = "1/140/145/150", [272064] = "1/150/150/150"},
[160491] = {[272065] = "1/130/140/150", [272066] = "1/140/145/150", [272067] = "1/150/150/150"},
[161134] = "1/150/150/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[164679] = {[282809] = "1/135/142/150", [282810] = "1/140/145/150", [282811] = "1/145/147/150"},
[164680] = {[282806] = "1/135/142/150", [282807] = "1/140/145/150", [282808] = "1/145/147/150"},
[164740] = "1/150/150/150",
[164913] = "1/150/150/150",
[164914] = "1/150/150/150",
[164915] = "1/150/150/150",
[165738] = "1/95/110/125",
[165742] = "1/95/110/125",
[165849] = "1/135/140/145",
[165885] = "1/150/150/150",
[165886] = "1/150/150/150",
[165887] = "1/150/150/150",
[165888] = "1/150/150/150",
[165890] = "1/150/150/150",
[165891] = "1/150/150/150",
[165892] = "1/150/150/150",
[165893] = "1/150/150/150",
[165895] = "1/150/150/150",
[165896] = "1/150/150/150",
[165897] = "1/150/150/150",
[165898] = "1/150/150/150",
[166979] = "1/125/137/150",
[166980] = "1/130/140/150",
[166981] = "1/125/137/150",
[166982] = "1/130/140/150",
[166983] = "1/125/137/150",
[166984] = "1/130/140/150",
[166985] = "1/125/137/150",
[166986] = "1/130/140/150",
[167940] = {[294784] = "1/165/170/175", [294785] = "1/170/172/175", [294786] = "1/175/175/175"},
[167997] = {[294787] = "1/165/170/175", [294788] = "1/170/172/175", [294789] = "1/175/175/175"},
[168521] = "1/150/162/175",
[168522] = "1/150/162/175",
[168523] = "1/150/162/175",
[168667] = "1/175/175/175",
[168689] = "1/175/175/175",
[168690] = "1/175/175/175",
[168691] = "1/175/175/175",
[168692] = "1/175/175/175",
[168693] = "1/175/175/175",
[168694] = "1/175/175/175",
[168695] = "1/175/175/175",
[168696] = "1/175/175/175",
[168697] = "1/175/175/175",
[168698] = "1/175/175/175",
[168699] = "1/175/175/175",
[168700] = "1/175/175/175",
[168807] = "1/155/157/160",
[168808] = "1/155/157/160",
[170313] = {[305861] = "1/165/170/175", [305862] = "1/165/170/175", [305863] = "1/165/170/175"},
[170314] = {[305858] = "1/165/170/175", [305859] = "1/165/170/175", [305860] = "1/165/170/175"},
[171003] = "1/175/175/175",
[171004] = "1/175/175/175",
[171005] = "1/175/175/175",
[171006] = "1/175/175/175",
[171007] = "1/175/175/175",
[171008] = "1/175/175/175",
[171009] = "1/175/175/175",
[171010] = "1/175/175/175",
[171011] = "1/175/175/175",
[171012] = "1/175/175/175",
[171013] = "1/175/175/175",
[171014] = "1/175/175/175",
[171320] = "1/200/200/200",
[172902] = "1/30/37/45",
[172903] = "1/20/27/35",
[172904] = "1/25/32/40",
[172905] = "1/95/97/100",
[172906] = "1/95/97/100",
[172907] = "1/95/97/100",
[172908] = "1/95/97/100",
[172912] = "1/75/77/80",
[172914] = "1/70/75/80",
[172915] = "1/55/60/65",
[172920] = "1/90/92/95",
[172921] = "1/90/92/95",
[172923] = "1/40/45/50",
[172924] = "1/85/90/95",
[172934] = "1/10/17/25",
[172935] = "1/10/17/25",
[172936] = "1/45/47/50",
[172937] = "1/75/77/80",
[173381] = "1/55/60/65",
[173382] = "1/75/80/85",
[173383] = "1/90/92/95",
[173384] = "1/200/200/200",
[180208] = "1/115/117/120",
[183942] = "1/35/37/40",
[184308] = "1/55/62/70",
-- Unknown item created by: Northrend Engineering (48) - EMP Generator (54736)
-- Unknown item created by: Northrend Engineering (48) - Frag Belt (54793)
-- Unknown item created by: Northrend Engineering (48) - Flexweave Underlay (55002)
-- Unknown item created by: Northrend Engineering (48) - Nitro Boosts (55016)
-- Unknown item created by: Northrend Engineering (48) - Mind Amplification Dish (67839)
-- Unknown item created by: Cataclysm Engineering (36) - Spinal Healing Injector (82200)
-- Unknown item created by: Cataclysm Engineering (36) - Invisibility Field (84424)
-- Unknown item created by: Cataclysm Engineering (36) - Cardboard Assassin (84425)
-- Unknown item created by: Cataclysm Engineering (36) - Grounded Plasma Shield (84427)
-- Unknown item created by: Pandaria Engineering (46) - Watergliding Jets (109099)
-- Unknown item created by: Pandaria Engineering (46) - Goblin Glider (126392)
-- Unknown item created by: Kul Tiran Engineering (147) - Belt Enchant: Holographic Horror Projector (255936)
-- Unknown item created by: Kul Tiran Engineering (147) - Belt Enchant: Personal Space Amplifier (255940)
-- Unknown item created by: Kul Tiran Engineering (147) - Belt Enchant: Miniaturized Plasma Shield (269123)
-- Invalid recipe: Kul Tiran Engineering (147) - Magical Intrusion Dampener (280732)
-- Invalid recipe: Kul Tiran Engineering (147) - Magical Intrusion Dampener (280733)
-- Invalid recipe: Kul Tiran Engineering (147) - Magical Intrusion Dampener (280734)
-- Unknown item created by: Shadowlands Engineering (40) - Dimensional Shifter (310495)
-- Unknown item created by: Shadowlands Engineering (40) - Electro-Jump (310496)
-- Unknown item created by: Shadowlands Engineering (40) - Damage Retaliator (310497)
-- Invalid recipe: Shadowlands Engineering (40) - Bug Zapifier (338119)
-- Invalid recipe: Shadowlands Engineering (40) - Energized Battery (338210)
-- Invalid recipe: Shadowlands Engineering (40) - Electro Cable (338212)
-- Invalid recipe: Shadowlands Engineering (40) - Power Hammer (338213)
-- Invalid recipe: Shadowlands Engineering (40) - Piston Assembly (338214)
-- Invalid recipe: Shadowlands Engineering (40) - Hardened Bolts (338216)
-- Invalid recipe: Shadowlands Engineering (40) - Boneclad Stake Launcher (338217)
-- Invalid recipe: Shadowlands Engineering (40) - Bone Reinforced Oxxein Tubing (338218)
-- Invalid recipe: Shadowlands Engineering (40) - Handful of Oxxein Bolts (338219)
-- Invalid recipe: Shadowlands Engineering (40) - Duelist's Pistol (338220)
-- Invalid recipe: Shadowlands Engineering (40) - Sinvyr Barrel (338222)
-- Invalid recipe: Shadowlands Engineering (40) - Sinvyr Trigger Mechanism (338223)



-- inscription
[954] = "15/65/70/75",
[955] = "1/65/70/75",
[1180] = "1/65/70/75",
[1181] = "1/65/70/75",
[1477] = "85/85/90/95",
[1711] = "75/75/80/85",
[1712] = "75/75/80/85",
[2289] = "80/80/85/90",
[2290] = "75/75/80/85",
[3012] = "15/65/70/75",
[4419] = "165/170/175/180",
[4422] = "155/160/165/170",
[4424] = "160/165/170/175",
[4425] = "175/180/185/190",
[4426] = "170/175/180/185",
[10306] = "210/215/220/225",
[10307] = "205/210/215/220",
[10308] = "215/220/225/230",
[10309] = "225/230/235/240",
[10310] = "220/225/230/235",
[27498] = "270/275/280/285",
[27499] = "260/265/270/275",
[27501] = "255/260/265/270",
[27502] = "250/255/260/265",
[27503] = "265/270/275/280",
[33457] = "1/20/25/30",
[33458] = "1/10/15/20",
[33460] = "295/300/300/300",
[33461] = "290/300/300/300",
[33462] = "1/15/20/25",
[37091] = "1/1/10/20",
[37092] = "1/40/45/50",
[37093] = "1/1/10/20",
[37094] = "1/30/35/40",
[37097] = "1/1/10/20",
[37098] = "1/35/40/45",
[37118] = "35/75/80/85",
[37168] = "85/125/137/150",
[38322] = "1/50/62/75",
[38682] = "35/75/87/100",
[39469] = "1/45/60/75",
[39774] = "75/75/77/80",
[40919] = "1/1/10/20",
[41100] = "1/300/300/300",
[42459] = "1/1/38/75",
[42751] = "1/1/10/20",
[43115] = "85/85/90/95",
[43116] = "1/100/100/105",
[43117] = "125/125/130/135",
[43118] = "1/150/150/155",
[43119] = "1/175/175/180",
[43120] = "1/200/200/205",
[43121] = "1/225/225/230",
[43122] = "1/250/250/255",
[43123] = "275/290/295/300",
[43124] = "1/1/3/5",
[43125] = "1/20/25/30",
[43126] = "1/1/10/20",
[43127] = "1/1/10/20",
[43334] = "1/1/10/20",
[43350] = "1/1/10/20",
[43366] = "1/300/300/300",
[43369] = "1/300/300/300",
[43373] = "1/300/300/300",
[43386] = "1/300/300/300",
[43394] = "1/300/300/300",
[43398] = "1/300/300/300",
[43400] = "1/300/300/300",
[43463] = "1/1/10/20",
[43464] = "1/50/55/60",
[43465] = "1/1/10/20",
[43466] = "1/45/50/55",
[43515] = "85/125/137/150",
[43535] = "1/300/300/300",
[43551] = "1/300/300/300",
[43654] = "125/150/162/175",
[43655] = "125/150/162/175",
[43656] = "175/200/205/210",
[43657] = "175/200/205/210",
[43660] = "225/250/255/260",
[43661] = "225/250/255/260",
[43663] = "275/290/295/300",
[43664] = "275/290/295/300",
[43666] = "1/40/45/50",
[43667] = "1/40/45/50",
[43850] = "200/205/210/215",
[44142] = "125/150/162/175",
[44161] = "175/200/205/210",
[44163] = "225/250/255/260",
[44210] = "1/50/62/75",
[44314] = "200/215/220/225",
[44315] = "1/1/10/20",
[44316] = "275/290/295/300",
[44317] = "1/50/62/75",
[44318] = "1/75/75/75",
[44922] = "1/300/300/300",
[45768] = "1/1/10/20",
[45789] = "1/300/300/300",
[45849] = "1/1/10/20",
[45854] = "1/1/10/20",
[49084] = "1/1/10/20",
[49632] = "1/50/62/75",
[60838] = "1/10/17/25",
[61978] = "1/1/1/1",
[61981] = "1/30/32/35",
[61987] = "1/75/75/75",
[62056] = "1/75/75/75",
[62231] = "1/35/37/40",
[62233] = "1/35/37/40",
[62234] = "1/70/72/75",
[62235] = "1/70/72/75",
[62236] = "1/70/72/75",
[62238] = "1/30/40/50",
[62239] = "1/20/30/40",
[62251] = "1/55/60/65",
[63246] = "1/40/50/60",
[63276] = "1/75/75/75",
[63303] = "1/25/30/35",
[63304] = "1/20/25/30",
[63305] = "1/1/5/10",
[63306] = "1/15/20/25",
[63307] = "1/10/15/20",
[63308] = "1/5/10/15",
[64670] = "75/90/100/110",
[77101] = "1/300/300/300",
[79254] = "1/10/15/20",
[79255] = "1/10/15/20",
[79257] = "1/75/75/75",
[79318] = "1/75/75/75",
[79333] = "1/45/50/55",
[79334] = "1/75/75/75",
[79335] = "1/75/75/75",
[79339] = "1/45/50/55",
[79340] = "1/75/75/75",
[79341] = "1/75/75/75",
[79342] = "1/45/50/55",
[79343] = "1/75/75/75",
[79538] = "1/1/10/20",
[79731] = "1/75/75/75",
[80587] = "1/300/300/300",
[80588] = "1/1/10/20",
[83006] = "1/75/75/75",
[83007] = "1/75/75/75",
[85221] = "1/300/300/300",
[87277] = "1/1/10/20",
[87392] = "1/1/10/20",
[87559] = "1/75/75/75",
[87560] = "1/75/75/75",
[87561] = "1/75/75/75",
[87562] = "1/75/75/75",
[87565] = "1/50/52/55",
[87566] = "1/65/70/75",
[87577] = "1/25/25/25",
[87578] = "1/25/25/25",
[87579] = "1/25/25/25",
[87580] = "1/25/25/25",
[87581] = "1/75/75/75",
[87582] = "1/75/75/75",
[87584] = "1/75/75/75",
[87585] = "1/75/75/75",
[87647] = "1/75/75/75",
[87648] = "1/75/75/75",
[87811] = "1/75/75/75",
[87814] = "1/75/75/75",
[87831] = "1/75/75/75",
[87881] = "1/1/10/20",
[87883] = "1/1/10/20",
[87885] = "1/300/300/300",
[87888] = "1/1/10/20",
[88806] = "1/75/75/75",
[89367] = "1/75/75/75",
[89368] = "1/75/75/75",
[89868] = "1/300/300/300",
[102483] = "1/70/72/75",
[104099] = "1/300/300/300",
[104104] = "1/300/300/300",
[104105] = "1/300/300/300",
[104108] = "1/1/10/20",
[104120] = "1/1/38/75",
[104122] = "1/300/300/300",
[104126] = "1/300/300/300",
[104127] = "1/300/300/300",
[104138] = "1/300/300/300",
[111526] = "1/100/100/100",
[112270] = "1/100/100/100",
[112377] = {[169081] = "1/1/50/100", [182125] = "1/100/100/100"},
[113111] = "1/1/1/1",
[113131] = "1/100/100/100",
[113134] = "1/100/100/100",
[113270] = "1/100/100/100",
[113289] = "1/100/100/100",
[113355] = "1/100/100/100",
[113992] = "1/1/3/5",
[114931] = {[190381] = "1/1/8/15", [190382] = "1/1/8/15", [190383] = "1/1/8/15", [190384] = "1/1/8/15", [190385] = "1/1/8/15", [190386] = "1/1/8/15"},
[114942] = "1/1/1/1",
[118061] = "1/1/1/1",
[118601] = "1/1/3/5",
[118602] = "1/1/3/5",
[118603] = "1/1/3/5",
[119126] = "1/1/1/1",
[119297] = "1/1/50/100",
[128304] = "1/1/8/15",
[128712] = {[191659] = "1/40/50/60", [192859] = "1/60/70/80", [192890] = "1/80/90/100"},
[128978] = {[192854] = "1/60/70/80", [192855] = "1/80/90/100", [192856] = "1/100/100/100"},
[128979] = "1/20/50/80",
[128980] = "1/20/40/60",
[128987] = {[192808] = "1/40/50/60", [192860] = "1/60/70/80", [192891] = "1/80/90/100"},
[128988] = {[192809] = "1/40/50/60", [192861] = "1/60/70/80", [192892] = "1/80/90/100"},
[128989] = {[192810] = "1/40/50/60", [192862] = "1/60/70/80", [192893] = "1/80/90/100"},
[128990] = {[192811] = "1/40/50/60", [192863] = "1/60/70/80", [192894] = "1/80/90/100"},
[128991] = {[192812] = "1/40/50/60", [192864] = "1/60/70/80", [192895] = "1/80/90/100"},
[128992] = {[192813] = "1/40/50/60", [192865] = "1/60/70/80", [192896] = "1/80/90/100"},
[128993] = {[192814] = "1/40/50/60", [192866] = "1/60/70/80", [192897] = "1/80/90/100"},
[128994] = {[192815] = "1/60/70/80", [192867] = "1/80/90/100", [192898] = "1/100/100/100"},
[128995] = {[192816] = "1/60/70/80", [192868] = "1/80/90/100", [192899] = "1/100/100/100"},
[128996] = {[192817] = "1/60/70/80", [192869] = "1/80/90/100", [192900] = "1/100/100/100"},
[128997] = {[192818] = "1/60/70/80", [192870] = "1/80/90/100", [192901] = "1/100/100/100"},
[128998] = {[192819] = "1/60/70/80", [192871] = "1/80/90/100", [192902] = "1/100/100/100"},
[128999] = {[192820] = "1/60/70/80", [192872] = "1/80/90/100", [192903] = "1/100/100/100"},
[129000] = {[192821] = "1/60/70/80", [192873] = "1/80/90/100", [192904] = "1/100/100/100"},
[129001] = {[192822] = "1/60/70/80", [192874] = "1/80/90/100", [192905] = "1/100/100/100"},
[129002] = {[192823] = "1/60/70/80", [192875] = "1/80/90/100", [192906] = "1/100/100/100"},
[129003] = {[192824] = "1/60/70/80", [192876] = "1/80/90/100", [192907] = "1/100/100/100"},
[129017] = "1/20/45/70",
[129018] = "1/20/45/70",
[129019] = "1/20/45/70",
[129020] = "1/20/45/70",
[129021] = "1/20/45/70",
[129022] = "1/20/45/70",
[129028] = "1/20/45/70",
[129029] = "1/20/45/70",
[129032] = {[209661] = "1/1/8/15", [209662] = "1/1/8/15", [210116] = "1/1/8/15"},
[129034] = {[209664] = "1/1/8/15", [247861] = "1/1/8/15"},
[129100] = "1/1/8/15",
[129211] = "1/20/40/60",
[136692] = "1/20/45/70",
[136693] = "1/20/45/70",
[136825] = "1/20/45/70",
[136826] = "1/20/45/70",
[136852] = "1/50/70/90",
[136856] = "1/50/70/90",
[136857] = "1/50/70/90",
[136926] = "1/1/8/15",
[137188] = "1/20/45/70",
[137191] = "1/20/45/70",
[137238] = "1/20/45/70",
[137239] = "1/20/45/70",
[137249] = "1/20/45/70",
[137250] = "1/20/45/70",
[137267] = "1/20/45/70",
[137269] = "1/20/45/70",
[137274] = "1/20/45/70",
[137287] = "1/20/45/70",
[137288] = "1/20/45/70",
[137289] = "1/20/45/70",
[137293] = "1/20/45/70",
[139270] = "1/20/45/70",
[139271] = "1/20/45/70",
[139278] = "1/20/45/70",
[139288] = "1/20/45/70",
[139289] = "1/20/45/70",
[139310] = "1/20/45/70",
[139311] = "1/20/45/70",
[139312] = "1/20/45/70",
[139315] = "1/20/45/70",
[139338] = "1/20/45/70",
[139339] = "1/20/45/70",
[139348] = "1/20/45/70",
[139352] = "1/20/45/70",
[139358] = "1/20/45/70",
[139362] = "1/20/45/70",
[139417] = "1/20/45/70",
[139435] = "1/20/45/70",
[139436] = "1/20/45/70",
[139437] = "1/20/45/70",
[139438] = "1/20/45/70",
[139442] = "1/20/45/70",
[140567] = "1/50/70/90",
[140568] = "1/50/70/90",
[140630] = "1/20/45/70",
[141333] = {[226248] = "1/50/60/70", [227239] = "1/50/60/70", [227240] = "1/50/60/70"},
[141446] = "1/20/40/60",
[141640] = "1/1/20/40",
[141641] = "1/1/35/70",
[141644] = {[165304] = "1/175/225/275", [165456] = "1/200/250/300", [165460] = "1/250/275/300", [165461] = "1/300/300/300", [165463] = "1/300/300/300", [165464] = "1/75/75/75", [165465] = "1/75/75/75", [165466] = "1/75/75/75", [165467] = "1/70/72/75", [165564] = "1/125/175/225"},
[141898] = "1/20/45/70",
[142101] = {[229177] = "1/60/70/80", [229180] = "1/60/70/80", [229183] = "1/80/90/100"},
[142102] = {[229178] = "1/60/70/80", [229181] = "1/60/70/80", [229184] = "1/80/90/100"},
[142103] = {[229179] = "1/60/70/80", [229182] = "1/60/70/80", [229185] = "1/80/90/100"},
[143588] = "1/20/45/70",
[143750] = "1/20/45/70",
[146406] = {[238577] = "1/40/50/60", [238578] = "1/60/70/80", [238579] = "1/80/90/100"},
[147119] = "1/20/45/70",
[149755] = "1/1/10/20",
[151538] = "1/20/45/70",
[151540] = "1/20/45/70",
[151542] = "1/20/45/70",
[151610] = {[247614] = "1/80/90/100", [247615] = "1/80/90/100", [247616] = "1/80/90/100"},
[152505] = "1/70/75/80",
[152506] = "1/70/75/80",
[152507] = "1/70/75/80",
[152508] = "1/70/75/80",
[152509] = "1/70/75/80",
[152510] = "1/70/75/80",
[152511] = "1/70/75/80",
[153031] = "1/20/45/70",
[153033] = "1/20/45/70",
[153036] = "1/20/45/70",
[153598] = {[256245] = "1/150/150/150", [256246] = "1/150/150/150", [278527] = "1/110/130/150"},
[153643] = {[256247] = "1/110/122/135", [256248] = "1/150/150/150", [256249] = "1/150/150/150"},
[153646] = {[256232] = "1/95/110/125", [256233] = "1/110/130/150", [256234] = "1/125/137/150"},
[153647] = {[256235] = "1/25/50/75", [256236] = "1/80/95/110", [256237] = "1/75/92/110"},
[153661] = {[256275] = "1/95/115/135", [256276] = "1/105/125/145", [256277] = "1/115/132/150"},
[153662] = {[256278] = "1/95/115/135", [256279] = "1/105/125/145", [256280] = "1/115/132/150"},
[153663] = {[256281] = "1/95/115/135", [256282] = "1/105/125/145", [256283] = "1/115/132/150"},
[153664] = {[256284] = "1/95/115/135", [256285] = "1/105/125/145", [256286] = "1/115/132/150"},
[153665] = {[256287] = "1/95/115/135", [256288] = "1/105/125/145", [256289] = "1/115/132/150"},
[153666] = {[256290] = "1/95/115/135", [256291] = "1/105/125/145", [256293] = "1/115/132/150"},
[153667] = {[256294] = "1/95/115/135", [256295] = "1/105/125/145", [256296] = "1/115/132/150"},
[153668] = {[256297] = "1/95/115/135", [256298] = "1/105/125/145", [256299] = "1/115/132/150"},
[153670] = "1/150/150/150",
[153673] = {[256303] = "1/150/150/150", [256304] = "1/150/150/150", [256305] = "1/150/150/150"},
[156563] = "1/150/150/150",
[156636] = "1/150/150/150",
[156637] = "1/150/150/150",
[156638] = "1/150/150/150",
[158187] = "1/25/37/50",
[158188] = "1/25/37/50",
[158189] = "1/25/37/50",
[158201] = "1/50/75/100",
[158202] = "1/50/87/125",
[158204] = "1/50/75/100",
[159825] = "1/45/60/75",
[159940] = {[269740] = "1/110/122/135", [269741] = "1/115/130/145", [269742] = "1/125/137/150"},
[162022] = "1/75/100/125",
[162027] = "1/75/100/125",
[162029] = "1/150/150/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[164682] = {[282803] = "1/135/142/150", [282804] = "1/140/145/150", [282805] = "1/145/147/150"},
[165016] = {[284292] = "1/125/137/150", [284293] = "1/135/142/150", [284294] = "1/145/147/150"},
[165017] = {[284295] = "1/125/137/150", [284296] = "1/135/142/150", [284297] = "1/145/147/150"},
[165692] = {[285639] = "1/150/150/150", [285640] = "1/150/150/150", [285641] = "1/150/150/150"},
[165733] = {[285925] = "1/150/150/150", [285926] = "1/150/150/150", [285927] = "1/150/150/150"},
[165745] = "1/95/110/125",
[166583] = "1/150/150/150",
[166664] = "1/150/150/150",
[167539] = "1/1/10/20",
[167942] = {[294790] = "1/165/170/175", [294791] = "1/170/172/175", [294792] = "1/175/175/175"},
[168487] = "1/150/162/175",
[168583] = "1/55/60/65",
[168586] = "1/55/60/65",
[168589] = "1/55/60/65",
[168624] = {[298625] = "1/165/170/175", [298647] = "1/170/172/175", [298648] = "1/175/175/175"},
[168663] = "1/125/150/175",
[168956] = "1/165/170/175",
[168959] = "1/165/170/175",
[168960] = "1/165/170/175",
[169301] = "1/175/175/175",
[169302] = "1/175/175/175",
[169321] = "1/175/175/175",
[169328] = "1/175/175/175",
[169701] = "1/55/60/65",
[170164] = "1/150/162/175",
[170165] = "1/150/162/175",
[170168] = "1/150/162/175",
[170173] = "1/150/162/175",
[170316] = {[305952] = "1/165/170/175", [305953] = "1/165/170/175", [305954] = "1/165/170/175"},
[170554] = "1/55/60/65",
[171203] = {[306481] = "1/175/175/175", [306482] = "1/175/175/175", [306483] = "1/175/175/175"},
[171315] = "1/55/60/65",
[172008] = "1/175/175/175",
[172010] = "1/175/175/175",
[172449] = "1/175/175/175",
[173048] = "1/70/72/75",
[173049] = "1/30/32/35",
[173050] = "1/30/35/40",
[173051] = "1/80/85/90",
[173053] = "1/80/85/90",
[173054] = "1/40/45/50",
[173058] = "1/15/20/25",
[173059] = "1/15/20/25",
[173062] = "1/80/85/90",
[173065] = "1/25/30/35",
[173066] = "1/95/110/125",
[173067] = "1/115/120/125",
[173160] = "1/85/92/100",
[173161] = "1/85/92/100",
[173162] = "1/85/92/100",
[173163] = "1/85/92/100",
[173381] = "1/50/52/55",
[173382] = "1/70/72/75",
[173428] = "1/40/45/50",
[175924] = "1/80/85/90",
[175970] = "1/65/70/75",
[177873] = "1/95/110/125",
[177874] = "1/95/110/125",
[177875] = "1/95/110/125",
[177876] = "1/95/110/125",
[180755] = "1/100/105/110",
[183942] = "1/45/47/50",
[184096] = "1/150/150/150",
[184097] = "1/150/150/150",
[184100] = "1/150/150/150",
[186522] = "1/100/100/100",
[186662] = "1/115/120/125",
-- Unknown item created by: Northrend Inscription (29) - Master's Inscription of the Axe (61117)
-- Unknown item created by: Northrend Inscription (29) - Master's Inscription of the Crag (61118)
-- Unknown item created by: Northrend Inscription (29) - Master's Inscription of the Pinnacle (61119)
-- Unknown item created by: Northrend Inscription (29) - Master's Inscription of the Storm (61120)
-- Unknown item created by: Cataclysm Inscription (38) - Swiftsteel Inscription (86375)
-- Unknown item created by: Cataclysm Inscription (38) - Lionsmane Inscription (86401)
-- Unknown item created by: Cataclysm Inscription (38) - Inscription of the Earth Prince (86402)
-- Unknown item created by: Cataclysm Inscription (38) - Felfire Inscription (86403)
-- Invalid recipe: Shadowlands Inscription (47) - Hymnal of Respite (338225)
-- Invalid recipe: Shadowlands Inscription (47) - Scroll of Calming Lyrics (338226)
-- Invalid recipe: Shadowlands Inscription (47) - Ardenberry Ink (338227)
-- Invalid recipe: Shadowlands Inscription (47) - Invocation of Duty (338228)
-- Invalid recipe: Shadowlands Inscription (47) - Poem on Duty (338229)
-- Invalid recipe: Shadowlands Inscription (47) - Opalescent Ink (338230)
-- Invalid recipe: Shadowlands Inscription (47) - Litany of Might (338231)
-- Invalid recipe: Shadowlands Inscription (47) - Scroll of Unyielding Strength (338232)
-- Invalid recipe: Shadowlands Inscription (47) - Necrotic Ink (338233)
-- Invalid recipe: Shadowlands Inscription (47) - Catalog of Sins (338234)
-- Invalid recipe: Shadowlands Inscription (47) - Scroll of Castigation (338235)
-- Invalid recipe: Shadowlands Inscription (47) - Prideful Ink (338236)



-- jewelcrafting
[20816] = "1/20/35/50",
[20817] = "50/70/80/90",
[20818] = "50/80/95/110",
[20820] = "60/90/105/120",
[20821] = "30/60/75/90",
[20823] = "70/100/115/130",
[20826] = "90/120/135/150",
[20827] = "80/110/125/140",
[20828] = "100/130/145/160",
[20830] = "1/140/155/170",
[20831] = "1/180/195/210",
[20832] = "120/150/165/180",
[20833] = "1/155/170/185",
[20906] = "1/30/45/60",
[20907] = "50/80/95/110",
[20909] = "110/140/155/170",
[20950] = "120/150/165/180",
[20954] = "125/155/170/185",
[20955] = "135/165/180/195",
[20958] = "150/180/195/210",
[20959] = "1/200/215/230",
[20960] = "170/200/215/230",
[20961] = "180/210/225/240",
[20963] = "150/170/180/190",
[20964] = "210/235/250/265",
[20966] = "1/190/205/220",
[20967] = "1/220/235/250",
[20969] = "1/250/265/280",
[21748] = "200/225/240/255",
[21752] = "225/235/245/255",
[21753] = "1/275/287/300",
[21754] = "1/270/285/300",
[21755] = "220/245/260/275",
[21756] = "1/225/240/255",
[21758] = "1/240/255/270",
[21760] = "1/250/265/280",
[21763] = "1/260/275/290",
[21764] = "235/260/275/290",
[21765] = "240/265/280/295",
[21766] = "1/275/287/300",
[21767] = "260/280/290/300",
[21768] = "275/285/292/300",
[21769] = "1/280/290/300",
[21774] = "1/285/292/300",
[21775] = "280/290/295/300",
[21777] = "1/295/297/300",
[21778] = "1/295/297/300",
[21779] = "1/20/30/40",
[21784] = "1/300/300/300",
[21789] = "1/300/300/300",
[21790] = "280/290/295/300",
[21791] = "290/300/300/300",
[21792] = "1/15/25/35",
[21931] = "1/30/45/60",
[21932] = "5/35/50/65",
[21933] = "50/80/95/110",
[21934] = "30/60/75/90",
[23094] = "1/300/300/300",
[23095] = "1/5/25/45",
[23098] = "1/1/20/40",
[23099] = "1/5/25/45",
[23100] = "1/15/35/55",
[23101] = "1/25/40/55",
[23103] = "1/1/20/40",
[23104] = "1/5/25/45",
[23105] = "1/15/35/55",
[23108] = "1/1/13/25",
[23109] = "1/325/325/325",
[23110] = "1/325/325/325",
[23111] = "1/25/40/55",
[23114] = "1/325/325/325",
[23115] = "1/15/35/55",
[23116] = "1/325/325/325",
[23118] = "1/1/20/40",
[23119] = "1/305/305/305",
[23120] = "1/15/35/55",
[24027] = "1/50/60/70",
[24028] = "1/350/350/350",
[24030] = "1/350/350/350",
[24032] = "1/350/350/350",
[24033] = "1/50/60/70",
[24035] = "1/350/350/350",
[24036] = "1/50/60/70",
[24039] = "1/50/60/70",
[24048] = "1/350/350/350",
[24051] = "1/350/350/350",
[24053] = "1/50/60/70",
[24054] = "1/50/60/70",
[24055] = "1/350/350/350",
[24056] = "1/50/60/70",
[24058] = "1/50/60/70",
[24059] = "1/50/60/70",
[24060] = "1/50/60/70",
[24061] = "1/350/350/350",
[24065] = "1/50/60/70",
[24066] = "1/50/60/70",
[24067] = "1/50/60/70",
[24074] = "1/20/30/40",
[24075] = "1/20/35/50",
[24076] = "1/30/40/50",
[24077] = "1/45/55/65",
[24078] = "1/45/55/65",
[24079] = "1/60/67/75",
[24080] = "1/65/70/75",
[24082] = "1/65/70/75",
[24085] = "1/70/72/75",
[24086] = "1/70/72/75",
[24087] = "1/55/65/75",
[24088] = "1/65/70/75",
[24089] = "1/75/75/75",
[24092] = "1/70/72/75",
[24093] = "1/70/72/75",
[24095] = "1/70/72/75",
[24097] = "1/70/72/75",
[24098] = "1/70/72/75",
[24106] = "1/65/70/75",
[24110] = "1/65/70/75",
[24114] = "1/70/72/75",
[24116] = "1/70/72/75",
[24117] = "1/75/75/75",
[24121] = "1/75/75/75",
[24122] = "1/75/75/75",
[24123] = "1/75/75/75",
[24124] = "1/75/75/75",
[24125] = "1/75/75/75",
[24126] = "1/75/75/75",
[24127] = "1/75/75/75",
[24128] = "1/75/75/75",
[25438] = "20/50/65/80",
[25439] = "20/50/65/80",
[25498] = "1/30/40/50",
[25880] = "50/70/80/90",
[25881] = "110/120/130/140",
[25882] = "175/175/185/195",
[25883] = "225/225/235/245",
[25890] = "1/75/75/75",
[25893] = "1/75/75/75",
[25894] = "1/75/75/75",
[25895] = "1/75/75/75",
[25896] = "1/75/75/75",
[25897] = "1/75/75/75",
[25898] = "1/75/75/75",
[25899] = "1/75/75/75",
[25901] = "1/75/75/75",
[28595] = "1/305/305/305",
[29157] = "180/190/200/210",
[29158] = "200/210/220/230",
[29159] = "280/290/295/300",
[29160] = "290/300/300/300",
[30419] = "75/105/120/135",
[30420] = "105/135/150/165",
[30421] = "230/255/270/285",
[30422] = "265/285/292/300",
[30804] = "65/95/110/125",
[30825] = "1/70/72/75",
[31079] = "1/25/35/45",
[31154] = "80/110/125/140",
[31398] = "1/75/75/75",
[31399] = "1/75/75/75",
[31866] = "1/25/40/55",
[31867] = "1/50/60/70",
[31868] = "1/50/60/70",
[31869] = "1/25/40/55",
[32193] = "1/75/75/75",
[32194] = "1/375/375/375",
[32196] = "1/375/375/375",
[32198] = "1/375/375/375",
[32199] = "1/75/75/75",
[32200] = "1/75/75/75",
[32201] = "1/375/375/375",
[32203] = "1/75/75/75",
[32205] = "1/375/375/375",
[32206] = "1/375/375/375",
[32209] = "1/75/75/75",
[32211] = "1/75/75/75",
[32212] = "1/375/375/375",
[32215] = "1/75/75/75",
[32217] = "1/75/75/75",
[32218] = "1/75/75/75",
[32220] = "1/375/375/375",
[32221] = "1/75/75/75",
[32222] = "1/75/75/75",
[32223] = "1/75/75/75",
[32224] = "1/75/75/75",
[32225] = "1/375/375/375",
[32226] = "1/75/75/75",
[32409] = "1/75/75/75",
[32410] = "1/75/75/75",
[32508] = "1/40/55/70",
[32772] = "1/35/45/55",
[32774] = "1/40/50/60",
[32776] = "1/75/75/75",
[32833] = "1/25/32/40",
[32836] = "1/50/60/70",
[33131] = "1/65/70/75",
[33133] = "1/65/70/75",
[33134] = "1/65/70/75",
[33135] = "1/65/70/75",
[33140] = "1/65/70/75",
[33143] = "1/65/70/75",
[33144] = "1/65/70/75",
[33782] = "1/50/60/70",
[34220] = "1/75/75/75",
[34358] = "1/365/365/365",
[34359] = "1/365/365/365",
[34360] = "1/365/365/365",
[34361] = "1/365/365/365",
[34362] = "1/365/365/365",
[34363] = "1/365/365/365",
[35315] = "1/50/60/70",
[35318] = "1/50/60/70",
[35501] = "1/75/75/75",
[35503] = "1/75/75/75",
[35693] = "1/75/75/75",
[35694] = "1/75/75/75",
[35700] = "1/75/75/75",
[35702] = "1/75/75/75",
[35703] = "1/75/75/75",
[35707] = "1/350/350/350",
[35758] = "1/75/75/75",
[35759] = "1/75/75/75",
[35760] = "1/375/375/375",
[35761] = "1/75/75/75",
[35945] = "1/50/60/70",
[36767] = "1/15/40/65",
[39900] = "1/1/20/40",
[39905] = "1/1/20/40",
[39907] = "1/1/20/40",
[39908] = "1/1/20/40",
[39909] = "1/1/20/40",
[39910] = "1/1/20/40",
[39912] = "1/1/20/40",
[39915] = "1/1/20/40",
[39917] = "1/1/20/40",
[39918] = "1/1/20/40",
[39919] = "1/1/20/40",
[39927] = "1/1/20/40",
[39932] = "1/1/20/40",
[39933] = "1/1/20/40",
[39934] = "1/1/20/40",
[39935] = "1/1/20/40",
[39939] = "1/1/20/40",
[39940] = "1/1/20/40",
[39942] = "1/1/20/40",
[39945] = "1/1/20/40",
[39947] = "1/1/20/40",
[39948] = "1/1/20/40",
[39949] = "1/1/20/40",
[39950] = "1/1/20/40",
[39951] = "1/1/20/40",
[39952] = "1/1/20/40",
[39954] = "1/350/350/350",
[39955] = "1/1/20/40",
[39956] = "1/1/20/40",
[39957] = "1/1/20/40",
[39958] = "1/1/20/40",
[39959] = "1/1/20/40",
[39965] = "1/1/20/40",
[39966] = "1/1/20/40",
[39967] = "1/1/20/40",
[39968] = "1/1/20/40",
[39975] = "1/1/20/40",
[39976] = "1/1/20/40",
[39977] = "1/1/20/40",
[39978] = "1/1/20/40",
[39979] = "1/1/20/40",
[39980] = "1/1/20/40",
[39981] = "1/1/20/40",
[39982] = "1/350/350/350",
[39983] = "1/1/20/40",
[39991] = "1/1/20/40",
[39992] = "1/1/20/40",
[39996] = "1/35/50/65",
[39997] = "1/35/50/65",
[40000] = "1/390/390/390",
[40001] = "1/35/50/65",
[40003] = "1/35/50/65",
[40008] = "1/35/50/65",
[40010] = "1/35/50/65",
[40011] = "1/35/50/65",
[40013] = "1/390/390/390",
[40014] = "1/35/50/65",
[40016] = "1/35/50/65",
[40017] = "1/35/50/65",
[40022] = "1/35/50/65",
[40023] = "1/35/50/65",
[40025] = "1/390/390/390",
[40026] = "1/390/390/390",
[40028] = "1/35/50/65",
[40032] = "1/35/50/65",
[40034] = "1/35/50/65",
[40037] = "1/35/50/65",
[40038] = "1/35/50/65",
[40039] = "1/35/50/65",
[40040] = "1/35/50/65",
[40041] = "1/35/50/65",
[40044] = "1/390/390/390",
[40045] = "1/450/450/450",
[40048] = "1/35/50/65",
[40049] = "1/35/50/65",
[40050] = "1/35/50/65",
[40051] = "1/390/390/390",
[40052] = "1/35/50/65",
[40055] = "1/390/390/390",
[40057] = "1/390/390/390",
[40058] = "1/35/50/65",
[40059] = "1/35/50/65",
[40086] = "1/35/50/65",
[40088] = "1/35/50/65",
[40089] = "1/390/390/390",
[40090] = "1/35/50/65",
[40091] = "1/35/50/65",
[40095] = "1/390/390/390",
[40098] = "1/390/390/390",
[40100] = "1/390/390/390",
[40102] = "1/390/390/390",
[40105] = "1/390/390/390",
[40106] = "1/35/50/65",
[40111] = "1/65/70/75",
[40112] = "1/450/450/450",
[40113] = "1/450/450/450",
[40115] = "1/450/450/450",
[40116] = "1/65/70/75",
[40118] = "1/65/70/75",
[40119] = "1/65/70/75",
[40120] = "1/450/450/450",
[40122] = "1/65/70/75",
[40124] = "1/450/450/450",
[40125] = "1/65/70/75",
[40127] = "1/65/70/75",
[40128] = "1/65/70/75",
[40129] = "1/65/70/75",
[40130] = "1/450/450/450",
[40133] = "1/450/450/450",
[40135] = "1/65/70/75",
[40139] = "1/65/70/75",
[40141] = "1/65/70/75",
[40142] = "1/65/70/75",
[40143] = "1/65/70/75",
[40144] = "1/65/70/75",
[40145] = "1/65/70/75",
[40146] = "1/65/70/75",
[40147] = "1/65/70/75",
[40149] = "1/450/450/450",
[40150] = "1/450/450/450",
[40152] = "1/65/70/75",
[40153] = "1/65/70/75",
[40154] = "1/65/70/75",
[40155] = "1/65/70/75",
[40157] = "1/450/450/450",
[40160] = "1/450/450/450",
[40162] = "1/65/70/75",
[40163] = "1/65/70/75",
[40164] = "1/450/450/450",
[40165] = "1/450/450/450",
[40166] = "1/65/70/75",
[40167] = "1/450/450/450",
[40168] = "1/65/70/75",
[40169] = "1/65/70/75",
[40171] = "1/65/70/75",
[40173] = "1/450/450/450",
[40177] = "1/450/450/450",
[40179] = "1/450/450/450",
[40180] = "1/450/450/450",
[40182] = "1/65/70/75",
[41285] = "1/440/440/440",
[41307] = "1/440/440/440",
[41333] = "1/440/440/440",
[41335] = "1/440/440/440",
[41339] = "1/440/440/440",
[41367] = "1/1/3/5",
[41375] = "1/440/440/440",
[41376] = "1/440/440/440",
[41377] = "1/440/440/440",
[41378] = "1/440/440/440",
[41379] = "1/440/440/440",
[41380] = "1/440/440/440",
[41381] = "1/440/440/440",
[41382] = "1/440/440/440",
[41385] = "1/440/440/440",
[41389] = "1/440/440/440",
[41395] = "1/440/440/440",
[41396] = "1/440/440/440",
[41397] = "1/440/440/440",
[41398] = "1/440/440/440",
[41400] = "1/440/440/440",
[41401] = "1/440/440/440",
[42142] = "1/15/40/65",
[42143] = "1/370/370/370",
[42144] = "1/370/370/370",
[42145] = "1/370/370/370",
[42149] = "1/370/370/370",
[42150] = "1/15/40/65",
[42151] = "1/370/370/370",
[42152] = "1/15/40/65",
[42154] = "1/15/40/65",
[42155] = "1/15/40/65",
[42156] = "1/15/40/65",
[42158] = "1/15/40/65",
[42336] = "1/5/25/45",
[42337] = "1/5/25/45",
[42338] = "1/25/35/45",
[42339] = "1/25/35/45",
[42340] = "1/65/70/75",
[42341] = "1/55/65/75",
[42395] = "1/55/65/75",
[42413] = "1/55/65/75",
[42418] = "1/55/65/75",
[42420] = "1/1/8/15",
[42421] = "1/5/15/25",
[42642] = "1/75/75/75",
[42643] = "1/75/75/75",
[42644] = "1/75/75/75",
[42645] = "1/75/75/75",
[42646] = "1/75/75/75",
[42647] = "1/75/75/75",
[42701] = "1/5/25/45",
[42702] = "1/35/50/65",
[43244] = "1/5/25/45",
[43245] = "1/5/25/45",
[43246] = "1/15/30/45",
[43247] = "1/15/30/45",
[43248] = "1/35/45/55",
[43249] = "1/35/45/55",
[43250] = "1/65/70/75",
[43251] = "1/65/70/75",
[43252] = "1/65/70/75",
[43253] = "1/65/70/75",
[43482] = "1/65/70/75",
[43498] = "1/65/70/75",
[43582] = "1/65/70/75",
[44063] = "1/55/65/75",
[44943] = "1/70/72/75",
[45054] = "1/300/300/300",
[45627] = "200/210/220/230",
[45808] = "1/65/70/75",
[45809] = "1/65/70/75",
[45812] = "1/65/70/75",
[45813] = "1/65/70/75",
[49110] = "1/65/70/75",
[52081] = "1/1/18/35",
[52082] = "1/1/18/35",
[52083] = "1/1/18/35",
[52084] = "1/1/18/35",
[52085] = "1/1/18/35",
[52086] = "1/1/18/35",
[52087] = "1/1/18/35",
[52088] = "1/1/18/35",
[52089] = "1/1/18/35",
[52090] = "1/1/18/35",
[52091] = "1/1/18/35",
[52093] = "1/1/18/35",
[52094] = "1/1/18/35",
[52095] = "1/1/18/35",
[52096] = "1/1/18/35",
[52097] = "1/1/18/35",
[52098] = "1/1/18/35",
[52099] = "1/1/18/35",
[52100] = "1/1/18/35",
[52101] = "1/1/18/35",
[52102] = "1/1/18/35",
[52103] = "1/1/18/35",
[52104] = "1/1/18/35",
[52105] = "1/1/18/35",
[52106] = "1/1/18/35",
[52108] = "1/1/18/35",
[52109] = "1/1/18/35",
[52110] = "1/1/18/35",
[52111] = "1/1/18/35",
[52112] = "1/1/18/35",
[52113] = "1/1/18/35",
[52114] = "1/1/18/35",
[52115] = "1/1/18/35",
[52116] = "1/1/18/35",
[52117] = "1/1/18/35",
[52118] = "1/1/18/35",
[52119] = "1/1/18/35",
[52120] = "1/1/18/35",
[52121] = "1/1/18/35",
[52122] = "1/1/18/35",
[52123] = "1/1/18/35",
[52124] = "1/1/18/35",
[52125] = "1/1/18/35",
[52126] = "1/1/18/35",
[52127] = "1/1/18/35",
[52128] = "1/1/18/35",
[52203] = "1/50/57/65",
[52204] = "1/50/57/65",
[52205] = "1/50/57/65",
[52206] = "1/50/57/65",
[52207] = "1/50/57/65",
[52208] = "1/50/57/65",
[52209] = "1/50/57/65",
[52210] = "1/50/57/65",
[52211] = "1/50/57/65",
[52212] = "1/50/57/65",
[52213] = "1/50/57/65",
[52214] = "1/50/57/65",
[52215] = "1/50/57/65",
[52216] = "1/50/57/65",
[52217] = "1/50/57/65",
[52218] = "1/50/57/65",
[52219] = "1/50/57/65",
[52220] = "1/50/57/65",
[52221] = "1/50/57/65",
[52222] = "1/50/57/65",
[52223] = "1/50/57/65",
[52224] = "1/50/57/65",
[52225] = "1/50/57/65",
[52226] = "1/50/57/65",
[52227] = "1/50/57/65",
[52228] = "1/50/57/65",
[52229] = "1/50/57/65",
[52230] = "1/50/57/65",
[52231] = "1/50/57/65",
[52232] = "1/50/57/65",
[52233] = "1/50/57/65",
[52234] = "1/50/57/65",
[52235] = "1/50/57/65",
[52236] = "1/50/57/65",
[52237] = "1/50/57/65",
[52238] = "1/50/57/65",
[52239] = "1/50/57/65",
[52240] = "1/50/57/65",
[52241] = "1/50/57/65",
[52242] = "1/50/57/65",
[52243] = "1/50/57/65",
[52244] = "1/50/57/65",
[52245] = "1/50/57/65",
[52246] = "1/50/57/65",
[52247] = "1/50/57/65",
[52248] = "1/50/57/65",
[52249] = "1/50/57/65",
[52250] = "1/50/57/65",
[52255] = "1/55/57/60",
[52257] = "1/55/57/60",
[52258] = "1/55/57/60",
[52259] = "1/55/57/60",
[52260] = "1/55/57/60",
[52261] = "1/55/57/60",
[52262] = "1/55/57/60",
[52263] = "1/55/57/60",
[52264] = "1/55/57/60",
[52265] = "1/55/57/60",
[52266] = "1/55/57/60",
[52267] = "1/55/57/60",
[52268] = "1/55/57/60",
[52269] = "1/55/57/60",
[52289] = "1/65/70/75",
[52291] = "1/65/70/75",
[52292] = "1/65/70/75",
[52293] = "1/65/70/75",
[52294] = "1/65/70/75",
[52295] = "1/65/70/75",
[52296] = "1/65/70/75",
[52297] = "1/65/70/75",
[52298] = "1/65/70/75",
[52299] = "1/65/70/75",
[52300] = "1/65/70/75",
[52301] = "1/65/70/75",
[52302] = "1/65/70/75",
[52304] = "1/75/75/75",
[52306] = "1/1/18/35",
[52307] = "1/1/18/35",
[52308] = "1/35/45/55",
[52309] = "1/45/55/65",
[52318] = "1/75/75/75",
[52319] = "1/75/75/75",
[52320] = "1/75/75/75",
[52321] = "1/75/75/75",
[52322] = "1/75/75/75",
[52323] = "1/75/75/75",
[52348] = "1/75/75/75",
[52350] = "1/75/75/75",
[52485] = "1/30/40/50",
[52486] = "1/35/45/55",
[52487] = "1/40/50/60",
[52489] = "1/75/75/75",
[52490] = "1/1/8/15",
[52492] = "1/20/25/30",
[52493] = "1/50/55/60",
[68356] = "1/50/57/65",
[68357] = "1/50/57/65",
[68358] = "1/50/57/65",
[68741] = "1/50/57/65",
[68778] = "1/65/70/75",
[68779] = "1/65/70/75",
[68780] = "1/65/70/75",
[69852] = "1/75/75/75",
[71817] = "1/75/75/75",
[71818] = "1/75/75/75",
[71819] = "1/75/75/75",
[71820] = "1/75/75/75",
[71822] = "1/75/75/75",
[71823] = "1/75/75/75",
[71824] = "1/75/75/75",
[71825] = "1/75/75/75",
[71826] = "1/75/75/75",
[71827] = "1/75/75/75",
[71828] = "1/75/75/75",
[71829] = "1/75/75/75",
[71830] = "1/75/75/75",
[71831] = "1/75/75/75",
[71832] = "1/75/75/75",
[71833] = "1/75/75/75",
[71834] = "1/75/75/75",
[71835] = "1/75/75/75",
[71836] = "1/75/75/75",
[71837] = "1/75/75/75",
[71838] = "1/75/75/75",
[71839] = "1/75/75/75",
[71840] = "1/75/75/75",
[71841] = "1/75/75/75",
[71842] = "1/75/75/75",
[71843] = "1/75/75/75",
[71844] = "1/75/75/75",
[71845] = "1/75/75/75",
[71846] = "1/75/75/75",
[71847] = "1/75/75/75",
[71848] = "1/75/75/75",
[71849] = "1/75/75/75",
[71850] = "1/75/75/75",
[71851] = "1/75/75/75",
[71852] = "1/75/75/75",
[71853] = "1/75/75/75",
[71854] = "1/75/75/75",
[71855] = "1/75/75/75",
[71856] = "1/75/75/75",
[71857] = "1/75/75/75",
[71858] = "1/75/75/75",
[71859] = "1/75/75/75",
[71860] = "1/75/75/75",
[71861] = "1/75/75/75",
[71862] = "1/75/75/75",
[71863] = "1/75/75/75",
[71864] = "1/75/75/75",
[71865] = "1/75/75/75",
[71866] = "1/75/75/75",
[71867] = "1/75/75/75",
[71868] = "1/75/75/75",
[71869] = "1/75/75/75",
[71870] = "1/75/75/75",
[71871] = "1/75/75/75",
[71872] = "1/75/75/75",
[71873] = "1/75/75/75",
[71874] = "1/75/75/75",
[71875] = "1/75/75/75",
[71876] = "1/75/75/75",
[71877] = "1/75/75/75",
[71878] = "1/75/75/75",
[71879] = "1/75/75/75",
[71880] = "1/75/75/75",
[71881] = "1/75/75/75",
[71882] = "1/75/75/75",
[71883] = "1/75/75/75",
[75067] = "1/65/70/75",
[75068] = "1/65/70/75",
[75071] = "1/65/70/75",
[75074] = "1/75/75/75",
[75075] = "1/75/75/75",
[75078] = "1/75/75/75",
[76132] = "1/75/75/75",
[76502] = "1/50/55/60",
[76504] = "1/50/55/60",
[76505] = "1/50/55/60",
[76506] = "1/50/55/60",
[76507] = "1/50/55/60",
[76508] = "1/50/55/60",
[76509] = "1/50/55/60",
[76510] = "1/50/55/60",
[76511] = "1/50/55/60",
[76512] = "1/50/55/60",
[76513] = "1/50/55/60",
[76514] = "1/50/55/60",
[76515] = "1/50/55/60",
[76517] = "1/50/55/60",
[76518] = "1/50/55/60",
[76519] = "1/50/55/60",
[76520] = "1/50/55/60",
[76521] = "1/50/55/60",
[76522] = "1/50/55/60",
[76524] = "1/50/55/60",
[76525] = "1/50/55/60",
[76526] = "1/50/55/60",
[76527] = "1/50/55/60",
[76528] = "1/50/55/60",
[76529] = "1/50/55/60",
[76530] = "1/50/55/60",
[76531] = "1/50/55/60",
[76532] = "1/50/55/60",
[76533] = "1/50/55/60",
[76534] = "1/50/55/60",
[76535] = "1/50/55/60",
[76536] = "1/50/55/60",
[76537] = "1/50/55/60",
[76538] = "1/50/55/60",
[76539] = "1/50/55/60",
[76540] = "1/50/55/60",
[76541] = "1/50/55/60",
[76542] = "1/50/55/60",
[76543] = "1/50/55/60",
[76544] = "1/50/55/60",
[76545] = "1/50/55/60",
[76546] = "1/50/55/60",
[76547] = "1/50/55/60",
[76548] = "1/50/55/60",
[76549] = "1/50/55/60",
[76550] = "1/50/55/60",
[76551] = "1/50/55/60",
[76552] = "1/50/55/60",
[76553] = "1/50/55/60",
[76554] = "1/50/55/60",
[76555] = "1/50/55/60",
[76556] = "1/50/55/60",
[76557] = "1/50/55/60",
[76558] = "1/50/55/60",
[76559] = "1/50/55/60",
[76560] = "1/50/55/60",
[76561] = "1/50/55/60",
[76562] = "1/50/55/60",
[76563] = "1/50/55/60",
[76564] = "1/50/55/60",
[76565] = "1/50/55/60",
[76566] = "1/50/55/60",
[76567] = "1/50/55/60",
[76568] = "1/50/55/60",
[76569] = "1/50/55/60",
[76636] = "1/75/75/75",
[76637] = "1/75/75/75",
[76638] = "1/75/75/75",
[76639] = "1/75/75/75",
[76640] = "1/75/75/75",
[76641] = "1/75/75/75",
[76642] = "1/75/75/75",
[76643] = "1/75/75/75",
[76644] = "1/75/75/75",
[76645] = "1/75/75/75",
[76646] = "1/75/75/75",
[76647] = "1/75/75/75",
[76648] = "1/75/75/75",
[76649] = "1/75/75/75",
[76650] = "1/75/75/75",
[76651] = "1/75/75/75",
[76652] = "1/75/75/75",
[76653] = "1/75/75/75",
[76654] = "1/75/75/75",
[76656] = "1/75/75/75",
[76657] = "1/75/75/75",
[76658] = "1/75/75/75",
[76659] = "1/75/75/75",
[76660] = "1/75/75/75",
[76661] = "1/75/75/75",
[76662] = "1/75/75/75",
[76663] = "1/75/75/75",
[76664] = "1/75/75/75",
[76665] = "1/75/75/75",
[76666] = "1/75/75/75",
[76667] = "1/75/75/75",
[76668] = "1/75/75/75",
[76669] = "1/75/75/75",
[76670] = "1/75/75/75",
[76671] = "1/75/75/75",
[76672] = "1/75/75/75",
[76673] = "1/75/75/75",
[76674] = "1/75/75/75",
[76675] = "1/75/75/75",
[76676] = "1/75/75/75",
[76677] = "1/75/75/75",
[76678] = "1/75/75/75",
[76679] = "1/75/75/75",
[76680] = "1/75/75/75",
[76681] = "1/75/75/75",
[76682] = "1/75/75/75",
[76683] = "1/75/75/75",
[76684] = "1/75/75/75",
[76685] = "1/75/75/75",
[76686] = "1/75/75/75",
[76687] = "1/75/75/75",
[76688] = "1/75/75/75",
[76689] = "1/75/75/75",
[76690] = "1/75/75/75",
[76691] = "1/75/75/75",
[76692] = "1/75/75/75",
[76693] = "1/75/75/75",
[76694] = "1/75/75/75",
[76695] = "1/75/75/75",
[76696] = "1/75/75/75",
[76697] = "1/75/75/75",
[76698] = "1/75/75/75",
[76699] = "1/75/75/75",
[76700] = "1/75/75/75",
[76701] = "1/75/75/75",
[76879] = "1/75/75/75",
[76884] = "1/75/75/75",
[76885] = "1/75/75/75",
[76886] = "1/75/75/75",
[76887] = "1/75/75/75",
[76888] = "1/75/75/75",
[76890] = "1/75/75/75",
[76891] = "1/75/75/75",
[76892] = "1/75/75/75",
[76893] = "1/75/75/75",
[76894] = "1/75/75/75",
[76895] = "1/75/75/75",
[76896] = "1/75/75/75",
[76897] = "1/75/75/75",
[82453] = "1/75/75/75",
[82774] = "1/75/75/75",
[82775] = "1/75/75/75",
[83087] = "1/75/75/75",
[83088] = "1/75/75/75",
[83089] = "1/75/75/75",
[83090] = "1/75/75/75",
[83141] = "1/50/55/60",
[83142] = "1/50/55/60",
[83143] = "1/50/55/60",
[83144] = "1/50/55/60",
[83145] = "1/50/55/60",
[83146] = "1/50/55/60",
[83147] = "1/50/55/60",
[83148] = "1/50/55/60",
[83149] = "1/50/55/60",
[83150] = "1/50/55/60",
[83151] = "1/50/55/60",
[83152] = "1/50/55/60",
[83793] = "1/50/55/60",
[83794] = "1/50/55/60",
[83795] = "1/50/55/60",
[83796] = "1/75/75/75",
[83798] = "1/75/75/75",
[83799] = "1/75/75/75",
[83800] = "1/75/75/75",
[83801] = "1/75/75/75",
[83802] = "1/75/75/75",
[83803] = "1/75/75/75",
[83804] = "1/75/75/75",
[83805] = "1/75/75/75",
[83806] = "1/75/75/75",
[89674] = "1/75/75/75",
[89675] = "1/50/55/60",
[89678] = "1/50/55/60",
[89680] = "1/75/75/75",
[90395] = "1/75/75/75",
[90397] = "1/75/75/75",
[90398] = "1/75/75/75",
[90399] = "1/75/75/75",
[90400] = "1/75/75/75",
[90401] = "1/75/75/75",
[90406] = "1/75/75/75",
[93404] = "1/50/55/60",
[93405] = "1/50/55/60",
[93406] = "1/50/55/60",
[93408] = "1/50/55/60",
[93409] = "1/50/55/60",
[93410] = "1/50/55/60",
[93705] = "1/75/75/75",
[93706] = "1/50/55/60",
[95469] = "1/75/75/75",
[112384] = "1/50/55/60",
[112498] = "1/50/55/60",
[115524] = {[170700] = "1/1/50/100", [182127] = "1/100/100/100"},
[115526] = "1/100/100/100",
[115794] = "1/100/100/100",
[115796] = "1/100/100/100",
[115798] = "1/100/100/100",
[115799] = "1/100/100/100",
[115800] = "1/100/100/100",
[115801] = "1/100/100/100",
[115803] = "1/100/100/100",
[115804] = "1/100/100/100",
[115805] = "1/100/100/100",
[115807] = "1/100/100/100",
[115808] = "1/100/100/100",
[115809] = "1/100/100/100",
[115811] = "1/100/100/100",
[115812] = "1/100/100/100",
[115814] = "1/100/100/100",
[115815] = "1/100/100/100",
[115987] = "1/50/55/60",
[115988] = "1/50/55/60",
[115989] = "1/50/55/60",
[115990] = "1/50/55/60",
[115991] = "1/50/55/60",
[115992] = "1/50/55/60",
[115993] = "1/50/55/60",
[115994] = "1/50/55/60",
[115995] = "1/50/55/60",
[118723] = "1/1/50/100",
[123918] = "1/1/1/1",
[123919] = "1/1/1/1",
[127760] = "1/100/100/100",
[127761] = "1/100/100/100",
[127762] = "1/100/100/100",
[127764] = "1/100/100/100",
[127765] = "1/100/100/100",
[130215] = "1/20/35/50",
[130216] = "1/20/35/50",
[130217] = "1/20/35/50",
[130218] = "1/20/35/50",
[130219] = "1/40/55/70",
[130220] = "1/40/55/70",
[130221] = "1/40/55/70",
[130222] = "1/40/55/70",
[130223] = {[195856] = "1/20/30/40", [195902] = "1/40/50/60", [195923] = "1/60/70/80"},
[130224] = {[195857] = "1/20/30/40", [195903] = "1/40/50/60", [195924] = "1/60/70/80"},
[130225] = {[195858] = "1/20/30/40", [195904] = "1/40/50/60", [195925] = "1/60/70/80"},
[130226] = {[195859] = "1/40/50/60", [195905] = "1/60/70/80", [195926] = "1/80/90/100"},
[130227] = {[195860] = "1/40/50/60", [195906] = "1/60/70/80", [195927] = "1/80/90/100"},
[130228] = {[195861] = "1/40/50/60", [195907] = "1/60/70/80", [195928] = "1/80/90/100"},
[130229] = {[195862] = "1/40/50/60", [195908] = "1/60/70/80", [195929] = "1/80/90/100"},
[130230] = {[195863] = "1/40/50/60", [195909] = "1/60/70/80", [195930] = "1/80/90/100"},
[130231] = {[195864] = "1/40/50/60", [195910] = "1/60/70/80", [195931] = "1/80/90/100"},
[130233] = {[195865] = "1/60/70/80", [195911] = "1/80/90/100", [195932] = "1/100/100/100"},
[130234] = {[195866] = "1/60/70/80", [195912] = "1/80/90/100", [195933] = "1/100/100/100"},
[130235] = {[195867] = "1/60/70/80", [195913] = "1/80/90/100", [195934] = "1/100/100/100"},
[130236] = {[195868] = "1/60/70/80", [195914] = "1/80/90/100", [195935] = "1/100/100/100"},
[130237] = {[195869] = "1/60/70/80", [195915] = "1/80/90/100", [195936] = "1/100/100/100"},
[130238] = {[195870] = "1/60/70/80", [195916] = "1/80/90/100", [195937] = "1/100/100/100"},
[130239] = {[195871] = "1/60/70/80", [195917] = "1/80/90/100", [195938] = "1/100/100/100"},
[130240] = {[195872] = "1/60/70/80", [195918] = "1/80/90/100", [195939] = "1/100/100/100"},
[130241] = {[195873] = "1/60/70/80", [195919] = "1/80/90/100", [195940] = "1/100/100/100"},
[130242] = {[195874] = "1/60/70/80", [195920] = "1/80/90/100", [195941] = "1/100/100/100"},
[130243] = {[195875] = "1/60/70/80", [195921] = "1/80/90/100", [195942] = "1/100/100/100"},
[130244] = {[195876] = "1/60/70/80", [195922] = "1/80/90/100", [195943] = "1/100/100/100"},
[130245] = "1/70/80/90",
[130246] = "1/80/90/100",
[130247] = "1/80/90/100",
[130248] = "1/80/90/100",
[130250] = "1/20/40/60",
[130251] = "1/100/100/100",
[130254] = "1/20/40/60",
[136711] = {[209603] = "1/20/30/40", [209606] = "1/40/50/60", [209609] = "1/60/70/80"},
[136712] = {[209604] = "1/40/50/60", [209607] = "1/60/70/80", [209610] = "1/80/90/100"},
[136713] = {[209605] = "1/40/50/60", [209608] = "1/60/70/80", [209611] = "1/80/90/100"},
[151564] = "1/1/1/1",
[151580] = "1/80/90/100",
[151583] = "1/80/90/100",
[151584] = "1/80/90/100",
[151585] = "1/80/90/100",
[151587] = {[247751] = "1/90/95/100", [247754] = "1/90/95/100", [247755] = "1/90/95/100"},
[151588] = {[247756] = "1/90/95/100", [247757] = "1/90/95/100", [247758] = "1/90/95/100"},
[151589] = {[247762] = "1/90/95/100", [247763] = "1/90/95/100", [247764] = "1/90/95/100"},
[151590] = {[247765] = "1/90/95/100", [247766] = "1/90/95/100", [247767] = "1/90/95/100"},
[152512] = "1/80/85/90",
[152513] = "1/80/85/90",
[152579] = "1/80/85/90",
[153637] = "1/50/75/100",
[153638] = "1/50/75/100",
[153639] = {[256255] = "1/105/120/135", [256256] = "1/150/150/150", [256257] = "1/150/150/150"},
[153640] = {[256258] = "1/105/120/135", [256259] = "1/150/150/150", [256260] = "1/150/150/150"},
[153683] = {[256513] = "1/75/105/135", [256520] = "1/105/127/150", [256521] = "1/125/137/150"},
[153684] = {[256512] = "1/75/105/135", [256518] = "1/105/127/150", [256519] = "1/125/137/150"},
[153685] = {[256511] = "1/75/105/135", [256516] = "1/105/127/150", [256517] = "1/125/137/150"},
[153686] = {[256510] = "1/75/105/135", [256514] = "1/105/127/150", [256515] = "1/125/137/150"},
[153687] = "1/25/50/75",
[153688] = "1/25/50/75",
[153689] = "1/25/50/75",
[153690] = "1/25/50/75",
[153707] = "1/150/150/150",
[153708] = "1/150/150/150",
[153709] = "1/150/150/150",
[153710] = "1/15/50/85",
[153711] = "1/15/50/85",
[153712] = "1/15/50/85",
[153713] = "1/15/50/85",
[153714] = "1/15/50/85",
[153715] = "1/15/50/85",
[153716] = "1/150/150/150",
[154126] = "1/105/125/145",
[154127] = "1/105/125/145",
[154128] = "1/105/125/145",
[154129] = "1/105/125/145",
[159939] = {[269734] = "1/105/120/135", [269735] = "1/115/130/145", [269736] = "1/125/137/150"},
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[164681] = {[282343] = "1/135/142/150", [282344] = "1/140/145/150", [282345] = "1/145/147/150"},
[165743] = "1/100/112/125",
[166519] = "1/140/145/150",
[166520] = "1/145/147/150",
[166521] = "1/150/150/150",
[166522] = "1/145/147/150",
[166523] = "1/150/150/150",
[166524] = "1/150/150/150",
[167943] = {[294793] = "1/165/170/175", [294794] = "1/170/172/175", [294795] = "1/175/175/175"},
[168185] = "1/150/162/175",
[168636] = "1/175/175/175",
[168637] = "1/175/175/175",
[168638] = "1/175/175/175",
[168639] = "1/165/170/175",
[168640] = "1/165/170/175",
[168641] = "1/165/170/175",
[168642] = "1/165/170/175",
[168701] = "1/175/175/175",
[168702] = "1/175/175/175",
[168703] = "1/175/175/175",
[169220] = "1/165/170/175",
[170318] = {[305168] = "1/165/170/175", [305170] = "1/165/170/175", [305171] = "1/165/170/175"},
[171075] = "1/175/175/175",
[171076] = "1/175/175/175",
[171077] = "1/175/175/175",
[171320] = "1/200/200/200",
[171828] = "1/30/45/60",
[171829] = "1/40/50/60",
[171830] = "1/40/50/60",
[171831] = "1/40/50/60",
[171832] = "1/40/50/60",
[171833] = "1/50/60/70",
[173121] = "1/25/42/60",
[173122] = "1/30/45/60",
[173123] = "1/15/37/60",
[173124] = "1/25/42/60",
[173125] = "1/30/45/60",
[173126] = "1/15/37/60",
[173127] = "1/65/82/100",
[173128] = "1/70/85/100",
[173129] = "1/65/82/100",
[173130] = "1/70/85/100",
[173131] = "1/100/100/100",
[173132] = "1/100/100/100",
[173133] = "1/100/100/100",
[173134] = "1/100/100/100",
[173135] = "1/40/50/60",
[173136] = "1/30/45/60",
[173137] = "1/35/47/60",
[173138] = "1/25/42/60",
[173140] = "1/50/62/75",
[173141] = "1/40/52/65",
[173142] = "1/50/62/75",
[173143] = "1/40/52/65",
[173144] = "1/100/100/100",
[173145] = "1/100/100/100",
[173146] = "1/100/100/100",
[173147] = "1/100/100/100",
[173381] = "1/50/52/55",
[173382] = "1/95/95/95",
[173383] = "1/100/100/100",
[173384] = "1/200/200/200",
[178926] = {[327920] = "1/100/100/100", [332039] = "1/100/100/100", [332074] = "1/100/100/100", [338978] = "1/100/100/100"},
[178927] = {[327921] = "1/100/100/100", [332040] = "1/100/100/100", [332075] = "1/100/100/100", [338977] = "1/100/100/100"},
[180760] = "1/10/15/20",
[183942] = "1/45/47/50",
[185960] = "1/100/100/100",
[186981] = "1/60/65/70",
[186982] = "1/100/100/100",
-- Unknown item created by: Northrend Designs (215) - Brilliant Scarlet Ruby (53946)
-- Invalid recipe: Legion Designs (110) - Empyrial Circlet (248937)
-- Invalid recipe: Legion Designs (110) - Empyrial Hesselian Setting (248938)
-- Invalid recipe: Legion Designs (110) - Empyrial Florid Malachite Setting (248939)
-- Invalid recipe: Legion Designs (110) - Empyrial Crown (248940)
-- Invalid recipe: Shadowlands Designs (61) - Gem Studded Bangle (338238)
-- Invalid recipe: Shadowlands Designs (61) - Engraved Phaedrum Band (338239)
-- Invalid recipe: Shadowlands Designs (61) - Polished Gemstones (338240)
-- Invalid recipe: Shadowlands Designs (61) - Gleaming Kyranite Necklace (338241)
-- Invalid recipe: Shadowlands Designs (61) - Kyranite Dangle (338242)
-- Invalid recipe: Shadowlands Designs (61) - Solenium Wire (338243)
-- Invalid recipe: Shadowlands Designs (61) - Carved Crystal Ring (338244)
-- Invalid recipe: Shadowlands Designs (61) - Hollowed Crystal (338245)
-- Invalid recipe: Shadowlands Designs (61) - Faceted Crystal (338246)
-- Invalid recipe: Shadowlands Designs (61) - Sinister Choker (338247)
-- Invalid recipe: Shadowlands Designs (61) - Brilliant Bauble (338248)
-- Invalid recipe: Shadowlands Designs (61) - Fine Sinvyr Chain (338249)



-- leatherworking
[2300] = "40/70/85/100",
[2302] = "1/40/55/70",
[2303] = "15/45/60/75",
[2304] = "1/30/45/60",
[2307] = "1/120/135/150",
[2308] = "85/105/120/135",
[2309] = "55/85/100/115",
[2310] = "60/90/105/120",
[2311] = "1/90/105/120",
[2312] = "1/105/120/135",
[2313] = "100/115/122/130",
[2314] = "120/145/157/170",
[2315] = "100/125/137/150",
[2316] = "110/135/147/160",
[2317] = "1/125/137/150",
[2318] = "1/20/30/40",
[2319] = "100/100/105/110",
[3719] = "150/170/180/190",
[4231] = "35/55/65/75",
[4233] = "100/115/122/130",
[4234] = "150/150/155/160",
[4236] = "150/160/165/170",
[4237] = "25/55/70/85",
[4239] = "55/85/100/115",
[4242] = "75/105/120/135",
[4243] = "85/115/130/145",
[4244] = "1/125/137/150",
[4246] = "80/110/125/140",
[4247] = "145/170/182/195",
[4248] = "1/155/167/180",
[4249] = "125/150/162/175",
[4250] = "1/145/157/170",
[4251] = "130/155/167/180",
[4252] = "1/165/177/190",
[4253] = "135/160/172/185",
[4254] = "1/170/180/190",
[4255] = "1/175/185/195",
[4256] = "1/195/205/215",
[4257] = "160/180/190/200",
[4258] = "1/190/200/210",
[4259] = "180/200/210/220",
[4260] = "1/215/225/235",
[4262] = "1/205/215/225",
[4264] = "1/220/230/240",
[4265] = "150/170/180/190",
[4304] = "200/200/202/205",
[4455] = "1/185/195/205",
[4456] = "1/185/195/205",
[5081] = "1/70/85/100",
[5739] = "190/210/220/230",
[5780] = "1/120/135/150",
[5781] = "1/125/140/155",
[5782] = "1/190/200/210",
[5783] = "1/210/220/230",
[5957] = "1/40/55/70",
[5958] = "1/130/142/155",
[5961] = "115/140/152/165",
[5962] = "160/180/190/200",
[5963] = "1/190/200/210",
[5964] = "175/195/205/215",
[5965] = "1/205/215/225",
[5966] = "190/210/220/230",
[6466] = "1/120/135/150",
[6467] = "1/130/142/155",
[6468] = "1/140/152/165",
[6709] = "1/115/130/145",
[7276] = "1/40/55/70",
[7277] = "1/40/55/70",
[7280] = "1/65/80/95",
[7281] = "70/100/115/130",
[7282] = "95/125/140/155",
[7283] = "1/125/137/150",
[7284] = "1/145/157/170",
[7285] = "120/145/157/170",
[7348] = "125/150/162/175",
[7349] = "1/160/172/185",
[7352] = "1/160/172/185",
[7358] = "1/165/177/190",
[7359] = "1/170/182/195",
[7373] = "1/185/195/205",
[7374] = "175/195/205/215",
[7375] = "1/195/205/215",
[7377] = "180/200/210/220",
[7378] = "185/205/215/225",
[7386] = "1/210/220/230",
[7387] = "195/215/225/235",
[7390] = "1/220/230/240",
[7391] = "1/220/230/240",
[8170] = "250/250/250/250",
[8172] = "200/200/200/200",
[8173] = "200/220/230/240",
[8174] = "1/220/230/240",
[8175] = "205/225/235/245",
[8176] = "205/225/235/245",
[8185] = "235/255/265/275",
[8187] = "1/225/235/245",
[8189] = "210/230/240/250",
[8191] = "230/250/260/270",
[8192] = "1/230/240/250",
[8193] = "230/250/260/270",
[8197] = "235/255/265/275",
[8198] = "210/230/240/250",
[8200] = "1/235/245/255",
[8201] = "1/240/250/260",
[8202] = "1/260/270/280",
[8203] = "1/240/250/260",
[8204] = "1/245/255/265",
[8205] = "1/240/250/260",
[8206] = "1/265/275/285",
[8207] = "1/260/270/280",
[8208] = "1/270/280/290",
[8209] = "1/255/265/275",
[8210] = "1/240/250/260",
[8211] = "1/245/255/265",
[8212] = "1/270/280/290",
[8213] = "1/265/275/285",
[8214] = "1/245/255/265",
[8215] = "1/270/280/290",
[8216] = "1/260/270/280",
[8345] = "1/245/255/265",
[8346] = "230/250/260/270",
[8347] = "1/245/255/265",
[8348] = "250/270/280/290",
[8349] = "250/270/280/290",
[8367] = "255/275/285/295",
[15045] = "1/280/290/300",
[15046] = "1/290/300/310",
[15047] = "1/320/330/340",
[15048] = "1/305/315/325",
[15049] = "1/315/325/335",
[15050] = "1/310/320/330",
[15051] = "1/320/330/340",
[15052] = "1/320/330/340",
[15053] = "1/305/315/325",
[15054] = "1/290/300/310",
[15055] = "1/320/330/340",
[15056] = "1/305/315/325",
[15057] = "1/295/305/315",
[15058] = "1/315/325/335",
[15059] = "1/320/330/340",
[15060] = "1/305/315/325",
[15061] = "1/290/300/310",
[15062] = "1/320/330/340",
[15063] = "1/310/320/330",
[15064] = "1/295/305/315",
[15065] = "1/305/315/325",
[15066] = "1/310/320/330",
[15067] = "1/290/300/310",
[15068] = "1/320/330/340",
[15069] = "1/305/315/325",
[15070] = "1/315/325/335",
[15071] = "1/295/305/315",
[15072] = "1/300/310/320",
[15073] = "1/295/305/315",
[15074] = "1/285/295/305",
[15075] = "1/310/320/330",
[15076] = "1/285/295/305",
[15077] = "1/275/285/295",
[15078] = "1/295/305/315",
[15079] = "1/305/315/325",
[15080] = "1/315/325/335",
[15081] = "1/320/330/340",
[15082] = "1/300/310/320",
[15083] = "1/280/290/300",
[15084] = "265/285/295/305",
[15085] = "300/320/330/340",
[15086] = "280/300/310/320",
[15087] = "290/310/320/330",
[15088] = "300/320/330/340",
[15090] = "300/320/330/340",
[15091] = "270/290/300/310",
[15092] = "275/295/305/315",
[15093] = "280/300/310/320",
[15094] = "290/310/320/330",
[15095] = "300/320/330/340",
[15096] = "300/320/330/340",
[15138] = "1/320/330/340",
[15407] = "250/250/255/260",
[15564] = "250/255/265/275",
[16982] = "1/315/325/335",
[16983] = "1/320/330/340",
[16984] = "1/320/330/340",
[17721] = "1/210/220/230",
[18238] = "1/210/220/230",
[18251] = "1/320/330/340",
[18258] = "1/285/290/295",
[18504] = "1/320/330/340",
[18506] = "1/320/330/340",
[18508] = "1/320/330/340",
[18509] = "1/320/330/340",
[18510] = "1/320/330/340",
[18511] = "1/320/330/340",
[18662] = "1/150/155/160",
[18948] = "1/175/185/195",
[19044] = "1/310/320/330",
[19049] = "1/320/330/340",
[19052] = "1/310/320/330",
[19058] = "1/320/330/340",
[19149] = "1/320/330/340",
[19157] = "1/320/330/340",
[19162] = "1/320/330/340",
[19163] = "1/320/330/340",
[19685] = "1/320/330/340",
[19686] = "1/320/330/340",
[19687] = "1/320/330/340",
[19688] = "1/320/330/340",
[19689] = "1/320/330/340",
[20295] = "300/320/330/340",
[20296] = "280/300/310/320",
[20380] = "1/320/330/340",
[20476] = "1/320/330/340",
[20477] = "1/320/330/340",
[20478] = "1/320/330/340",
[20479] = "1/320/330/340",
[20480] = "1/320/330/340",
[20481] = "1/320/330/340",
[20575] = "1/125/137/150",
[21278] = "1/320/330/340",
[21887] = "1/1/5/10",
[22661] = "1/320/330/340",
[22662] = "1/320/330/340",
[22663] = "1/320/330/340",
[22664] = "1/320/330/340",
[22665] = "1/320/330/340",
[22666] = "1/320/330/340",
[22759] = "1/320/330/340",
[22760] = "1/320/330/340",
[22761] = "1/320/330/340",
[23793] = "1/25/30/35",
[25650] = "1/10/25/40",
[25651] = "1/35/40/45",
[25652] = "1/35/40/45",
[25653] = "1/60/67/75",
[25654] = "1/10/20/30",
[25655] = "1/20/30/40",
[25656] = "1/30/40/50",
[25657] = "1/45/55/65",
[25659] = "1/45/55/65",
[25660] = "1/35/45/55",
[25661] = "1/20/30/40",
[25662] = "1/10/20/30",
[25668] = "1/30/40/50",
[25669] = "1/10/20/30",
[25670] = "1/25/35/45",
[25671] = "1/40/50/60",
[25673] = "1/10/20/30",
[25674] = "1/20/30/40",
[25675] = "1/30/40/50",
[25676] = "1/40/50/60",
[25679] = "1/1/5/10",
[25680] = "1/60/67/75",
[25681] = "1/60/67/75",
[25682] = "1/60/67/75",
[25683] = "1/60/67/75",
[25685] = "1/50/60/70",
[25686] = "1/60/67/75",
[25687] = "1/60/67/75",
[25689] = "1/70/72/75",
[25690] = "1/65/70/75",
[25691] = "1/65/70/75",
[25692] = "1/50/60/70",
[25693] = "1/60/67/75",
[25694] = "1/50/60/70",
[25695] = "1/60/67/75",
[25696] = "1/70/72/75",
[25697] = "1/70/72/75",
[25699] = "1/1/5/10",
[25700] = "1/1/5/10",
[25707] = "1/1/5/10",
[25708] = "1/1/5/10",
[29489] = "1/60/67/75",
[29490] = "1/60/67/75",
[29491] = "1/60/67/75",
[29492] = "1/60/67/75",
[29493] = "1/60/67/75",
[29494] = "1/60/67/75",
[29495] = "1/60/67/75",
[29496] = "1/60/67/75",
[29497] = "1/60/67/75",
[29498] = "1/60/67/75",
[29499] = "1/60/67/75",
[29500] = "1/60/67/75",
[29502] = "1/75/75/75",
[29503] = "1/75/75/75",
[29504] = "1/75/75/75",
[29505] = "1/75/75/75",
[29506] = "1/75/75/75",
[29507] = "1/75/75/75",
[29508] = "1/75/75/75",
[29509] = "1/75/75/75",
[29510] = "1/75/75/75",
[29511] = "1/75/75/75",
[29512] = "1/75/75/75",
[29514] = "1/75/75/75",
[29515] = "1/75/75/75",
[29516] = "1/75/75/75",
[29517] = "1/75/75/75",
[29519] = "1/75/75/75",
[29520] = "1/75/75/75",
[29521] = "1/75/75/75",
[29522] = "1/75/75/75",
[29523] = "1/75/75/75",
[29524] = "1/75/75/75",
[29525] = "1/75/75/75",
[29526] = "1/75/75/75",
[29527] = "1/75/75/75",
[29528] = "1/40/47/55",
[29529] = "1/65/70/75",
[29530] = "1/45/52/60",
[29531] = "1/50/57/65",
[29532] = "1/70/72/75",
[29533] = "1/35/45/55",
[29534] = "1/35/45/55",
[29535] = "1/65/70/75",
[29536] = "1/65/70/75",
[29539] = "1/1/5/10",
[29540] = "1/35/40/45",
[29547] = "1/1/5/10",
[29548] = "1/1/5/10",
[29964] = "260/300/300/300",
[29970] = "260/300/300/300",
[29971] = "260/300/300/300",
[29973] = "1/50/60/70",
[29974] = "1/50/60/70",
[29975] = "1/50/60/70",
[30039] = "1/75/75/75",
[30040] = "1/75/75/75",
[30041] = "1/75/75/75",
[30042] = "1/75/75/75",
[30043] = "1/75/75/75",
[30044] = "1/75/75/75",
[30045] = "1/75/75/75",
[30046] = "1/75/75/75",
[32393] = "1/75/75/75",
[32394] = "1/75/75/75",
[32395] = "1/75/75/75",
[32396] = "1/75/75/75",
[32397] = "1/75/75/75",
[32398] = "1/75/75/75",
[32399] = "1/75/75/75",
[32400] = "1/75/75/75",
[32574] = "1/375/375/375",
[32575] = "1/375/375/375",
[32577] = "1/375/375/375",
[32579] = "1/375/375/375",
[32580] = "1/375/375/375",
[32581] = "1/75/75/75",
[32582] = "1/375/375/375",
[32583] = "1/375/375/375",
[33122] = "1/70/72/75",
[33204] = "1/75/75/75",
[33568] = "1/1/3/5",
[34105] = "1/60/67/75",
[34207] = "1/55/60/65",
[34330] = "1/55/60/65",
[34369] = "1/365/365/365",
[34370] = "1/365/365/365",
[34371] = "1/365/365/365",
[34372] = "1/365/365/365",
[34373] = "1/365/365/365",
[34374] = "1/365/365/365",
[34375] = "1/365/365/365",
[34376] = "1/365/365/365",
[34482] = "1/10/20/30",
[34490] = "1/350/350/350",
[38347] = "1/45/47/50",
[38371] = "1/35/40/45",
[38372] = "1/30/35/40",
[38373] = "1/60/65/70",
[38374] = "1/60/65/70",
[38375] = "1/1/5/10",
[38376] = "1/25/27/30",
[38399] = "1/45/47/50",
[38400] = "1/10/20/30",
[38401] = "1/15/25/35",
[38402] = "1/20/30/40",
[38403] = "1/15/25/35",
[38404] = "1/10/20/30",
[38405] = "1/20/30/40",
[38406] = "1/5/12/20",
[38407] = "1/15/25/35",
[38408] = "1/15/25/35",
[38409] = "1/10/20/30",
[38410] = "1/10/20/30",
[38411] = "1/20/30/40",
[38412] = "1/10/20/30",
[38413] = "1/20/30/40",
[38414] = "1/15/25/35",
[38415] = "1/20/30/40",
[38416] = "1/10/20/30",
[38417] = "1/20/30/40",
[38418] = "1/15/25/35",
[38419] = "1/20/30/40",
[38420] = "1/15/25/35",
[38421] = "1/10/20/30",
[38422] = "1/10/20/30",
[38424] = "1/15/25/35",
[38425] = "1/10/20/30",
[38433] = "1/25/35/45",
[38434] = "1/25/35/45",
[38435] = "1/25/35/45",
[38436] = "1/25/35/45",
[38437] = "1/25/35/45",
[38438] = "1/25/35/45",
[38439] = "1/25/35/45",
[38440] = "1/25/35/45",
[38441] = "1/15/25/35",
[38557] = "1/1/3/5",
[38558] = "1/1/3/5",
[38561] = "1/1/3/5",
[38590] = "1/40/50/60",
[38591] = "1/35/45/55",
[38592] = "1/35/45/55",
[41238] = "1/30/40/50",
[42731] = "1/55/60/65",
[43129] = "1/55/60/65",
[43130] = "1/50/55/60",
[43131] = "1/50/55/60",
[43132] = "1/55/60/65",
[43133] = "1/50/55/60",
[43255] = "1/50/55/60",
[43256] = "1/50/55/60",
[43257] = "1/55/60/65",
[43258] = "1/50/55/60",
[43260] = "1/50/55/60",
[43261] = "1/50/55/60",
[43262] = "1/50/55/60",
[43263] = "1/50/55/60",
[43264] = "1/50/55/60",
[43265] = "1/55/60/65",
[43266] = "1/55/60/65",
[43271] = "1/55/60/65",
[43273] = "1/55/60/65",
[43433] = "1/50/55/60",
[43434] = "1/50/55/60",
[43435] = "1/50/55/60",
[43436] = "1/55/60/65",
[43437] = "1/55/60/65",
[43438] = "1/55/60/65",
[43439] = "1/55/60/65",
[43442] = "1/55/60/65",
[43443] = "1/55/60/65",
[43444] = "1/50/55/60",
[43445] = "1/50/55/60",
[43446] = "1/55/60/65",
[43447] = "1/50/55/60",
[43448] = "1/55/60/65",
[43449] = "1/50/55/60",
[43450] = "1/55/60/65",
[43451] = "1/55/60/65",
[43452] = "1/50/55/60",
[43453] = "1/50/55/60",
[43454] = "1/55/60/65",
[43455] = "1/50/55/60",
[43456] = "1/55/60/65",
[43457] = "1/50/55/60",
[43458] = "1/75/75/75",
[43459] = "1/75/75/75",
[43461] = "1/75/75/75",
[43469] = "1/75/75/75",
[43481] = "1/75/75/75",
[43484] = "1/75/75/75",
[43495] = "1/75/75/75",
[43502] = "1/75/75/75",
[43565] = "1/75/75/75",
[43566] = "1/75/75/75",
[43590] = "1/60/67/75",
[43591] = "1/55/65/75",
[43592] = "1/55/65/75",
[43593] = "1/60/67/75",
[43594] = "1/55/65/75",
[43595] = "1/55/65/75",
[44436] = "1/35/45/55",
[44437] = "1/35/45/55",
[44438] = "1/40/50/60",
[44440] = "1/35/45/55",
[44441] = "1/35/45/55",
[44442] = "1/40/50/60",
[44443] = "1/35/45/55",
[44444] = "1/35/45/55",
[44445] = "1/40/50/60",
[44446] = "1/45/47/50",
[44930] = "1/75/75/75",
[44931] = "1/75/75/75",
[44963] = "1/60/65/70",
[45553] = "1/75/75/75",
[45554] = "1/75/75/75",
[45555] = "1/75/75/75",
[45556] = "1/75/75/75",
[45562] = "1/75/75/75",
[45563] = "1/75/75/75",
[45564] = "1/75/75/75",
[45565] = "1/75/75/75",
[47576] = "1/75/75/75",
[47577] = "1/75/75/75",
[47579] = "1/75/75/75",
[47580] = "1/75/75/75",
[47581] = "1/75/75/75",
[47582] = "1/75/75/75",
[47583] = "1/75/75/75",
[47584] = "1/75/75/75",
[47595] = "1/75/75/75",
[47596] = "1/75/75/75",
[47597] = "1/75/75/75",
[47598] = "1/75/75/75",
[47599] = "1/75/75/75",
[47600] = "1/75/75/75",
[47601] = "1/75/75/75",
[47602] = "1/75/75/75",
[49633] = "1/65/70/75",
[49634] = "1/65/70/75",
[49894] = "1/75/75/75",
[49895] = "1/75/75/75",
[49896] = "1/75/75/75",
[49897] = "1/75/75/75",
[49898] = "1/75/75/75",
[49899] = "1/75/75/75",
[49900] = "1/75/75/75",
[49901] = "1/75/75/75",
[52976] = "1/1/3/5",
[52979] = "1/1/3/5",
[52982] = "1/1/3/5",
[56477] = "1/1/3/5",
[56480] = "1/425/425/425",
[56481] = "1/425/425/425",
[56482] = "1/425/425/425",
[56483] = "1/425/425/425",
[56484] = "1/425/425/425",
[56489] = "1/425/425/425",
[56490] = "1/425/425/425",
[56491] = "1/425/425/425",
[56494] = "1/425/425/425",
[56495] = "1/425/425/425",
[56498] = "1/425/425/425",
[56499] = "1/425/425/425",
[56502] = "1/425/425/425",
[56503] = "1/425/425/425",
[56504] = "1/425/425/425",
[56505] = "1/425/425/425",
[56508] = "1/425/425/425",
[56509] = "1/425/425/425",
[56512] = "1/425/425/425",
[56513] = "1/425/425/425",
[56516] = "1/425/425/425",
[56517] = "1/425/425/425",
[56518] = "1/425/425/425",
[56519] = "1/425/425/425",
[56536] = "1/70/72/75",
[56537] = "1/70/72/75",
[56538] = "1/70/72/75",
[56539] = "1/70/72/75",
[56548] = "1/75/75/75",
[56549] = "1/75/75/75",
[56550] = "1/75/75/75",
[56551] = "1/75/75/75",
[56561] = "1/75/75/75",
[56562] = "1/75/75/75",
[56563] = "1/75/75/75",
[56564] = "1/75/75/75",
[69939] = "1/75/75/75",
[69941] = "1/75/75/75",
[69942] = "1/75/75/75",
[69943] = "1/75/75/75",
[69949] = "1/75/75/75",
[69950] = "1/75/75/75",
[69951] = "1/75/75/75",
[69952] = "1/75/75/75",
[70136] = "1/70/72/75",
[70137] = "1/70/72/75",
[71720] = "1/75/75/75",
[71985] = "1/75/75/75",
[71986] = "1/75/75/75",
[71987] = "1/75/75/75",
[71988] = "1/75/75/75",
[71994] = "1/75/75/75",
[71995] = "1/75/75/75",
[71996] = "1/75/75/75",
[71997] = "1/75/75/75",
[72120] = "1/1/5/10",
[72163] = {[131865] = "1/25/40/55", [140040] = "1/75/75/75", [140041] = "1/75/75/75"},
[75061] = "1/75/75/75",
[75076] = "1/60/62/65",
[75077] = "1/60/62/65",
[75080] = "1/75/75/75",
[75081] = "1/70/72/75",
[75083] = "1/70/72/75",
[75084] = "1/75/75/75",
[75085] = "1/65/70/75",
[75090] = "1/75/75/75",
[75092] = "1/70/72/75",
[75094] = "1/65/70/75",
[75097] = "1/75/75/75",
[75099] = "1/75/75/75",
[75100] = "1/75/75/75",
[75101] = "1/70/72/75",
[75102] = "1/75/75/75",
[75103] = "1/75/75/75",
[75104] = "1/65/70/75",
[75105] = "1/75/75/75",
[75106] = "1/65/70/75",
[75107] = "1/75/75/75",
[75108] = "1/75/75/75",
[75109] = "1/70/72/75",
[75110] = "1/70/72/75",
[75111] = "1/75/75/75",
[75112] = "1/75/75/75",
[75113] = "1/70/72/75",
[75114] = "1/65/70/75",
[75115] = "1/75/75/75",
[75116] = "1/65/70/75",
[75117] = "1/65/70/75",
[75127] = "1/75/75/75",
[75130] = "1/70/72/75",
[75131] = "1/65/70/75",
[79101] = "1/1/5/10",
[83763] = "1/75/75/75",
[83764] = "1/75/75/75",
[83765] = "1/75/75/75",
[85559] = "1/10/15/20",
[85568] = "1/25/40/55",
[85569] = "1/35/50/65",
[85570] = "1/45/57/70",
[85787] = "1/75/75/75",
[85788] = "1/75/75/75",
[85789] = "1/75/75/75",
[85790] = "1/75/75/75",
[85791] = "1/75/75/75",
[85792] = "1/75/75/75",
[85793] = "1/75/75/75",
[85794] = "1/75/75/75",
[85795] = "1/75/75/75",
[85796] = "1/75/75/75",
[85797] = "1/75/75/75",
[85798] = "1/75/75/75",
[85799] = "1/75/75/75",
[85800] = "1/75/75/75",
[85801] = "1/75/75/75",
[85802] = "1/75/75/75",
[85803] = "1/75/75/75",
[85804] = "1/75/75/75",
[85805] = "1/75/75/75",
[85806] = "1/75/75/75",
[85807] = "1/75/75/75",
[85808] = "1/75/75/75",
[85809] = "1/75/75/75",
[85810] = "1/75/75/75",
[85811] = "1/75/75/75",
[85812] = "1/75/75/75",
[85813] = "1/75/75/75",
[85814] = "1/75/75/75",
[85815] = "1/75/75/75",
[85816] = "1/75/75/75",
[85817] = "1/75/75/75",
[85818] = "1/75/75/75",
[85819] = "1/75/75/75",
[85820] = "1/75/75/75",
[85821] = "1/75/75/75",
[85822] = "1/75/75/75",
[85823] = "1/75/75/75",
[85824] = "1/75/75/75",
[85825] = "1/75/75/75",
[85826] = "1/75/75/75",
[85827] = "1/75/75/75",
[85828] = "1/75/75/75",
[85829] = "1/75/75/75",
[85830] = "1/75/75/75",
[85831] = "1/75/75/75",
[85832] = "1/25/40/55",
[85833] = "1/15/30/45",
[85834] = "1/20/35/50",
[85835] = "1/50/62/75",
[85836] = "1/35/50/65",
[85837] = "1/45/57/70",
[85838] = "1/40/55/70",
[85839] = "1/30/45/60",
[85840] = "1/75/75/75",
[85841] = "1/20/35/50",
[85842] = "1/25/40/55",
[85843] = "1/15/30/45",
[85844] = "1/45/57/70",
[85845] = "1/30/45/60",
[85846] = "1/40/55/70",
[85847] = "1/50/62/75",
[85848] = "1/35/50/65",
[85849] = "1/75/75/75",
[85850] = "1/75/75/75",
[85851] = "1/45/57/70",
[85852] = "1/50/62/75",
[85853] = "1/50/62/75",
[93458] = "1/75/75/75",
[93459] = "1/75/75/75",
[93460] = "1/75/75/75",
[93461] = "1/75/75/75",
[93462] = "1/75/75/75",
[93463] = "1/75/75/75",
[93464] = "1/75/75/75",
[93465] = "1/75/75/75",
[93466] = "1/75/75/75",
[93467] = "1/75/75/75",
[93468] = "1/75/75/75",
[93469] = "1/75/75/75",
[93470] = "1/75/75/75",
[93472] = "1/75/75/75",
[93473] = "1/75/75/75",
[93474] = "1/75/75/75",
[93475] = "1/75/75/75",
[93476] = "1/75/75/75",
[93477] = "1/75/75/75",
[93478] = "1/75/75/75",
[93479] = "1/75/75/75",
[93488] = "1/75/75/75",
[93489] = "1/75/75/75",
[93490] = "1/75/75/75",
[93491] = "1/75/75/75",
[93492] = "1/75/75/75",
[93493] = "1/75/75/75",
[93494] = "1/75/75/75",
[93495] = "1/75/75/75",
[93496] = "1/75/75/75",
[93497] = "1/75/75/75",
[93498] = "1/75/75/75",
[93504] = "1/75/75/75",
[93505] = "1/75/75/75",
[93506] = "1/75/75/75",
[93507] = "1/75/75/75",
[93509] = "1/75/75/75",
[93511] = "1/75/75/75",
[93513] = "1/75/75/75",
[93515] = "1/75/75/75",
[93517] = "1/75/75/75",
[93519] = "1/75/75/75",
[93521] = "1/75/75/75",
[93523] = "1/75/75/75",
[93525] = "1/75/75/75",
[93566] = "1/75/75/75",
[93567] = "1/75/75/75",
[93568] = "1/75/75/75",
[93569] = "1/75/75/75",
[93570] = "1/75/75/75",
[93571] = "1/75/75/75",
[93572] = "1/75/75/75",
[93573] = "1/75/75/75",
[93574] = "1/75/75/75",
[93575] = "1/75/75/75",
[93576] = "1/75/75/75",
[93577] = "1/75/75/75",
[93578] = "1/75/75/75",
[93579] = "1/75/75/75",
[93580] = "1/75/75/75",
[93581] = "1/75/75/75",
[93582] = "1/75/75/75",
[93583] = "1/75/75/75",
[93584] = "1/75/75/75",
[93585] = "1/75/75/75",
[93586] = "1/75/75/75",
[93587] = "1/75/75/75",
[93588] = "1/75/75/75",
[93589] = "1/75/75/75",
[93590] = "1/75/75/75",
[93591] = "1/75/75/75",
[93592] = "1/75/75/75",
[93593] = "1/75/75/75",
[93594] = "1/75/75/75",
[94269] = "1/75/75/75",
[94270] = "1/75/75/75",
[94271] = "1/75/75/75",
[94272] = "1/75/75/75",
[94273] = "1/75/75/75",
[94274] = "1/75/75/75",
[94275] = "1/75/75/75",
[94276] = "1/75/75/75",
[95536] = "1/70/72/75",
[98600] = "1/75/75/75",
[98601] = "1/75/75/75",
[98604] = "1/75/75/75",
[98605] = "1/75/75/75",
[98609] = "1/75/75/75",
[98610] = "1/75/75/75",
[98613] = "1/75/75/75",
[98614] = "1/75/75/75",
[98617] = {[142976] = "1/75/75/75", [146923] = "1/75/75/75"},
[98789] = "1/75/75/75",
[98790] = "1/75/75/75",
[98791] = "1/75/75/75",
[98792] = "1/75/75/75",
[98793] = "1/75/75/75",
[98794] = "1/75/75/75",
[98795] = "1/75/75/75",
[98796] = "1/75/75/75",
[98797] = "1/75/75/75",
[98798] = "1/75/75/75",
[98799] = "1/75/75/75",
[98800] = "1/75/75/75",
[98801] = "1/75/75/75",
[98802] = "1/75/75/75",
[98803] = "1/75/75/75",
[98804] = "1/75/75/75",
[98805] = "1/75/75/75",
[98806] = "1/75/75/75",
[98807] = "1/75/75/75",
[98808] = "1/75/75/75",
[98809] = "1/75/75/75",
[98814] = "1/75/75/75",
[98815] = "1/75/75/75",
[98816] = "1/75/75/75",
[98817] = "1/75/75/75",
[98818] = "1/75/75/75",
[98819] = "1/75/75/75",
[98820] = "1/75/75/75",
[98821] = "1/75/75/75",
[98822] = "1/75/75/75",
[98823] = "1/75/75/75",
[98824] = "1/75/75/75",
[98830] = "1/75/75/75",
[98831] = "1/75/75/75",
[98832] = "1/75/75/75",
[98833] = "1/75/75/75",
[98834] = "1/75/75/75",
[98835] = "1/75/75/75",
[98836] = "1/75/75/75",
[98837] = "1/75/75/75",
[98838] = "1/75/75/75",
[98839] = "1/75/75/75",
[98840] = "1/75/75/75",
[98841] = "1/75/75/75",
[98842] = "1/75/75/75",
[98881] = "1/75/75/75",
[98882] = "1/75/75/75",
[98883] = "1/75/75/75",
[98884] = "1/75/75/75",
[98885] = "1/75/75/75",
[98886] = "1/75/75/75",
[98887] = "1/75/75/75",
[98888] = "1/75/75/75",
[98889] = "1/75/75/75",
[98890] = "1/75/75/75",
[98891] = "1/75/75/75",
[98892] = "1/75/75/75",
[98893] = "1/75/75/75",
[98894] = "1/75/75/75",
[98895] = "1/75/75/75",
[98896] = "1/75/75/75",
[98897] = "1/75/75/75",
[98898] = "1/75/75/75",
[98899] = "1/75/75/75",
[98900] = "1/75/75/75",
[98901] = "1/75/75/75",
[98902] = "1/75/75/75",
[98903] = "1/75/75/75",
[98904] = "1/75/75/75",
[98905] = "1/75/75/75",
[98906] = "1/75/75/75",
[98907] = "1/75/75/75",
[98908] = "1/75/75/75",
[98909] = "1/75/75/75",
[102351] = "1/70/72/75",
[108883] = "1/100/100/100",
[110611] = {[171391] = "1/1/50/100", [182121] = "1/100/100/100"},
[116164] = "1/50/55/60",
[116165] = "1/50/55/60",
[116166] = "1/50/55/60",
[116167] = "1/50/55/60",
[116168] = "1/50/55/60",
[116169] = "1/50/55/60",
[116170] = "1/100/100/100",
[116171] = "1/100/100/100",
[116174] = "1/100/100/100",
[116175] = "1/100/100/100",
[116176] = "1/100/100/100",
[116177] = "1/100/100/100",
[116178] = "1/100/100/100",
[116179] = "1/100/100/100",
[116180] = "1/100/100/100",
[116181] = "1/100/100/100",
[116182] = "1/100/100/100",
[116183] = "1/100/100/100",
[116187] = "1/100/100/100",
[116188] = "1/100/100/100",
[116189] = "1/100/100/100",
[116190] = "1/100/100/100",
[116191] = "1/100/100/100",
[116192] = "1/100/100/100",
[116193] = "1/100/100/100",
[116194] = "1/100/100/100",
[116259] = "1/100/100/100",
[116260] = "1/100/100/100",
[116261] = "1/100/100/100",
[116986] = "1/1/1/1",
[116987] = "1/1/1/1",
[116988] = "1/1/1/1",
[116989] = "1/1/1/1",
[116990] = "1/1/1/1",
[116991] = "1/1/1/1",
[116992] = "1/1/1/1",
[116993] = "1/1/1/1",
[116994] = "1/1/1/1",
[116995] = "1/1/1/1",
[116996] = "1/1/1/1",
[116997] = "1/1/1/1",
[116998] = "1/1/1/1",
[117000] = "1/1/1/1",
[117001] = "1/1/1/1",
[117002] = "1/1/1/1",
[117003] = "1/1/1/1",
[117004] = "1/1/1/1",
[117005] = "1/1/1/1",
[117006] = "1/1/1/1",
[117007] = "1/1/1/1",
[117008] = "1/1/1/1",
[117009] = "1/1/1/1",
[118721] = "1/1/50/100",
[120257] = "1/50/55/60",
[128876] = {[194702] = "1/20/30/40", [194710] = "1/40/50/60", [194718] = "1/60/70/80"},
[128877] = {[194701] = "1/20/30/40", [194709] = "1/40/50/60", [194715] = "1/60/70/80"},
[128878] = {[194700] = "1/20/30/40", [194708] = "1/40/50/60", [194714] = "1/60/70/80"},
[128879] = {[194699] = "1/20/30/40", [194707] = "1/40/50/60", [194713] = "1/60/70/80"},
[128880] = {[194698] = "1/20/30/40", [194706] = "1/40/50/60", [194712] = "1/60/70/80"},
[128881] = {[194697] = "1/20/30/40", [194705] = "1/40/50/60", [194717] = "1/60/70/80"},
[128882] = {[194696] = "1/20/30/40", [194704] = "1/40/50/60", [194716] = "1/60/70/80"},
[128883] = {[194695] = "1/20/30/40", [194703] = "1/40/50/60", [194711] = "1/60/70/80"},
[128884] = {[194726] = "1/80/90/100", [194734] = "1/100/100/100", [194791] = "1/60/70/80"},
[128885] = {[194725] = "1/80/90/100", [194733] = "1/100/100/100", [194785] = "1/60/70/80"},
[128886] = {[194724] = "1/80/90/100", [194732] = "1/100/100/100", [194790] = "1/60/70/80"},
[128887] = {[194723] = "1/80/90/100", [194731] = "1/100/100/100", [194784] = "1/60/70/80"},
[128888] = {[194722] = "1/80/90/100", [194730] = "1/100/100/100", [194786] = "1/60/70/80"},
[128889] = {[194721] = "1/80/90/100", [194729] = "1/100/100/100", [194789] = "1/60/70/80"},
[128890] = {[194720] = "1/80/90/100", [194728] = "1/100/100/100", [194788] = "1/60/70/80"},
[128891] = {[194719] = "1/80/90/100", [194727] = "1/100/100/100", [194787] = "1/60/70/80"},
[128892] = {[194742] = "1/20/30/40", [194750] = "1/40/50/60", [194758] = "1/60/70/80"},
[128893] = {[194741] = "1/20/30/40", [194749] = "1/40/50/60", [194755] = "1/60/70/80"},
[128894] = {[194740] = "1/20/30/40", [194748] = "1/40/50/60", [194754] = "1/60/70/80"},
[128895] = {[194739] = "1/20/30/40", [194747] = "1/40/50/60", [194753] = "1/60/70/80"},
[128896] = {[194738] = "1/20/30/40", [194746] = "1/40/50/60", [194752] = "1/60/70/80"},
[128897] = {[194737] = "1/20/30/40", [194745] = "1/40/50/60", [194757] = "1/60/70/80"},
[128898] = {[194736] = "1/20/30/40", [194744] = "1/40/50/60", [194756] = "1/60/70/80"},
[128899] = {[194735] = "1/20/30/40", [194743] = "1/40/50/60", [194751] = "1/60/70/80"},
[128900] = {[194766] = "1/80/90/100", [194774] = "1/100/100/100", [194795] = "1/60/70/80"},
[128901] = {[194765] = "1/80/90/100", [194773] = "1/100/100/100", [194793] = "1/60/70/80"},
[128902] = {[194764] = "1/80/90/100", [194772] = "1/100/100/100", [194799] = "1/60/70/80"},
[128903] = {[194763] = "1/80/90/100", [194771] = "1/100/100/100", [194794] = "1/60/70/80"},
[128904] = {[194762] = "1/80/90/100", [194770] = "1/100/100/100", [194792] = "1/60/70/80"},
[128905] = {[194761] = "1/80/90/100", [194769] = "1/100/100/100", [194798] = "1/60/70/80"},
[128906] = {[194760] = "1/80/90/100", [194768] = "1/100/100/100", [194797] = "1/60/70/80"},
[128907] = {[194759] = "1/80/90/100", [194767] = "1/100/100/100", [194796] = "1/60/70/80"},
[129956] = "1/20/45/70",
[129958] = "1/20/32/45",
[129960] = "1/20/45/70",
[129961] = "1/20/45/70",
[129962] = "1/100/100/100",
[129963] = "1/1/1/1",
[129964] = "1/1/1/1",
[129975] = "1/1/1/1",
[130090] = "1/1/1/1",
[130130] = "1/1/1/1",
[130869] = "1/1/1/1",
[130870] = "1/1/1/1",
[130872] = "1/1/1/1",
[130873] = {[196383] = "1/1/1/1", [196384] = "1/1/1/1"},
[130875] = {[196385] = "1/1/1/1", [208615] = "1/1/1/1"},
[130878] = "1/1/1/1",
[130879] = "1/1/1/1",
[130880] = "1/1/1/1",
[130887] = "1/1/1/1",
[130894] = "1/1/1/1",
[130895] = "1/1/1/1",
[130896] = "1/1/1/1",
[130937] = "1/1/1/1",
[131746] = "1/20/32/45",
[132487] = "85/115/130/145",
[132488] = "90/120/135/150",
[132489] = "70/110/125/140",
[132490] = "55/85/100/115",
[132491] = "70/100/115/130",
[132492] = "105/125/140/155",
[132493] = "95/125/137/150",
[132494] = "95/125/137/150",
[132495] = "120/150/162/175",
[132496] = "105/135/147/160",
[132497] = "110/140/152/165",
[132498] = "130/160/172/185",
[132499] = "115/145/157/170",
[132520] = "165/195/205/215",
[132521] = "190/220/230/240",
[132522] = "185/215/225/235",
[132532] = "155/185/195/205",
[132533] = "140/170/180/190",
[132534] = "150/180/190/200",
[132535] = "165/195/205/215",
[132536] = "190/220/230/240",
[132537] = "190/220/230/240",
[132538] = "165/195/205/215",
[132539] = "160/190/200/210",
[132540] = "180/210/220/230",
[132541] = "185/215/225/235",
[132542] = "150/180/190/200",
[132543] = "125/155/167/180",
[132544] = "190/220/230/240",
[132545] = "85/125/137/150",
[132546] = "135/165/175/185",
[132547] = "100/130/142/155",
[132548] = "90/120/135/150",
[136539] = "1/1/1/1",
[142406] = {[230936] = "1/20/40/60", [230954] = "1/40/50/60", [230955] = "1/60/70/80"},
[146668] = "1/100/100/100",
[146669] = "1/100/100/100",
[151577] = {[247800] = "1/90/95/100", [247801] = "1/90/95/100", [247802] = "1/90/95/100"},
[151578] = {[247803] = "1/90/95/100", [247804] = "1/90/95/100", [247805] = "1/90/95/100"},
[151791] = "1/300/300/300",
[152542] = "1/60/65/70",
[154138] = "1/50/75/100",
[154139] = "1/15/50/85",
[154140] = "1/15/50/85",
[154141] = "1/50/75/100",
[154142] = "1/25/55/85",
[154143] = "1/50/75/100",
[154144] = "1/15/50/85",
[154145] = "1/10/47/85",
[154146] = "1/50/75/100",
[154147] = "1/15/50/85",
[154148] = "1/15/50/85",
[154149] = "1/50/75/100",
[154150] = "1/25/55/85",
[154151] = "1/50/75/100",
[154152] = "1/15/50/85",
[154153] = "1/10/47/85",
[154159] = {[256787] = "1/100/117/135", [256788] = "1/115/132/150", [256789] = "1/120/135/150"},
[154160] = "1/25/55/85",
[154161] = "1/25/55/85",
[154162] = {[256779] = "1/100/117/135", [256780] = "1/115/132/150", [256781] = "1/120/135/150"},
[154163] = {[256782] = "1/100/117/135", [256783] = "1/115/132/150", [256784] = "1/120/135/150"},
[154166] = {[256790] = "1/85/105/125", [286019] = "1/110/120/130", [286021] = "1/115/125/135"},
[154167] = "1/150/150/150",
[154168] = "1/85/105/125",
[154169] = "1/75/100/125",
[159884] = {[269516] = "1/100/117/135", [269517] = "1/110/127/145", [269518] = "1/120/135/150"},
[159885] = {[269519] = "1/100/117/135", [269520] = "1/110/127/145", [269521] = "1/120/135/150"},
[159886] = {[269522] = "1/100/117/135", [269523] = "1/110/127/145", [269524] = "1/120/135/150"},
[159887] = {[269525] = "1/100/117/135", [269526] = "1/110/127/145", [269527] = "1/120/135/150"},
[159888] = {[269528] = "1/100/117/135", [269529] = "1/110/127/145", [269530] = "1/120/135/150"},
[159889] = {[269531] = "1/100/117/135", [269532] = "1/110/127/145", [269533] = "1/120/135/150"},
[159890] = {[269534] = "1/100/117/135", [269535] = "1/110/127/145", [269536] = "1/120/135/150"},
[159891] = {[269537] = "1/100/117/135", [269538] = "1/110/127/145", [269539] = "1/120/135/150"},
[159892] = {[269540] = "1/100/117/135", [269541] = "1/110/127/145", [269542] = "1/120/135/150"},
[159893] = {[269543] = "1/100/117/135", [269544] = "1/110/127/145", [269545] = "1/120/135/150"},
[159896] = {[269552] = "1/100/117/135", [269553] = "1/110/127/145", [269554] = "1/120/135/150"},
[161946] = "1/150/150/150",
[161947] = "1/150/150/150",
[161961] = "1/150/150/150",
[161962] = "1/150/150/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[162468] = "1/150/150/150",
[162470] = "1/150/150/150",
[162472] = "1/150/150/150",
[162474] = "1/150/150/150",
[162489] = "1/150/150/150",
[162490] = "1/150/150/150",
[162493] = "1/150/150/150",
[162494] = "1/150/150/150",
[164658] = {[282327] = "1/135/142/150", [282328] = "1/140/145/150", [282329] = "1/145/147/150"},
[164659] = {[282324] = "1/135/142/150", [282325] = "1/140/145/150", [282326] = "1/145/147/150"},
[164660] = {[282321] = "1/135/142/150", [282322] = "1/140/145/150", [282323] = "1/145/147/150"},
[164661] = {[282318] = "1/135/142/150", [282319] = "1/140/145/150", [282320] = "1/145/147/150"},
[164662] = {[282312] = "1/135/142/150", [282313] = "1/140/145/150", [282314] = "1/145/147/150"},
[164663] = {[282309] = "1/135/142/150", [282310] = "1/140/145/150", [282311] = "1/145/147/150"},
[164664] = {[282306] = "1/135/142/150", [282307] = "1/140/145/150", [282308] = "1/145/147/150"},
[164665] = {[282302] = "1/135/142/150", [282303] = "1/140/145/150", [282305] = "1/145/147/150"},
[164666] = {[282290] = "1/135/142/150", [282291] = "1/140/145/150", [282292] = "1/145/147/150"},
[164667] = {[282287] = "1/135/142/150", [282288] = "1/140/145/150", [282289] = "1/145/147/150"},
[164670] = {[282277] = "1/135/142/150", [282278] = "1/140/145/150", [282281] = "1/145/147/150"},
[164978] = "1/150/150/150",
[165382] = "1/150/150/150",
[165383] = "1/150/150/150",
[165388] = "1/150/150/150",
[165391] = "1/150/150/150",
[165396] = "1/150/150/150",
[165399] = "1/150/150/150",
[165404] = "1/150/150/150",
[165408] = "1/150/150/150",
[165412] = "1/150/150/150",
[165416] = "1/150/150/150",
[165420] = "1/150/150/150",
[165424] = "1/150/150/150",
[165699] = "1/100/112/125",
[165747] = "1/95/110/125",
[165749] = "1/95/110/125",
[167935] = {[294826] = "1/165/170/175", [294827] = "1/170/172/175", [294828] = "1/175/175/175"},
[167945] = {[294808] = "1/165/170/175", [294809] = "1/170/172/175", [294810] = "1/175/175/175"},
[167947] = {[294799] = "1/165/170/175", [294800] = "1/170/172/175", [294801] = "1/175/175/175"},
[167949] = {[294802] = "1/165/170/175", [294803] = "1/170/172/175", [294804] = "1/175/175/175"},
[167951] = {[294796] = "1/165/170/175", [294797] = "1/170/172/175", [294798] = "1/175/175/175"},
[167953] = {[294805] = "1/165/170/175", [294806] = "1/170/172/175", [294807] = "1/175/175/175"},
[167955] = {[294823] = "1/165/170/175", [294824] = "1/170/172/175", [294825] = "1/175/175/175"},
[167957] = {[294814] = "1/165/170/175", [294815] = "1/170/172/175", [294816] = "1/175/175/175"},
[167959] = {[294817] = "1/165/170/175", [294818] = "1/170/172/175", [294819] = "1/175/175/175"},
[167961] = {[294811] = "1/165/170/175", [294812] = "1/170/172/175", [294813] = "1/175/175/175"},
[167963] = {[294820] = "1/165/170/175", [294821] = "1/170/172/175", [294822] = "1/175/175/175"},
[168419] = {[301411] = "1/165/170/175", [324735] = "1/90/92/95"},
[168704] = "1/175/175/175",
[168705] = "1/175/175/175",
[168706] = "1/175/175/175",
[168707] = "1/175/175/175",
[168708] = "1/175/175/175",
[168709] = "1/175/175/175",
[168716] = "1/175/175/175",
[168717] = "1/175/175/175",
[168718] = "1/175/175/175",
[168719] = "1/175/175/175",
[168720] = "1/175/175/175",
[168721] = "1/175/175/175",
[169445] = "1/165/170/175",
[170342] = {[304415] = "1/165/170/175", [304416] = "1/165/170/175", [304417] = "1/165/170/175"},
[170343] = {[304424] = "1/165/170/175", [304425] = "1/165/170/175", [304426] = "1/165/170/175"},
[170344] = {[304418] = "1/165/170/175", [304419] = "1/165/170/175", [304420] = "1/165/170/175"},
[170345] = {[304412] = "1/165/170/175", [304413] = "1/165/170/175", [304414] = "1/165/170/175"},
[170346] = {[304421] = "1/165/170/175", [304422] = "1/165/170/175", [304423] = "1/165/170/175"},
[170352] = {[304439] = "1/165/170/175", [304440] = "1/165/170/175", [304441] = "1/165/170/175"},
[170353] = {[304430] = "1/165/170/175", [304431] = "1/165/170/175", [304432] = "1/165/170/175"},
[170354] = {[304433] = "1/165/170/175", [304434] = "1/165/170/175", [304435] = "1/165/170/175"},
[170355] = {[304427] = "1/165/170/175", [304428] = "1/165/170/175", [304429] = "1/165/170/175"},
[170356] = {[304436] = "1/165/170/175", [304437] = "1/165/170/175", [304438] = "1/165/170/175"},
[170362] = {[304442] = "1/165/167/170", [304443] = "1/165/167/170", [304444] = "1/165/167/170"},
[170432] = "1/175/175/175",
[170433] = "1/175/175/175",
[170434] = "1/175/175/175",
[170435] = "1/175/175/175",
[170436] = "1/175/175/175",
[170437] = "1/175/175/175",
[170438] = "1/175/175/175",
[170439] = "1/175/175/175",
[170440] = "1/175/175/175",
[170441] = "1/175/175/175",
[170442] = "1/175/175/175",
[170443] = "1/175/175/175",
[171320] = "1/200/200/200",
[172096] = "1/80/82/85",
[172097] = "1/90/92/95",
[172233] = "1/110/112/115",
[172234] = "1/40/45/50",
[172235] = "1/10/15/20",
[172236] = "1/25/30/35",
[172237] = "1/35/40/45",
[172238] = "1/45/50/55",
[172239] = "1/50/55/60",
[172240] = "1/20/25/30",
[172241] = "1/10/15/20",
[172242] = "1/40/45/50",
[172243] = "1/10/15/20",
[172244] = "1/25/30/35",
[172245] = "1/35/40/45",
[172246] = "1/45/50/55",
[172247] = "1/50/55/60",
[172248] = "1/20/25/30",
[172249] = "1/10/15/20",
[172250] = "1/90/95/100",
[172251] = "1/65/70/75",
[172252] = "1/75/80/85",
[172253] = "1/85/90/95",
[172254] = "1/100/100/100",
[172255] = "1/100/100/100",
[172256] = "1/70/75/80",
[172257] = "1/60/65/70",
[172258] = "1/90/95/100",
[172259] = "1/65/70/75",
[172260] = "1/75/80/85",
[172261] = "1/85/90/95",
[172262] = "1/100/100/100",
[172263] = "1/100/100/100",
[172264] = "1/70/75/80",
[172265] = "1/60/65/70",
[172314] = {[309199] = "1/110/112/115", [332015] = "1/110/112/115", [332050] = "1/110/112/115", [338979] = "1/110/112/115"},
[172315] = {[309198] = "1/110/112/115", [332014] = "1/110/112/115", [332049] = "1/110/112/115", [338980] = "1/110/112/115"},
[172316] = {[309200] = "1/110/112/115", [332016] = "1/110/112/115", [332051] = "1/110/112/115", [338981] = "1/110/112/115"},
[172317] = {[309201] = "1/110/112/115", [332017] = "1/110/112/115", [332052] = "1/110/112/115", [338982] = "1/110/112/115"},
[172318] = {[309202] = "1/110/112/115", [332018] = "1/110/112/115", [332053] = "1/110/112/115", [338983] = "1/110/112/115"},
[172319] = {[309203] = "1/110/112/115", [332019] = "1/110/112/115", [332054] = "1/110/112/115", [338984] = "1/110/112/115"},
[172320] = {[309204] = "1/110/112/115", [332020] = "1/110/112/115", [332055] = "1/110/112/115", [338985] = "1/110/112/115"},
[172321] = {[309205] = "1/110/112/115", [332021] = "1/110/112/115", [332056] = "1/110/112/115", [338986] = "1/110/112/115"},
[172322] = {[309207] = "1/110/112/115", [332023] = "1/110/112/115", [332058] = "1/110/112/115", [338987] = "1/110/112/115"},
[172323] = {[309206] = "1/110/112/115", [332022] = "1/110/112/115", [332057] = "1/110/112/115", [338988] = "1/110/112/115"},
[172324] = {[309208] = "1/110/112/115", [332024] = "1/110/112/115", [332059] = "1/110/112/115", [338989] = "1/110/112/115"},
[172325] = {[309209] = "1/110/112/115", [332025] = "1/110/112/115", [332060] = "1/110/112/115", [338990] = "1/110/112/115"},
[172326] = {[309210] = "1/110/112/115", [332026] = "1/110/112/115", [332061] = "1/110/112/115", [338991] = "1/110/112/115"},
[172327] = {[309211] = "1/110/112/115", [332027] = "1/110/112/115", [332062] = "1/110/112/115", [338992] = "1/110/112/115"},
[172328] = {[309212] = "1/110/112/115", [332028] = "1/110/112/115", [332063] = "1/110/112/115", [338993] = "1/110/112/115"},
[172329] = {[309213] = "1/110/112/115", [332029] = "1/110/112/115", [332064] = "1/110/112/115", [338994] = "1/110/112/115"},
[172346] = "1/10/12/15",
[172347] = "1/60/62/65",
[172348] = "1/25/27/30",
[172349] = "1/45/47/50",
[172350] = "1/40/42/45",
[172351] = "1/55/57/60",
[173381] = "1/55/60/65",
[173382] = "1/75/80/85",
[173383] = "1/90/92/95",
[173384] = "1/200/200/200",
[180055] = {[330180] = "1/1/10/20", [330186] = "1/1/10/20", [330191] = "1/1/10/20", [330196] = "1/1/10/20", [330201] = "1/1/10/20", [330206] = "1/1/10/20", [330211] = "1/1/10/20", [330216] = "1/1/10/20"},
[180057] = {[330181] = "1/1/10/20", [330187] = "1/1/10/20", [330192] = "1/1/10/20", [330197] = "1/1/10/20", [330202] = "1/1/10/20", [330207] = "1/1/10/20", [330212] = "1/1/10/20", [330218] = "1/1/10/20"},
[180058] = {[330183] = "1/1/10/20", [330188] = "1/1/10/20", [330193] = "1/1/10/20", [330198] = "1/1/10/20", [330203] = "1/1/10/20", [330208] = "1/1/10/20", [330213] = "1/1/10/20", [330219] = "1/1/10/20"},
[180059] = {[330184] = "1/1/10/20", [330189] = "1/1/10/20", [330194] = "1/1/10/20", [330199] = "1/1/10/20", [330204] = "1/1/10/20", [330209] = "1/1/10/20", [330214] = "1/1/10/20", [330220] = "1/1/10/20"},
[180060] = {[330185] = "1/1/10/20", [330190] = "1/1/10/20", [330195] = "1/1/10/20", [330200] = "1/1/10/20", [330205] = "1/1/10/20", [330210] = "1/1/10/20", [330215] = "1/1/10/20", [330221] = "1/1/10/20"},
[183942] = "1/50/55/60",
[185960] = "1/110/112/115",
[186686] = "1/55/60/65",
[186702] = "1/80/82/85",
[186985] = "1/100/100/100",
-- Unknown item created by: Pandaria Patterns (255) - Primal Leg Reinforcements (124559)
-- Unknown item created by: Pandaria Patterns (255) - Draconic Leg Reinforcements (124561)
-- Unknown item created by: Pandaria Patterns (255) - Heavy Leg Reinforcements (124563)
-- Invalid recipe: Legion Patterns (140) - Drum of Primal Might (293135)
-- Invalid recipe: Shadowlands Patterns (126) - Dyed Runestag Leather (338253)
-- Invalid recipe: Shadowlands Patterns (126) - Runestag Leather Strap (338254)
-- Invalid recipe: Shadowlands Patterns (126) - Stalker's Leather Quiver (338255)
-- Invalid recipe: Shadowlands Patterns (126) - Steelhide Leather Harness (338257)
-- Invalid recipe: Shadowlands Patterns (126) - Steelhide Leather Belt (338258)
-- Invalid recipe: Shadowlands Patterns (126) - Steelhide Leather Strap (338259)
-- Invalid recipe: Shadowlands Patterns (126) - Bonestudded Fist (338260)
-- Invalid recipe: Shadowlands Patterns (126) - Cleaned Hide (338262)
-- Invalid recipe: Shadowlands Patterns (126) - Courtly Leather Boots (338263)
-- Invalid recipe: Shadowlands Patterns (126) - Tortured Sole (338264)
-- Invalid recipe: Shadowlands Patterns (126) - Softened Leather (338265)



-- mining
[2840] = "1/20/40/60",
[2841] = "50/50/75/100",
[2842] = "65/100/105/110",
[3575] = "100/100/125/150",
[3576] = "1/50/57/75",
[3577] = "115/150/155/160",
[3859] = "125/125/130/135",
[3860] = "150/150/175/200",
[6037] = "165/200/205/210",
[11371] = "1/300/305/310",
[12359] = "200/200/245/290",
[12655] = "250/250/270/290",
[17771] = "1/300/300/300",
[22573] = "1/1/5/10",
[22574] = "1/1/5/10",
[23445] = "1/1/13/25",
[23446] = "1/25/32/40",
[23447] = "1/50/57/65",
[23448] = "1/40/57/75",
[23449] = "1/75/75/75",
[23573] = "1/75/75/75",
[35128] = "1/75/75/75",
[36913] = "1/50/62/75",
[36916] = "1/1/13/25",
[37663] = "1/75/75/75",
[41163] = "1/75/75/75",
[51950] = "1/75/75/75",
[52186] = "1/1/25/50",
[53039] = "1/50/62/75",
[54849] = "1/1/13/25",
[72095] = "1/75/75/75",
[72096] = "1/1/25/50",



-- tailoring
[1251] = "1/40/50/60",
[2568] = "10/45/57/70",
[2569] = "65/90/107/125",
[2570] = "1/35/47/60",
[2572] = "1/65/82/100",
[2575] = "40/65/82/100",
[2576] = "1/35/47/60",
[2577] = "40/65/82/100",
[2578] = "70/95/112/130",
[2579] = "70/95/112/130",
[2580] = "60/85/102/120",
[2581] = "1/80/90/100",
[2582] = "85/110/127/145",
[2583] = "95/120/137/155",
[2584] = "75/100/117/135",
[2585] = "1/130/147/165",
[2587] = "100/110/120/130",
[2996] = "1/25/37/50",
[2997] = "75/90/97/105",
[3530] = "1/115/132/150",
[3531] = "1/150/167/185",
[4238] = "45/70/87/105",
[4240] = "80/105/122/140",
[4241] = "1/120/137/155",
[4245] = "150/170/185/200",
[4305] = "125/135/140/145",
[4307] = "35/60/77/95",
[4308] = "60/85/102/120",
[4309] = "70/95/112/130",
[4310] = "85/110/127/145",
[4311] = "1/125/142/160",
[4312] = "80/105/122/140",
[4313] = "1/120/137/155",
[4314] = "110/135/152/170",
[4315] = "1/145/162/180",
[4316] = "110/135/152/170",
[4317] = "1/150/167/185",
[4318] = "130/150/165/180",
[4319] = "1/165/180/195",
[4320] = "125/150/167/185",
[4321] = "1/160/175/190",
[4322] = "1/185/200/215",
[4323] = "1/190/205/220",
[4324] = "150/170/185/200",
[4325] = "1/195/210/225",
[4326] = "185/205/220/235",
[4327] = "1/220/235/250",
[4328] = "1/200/215/230",
[4329] = "1/220/235/250",
[4330] = "110/135/152/170",
[4331] = "1/150/167/185",
[4332] = "1/145/150/155",
[4333] = "1/165/170/175",
[4334] = "170/180/185/190",
[4335] = "1/195/200/205",
[4336] = "1/210/215/220",
[4339] = "175/180/182/185",
[4343] = "30/55/72/90",
[4344] = "1/35/47/60",
[5542] = "90/115/132/150",
[5762] = "1/95/112/130",
[5763] = "1/140/157/175",
[5764] = "1/195/210/225",
[5765] = "1/205/220/235",
[5766] = "135/155/170/185",
[5770] = "1/170/185/200",
[6238] = "30/55/72/90",
[6239] = "1/80/97/115",
[6240] = "1/80/97/115",
[6241] = "30/55/72/90",
[6242] = "1/95/112/130",
[6263] = "1/125/142/160",
[6264] = "1/140/157/175",
[6384] = "1/145/162/180",
[6385] = "1/145/162/180",
[6450] = "1/180/195/210",
[6451] = "1/210/225/240",
[6786] = "40/65/82/100",
[6787] = "110/135/152/170",
[6795] = "160/170/175/180",
[6796] = "175/185/190/195",
[6836] = "1/255/270/285",
[7026] = "15/50/67/85",
[7046] = "140/160/175/190",
[7047] = "1/165/180/195",
[7048] = "145/155/160/165",
[7049] = "1/170/185/200",
[7050] = "160/170/175/180",
[7051] = "170/190/205/220",
[7052] = "175/195/210/225",
[7053] = "1/195/210/225",
[7054] = "190/210/225/240",
[7055] = "175/195/210/225",
[7056] = "1/200/215/230",
[7057] = "180/200/215/230",
[7058] = "185/205/215/225",
[7059] = "1/210/225/240",
[7060] = "1/210/225/240",
[7061] = "1/215/230/245",
[7062] = "195/215/225/235",
[7063] = "1/220/235/250",
[7064] = "210/225/240/255",
[7065] = "1/185/200/215",
[8544] = "1/240/245/250",
[8545] = "1/260/267/275",
[9998] = "205/220/235/250",
[9999] = "205/220/235/250",
[10001] = "210/225/240/255",
[10002] = "210/225/240/255",
[10003] = "215/230/245/260",
[10004] = "215/230/245/260",
[10007] = "1/230/245/260",
[10008] = "1/220/225/230",
[10009] = "1/230/245/260",
[10018] = "1/240/255/270",
[10019] = "225/240/255/270",
[10021] = "225/240/255/270",
[10023] = "225/240/255/270",
[10024] = "230/245/260/275",
[10025] = "1/260/275/290",
[10026] = "230/245/260/275",
[10027] = "230/245/260/275",
[10028] = "235/250/265/280",
[10029] = "1/250/265/280",
[10030] = "1/255/270/285",
[10031] = "240/255/270/285",
[10033] = "1/255/270/285",
[10034] = "1/245/250/255",
[10035] = "1/250/255/260",
[10036] = "1/265/280/295",
[10040] = "1/255/260/265",
[10041] = "250/265/280/295",
[10042] = "225/240/255/270",
[10044] = "245/260/275/290",
[10045] = "1/35/47/60",
[10046] = "20/50/67/85",
[10047] = "75/100/117/135",
[10048] = "1/145/162/180",
[10050] = "225/240/255/270",
[10051] = "235/250/265/280",
[10052] = "1/225/230/235",
[10053] = "235/240/245/250",
[10054] = "1/235/240/245",
[10055] = "1/240/245/250",
[10056] = "215/220/225/230",
[13856] = "255/270/285/300",
[13857] = "260/275/287/300",
[13858] = "260/275/287/300",
[13860] = "265/280/290/300",
[13863] = "275/290/295/300",
[13864] = "280/295/297/300",
[13865] = "285/300/300/300",
[13866] = "295/300/300/300",
[13867] = "300/300/300/300",
[13868] = "1/270/285/300",
[13869] = "255/270/285/300",
[13870] = "265/280/290/300",
[13871] = "280/295/297/300",
[14042] = "1/275/287/300",
[14043] = "1/285/292/300",
[14044] = "1/290/295/300",
[14045] = "1/295/297/300",
[14046] = "1/275/287/300",
[14048] = "250/255/257/260",
[14100] = "270/285/292/300",
[14101] = "270/285/292/300",
[14103] = "275/290/295/300",
[14104] = "1/300/300/300",
[14106] = "300/300/300/300",
[14107] = "1/290/295/300",
[14108] = "285/300/300/300",
[14111] = "290/300/300/300",
[14112] = "300/300/300/300",
[14128] = "300/300/300/300",
[14130] = "300/300/300/300",
[14132] = "275/290/295/300",
[14134] = "1/290/295/300",
[14136] = "1/300/300/300",
[14137] = "1/300/300/300",
[14138] = "1/300/300/300",
[14139] = "1/300/300/300",
[14140] = "1/300/300/300",
[14141] = "275/290/295/300",
[14142] = "270/285/292/300",
[14143] = "265/280/290/300",
[14144] = "290/300/300/300",
[14146] = "1/300/300/300",
[14152] = "1/300/300/300",
[14153] = "1/300/300/300",
[14154] = "1/300/300/300",
[14155] = "1/300/300/300",
[14156] = "1/300/300/300",
[14342] = "1/290/295/300",
[14529] = "1/290/295/300",
[14530] = "1/300/300/300",
[15802] = "1/295/297/300",
[16979] = "1/300/300/300",
[16980] = "1/300/300/300",
[17723] = "1/200/205/210",
[18258] = "1/285/290/295",
[18263] = "1/300/300/300",
[18405] = "1/300/300/300",
[18407] = "1/300/300/300",
[18408] = "1/300/300/300",
[18409] = "1/300/300/300",
[18413] = "1/300/300/300",
[18486] = "1/300/300/300",
[19047] = "1/300/300/300",
[19050] = "1/300/300/300",
[19056] = "1/300/300/300",
[19059] = "1/300/300/300",
[19156] = "1/300/300/300",
[19165] = "1/300/300/300",
[19682] = "1/300/300/300",
[19683] = "1/300/300/300",
[19684] = "1/300/300/300",
[20537] = "1/300/300/300",
[20538] = "1/300/300/300",
[20539] = "1/300/300/300",
[21340] = "1/275/287/300",
[21341] = "1/300/300/300",
[21342] = "1/300/300/300",
[21840] = "1/5/15/25",
[21841] = "1/20/30/40",
[21842] = "1/30/35/40",
[21843] = "1/40/45/50",
[21844] = "1/45/50/55",
[21845] = "1/50/55/60",
[21846] = "1/65/70/75",
[21847] = "1/75/75/75",
[21848] = "1/75/75/75",
[21849] = "1/20/25/30",
[21850] = "1/20/25/30",
[21851] = "1/30/35/40",
[21852] = "1/35/40/45",
[21853] = "1/45/50/55",
[21854] = "1/50/55/60",
[21855] = "1/55/60/65",
[21858] = "1/75/75/75",
[21859] = "1/50/55/60",
[21860] = "1/60/65/70",
[21861] = "1/70/72/75",
[21862] = "1/70/72/75",
[21863] = "1/65/70/75",
[21864] = "1/75/75/75",
[21865] = "1/75/75/75",
[21866] = "1/60/65/70",
[21867] = "1/70/72/75",
[21868] = "1/75/75/75",
[21869] = "1/65/70/75",
[21870] = "1/75/75/75",
[21871] = "1/75/75/75",
[21872] = "1/75/75/75",
[21873] = "1/65/70/75",
[21874] = "1/75/75/75",
[21875] = "1/75/75/75",
[21876] = "1/75/75/75",
[21990] = "1/30/47/65",
[21991] = "1/50/62/75",
[22246] = "1/240/255/270",
[22248] = "1/290/295/300",
[22249] = "1/15/30/45",
[22251] = "1/290/295/300",
[22252] = "1/15/30/45",
[22652] = "1/15/30/45",
[22654] = "1/15/30/45",
[22655] = "1/15/30/45",
[22658] = "1/15/30/45",
[22660] = "1/300/300/300",
[22756] = "1/300/300/300",
[22757] = "1/300/300/300",
[22758] = "1/300/300/300",
[24249] = "1/60/65/70",
[24250] = "1/60/65/70",
[24251] = "1/60/65/70",
[24252] = "1/60/65/70",
[24253] = "1/60/65/70",
[24254] = "1/60/65/70",
[24255] = "1/75/75/75",
[24256] = "1/75/75/75",
[24257] = "1/75/75/75",
[24258] = "1/75/75/75",
[24259] = "1/75/75/75",
[24260] = "1/75/75/75",
[24261] = "1/75/75/75",
[24262] = "1/75/75/75",
[24263] = "1/75/75/75",
[24264] = "1/75/75/75",
[24266] = "1/75/75/75",
[24267] = "1/75/75/75",
[24268] = "1/1/10/20",
[24270] = "1/50/55/60",
[24271] = "1/50/55/60",
[24272] = "1/50/55/60",
[24273] = "1/45/50/55",
[24274] = "1/75/75/75",
[24275] = "1/45/50/55",
[24276] = "1/75/75/75",
[30035] = "1/75/75/75",
[30036] = "1/75/75/75",
[30037] = "1/75/75/75",
[30038] = "1/75/75/75",
[30831] = "1/60/65/70",
[30837] = "1/60/65/70",
[30838] = "1/70/72/75",
[30839] = "1/75/75/75",
[32389] = "1/75/75/75",
[32390] = "1/75/75/75",
[32391] = "1/75/75/75",
[32392] = "1/75/75/75",
[32420] = "1/75/75/75",
[32584] = "1/375/375/375",
[32585] = "1/375/375/375",
[32586] = "1/375/375/375",
[32587] = "1/375/375/375",
[34364] = "1/365/365/365",
[34365] = "1/365/365/365",
[34366] = "1/365/365/365",
[34367] = "1/365/365/365",
[34721] = "1/15/25/35",
[34722] = "1/50/62/75",
[38225] = "1/75/75/75",
[38277] = "1/265/280/295",
[38278] = "1/250/255/260",
[41248] = "1/25/30/35",
[41249] = "1/25/30/35",
[41250] = "1/25/30/35",
[41251] = "1/25/30/35",
[41252] = "1/25/30/35",
[41253] = "1/25/30/35",
[41254] = "1/25/30/35",
[41255] = "1/25/30/35",
[41509] = "1/1/3/5",
[41510] = "1/1/3/5",
[41511] = "1/25/27/30",
[41512] = "1/1/3/5",
[41513] = "1/1/3/5",
[41515] = "1/1/8/15",
[41516] = "1/55/65/75",
[41519] = "1/15/25/35",
[41520] = "1/10/20/30",
[41521] = "1/15/25/35",
[41522] = "1/5/15/25",
[41523] = "1/20/30/40",
[41525] = "1/25/35/45",
[41528] = "1/20/30/40",
[41543] = "1/25/30/35",
[41544] = "1/45/50/55",
[41545] = "1/40/45/50",
[41546] = "1/30/35/40",
[41548] = "1/30/35/40",
[41549] = "1/40/45/50",
[41550] = "1/45/50/55",
[41551] = "1/35/40/45",
[41553] = "1/50/55/60",
[41554] = "1/55/60/65",
[41555] = "1/50/55/60",
[41593] = "1/50/55/60",
[41594] = "1/50/55/60",
[41595] = "1/50/55/60",
[41597] = "1/65/70/75",
[41598] = "1/70/72/75",
[41599] = "1/55/65/75",
[41600] = "1/75/75/75",
[41601] = "1/25/30/35",
[41602] = "1/60/65/70",
[41603] = "1/25/30/35",
[41604] = "1/60/65/70",
[41607] = "1/20/25/30",
[41608] = "1/25/30/35",
[41609] = "1/60/67/75",
[41610] = "1/60/67/75",
[41984] = "1/60/65/70",
[41985] = "1/55/65/75",
[41986] = "1/55/65/75",
[42093] = "1/60/65/70",
[42095] = "1/55/65/75",
[42096] = "1/55/65/75",
[42100] = "1/75/75/75",
[42101] = "1/75/75/75",
[42102] = "1/75/75/75",
[42103] = "1/70/72/75",
[42111] = "1/70/72/75",
[42113] = "1/70/72/75",
[43583] = "1/60/67/75",
[43584] = "1/55/65/75",
[43585] = "1/55/65/75",
[43969] = "1/50/60/70",
[43970] = "1/55/65/75",
[43971] = "1/55/65/75",
[43972] = "1/55/65/75",
[43973] = "1/55/65/75",
[43974] = "1/50/60/70",
[43975] = "1/55/65/75",
[44211] = "1/1/8/15",
[44554] = "1/1/3/5",
[44558] = "1/60/67/75",
[45557] = "1/75/75/75",
[45558] = "1/75/75/75",
[45566] = "1/75/75/75",
[45567] = "1/75/75/75",
[45626] = "125/150/167/185",
[45773] = "1/65/70/75",
[45810] = "1/35/40/45",
[45811] = "1/30/35/40",
[47585] = "1/75/75/75",
[47586] = "1/75/75/75",
[47587] = "1/75/75/75",
[47588] = "1/75/75/75",
[47603] = "1/75/75/75",
[47604] = "1/75/75/75",
[47605] = "1/75/75/75",
[47606] = "1/75/75/75",
[49890] = "1/75/75/75",
[49891] = "1/75/75/75",
[49892] = "1/75/75/75",
[49893] = "1/75/75/75",
[53049] = "1/25/30/35",
[53050] = "1/50/62/75",
[53051] = {[74558] = "1/30/47/65", [88893] = "1/30/47/65"},
[53643] = "1/1/3/5",
[54440] = {[75141] = "1/75/75/75", [75142] = "1/75/75/75", [75144] = "1/75/75/75", [75145] = "1/75/75/75", [75146] = "1/75/75/75", [94743] = "1/75/75/75"},
[54441] = "1/55/60/65",
[54442] = "1/1/3/5",
[54443] = "1/40/42/45",
[54444] = "1/75/75/75",
[54445] = "1/40/42/45",
[54446] = "1/50/52/55",
[54447] = "1/15/17/20",
[54448] = "1/75/75/75",
[54449] = "1/20/22/25",
[54450] = "1/75/75/75",
[54451] = "1/75/75/75",
[54471] = "1/5/10/15",
[54472] = "1/15/20/25",
[54473] = "1/5/10/15",
[54474] = "1/10/15/20",
[54475] = "1/25/27/30",
[54476] = "1/20/25/30",
[54477] = "1/10/15/20",
[54478] = "1/20/22/25",
[54479] = "1/35/37/40",
[54480] = "1/25/30/35",
[54481] = "1/25/30/35",
[54482] = "1/30/35/40",
[54483] = "1/35/40/45",
[54484] = "1/35/40/45",
[54485] = "1/50/52/55",
[54486] = "1/50/52/55",
[54503] = "1/75/75/75",
[54504] = "1/75/75/75",
[54505] = "1/75/75/75",
[54506] = "1/75/75/75",
[54797] = "1/60/67/75",
[69944] = "1/75/75/75",
[69945] = "1/75/75/75",
[69953] = "1/75/75/75",
[69954] = "1/75/75/75",
[70138] = "1/40/42/45",
[71980] = "1/75/75/75",
[71981] = "1/75/75/75",
[71989] = "1/75/75/75",
[71990] = "1/75/75/75",
[72985] = "1/25/27/30",
[72986] = "1/30/47/65",
[75062] = "1/75/75/75",
[75063] = "1/75/75/75",
[75064] = "1/60/65/70",
[75065] = "1/50/52/55",
[75070] = "1/70/72/75",
[75072] = "1/75/75/75",
[75073] = "1/75/75/75",
[75082] = "1/75/75/75",
[75086] = "1/65/70/75",
[75087] = "1/70/72/75",
[75088] = "1/75/75/75",
[75089] = "1/55/60/65",
[75091] = "1/65/70/75",
[75093] = "1/75/75/75",
[75095] = "1/75/75/75",
[75096] = "1/65/70/75",
[75098] = "1/55/60/65",
[82397] = "1/50/60/70",
[82398] = "1/30/40/50",
[82399] = "1/50/60/70",
[82400] = "1/20/30/40",
[82401] = "1/40/50/60",
[82402] = "1/20/30/40",
[82403] = "1/40/50/60",
[82404] = "1/30/40/50",
[82421] = "1/75/75/75",
[82422] = "1/75/75/75",
[82423] = "1/75/75/75",
[82424] = "1/75/75/75",
[82425] = "1/75/75/75",
[82426] = "1/75/75/75",
[82427] = "1/75/75/75",
[82428] = "1/75/75/75",
[82429] = "1/75/75/75",
[82430] = "1/75/75/75",
[82431] = "1/75/75/75",
[82432] = "1/75/75/75",
[82433] = "1/75/75/75",
[82434] = "1/75/75/75",
[82435] = "1/75/75/75",
[82436] = "1/75/75/75",
[82437] = "1/75/75/75",
[82438] = "1/75/75/75",
[82439] = "1/75/75/75",
[82440] = "1/75/75/75",
[82441] = "1/1/5/10",
[82442] = "1/25/35/45",
[82443] = "1/35/45/55",
[82444] = "1/75/75/75",
[82445] = "1/75/75/75",
[82446] = "1/75/75/75",
[82447] = "1/75/75/75",
[86311] = "1/75/75/75",
[86312] = "1/75/75/75",
[86313] = "1/75/75/75",
[86314] = "1/75/75/75",
[92726] = "1/1/3/5",
[92960] = "1/45/55/65",
[93420] = "1/75/75/75",
[93421] = "1/75/75/75",
[93428] = "1/75/75/75",
[93429] = "1/75/75/75",
[93430] = "1/75/75/75",
[93431] = "1/75/75/75",
[93432] = "1/75/75/75",
[93433] = "1/75/75/75",
[93434] = "1/75/75/75",
[93435] = "1/75/75/75",
[93436] = "1/75/75/75",
[93437] = "1/75/75/75",
[93438] = "1/75/75/75",
[93439] = "1/75/75/75",
[93499] = "1/75/75/75",
[93500] = "1/75/75/75",
[93501] = "1/75/75/75",
[93502] = "1/75/75/75",
[93503] = "1/75/75/75",
[93550] = "1/75/75/75",
[93551] = "1/75/75/75",
[93552] = "1/75/75/75",
[93553] = "1/75/75/75",
[93554] = "1/75/75/75",
[93555] = "1/75/75/75",
[93556] = "1/75/75/75",
[93557] = "1/75/75/75",
[93558] = "1/75/75/75",
[93559] = "1/75/75/75",
[93607] = "1/75/75/75",
[93608] = "1/75/75/75",
[93615] = "1/75/75/75",
[93616] = "1/75/75/75",
[93617] = "1/75/75/75",
[93618] = "1/75/75/75",
[93619] = "1/75/75/75",
[94277] = "1/75/75/75",
[94278] = "1/75/75/75",
[94279] = "1/75/75/75",
[94280] = "1/75/75/75",
[98599] = "1/75/75/75",
[98603] = "1/75/75/75",
[98608] = "1/75/75/75",
[98612] = "1/75/75/75",
[98619] = {[143011] = "1/75/75/75", [146925] = "1/75/75/75"},
[98756] = "1/75/75/75",
[98757] = "1/75/75/75",
[98763] = "1/75/75/75",
[98764] = "1/75/75/75",
[98765] = "1/75/75/75",
[98766] = "1/75/75/75",
[98767] = "1/75/75/75",
[98768] = "1/75/75/75",
[98769] = "1/75/75/75",
[98770] = "1/75/75/75",
[98771] = "1/75/75/75",
[98772] = "1/75/75/75",
[98773] = "1/75/75/75",
[98774] = "1/75/75/75",
[98825] = "1/75/75/75",
[98826] = "1/75/75/75",
[98827] = "1/75/75/75",
[98828] = "1/75/75/75",
[98829] = "1/75/75/75",
[98865] = "1/75/75/75",
[98866] = "1/75/75/75",
[98867] = "1/75/75/75",
[98868] = "1/75/75/75",
[98869] = "1/75/75/75",
[98870] = "1/75/75/75",
[98871] = "1/75/75/75",
[98872] = "1/75/75/75",
[98873] = "1/75/75/75",
[98874] = "1/75/75/75",
[98913] = "1/75/75/75",
[98914] = "1/75/75/75",
[98921] = "1/75/75/75",
[98922] = "1/75/75/75",
[98923] = "1/75/75/75",
[98924] = "1/75/75/75",
[98925] = "1/75/75/75",
[111556] = {[168835] = "1/1/50/100", [182123] = "1/100/100/100"},
[111603] = "1/1/25/50",
[113216] = "1/100/100/100",
[114809] = "1/100/100/100",
[114810] = "1/100/100/100",
[114811] = "1/100/100/100",
[114812] = "1/100/100/100",
[114813] = "1/100/100/100",
[114814] = "1/100/100/100",
[114815] = "1/100/100/100",
[114816] = "1/100/100/100",
[114817] = "1/100/100/100",
[114818] = "1/100/100/100",
[114819] = "1/100/100/100",
[114821] = "1/100/100/100",
[114828] = "1/50/55/60",
[114829] = "1/50/55/60",
[114831] = "1/50/55/60",
[114836] = "1/100/100/100",
[115363] = "1/100/100/100",
[118115] = "1/1/1/1",
[118123] = "1/1/1/1",
[118670] = "1/1/1/1",
[118722] = "1/1/50/100",
[119035] = "1/1/1/1",
[126987] = {[185925] = "1/20/30/40", [185941] = "1/40/50/60", [185945] = "1/60/70/80"},
[126988] = {[185924] = "1/20/30/40", [185940] = "1/40/50/60", [208352] = "1/60/70/80"},
[126989] = {[185923] = "1/20/30/40", [185939] = "1/40/50/60", [208350] = "1/60/70/80"},
[126990] = {[185922] = "1/20/30/40", [185938] = "1/40/50/60", [208351] = "1/60/70/80"},
[126991] = {[185921] = "1/20/30/40", [185937] = "1/40/50/60", [208353] = "1/60/70/80"},
[126992] = {[185920] = "1/20/30/40", [185936] = "1/40/50/60", [185944] = "1/60/70/80"},
[126993] = {[185919] = "1/20/30/40", [185935] = "1/40/50/60", [185943] = "1/60/70/80"},
[126994] = {[185918] = "1/20/30/40", [185934] = "1/40/50/60", [185942] = "1/60/70/80"},
[126995] = {[185933] = "1/60/70/80", [185953] = "1/80/90/100", [185961] = "1/100/100/100"},
[126996] = {[185932] = "1/60/70/80", [185952] = "1/80/90/100", [185960] = "1/100/100/100"},
[126997] = {[185931] = "1/60/70/80", [185951] = "1/80/90/100", [185959] = "1/100/100/100"},
[126998] = {[185930] = "1/60/70/80", [185950] = "1/80/90/100", [185958] = "1/100/100/100"},
[126999] = {[185929] = "1/60/70/80", [185949] = "1/80/90/100", [185957] = "1/100/100/100"},
[127000] = {[185928] = "1/60/70/80", [185948] = "1/80/90/100", [185956] = "1/100/100/100"},
[127001] = {[185927] = "1/60/70/80", [185947] = "1/80/90/100", [185955] = "1/100/100/100"},
[127002] = {[185926] = "1/60/70/80", [185946] = "1/80/90/100", [185954] = "1/100/100/100"},
[127004] = "1/60/70/80",
[127016] = "1/20/40/60",
[127017] = "1/20/40/60",
[127019] = {[186112] = "1/60/70/80", [186113] = "1/80/90/100", [186114] = "1/100/100/100"},
[127020] = {[186115] = "1/60/70/80", [186116] = "1/80/90/100", [186117] = "1/100/100/100"},
[127031] = "1/20/40/60",
[127032] = "1/20/40/60",
[127033] = {[186106] = "1/60/70/80", [186107] = "1/80/90/100", [186108] = "1/100/100/100"},
[127034] = {[186109] = "1/60/70/80", [186110] = "1/80/90/100", [186111] = "1/100/100/100"},
[127035] = "1/20/40/60",
[127294] = "1/1/1/1",
[127344] = "1/1/1/1",
[127345] = "1/1/1/1",
[127359] = "1/1/1/1",
[127360] = "1/1/1/1",
[127361] = "1/1/1/1",
[127363] = "1/1/1/1",
[127364] = "1/1/1/1",
[127367] = "1/1/1/1",
[127370] = "1/1/1/1",
[127372] = "1/1/1/1",
[127373] = "1/1/1/1",
[133940] = "1/10/20/30",
[133942] = "1/70/80/90",
[137556] = "1/20/40/60",
[137557] = "1/20/40/60",
[137558] = "1/20/40/60",
[139503] = "1/20/40/60",
[142075] = {[229041] = "1/100/100/100", [229043] = "1/100/100/100", [229045] = "1/100/100/100"},
[142332] = "1/40/50/60",
[146666] = "1/100/105/110",
[151571] = {[247807] = "1/90/95/100", [247808] = "1/90/95/100", [247809] = "1/90/95/100"},
[151771] = "1/265/280/295",
[151772] = "1/265/280/295",
[151790] = "1/250/250/250",
[151792] = "1/250/250/250",
[154685] = "1/75/87/100",
[154686] = "1/15/50/85",
[154687] = "1/15/50/85",
[154688] = "1/50/75/100",
[154689] = "1/25/55/85",
[154690] = "1/50/75/100",
[154691] = "1/15/50/85",
[154692] = "1/10/47/85",
[154695] = {[257125] = "1/85/105/125", [257126] = "1/110/127/145", [257127] = "1/125/137/150"},
[154696] = {[257128] = "1/150/150/150", [257129] = "1/150/150/150", [257130] = "1/150/150/150"},
[154697] = "1/50/75/100",
[154700] = {[257114] = "1/100/117/135", [257115] = "1/150/150/150", [257116] = "1/150/150/150"},
[154705] = {[257137] = "1/90/95/100", [257138] = "1/150/150/150", [257139] = "1/150/150/150"},
[154706] = {[257134] = "1/90/95/100", [257135] = "1/150/150/150", [257136] = "1/150/150/150"},
[154707] = {[257131] = "1/90/95/100", [257132] = "1/150/150/150", [257133] = "1/150/150/150"},
[158378] = "1/100/125/150",
[158381] = "1/10/42/75",
[158382] = "1/75/87/100",
[159791] = "1/10/42/75",
[159792] = "1/85/105/125",
[159912] = {[269599] = "1/100/117/135", [269600] = "1/110/127/145", [269601] = "1/125/137/150"},
[159913] = {[269602] = "1/100/117/135", [269603] = "1/110/127/145", [269604] = "1/125/137/150"},
[159914] = {[269605] = "1/100/117/135", [269606] = "1/110/127/145", [269607] = "1/125/137/150"},
[159915] = {[269608] = "1/100/117/135", [269609] = "1/110/127/145", [269610] = "1/125/137/150"},
[159916] = {[269611] = "1/100/117/135", [269612] = "1/110/127/145", [269613] = "1/125/137/150"},
[159917] = {[269596] = "1/100/117/135", [269597] = "1/110/127/145", [269598] = "1/125/137/150"},
[161985] = "1/150/150/150",
[161986] = "1/150/150/150",
[162460] = "1/1/25/50",
[162461] = "1/1/25/50",
[162476] = "1/150/150/150",
[162478] = "1/150/150/150",
[162487] = "1/150/150/150",
[162488] = "1/150/150/150",
[164671] = {[282194] = "1/135/142/150", [282195] = "1/140/145/150", [282196] = "1/145/147/150"},
[164672] = {[282191] = "1/135/142/150", [282192] = "1/140/145/150", [282193] = "1/145/147/150"},
[164673] = {[282175] = "1/135/142/150", [282176] = "1/140/145/150", [282177] = "1/145/147/150"},
[164674] = {[282168] = "1/135/142/150", [282169] = "1/140/145/150", [282170] = "1/145/147/150"},
[164675] = {[282164] = "1/135/142/150", [282165] = "1/140/145/150", [282166] = "1/145/147/150"},
[164676] = {[282204] = "1/135/142/150", [282275] = "1/140/145/150", [282276] = "1/145/147/150"},
[164733] = "1/150/150/150",
[165377] = "1/150/150/150",
[165385] = "1/150/150/150",
[165393] = "1/150/150/150",
[165402] = "1/150/150/150",
[165410] = "1/150/150/150",
[165418] = "1/150/150/150",
[165739] = "1/95/110/125",
[167977] = {[294841] = "1/165/170/175", [294842] = "1/170/172/175", [294843] = "1/175/175/175"},
[167979] = {[294832] = "1/165/170/175", [294833] = "1/170/172/175", [294834] = "1/175/175/175"},
[167981] = {[294844] = "1/165/170/175", [294845] = "1/170/172/175", [294846] = "1/175/175/175"},
[167983] = {[294829] = "1/165/170/175", [294830] = "1/170/172/175", [294831] = "1/175/175/175"},
[167985] = {[294835] = "1/165/170/175", [294836] = "1/170/172/175", [294837] = "1/175/175/175"},
[167987] = {[294838] = "1/165/170/175", [294839] = "1/170/172/175", [294840] = "1/175/175/175"},
[168427] = "1/165/170/175",
[168728] = "1/175/175/175",
[168729] = "1/175/175/175",
[168730] = "1/175/175/175",
[168731] = "1/175/175/175",
[168732] = "1/175/175/175",
[168733] = "1/175/175/175",
[169456] = "1/150/162/175",
[170320] = {[304565] = "1/165/170/175", [304566] = "1/165/170/175", [304567] = "1/165/170/175"},
[170323] = {[304580] = "1/165/170/175", [304581] = "1/165/170/175", [304582] = "1/165/170/175"},
[170324] = {[304577] = "1/165/170/175", [304578] = "1/165/170/175", [304579] = "1/165/170/175"},
[170325] = {[304574] = "1/165/170/175", [304575] = "1/165/170/175", [304576] = "1/165/170/175"},
[170327] = {[304568] = "1/165/170/175", [304569] = "1/165/170/175", [304570] = "1/165/170/175"},
[170340] = {[304571] = "1/165/170/175", [304572] = "1/165/170/175", [304573] = "1/165/170/175"},
[170456] = "1/175/175/175",
[170457] = "1/175/175/175",
[170458] = "1/175/175/175",
[170459] = "1/175/175/175",
[170460] = "1/175/175/175",
[170461] = "1/175/175/175",
[171320] = "1/200/200/200",
[173191] = "1/55/65/75",
[173192] = "1/10/15/20",
[173193] = "1/40/45/50",
[173194] = "1/30/35/40",
[173195] = "1/10/15/20",
[173196] = "1/25/30/35",
[173197] = "1/35/40/45",
[173198] = "1/45/50/55",
[173199] = "1/50/55/60",
[173200] = "1/20/25/30",
[173201] = "1/10/15/20",
[173214] = "1/90/95/100",
[173215] = "1/80/85/90",
[173216] = "1/65/70/75",
[173217] = "1/75/80/85",
[173218] = "1/85/90/95",
[173219] = "1/100/100/100",
[173220] = "1/100/100/100",
[173221] = "1/70/75/80",
[173222] = "1/60/65/70",
[173241] = {[310879] = "1/100/100/100", [332031] = "1/100/100/100", [332066] = "1/100/100/100", [338996] = "1/100/100/100"},
[173242] = {[310880] = "1/100/100/100", [332032] = "1/100/100/100", [332067] = "1/100/100/100", [338995] = "1/100/100/100"},
[173243] = {[310878] = "1/100/100/100", [332030] = "1/100/100/100", [332065] = "1/100/100/100", [338997] = "1/100/100/100"},
[173244] = {[310881] = "1/100/100/100", [332033] = "1/100/100/100", [332068] = "1/100/100/100", [338998] = "1/100/100/100"},
[173245] = {[310882] = "1/100/100/100", [332034] = "1/100/100/100", [332069] = "1/100/100/100", [339000] = "1/100/100/100"},
[173246] = {[310883] = "1/100/100/100", [332035] = "1/100/100/100", [332070] = "1/100/100/100", [339001] = "1/100/100/100"},
[173247] = {[310884] = "1/100/100/100", [332036] = "1/100/100/100", [332071] = "1/100/100/100", [339002] = "1/100/100/100"},
[173248] = {[310885] = "1/100/100/100", [332037] = "1/100/100/100", [332072] = "1/100/100/100", [339003] = "1/100/100/100"},
[173249] = {[310886] = "1/100/100/100", [332038] = "1/100/100/100", [332073] = "1/100/100/100", [339004] = "1/100/100/100"},
[173381] = "1/55/60/65",
[173382] = "1/75/80/85",
[173383] = "1/90/92/95",
[173384] = "1/100/105/110",
[180055] = {[330222] = "1/1/10/20", [330227] = "1/1/10/20", [330232] = "1/1/10/20", [330237] = "1/1/10/20", [330242] = "1/1/10/20", [330247] = "1/1/10/20", [330252] = "1/1/10/20", [330257] = "1/1/10/20"},
[180057] = {[330223] = "1/1/10/20", [330228] = "1/1/10/20", [330233] = "1/1/10/20", [330238] = "1/1/10/20", [330243] = "1/1/10/20", [330248] = "1/1/10/20", [330253] = "1/1/10/20", [330258] = "1/1/10/20"},
[180058] = {[330224] = "1/1/10/20", [330229] = "1/1/10/20", [330234] = "1/1/10/20", [330239] = "1/1/10/20", [330244] = "1/1/10/20", [330249] = "1/1/10/20", [330254] = "1/1/10/20", [330259] = "1/1/10/20"},
[180059] = {[330225] = "1/1/10/20", [330230] = "1/1/10/20", [330235] = "1/1/10/20", [330240] = "1/1/10/20", [330245] = "1/1/10/20", [330250] = "1/1/10/20", [330255] = "1/1/10/20", [330260] = "1/1/10/20"},
[180060] = {[330226] = "1/1/10/20", [330231] = "1/1/10/20", [330236] = "1/1/10/20", [330241] = "1/1/10/20", [330246] = "1/1/10/20", [330251] = "1/1/10/20", [330256] = "1/1/10/20", [330261] = "1/1/10/20"},
[180752] = "1/15/20/25",
[183942] = "1/55/60/65",
[184479] = "1/25/32/40",
[184480] = "1/75/80/85",
[185960] = "1/100/100/100",
[186975] = "1/15/20/25",
-- Unknown item created by: Pandaria Patterns (132) - Master's Spellthread (125496)
-- Unknown item created by: Pandaria Patterns (132) - Sanctified Spellthread (125497)
-- Unknown item created by: Kul Tiran Patterns (143) - Resilient Spellthread (279182)
-- Unknown item created by: Kul Tiran Patterns (143) - Discreet Spellthread (279183)
-- Unknown item created by: Kul Tiran Patterns (143) - Feathery Spellthread (279184)
-- Invalid recipe: Shadowlands Patterns (78) - Cloak of Camouflage (338267)
-- Invalid recipe: Shadowlands Patterns (78) - Bolt of Ardensilk Cloth (338269)
-- Invalid recipe: Shadowlands Patterns (78) - Ardensilk Cloth (338270)
-- Invalid recipe: Shadowlands Patterns (78) - Woven Gossamer Tunic (338271)
-- Invalid recipe: Shadowlands Patterns (78) - Bolt of Woven Gossamer (338272)
-- Invalid recipe: Shadowlands Patterns (78) - Gossamer Cloth (338273)
-- Invalid recipe: Shadowlands Patterns (78) - Haunting Hood (338275)
-- Invalid recipe: Shadowlands Patterns (78) - Bolt of Bleakcloth (338276)
-- Invalid recipe: Shadowlands Patterns (78) - Bleakcloth (338277)
-- Invalid recipe: Shadowlands Patterns (78) - Looming Tapestry (338278)
-- Invalid recipe: Shadowlands Patterns (78) - Bolt of Prideweave (338279)
-- Invalid recipe: Shadowlands Patterns (78) - Prideweave Cloth (338280)



-- cooking
[724] = "1/90/110/130",
[733] = "1/115/135/155",
[787] = "1/45/65/85",
[1017] = "1/140/160/180",
[1082] = "1/135/155/175",
[2679] = "1/45/65/85",
[2680] = "10/50/70/90",
[2681] = "1/45/65/85",
[2682] = "1/125/145/165",
[2683] = "75/115/135/155",
[2684] = "50/90/110/130",
[2685] = "1/130/150/170",
[2687] = "80/120/140/160",
[2888] = "1/60/80/100",
[3220] = "1/100/120/140",
[3662] = "1/120/140/160",
[3663] = "1/130/150/170",
[3664] = "1/160/180/200",
[3665] = "1/170/190/210",
[3666] = "1/150/170/190",
[3726] = "1/150/170/190",
[3727] = "1/175/195/215",
[3728] = "150/190/210/230",
[3729] = "175/215/235/255",
[4457] = "175/215/235/255",
[4592] = "1/90/110/130",
[4593] = "1/140/160/180",
[4594] = "1/190/210/230",
[5095] = "1/90/110/130",
[5472] = "10/50/70/90",
[5473] = "1/60/80/100",
[5474] = "1/75/95/115",
[5476] = "50/90/110/130",
[5477] = "1/90/110/130",
[5478] = "1/130/150/170",
[5479] = "1/140/160/180",
[5480] = "1/150/170/190",
[5525] = "50/90/110/130",
[5526] = "1/130/150/170",
[5527] = "125/165/185/205",
[6038] = "1/215/235/255",
[6290] = "1/45/65/85",
[6316] = "1/90/110/130",
[6657] = "1/125/145/165",
[6887] = "225/250/262/275",
[6888] = "1/45/65/85",
[6890] = "1/80/100/120",
[7676] = "1/100/120/140",
[8364] = "1/215/235/255",
[10841] = "1/175/190/205",
[12209] = "1/165/185/205",
[12210] = "1/215/235/255",
[12212] = "1/215/235/255",
[12213] = "1/215/235/255",
[12214] = "1/215/235/255",
[12215] = "1/225/237/250",
[12216] = "1/250/262/275",
[12217] = "1/225/237/250",
[12218] = "1/250/262/275",
[12224] = "1/45/65/85",
[13851] = "1/215/235/255",
[13927] = "1/250/262/275",
[13928] = "240/265/277/290",
[13929] = "1/265/277/290",
[13930] = "1/250/262/275",
[13931] = "250/275/285/295",
[13932] = "250/275/285/295",
[13933] = "1/300/300/300",
[13934] = "1/300/300/300",
[13935] = "1/300/300/300",
[16766] = "1/250/262/275",
[17197] = "1/45/65/85",
[17198] = "1/75/95/115",
[17222] = "200/225/237/250",
[18045] = "1/250/262/275",
[18254] = "1/300/300/300",
[20074] = "1/160/180/200",
[20452] = "1/300/300/300",
[21023] = "1/300/300/300",
[21072] = "1/120/140/160",
[21217] = "1/215/235/255",
[22645] = "1/100/120/140",
[24105] = "1/45/65/85",
[27635] = "1/45/65/85",
[27636] = "1/90/110/130",
[27651] = "1/20/30/40",
[27655] = "1/20/30/40",
[27657] = "1/35/45/55",
[27658] = "1/45/55/65",
[27659] = "1/45/55/65",
[27660] = "1/45/55/65",
[27661] = "1/20/30/40",
[27662] = "1/20/30/40",
[27663] = "1/30/40/50",
[27664] = "1/40/50/60",
[27665] = "1/40/50/60",
[27666] = "1/45/55/65",
[27667] = "1/70/72/75",
[30155] = "1/20/30/40",
[30816] = "1/30/35/40",
[31672] = "1/55/65/75",
[31673] = "1/55/65/75",
[33004] = "1/250/275/300",
[33048] = "1/35/45/55",
[33052] = "1/75/75/75",
[33053] = "1/75/75/75",
[33825] = "1/35/45/55",
[33866] = "1/20/30/40",
[33867] = "1/20/30/40",
[33872] = "1/35/45/55",
[33874] = "1/45/55/65",
[33924] = "1/50/62/75",
[34411] = "1/300/300/300",
[34747] = "1/1/3/5",
[34748] = "1/1/20/40",
[34749] = "1/1/20/40",
[34750] = "1/1/20/40",
[34751] = "1/1/20/40",
[34752] = "1/1/20/40",
[34753] = "1/1/25/50",
[34754] = "1/50/62/75",
[34755] = "1/50/62/75",
[34756] = "1/50/62/75",
[34757] = "1/50/62/75",
[34758] = "1/50/62/75",
[34759] = "1/1/3/5",
[34760] = "1/1/3/5",
[34761] = "1/1/3/5",
[34762] = "1/1/20/40",
[34763] = "1/1/20/40",
[34764] = "1/1/20/40",
[34765] = "1/1/20/40",
[34766] = "1/50/62/75",
[34767] = "1/50/62/75",
[34768] = "1/50/62/75",
[34769] = "1/50/62/75",
[34832] = "1/100/105/110",
[35563] = "250/275/285/295",
[35565] = "250/275/285/295",
[39520] = "1/1/13/25",
[42942] = "1/1/20/40",
[42993] = "1/50/62/75",
[42994] = "1/50/62/75",
[42995] = "1/50/62/75",
[42996] = "1/50/62/75",
[42997] = "1/50/62/75",
[42998] = "1/50/62/75",
[42999] = "1/50/62/75",
[43000] = "1/50/62/75",
[43001] = "1/50/62/75",
[43004] = "1/50/62/75",
[43005] = "1/50/62/75",
[43015] = "1/75/75/75",
[43268] = "1/1/20/40",
[43478] = "1/60/67/75",
[43480] = "1/75/75/75",
[43488] = "1/1/3/5",
[43490] = "1/1/3/5",
[43491] = "1/1/8/15",
[43492] = "1/1/3/5",
[44836] = {[62044] = "1/150/162/175", [66036] = "1/150/162/175"},
[44837] = {[62050] = "1/90/102/115", [66038] = "1/90/102/115"},
[44838] = {[62045] = "1/205/217/230", [66037] = "1/205/217/230"},
[44839] = {[62051] = "1/270/282/295", [66034] = "1/270/282/295"},
[44840] = {[62049] = "1/210/222/235", [66035] = "1/210/222/235"},
[44953] = "1/1/43/85",
[45932] = "1/25/37/50",
[46691] = "1/30/35/40",
[62289] = "1/75/75/75",
[62290] = "1/75/75/75",
[62649] = "1/75/75/75",
[62651] = "1/15/27/40",
[62652] = "1/15/27/40",
[62653] = "1/15/27/40",
[62654] = "1/15/27/40",
[62655] = "1/15/27/40",
[62656] = "1/15/27/40",
[62657] = "1/15/27/40",
[62658] = "1/40/47/55",
[62659] = "1/40/47/55",
[62660] = "1/40/47/55",
[62661] = "1/65/70/75",
[62662] = "1/65/70/75",
[62663] = "1/65/70/75",
[62664] = "1/65/70/75",
[62665] = "1/65/70/75",
[62666] = "1/65/70/75",
[62667] = "1/65/70/75",
[62668] = "1/65/70/75",
[62669] = "1/65/70/75",
[62670] = "1/65/70/75",
[62671] = "1/65/70/75",
[62672] = "1/75/75/75",
[62673] = "1/1/10/20",
[62674] = "1/5/10/15",
[62675] = "1/5/10/15",
[62676] = "1/1/8/15",
[62677] = "1/40/50/60",
[62680] = "1/60/62/65",
[62790] = "1/1/5/10",
[67230] = "40/80/100/120",
[68687] = "1/40/50/60",
[74636] = "1/1/5/10",
[74641] = "1/1/5/10",
[74642] = "1/25/27/30",
[74643] = "1/25/27/30",
[74644] = "1/25/27/30",
[74645] = "1/50/50/50",
[74646] = "1/75/75/75",
[74647] = "1/50/50/50",
[74648] = "1/75/75/75",
[74649] = "1/50/50/50",
[74650] = "1/75/75/75",
[74651] = "1/25/27/30",
[74652] = "1/50/50/50",
[74653] = "1/75/75/75",
[74654] = "1/25/27/30",
[74655] = "1/50/50/50",
[74656] = "1/75/75/75",
[74919] = "1/75/75/75",
[75016] = "1/75/75/75",
[75026] = "1/25/27/30",
[75037] = "1/50/50/50",
[75038] = "1/75/75/75",
[81400] = "1/1/5/10",
[81401] = "1/1/5/10",
[81402] = "1/1/5/10",
[81403] = "1/1/5/10",
[81404] = "1/1/5/10",
[81405] = "1/1/5/10",
[81406] = "1/1/5/10",
[81408] = "1/1/5/10",
[81409] = "1/1/5/10",
[81410] = "1/1/5/10",
[81411] = "1/1/5/10",
[81412] = "1/1/5/10",
[81413] = "1/1/5/10",
[81414] = "1/1/5/10",
[85501] = "1/5/15/25",
[85504] = "1/5/15/25",
[86026] = "1/1/5/10",
[86057] = "1/1/5/10",
[86069] = "1/5/15/25",
[86070] = "1/1/5/10",
[86073] = "1/75/75/75",
[86074] = "1/75/75/75",
[86432] = "1/75/75/75",
[87226] = "1/75/75/75",
[87228] = "1/75/75/75",
[87230] = "1/75/75/75",
[87232] = "1/75/75/75",
[87234] = "1/75/75/75",
[87236] = "1/75/75/75",
[87238] = "1/75/75/75",
[87240] = "1/75/75/75",
[87242] = "1/75/75/75",
[87244] = "1/75/75/75",
[87246] = "1/75/75/75",
[87248] = "1/75/75/75",
[87264] = "1/75/75/75",
[101630] = "1/75/75/75",
[101661] = "1/75/75/75",
[101662] = "1/75/75/75",
[101745] = "1/75/75/75",
[101746] = "1/75/75/75",
[101747] = "1/75/75/75",
[101748] = "1/75/75/75",
[101749] = "1/75/75/75",
[101750] = "1/75/75/75",
[111431] = "1/50/75/100",
[111433] = "1/50/75/100",
[111434] = "1/50/75/100",
[111436] = "1/50/75/100",
[111437] = "1/50/75/100",
[111438] = "1/50/75/100",
[111439] = "1/50/75/100",
[111441] = "1/50/75/100",
[111442] = "1/50/75/100",
[111444] = "1/50/75/100",
[111445] = "1/50/75/100",
[111446] = "1/50/75/100",
[111447] = "1/75/87/100",
[111449] = "1/75/87/100",
[111450] = "1/75/87/100",
[111452] = "1/75/87/100",
[111453] = "1/75/87/100",
[111454] = "1/75/87/100",
[111455] = "1/1/25/50",
[111456] = "1/1/25/50",
[111457] = "1/100/100/100",
[111458] = "1/100/100/100",
[122343] = "1/1/8/15",
[122344] = "1/1/8/15",
[122345] = "1/1/8/15",
[122346] = "1/1/8/15",
[122347] = "1/1/8/15",
[122348] = "1/1/8/15",
[126934] = "1/50/75/100",
[126935] = "1/245/265/285",
[126936] = "1/125/150/175",
[128498] = "1/1/8/15",
[133557] = {[201413] = "1/20/30/40", [201524] = "1/40/50/60", [201544] = "1/60/70/80"},
[133561] = {[201496] = "1/20/30/40", [201525] = "1/40/50/60", [201545] = "1/60/70/80"},
[133562] = {[201497] = "1/20/30/40", [201526] = "1/40/50/60", [201546] = "1/60/70/80"},
[133563] = {[201498] = "1/20/30/40", [201527] = "1/40/50/60", [201547] = "1/60/70/80"},
[133564] = {[201499] = "1/20/30/40", [201528] = "1/40/50/60", [201548] = "1/60/70/80"},
[133565] = {[201500] = "1/40/50/60", [201529] = "1/60/70/80", [201549] = "1/80/90/100"},
[133566] = {[201501] = "1/40/50/60", [201530] = "1/60/70/80", [201550] = "1/80/90/100"},
[133567] = {[201502] = "1/40/50/60", [201531] = "1/60/70/80", [201551] = "1/80/90/100"},
[133568] = {[201503] = "1/40/50/60", [201532] = "1/60/70/80", [201552] = "1/80/90/100"},
[133569] = {[201504] = "1/40/50/60", [201533] = "1/60/70/80", [201553] = "1/80/90/100"},
[133570] = {[201505] = "1/60/70/80", [201534] = "1/80/90/100", [201554] = "1/100/100/100"},
[133571] = {[201506] = "1/60/70/80", [201535] = "1/80/90/100", [201555] = "1/100/100/100"},
[133572] = {[201507] = "1/60/70/80", [201536] = "1/80/90/100", [201556] = "1/100/100/100"},
[133573] = {[201508] = "1/60/70/80", [201537] = "1/80/90/100", [201557] = "1/100/100/100"},
[133574] = {[201511] = "1/60/70/80", [201538] = "1/80/90/100", [201558] = "1/100/100/100"},
[133575] = {[201512] = "1/20/30/40", [201539] = "1/40/50/60", [201559] = "1/60/70/80"},
[133576] = {[201513] = "1/20/30/40", [201540] = "1/40/50/60", [201560] = "1/60/70/80"},
[133577] = {[201514] = "1/20/30/40", [201541] = "1/40/50/60", [201561] = "1/60/70/80"},
[133578] = {[201515] = "1/40/50/60", [201542] = "1/60/70/80", [201562] = "1/80/90/100"},
[133579] = {[201516] = "1/60/70/80", [201543] = "1/80/90/100", [201563] = "1/100/100/100"},
[133681] = {[201683] = "1/60/70/80", [201684] = "1/80/90/100", [201685] = "1/100/100/100"},
[142334] = "1/80/90/100",
[152564] = "1/50/70/90",
[154881] = {[259411] = "1/35/67/100", [259412] = "1/50/80/110", [259413] = "1/60/90/120"},
[154882] = {[259414] = "1/90/105/120", [259415] = "1/110/130/150", [259416] = "1/150/150/150"},
[154883] = {[259424] = "1/35/67/100", [259425] = "1/50/80/110", [259426] = "1/60/90/120"},
[154884] = {[259427] = "1/90/105/120", [259428] = "1/110/130/150", [259429] = "1/150/150/150"},
[154885] = {[259442] = "1/35/67/100", [259443] = "1/50/80/110", [259444] = "1/60/90/120"},
[154886] = {[259445] = "1/90/105/120", [259446] = "1/110/130/150", [259447] = "1/150/150/150"},
[154887] = {[259436] = "1/35/67/100", [259437] = "1/50/80/110", [259438] = "1/60/90/120"},
[154888] = {[259439] = "1/90/105/120", [259440] = "1/110/130/150", [259441] = "1/150/150/150"},
[154889] = {[259430] = "1/15/45/75", [259431] = "1/35/67/100", [259432] = "1/50/80/110"},
[154891] = {[259433] = "1/85/102/120", [259434] = "1/110/130/150", [259435] = "1/150/150/150"},
[156525] = {[259418] = "1/110/125/140", [259419] = "1/150/150/150", [259420] = "1/150/150/150"},
[156526] = {[259421] = "1/150/150/150", [259422] = "1/150/150/150", [259423] = "1/150/150/150"},
[163781] = "1/50/75/100",
[165755] = "1/100/117/135",
[166240] = {[287108] = "1/150/150/150", [287110] = "1/150/150/150", [287112] = "1/150/150/150"},
[166343] = {[288027] = "1/35/67/100", [288028] = "1/50/80/110", [288029] = "1/60/90/120"},
[166344] = {[288030] = "1/90/105/120", [288032] = "1/110/130/150", [288033] = "1/150/150/150"},
[166804] = {[290471] = "1/120/125/130", [290472] = "1/125/127/130", [290473] = "1/130/132/135"},
[168310] = {[297078] = "1/165/170/175", [297079] = "1/170/172/175", [297080] = "1/175/175/175"},
[168311] = {[297084] = "1/165/170/175", [297085] = "1/170/172/175", [297086] = "1/175/175/175"},
[168312] = {[297074] = "1/175/175/175", [297075] = "1/170/172/175", [297077] = "1/165/170/175"},
[168313] = {[297081] = "1/165/170/175", [297082] = "1/170/172/175", [297083] = "1/175/175/175"},
[168314] = {[297087] = "1/165/170/175", [297088] = "1/170/172/175", [297089] = "1/175/175/175"},
[168315] = {[297105] = "1/165/170/175", [297106] = "1/170/172/175", [297107] = "1/175/175/175"},
[169280] = "1/175/175/175",
[169449] = "1/165/170/175",
[172040] = "1/30/32/35",
[172041] = "1/70/72/75",
[172042] = "1/75/75/75",
[172043] = "1/75/75/75",
[172044] = "1/40/42/45",
[172045] = "1/60/62/65",
[172046] = "1/20/22/25",
[172047] = "1/50/52/55",
[172048] = "1/35/37/40",
[172049] = "1/65/67/70",
[172050] = "1/30/32/35",
[172051] = "1/60/62/65",
[172061] = "1/75/75/75",
[172062] = "1/75/75/75",
[172063] = "1/75/75/75",
[172068] = "1/20/22/25",
[172069] = "1/50/52/55",
[174348] = "1/165/170/175",
[174349] = "1/165/170/175",
[174350] = "1/165/170/175",
[174351] = "1/165/170/175",
[174352] = "1/165/170/175",
[184624] = "1/125/150/175",
[184682] = "1/10/15/20",
[184690] = "1/15/20/25",
[186704] = "1/75/75/75",
[186725] = "1/50/52/55",
[186726] = "1/30/32/35",
-- Invalid recipe: Shadowlands Cuisine (31) - Arden Apple Pie (338100)
-- Invalid recipe: Shadowlands Cuisine (31) - Oat Pie Crust (338101)
-- Invalid recipe: Shadowlands Cuisine (31) - Sliced Arden Apples (338102)
-- Invalid recipe: Shadowlands Cuisine (31) - Steward Stew (338105)
-- Invalid recipe: Shadowlands Cuisine (31) - Grazer Bone Broth (338106)
-- Invalid recipe: Shadowlands Cuisine (31) - Diced Vegetables (338107)
-- Invalid recipe: Shadowlands Cuisine (31) - Spider Jerky (338110)
-- Invalid recipe: Shadowlands Cuisine (31) - Thick Spider Meat (338113)
-- Invalid recipe: Shadowlands Cuisine (31) - Ember Sauce (338115)
-- Invalid recipe: Shadowlands Cuisine (31) - Skewered Meats (338116)
-- Invalid recipe: Shadowlands Cuisine (31) - Seared Cutlets (338117)
	
}
Skillet.db.global.SkillLineAbility_era = {
--[====[@version-classic@
[2149] = '1/40/55/70',
[2153] = '30/45/60/75',
[2152] = '1/30/45/60',
[2158] = '45/120/135/150',
[2159] = '1/105/120/135',
[2160] = '50/70/85/100',
[2161] = '65/85/100/115',
[2162] = '65/90/105/120',
[2163] = '70/90/105/120',
[2164] = '70/105/120/135',
[2165] = '75/115/122/130',
[2166] = '125/145/157/170',
[2167] = '100/125/137/150',
[2168] = '110/135/147/160',
[2169] = '100/125/137/150',
[2330] = '1/55/75/95',
[2329] = '1/55/75/95',
[2331] = '30/65/85/105',
[2332] = '40/70/90/110',
[2334] = '50/80/100/120',
[2335] = '60/90/110/130',
[2336] = '70/100/120/140',
[2337] = '80/85/105/125',
[2538] = '1/45/65/85',
[2539] = '30/50/70/90',
[2540] = '1/45/65/85',
[2541] = '65/90/110/130',
[2542] = '65/90/110/130',
[2543] = '75/115/135/155',
[2544] = '75/115/135/155',
[2545] = '85/125/145/165',
[2546] = '110/120/140/160',
[2547] = '125/135/155/175',
[2548] = '135/130/150/170',
[2549] = '135/140/160/180',
[2577] = '1/100/112/125',
[2578] = '1/125/137/150',
[2579] = '1/150/162/175',
[2658] = '1/100/112/125',
[2659] = '1/65/90/115',
[2660] = '1/15/35/55',
[2661] = '55/75/95/115',
[2662] = '40/50/70/90',
[2663] = '1/20/40/60',
[2664] = '1/115/127/140',
[2665] = '75/65/72/80',
[2666] = '80/110/130/150',
[2667] = '90/120/140/160',
[2668] = '95/145/160/175',
[2670] = '105/145/160/175',
[2672] = '120/150/165/180',
[2674] = '125/125/132/140',
[2675] = '135/175/190/205',
[2737] = '1/55/75/95',
[2740] = '75/140/155/170',
[2741] = '85/145/160/175',
[2738] = '1/60/80/100',
[2739] = '40/65/85/105',
[2742] = '95/150/165/180',
[2795] = '40/60/80/100',
[2835] = '1/175/200/225',
[2837] = '1/215/240/265',
[2881] = '1/20/30/40',
[3115] = '1/15/35/55',
[3117] = '1/125/132/140',
[3116] = '1/65/72/80',
[3171] = '1/120/140/160',
[3172] = '1/135/155/175',
[3173] = '1/145/165/185',
[3174] = '1/145/165/185',
[3176] = '1/150/170/190',
[3177] = '1/155/175/195',
[2333] = '1/165/185/205',
[3188] = '1/175/195/215',
[3170] = '1/60/80/100',
[3230] = '1/80/100/120',
[3275] = '1/30/45/60',
[3276] = '1/50/75/100',
[3277] = '1/80/115/150',
[3278] = '1/115/150/185',
[3308] = '1/170/177/185',
[3307] = '1/130/135/140',
[3304] = '1/50/62/75',
[3292] = '1/135/155/175',
[3293] = '1/75/95/115',
[3294] = '1/110/130/150',
[3295] = '1/155/170/185',
[3296] = '1/160/175/190',
[3297] = '1/175/190/205',
[3319] = '1/60/80/100',
[3320] = '1/45/65/85',
[3321] = '1/75/95/115',
[3323] = '1/80/100/120',
[3324] = '1/85/105/125',
[3325] = '1/100/120/140',
[3326] = '1/75/87/100',
[3328] = '1/140/155/170',
[3330] = '1/155/170/185',
[3331] = '1/160/175/190',
[3333] = '1/165/180/195',
[3334] = '1/175/190/205',
[3336] = '1/180/195/210',
[3337] = '1/125/137/150',
[3370] = '1/120/140/160',
[3371] = '1/100/120/140',
[3372] = '1/130/150/170',
[3373] = '1/160/180/200',
[3376] = '1/170/190/210',
[3377] = '1/150/170/190',
[3397] = '1/150/170/190',
[3398] = '1/175/195/215',
[3399] = '1/190/210/230',
[3400] = '1/215/235/255',
[3447] = '1/135/155/175',
[3448] = '1/185/205/225',
[3449] = '1/190/210/230',
[3450] = '1/195/215/235',
[3451] = '1/200/220/240',
[3452] = '1/180/200/220',
[3453] = '1/215/235/255',
[3454] = '1/220/240/260',
[3420] = '1/125/150/175',
[3491] = '1/135/150/165',
[3492] = '1/185/197/210',
[3493] = '1/200/212/225',
[3494] = '1/180/192/205',
[3495] = '1/195/207/220',
[3496] = '1/205/217/230',
[3497] = '1/225/237/250',
[3498] = '1/210/222/235',
[3500] = '1/225/237/250',
[3501] = '1/190/202/215',
[3502] = '1/195/207/220',
[3503] = '1/215/227/240',
[3504] = '1/185/197/210',
[3505] = '1/200/212/225',
[3506] = '1/180/192/205',
[3507] = '1/195/207/220',
[3508] = '1/205/217/230',
[3511] = '1/220/232/245',
[3513] = '1/210/222/235',
[3515] = '1/225/237/250',
[3569] = '1/165/165/165',
[3753] = '1/55/70/85',
[3756] = '1/85/100/115',
[3759] = '1/105/120/135',
[3760] = '1/170/180/190',
[3761] = '1/115/130/145',
[3762] = '1/125/137/150',
[3763] = '1/110/125/140',
[3764] = '1/170/182/195',
[3765] = '1/155/167/180',
[3766] = '1/150/162/175',
[3767] = '1/145/157/170',
[3768] = '1/155/167/180',
[3769] = '1/165/177/190',
[3770] = '1/160/172/185',
[3771] = '1/170/180/190',
[3772] = '1/175/185/195',
[3773] = '1/195/205/215',
[3774] = '1/180/190/200',
[3775] = '1/190/200/210',
[3776] = '1/200/210/220',
[3777] = '1/215/225/235',
[3778] = '1/205/215/225',
[3779] = '1/220/230/240',
[3816] = '1/55/65/75',
[3817] = '1/115/122/130',
[3818] = '1/160/165/170',
[3780] = '1/170/180/190',
[2963] = '1/25/37/50',
[2387] = '1/35/47/60',
[2385] = '1/45/57/70',
[2389] = '1/65/82/100',
[2386] = '1/90/107/125',
[2392] = '1/65/82/100',
[2393] = '1/35/47/60',
[2394] = '1/65/82/100',
[2397] = '1/85/102/120',
[2395] = '1/95/112/130',
[2396] = '1/95/112/130',
[2964] = '1/90/97/105',
[2402] = '1/100/117/135',
[2399] = '1/110/127/145',
[2401] = '1/120/137/155',
[2403] = '1/130/147/165',
[2406] = '1/110/120/130',
[3839] = '1/135/140/145',
[3865] = '1/180/182/185',
[3840] = '1/60/77/95',
[3841] = '1/85/102/120',
[3842] = '1/95/112/130',
[3843] = '1/110/127/145',
[3844] = '1/125/142/160',
[3845] = '1/105/122/140',
[3847] = '1/120/137/155',
[3848] = '1/135/152/170',
[3849] = '1/145/162/180',
[3850] = '1/135/152/170',
[3851] = '1/150/167/185',
[3852] = '1/150/165/180',
[3854] = '1/165/180/195',
[3855] = '1/150/167/185',
[3856] = '1/160/175/190',
[3857] = '1/185/200/215',
[3858] = '1/190/205/220',
[3859] = '1/170/185/200',
[3860] = '1/195/210/225',
[3861] = '1/205/220/235',
[3862] = '1/220/235/250',
[3863] = '1/200/215/230',
[3864] = '1/220/235/250',
[3866] = '1/135/152/170',
[3868] = '1/150/167/185',
[3869] = '1/145/150/155',
[3870] = '1/165/170/175',
[3871] = '1/180/185/190',
[3872] = '1/195/200/205',
[3873] = '1/210/215/220',
[3914] = '1/55/72/90',
[3915] = '1/35/47/60',
[3918] = '1/20/30/40',
[3919] = '1/30/45/60',
[3920] = '1/30/45/60',
[3922] = '1/45/52/60',
[3923] = '1/60/75/90',
[3924] = '1/80/95/110',
[3925] = '1/80/95/110',
[3977] = '1/90/105/120',
[3973] = '1/110/125/140',
[3926] = '1/95/110/125',
[3928] = '1/105/120/135',
[3929] = '1/85/90/95',
[3930] = '1/85/90/95',
[3931] = '1/90/97/105',
[3932] = '1/115/130/145',
[3933] = '1/130/145/160',
[3934] = '1/130/145/160',
[3936] = '1/130/142/155',
[3937] = '1/105/130/155',
[3938] = '1/105/130/155',
[3978] = '1/135/147/160',
[3939] = '1/145/157/170',
[3940] = '1/145/157/170',
[3941] = '1/120/145/170',
[3942] = '1/125/150/175',
[3944] = '1/125/150/175',
[3945] = '1/125/135/145',
[3946] = '1/125/135/145',
[3947] = '1/125/135/145',
[3949] = '1/155/167/180',
[3950] = '1/140/165/190',
[3952] = '1/165/177/190',
[3953] = '1/145/170/195',
[3954] = '1/170/182/195',
[3955] = '1/175/187/200',
[3956] = '1/175/187/200',
[3957] = '1/175/185/195',
[3958] = '1/160/170/180',
[3959] = '1/180/190/200',
[3960] = '1/185/195/205',
[3961] = '1/170/190/210',
[3962] = '1/175/195/215',
[3963] = '1/175/195/215',
[3979] = '1/200/210/220',
[3965] = '1/185/205/225',
[3966] = '1/205/215/225',
[3967] = '1/190/210/230',
[3968] = '1/215/225/235',
[3969] = '1/220/230/240',
[3971] = '1/220/230/240',
[3972] = '1/200/220/240',
[4094] = '1/215/235/255',
[4097] = '1/185/195/205',
[4096] = '1/185/195/205',
[818] = '1/25/50/75',
[4508] = '1/80/100/120',
[4942] = '1/230/250/270',
[2657] = '1/25/47/70',
[5244] = '1/70/85/100',
[5763] = '1/150/175/200',
[6412] = '1/50/70/90',
[6413] = '1/60/80/100',
[6414] = '1/75/95/115',
[6415] = '1/90/110/130',
[6416] = '1/90/110/130',
[6417] = '1/130/150/170',
[6418] = '1/140/160/180',
[6419] = '1/150/170/190',
[6458] = '1/160/172/185',
[6501] = '1/130/150/170',
[6500] = '1/165/185/205',
[6499] = '1/90/110/130',
[6510] = '1/170/195/220',
[6518] = '1/170/185/200',
[6517] = '1/140/155/170',
[6521] = '1/115/132/150',
[2671] = '1/145/160/175',
[2673] = '1/160/175/190',
[3758] = '1/120/137/155',
[3755] = '1/70/87/105',
[3757] = '1/105/122/140',
[3813] = '1/170/185/200',
[6624] = '1/175/195/215',
[6619] = '1/150/170/190',
[6618] = '1/195/215/235',
[6617] = '1/90/110/130',
[6661] = '1/210/220/230',
[6686] = '1/95/112/130',
[6688] = '1/140/157/175',
[6690] = '1/155/170/185',
[6692] = '1/170/185/200',
[6693] = '1/195/210/225',
[6695] = '1/205/220/235',
[6702] = '1/120/135/150',
[6705] = '1/210/220/230',
[6703] = '1/125/140/155',
[6704] = '1/190/200/210',
[7126] = '1/40/55/70',
[7133] = '1/130/142/155',
[7135] = '1/140/152/165',
[7147] = '1/180/190/200',
[7149] = '1/190/200/210',
[7151] = '1/195/205/215',
[7153] = '1/205/215/225',
[7156] = '1/210/220/230',
[7179] = '1/120/140/160',
[7181] = '1/175/195/215',
[7183] = '1/55/75/95',
[7213] = '1/215/235/255',
[7224] = '1/215/227/240',
[7223] = '1/210/222/235',
[7221] = '1/180/195/210',
[7222] = '1/190/202/215',
[7257] = '1/210/230/250',
[7258] = '1/205/225/245',
[7255] = '1/130/150/170',
[7259] = '1/210/230/250',
[7256] = '1/160/180/200',
[7359] = '1/85/110/135',
[7408] = '1/105/125/145',
[7418] = '1/70/90/110',
[7420] = '1/70/90/110',
[7421] = '1/5/7/10',
[7426] = '1/90/110/130',
[7428] = '1/80/100/120',
[7430] = '1/70/80/90',
[7443] = '1/80/100/120',
[7454] = '1/95/115/135',
[7457] = '1/100/120/140',
[7623] = '1/55/72/90',
[7624] = '1/55/72/90',
[7630] = '1/80/97/115',
[7629] = '1/80/97/115',
[7633] = '1/95/112/130',
[7636] = '1/115/132/150',
[7639] = '1/125/142/160',
[7643] = '1/140/157/175',
[7748] = '1/105/125/145',
[7751] = '1/45/65/85',
[7752] = '1/45/65/85',
[7753] = '1/90/110/130',
[7754] = '1/90/110/130',
[7755] = '1/140/160/180',
[7766] = '1/105/125/145',
[7771] = '1/110/130/150',
[7776] = '1/115/135/155',
[7779] = '1/115/135/155',
[7782] = '1/115/135/155',
[7786] = '1/120/140/160',
[7788] = '1/120/140/160',
[7745] = '1/130/150/170',
[7793] = '1/130/150/170',
[7795] = '1/130/150/170',
[7817] = '1/125/140/155',
[7818] = '1/105/107/110',
[7827] = '1/90/110/130',
[7828] = '1/190/210/230',
[7836] = '1/80/90/100',
[7837] = '1/150/160/170',
[7841] = '1/130/150/170',
[7845] = '1/165/185/205',
[7857] = '1/145/165/185',
[7859] = '1/145/165/185',
[7861] = '1/150/170/190',
[7863] = '1/150/170/190',
[7867] = '1/150/170/190',
[7892] = '1/145/162/180',
[7893] = '1/145/162/180',
[7928] = '1/150/180/210',
[7929] = '1/180/210/240',
[7934] = '1/80/115/150',
[7935] = '1/130/165/200',
[7955] = '1/140/152/165',
[7953] = '1/120/135/150',
[7954] = '1/130/142/155',
[8238] = '1/125/145/165',
[8240] = '1/120/140/160',
[8243] = '1/185/205/225',
[8322] = '1/115/130/145',
[8334] = '1/115/122/130',
[8339] = '1/115/122/130',
[8366] = '1/110/130/150',
[8367] = '1/140/160/180',
[8368] = '1/170/185/200',
[8465] = '1/65/82/100',
[8467] = '1/135/152/170',
[8489] = '1/185/190/195',
[8483] = '1/170/175/180',
[8604] = '1/45/65/85',
[8607] = '1/80/100/120',
[8681] = '1/125/150/175',
[8687] = '1/165/190/215',
[8691] = '1/205/230/255',
[8694] = '1/215/240/265',
[8768] = '1/150/152/155',
[8776] = '1/50/67/85',
[8758] = '1/160/175/190',
[8760] = '1/155/160/165',
[8762] = '1/170/175/180',
[8764] = '1/190/205/220',
[8766] = '1/195/210/225',
[8770] = '1/210/225/240',
[8772] = '1/195/210/225',
[8774] = '1/200/215/230',
[8778] = '1/160/175/190',
[8780] = '1/165/180/195',
[8782] = '1/170/185/200',
[8784] = '1/185/200/215',
[8786] = '1/195/210/225',
[8789] = '1/200/215/230',
[8791] = '1/205/215/225',
[8793] = '1/210/225/240',
[8795] = '1/210/225/240',
[8797] = '1/215/230/245',
[8799] = '1/215/225/235',
[8802] = '1/220/235/250',
[8804] = '1/225/240/255',
[8880] = '1/70/90/110',
[8895] = '1/245/255/265',
[9058] = '1/40/55/70',
[9059] = '1/40/55/70',
[9060] = '1/60/75/90',
[9062] = '1/60/75/90',
[9064] = '1/65/80/95',
[9065] = '1/100/115/130',
[9068] = '1/125/140/155',
[9070] = '1/125/137/150',
[9072] = '1/145/157/170',
[9074] = '1/145/157/170',
[9145] = '1/150/162/175',
[9146] = '1/160/172/185',
[9147] = '1/160/172/185',
[9148] = '1/165/177/190',
[9149] = '1/170/182/195',
[9193] = '1/170/180/190',
[9194] = '1/170/180/190',
[9195] = '1/185/195/205',
[9196] = '1/195/205/215',
[9197] = '1/195/205/215',
[9198] = '1/200/210/220',
[9201] = '1/205/215/225',
[9202] = '1/210/220/230',
[9206] = '1/215/225/235',
[9207] = '1/220/230/240',
[9208] = '1/220/230/240',
[9269] = '1/150/162/175',
[9271] = '1/150/160/170',
[9273] = '1/160/180/200',
[9513] = '1/100/120/140',
[9811] = '1/185/197/210',
[9813] = '1/185/197/210',
[9814] = '1/200/212/225',
[9818] = '1/205/217/230',
[9820] = '1/210/222/235',
[9916] = '1/225/237/250',
[9918] = '1/200/205/210',
[9921] = '1/200/205/210',
[9920] = '1/200/205/210',
[9926] = '1/225/235/245',
[9928] = '1/225/235/245',
[9931] = '1/230/240/250',
[9933] = '1/230/240/250',
[9935] = '1/235/245/255',
[9937] = '1/235/245/255',
[9939] = '1/235/245/255',
[9942] = '1/240/250/260',
[9945] = '1/240/250/260',
[9950] = '1/240/250/260',
[9952] = '1/245/255/265',
[9954] = '1/245/255/265',
[9957] = '1/250/260/270',
[9959] = '1/250/260/270',
[9961] = '1/250/260/270',
[9964] = '1/255/265/275',
[9966] = '1/255/265/275',
[9968] = '1/255/265/275',
[9970] = '1/255/265/275',
[9972] = '1/260/270/280',
[9974] = '1/265/275/285',
[9979] = '1/265/275/285',
[9980] = '1/265/275/285',
[9983] = '1/70/90/110',
[9985] = '1/155/170/185',
[9986] = '1/160/175/190',
[9987] = '1/165/180/195',
[9993] = '1/235/247/260',
[9995] = '1/245/257/270',
[9997] = '1/250/262/275',
[10001] = '1/255/267/280',
[10003] = '1/260/272/285',
[10005] = '1/265/277/290',
[10007] = '1/270/282/295',
[10009] = '1/270/282/295',
[10011] = '1/275/287/300',
[10013] = '1/280/292/305',
[10015] = '1/285/297/310',
[10098] = '1/230/230/230',
[10097] = '1/175/175/175',
[10482] = '1/200/200/200',
[10487] = '1/220/230/240',
[10490] = '1/220/230/240',
[10499] = '1/225/235/245',
[10507] = '1/225/235/245',
[10509] = '1/225/235/245',
[10511] = '1/230/240/250',
[10516] = '1/230/240/250',
[10518] = '1/230/240/250',
[10520] = '1/235/245/255',
[10525] = '1/240/250/260',
[10529] = '1/240/250/260',
[10531] = '1/240/250/260',
[10533] = '1/240/250/260',
[10542] = '1/245/255/265',
[10544] = '1/245/255/265',
[10546] = '1/245/255/265',
[10619] = '1/245/255/265',
[10621] = '1/245/255/265',
[10548] = '1/250/260/270',
[10550] = '1/250/260/270',
[10552] = '1/250/260/270',
[10630] = '1/250/260/270',
[10554] = '1/255/265/275',
[10556] = '1/255/265/275',
[10558] = '1/255/265/275',
[10560] = '1/260/270/280',
[10562] = '1/260/270/280',
[10564] = '1/260/270/280',
[10566] = '1/265/275/285',
[10568] = '1/265/275/285',
[10570] = '1/270/280/290',
[10572] = '1/270/280/290',
[10574] = '1/270/280/290',
[10632] = '1/270/280/290',
[10647] = '1/270/280/290',
[10650] = '1/275/285/295',
[10840] = '1/210/240/270',
[10841] = '1/240/270/300',
[11341] = '1/245/270/295',
[11342] = '1/285/310/335',
[11343] = '1/325/350/375',
[11357] = '1/255/280/305',
[11358] = '1/295/320/345',
[3421] = '1/275/300/325',
[11400] = '1/285/310/335',
[11447] = '1/190/210/230',
[11449] = '1/205/225/245',
[11450] = '1/215/235/255',
[11451] = '1/220/240/260',
[11448] = '1/220/240/260',
[11452] = '1/225/245/265',
[11453] = '1/225/245/265',
[11456] = '1/225/245/265',
[11457] = '1/230/250/270',
[11458] = '1/240/260/280',
[11459] = '1/240/260/280',
[11460] = '1/245/265/285',
[11461] = '1/250/270/290',
[11464] = '1/250/270/290',
[11465] = '1/250/270/290',
[11466] = '1/255/275/295',
[11467] = '1/255/275/295',
[11468] = '1/255/275/295',
[11472] = '1/260/280/300',
[11473] = '1/260/280/300',
[11476] = '1/265/285/305',
[11477] = '1/265/285/305',
[11478] = '1/265/285/305',
[11479] = '1/240/260/280',
[11480] = '1/240/260/280',
[11643] = '1/225/235/245',
[12044] = '1/35/47/60',
[12045] = '1/50/67/85',
[12046] = '1/100/117/135',
[12047] = '1/145/162/180',
[12048] = '1/220/235/250',
[12049] = '1/220/235/250',
[12050] = '1/225/240/255',
[12052] = '1/225/240/255',
[12053] = '1/230/245/260',
[12055] = '1/230/245/260',
[12056] = '1/230/245/260',
[12059] = '1/220/225/230',
[12060] = '1/230/245/260',
[12061] = '1/220/225/230',
[12062] = '1/235/250/265',
[12063] = '1/235/250/265',
[12064] = '1/225/230/235',
[12065] = '1/240/255/270',
[12066] = '1/240/255/270',
[12067] = '1/240/255/270',
[12068] = '1/240/255/270',
[12069] = '1/240/255/270',
[12070] = '1/240/255/270',
[12071] = '1/240/255/270',
[12072] = '1/245/260/275',
[12073] = '1/245/260/275',
[12074] = '1/245/260/275',
[12075] = '1/235/240/245',
[12076] = '1/250/265/280',
[12077] = '1/240/245/250',
[12078] = '1/250/265/280',
[12079] = '1/250/265/280',
[12080] = '1/240/245/250',
[12081] = '1/255/270/285',
[12082] = '1/255/270/285',
[12083] = '1/255/270/285',
[12084] = '1/255/270/285',
[12085] = '1/245/250/255',
[12086] = '1/260/275/290',
[12087] = '1/260/275/290',
[12088] = '1/260/275/290',
[12089] = '1/250/255/260',
[12090] = '1/265/280/295',
[12091] = '1/255/260/265',
[12092] = '1/265/280/295',
[12093] = '1/265/280/295',
[12260] = '1/15/35/55',
[12259] = '1/180/192/205',
[12609] = '1/220/240/260',
[12584] = '1/150/170/190',
[12585] = '1/175/185/195',
[12586] = '1/175/185/195',
[12587] = '1/195/205/215',
[12590] = '1/175/195/215',
[12589] = '1/195/215/235',
[12591] = '1/200/220/240',
[12594] = '1/225/235/245',
[12595] = '1/225/235/245',
[12596] = '1/210/230/250',
[12597] = '1/230/240/250',
[12599] = '1/215/235/255',
[12603] = '1/215/235/255',
[12607] = '1/240/250/260',
[12614] = '1/240/250/260',
[12615] = '1/245/255/265',
[12616] = '1/245/255/265',
[12617] = '1/250/260/270',
[12618] = '1/250/260/270',
[12619] = '1/235/255/275',
[12620] = '1/260/270/280',
[12621] = '1/245/265/285',
[12622] = '1/265/275/285',
[12624] = '1/270/280/290',
[12715] = '1/205/205/205',
[12716] = '1/225/235/245',
[12717] = '1/225/235/245',
[12718] = '1/225/235/245',
[12760] = '1/205/225/245',
[12719] = '1/210/230/250',
[12720] = '1/235/245/255',
[12722] = '1/240/250/260',
[12755] = '1/230/250/270',
[12754] = '1/235/255/275',
[12759] = '1/260/270/280',
[12758] = '1/265/275/285',
[12895] = '1/205/205/205',
[12897] = '1/230/240/250',
[12899] = '1/225/235/245',
[12900] = '1/205/225/245',
[12902] = '1/230/240/250',
[12903] = '1/235/245/255',
[12904] = '1/240/250/260',
[12905] = '1/245/255/265',
[12906] = '1/250/260/270',
[12907] = '1/255/265/275',
[12908] = '1/260/270/280',
[13028] = '1/215/235/255',
[13220] = '1/185/210/235',
[13228] = '1/225/250/275',
[13229] = '1/265/290/315',
[13230] = '1/305/330/355',
[13262] = '1/20/40/60',
[13378] = '1/130/150/170',
[13380] = '1/135/155/175',
[13419] = '1/135/155/175',
[13421] = '1/140/160/180',
[13464] = '1/140/160/180',
[11454] = '1/225/237/250',
[13485] = '1/155/175/195',
[13501] = '1/155/175/195',
[13503] = '1/165/185/205',
[13522] = '1/160/180/200',
[13529] = '1/170/190/210',
[13536] = '1/165/185/205',
[13538] = '1/165/185/205',
[13607] = '1/170/190/210',
[13612] = '1/170/190/210',
[13617] = '1/170/190/210',
[13620] = '1/170/190/210',
[13622] = '1/175/195/215',
[13626] = '1/175/195/215',
[13628] = '1/175/195/215',
[13631] = '1/175/195/215',
[13635] = '1/175/195/215',
[13637] = '1/180/200/220',
[13640] = '1/180/200/220',
[13642] = '1/185/205/225',
[13644] = '1/190/210/230',
[13646] = '1/190/210/230',
[13648] = '1/190/210/230',
[13653] = '1/195/215/235',
[13655] = '1/195/215/235',
[13657] = '1/195/215/235',
[13659] = '1/200/220/240',
[13661] = '1/200/220/240',
[13663] = '1/205/225/245',
[13687] = '1/210/230/250',
[13689] = '1/215/235/255',
[13693] = '1/215/235/255',
[13695] = '1/220/240/260',
[13698] = '1/220/240/260',
[13700] = '1/220/240/260',
[13702] = '1/220/240/260',
[13746] = '1/225/245/265',
[13794] = '1/225/245/265',
[13815] = '1/230/250/270',
[13817] = '1/230/250/270',
[13822] = '1/230/250/270',
[13836] = '1/235/255/275',
[13841] = '1/235/255/275',
[13846] = '1/240/260/280',
[13858] = '1/240/260/280',
[13868] = '1/245/265/285',
[13882] = '1/245/265/285',
[13887] = '1/245/265/285',
[13890] = '1/245/265/285',
[13898] = '1/285/305/325',
[13905] = '1/250/270/290',
[13915] = '1/250/270/290',
[13917] = '1/250/270/290',
[13931] = '1/255/275/295',
[13933] = '1/255/275/295',
[13935] = '1/255/275/295',
[13937] = '1/260/280/300',
[13939] = '1/260/280/300',
[13941] = '1/265/285/305',
[13943] = '1/265/285/305',
[13945] = '1/265/285/305',
[13947] = '1/270/290/310',
[13948] = '1/270/290/310',
[14379] = '1/155/157/160',
[14380] = '1/205/207/210',
[14293] = '1/75/95/115',
[14807] = '1/110/130/150',
[14809] = '1/175/195/215',
[14810] = '1/195/215/235',
[14891] = '1/230/230/230',
[14930] = '1/245/255/265',
[14932] = '1/245/255/265',
[15255] = '1/200/220/240',
[15296] = '1/305/315/325',
[15293] = '1/290/300/310',
[15292] = '1/285/295/305',
[15294] = '1/295/305/315',
[15295] = '1/300/310/320',
[15596] = '1/285/305/325',
[15633] = '1/205/205/205',
[15628] = '1/205/205/205',
[15833] = '1/245/265/285',
[15935] = '1/45/65/85',
[15853] = '1/165/185/205',
[15855] = '1/215/235/255',
[15856] = '1/215/235/255',
[15861] = '1/215/235/255',
[15863] = '1/215/235/255',
[15865] = '1/215/235/255',
[15906] = '1/240/260/280',
[15910] = '1/240/260/280',
[15915] = '1/265/285/305',
[15933] = '1/265/285/305',
[15972] = '1/205/217/230',
[15973] = '1/215/227/240',
[16153] = '1/250/250/250',
[16641] = '1/255/257/260',
[16640] = '1/255/257/260',
[16639] = '1/255/257/260',
[16642] = '1/270/280/290',
[16643] = '1/270/280/290',
[16644] = '1/275/285/295',
[16645] = '1/280/290/300',
[16646] = '1/285/295/305',
[16647] = '1/285/295/305',
[16648] = '1/290/300/310',
[16649] = '1/290/300/310',
[16650] = '1/290/300/310',
[16651] = '1/295/305/315',
[16652] = '1/300/310/320',
[16653] = '1/300/310/320',
[16654] = '1/305/315/325',
[16667] = '1/305/315/325',
[16656] = '1/310/320/330',
[16660] = '1/310/320/330',
[16655] = '1/310/320/330',
[16657] = '1/315/325/335',
[16658] = '1/315/325/335',
[16659] = '1/315/325/335',
[16662] = '1/320/330/340',
[16663] = '1/320/330/340',
[16664] = '1/320/330/340',
[16665] = '1/320/330/340',
[16724] = '1/320/330/340',
[16725] = '1/320/330/340',
[16726] = '1/320/330/340',
[16730] = '1/320/330/340',
[16728] = '1/320/330/340',
[16729] = '1/320/330/340',
[16731] = '1/320/330/340',
[16732] = '1/320/330/340',
[16741] = '1/320/330/340',
[16742] = '1/320/330/340',
[16744] = '1/320/330/340',
[16745] = '1/320/330/340',
[16746] = '1/320/330/340',
[16960] = '1/285/297/310',
[16965] = '1/295/307/320',
[16967] = '1/295/307/320',
[16969] = '1/300/312/325',
[16970] = '1/300/312/325',
[16971] = '1/305/317/330',
[16973] = '1/305/317/330',
[16978] = '1/305/317/330',
[16980] = '1/310/322/335',
[16983] = '1/310/322/335',
[16984] = '1/315/327/340',
[16985] = '1/315/327/340',
[16986] = '1/325/337/350',
[16987] = '1/325/337/350',
[16988] = '1/320/330/340',
[16990] = '1/320/330/340',
[16991] = '1/320/330/340',
[16992] = '1/320/330/340',
[16993] = '1/320/330/340',
[16994] = '1/320/330/340',
[16995] = '1/320/330/340',
[16661] = '1/315/325/335',
[17181] = '1/250/255/260',
[17180] = '1/250/255/260',
[17187] = '1/275/282/290',
[17551] = '1/250/255/260',
[17552] = '1/270/290/310',
[17553] = '1/275/295/315',
[17554] = '1/280/300/320',
[17555] = '1/285/305/325',
[17556] = '1/290/310/330',
[17557] = '1/290/310/330',
[17559] = '1/275/282/290',
[17561] = '1/275/282/290',
[17566] = '1/275/282/290',
[17560] = '1/275/282/290',
[17563] = '1/275/282/290',
[17562] = '1/275/282/290',
[17564] = '1/275/282/290',
[17565] = '1/275/282/290',
[17570] = '1/295/315/335',
[17571] = '1/295/315/335',
[17572] = '1/300/320/340',
[17573] = '1/300/320/340',
[17574] = '1/305/325/345',
[17575] = '1/305/325/345',
[17576] = '1/305/325/345',
[17577] = '1/305/325/345',
[17578] = '1/305/325/345',
[17579] = '1/305/325/345',
[17580] = '1/310/330/350',
[17632] = '1/315/322/330',
[17634] = '1/315/322/330',
[17635] = '1/315/322/330',
[17636] = '1/315/322/330',
[17637] = '1/315/322/330',
[17638] = '1/315/322/330',
[18239] = '1/265/285/305',
[18238] = '1/265/285/305',
[18241] = '1/265/285/305',
[18240] = '1/280/300/320',
[18242] = '1/280/300/320',
[18243] = '1/290/310/330',
[18244] = '1/290/310/330',
[18245] = '1/315/335/355',
[18246] = '1/315/335/355',
[18247] = '1/315/335/355',
[18401] = '1/255/257/260',
[18402] = '1/270/285/300',
[18403] = '1/270/285/300',
[18404] = '1/270/285/300',
[18406] = '1/275/290/305',
[18405] = '1/275/290/305',
[18407] = '1/275/290/305',
[18408] = '1/275/290/305',
[18409] = '1/280/295/310',
[18410] = '1/280/295/310',
[18411] = '1/280/295/310',
[18412] = '1/285/300/315',
[18415] = '1/285/300/315',
[18413] = '1/285/300/315',
[18414] = '1/285/300/315',
[18416] = '1/290/305/320',
[18417] = '1/290/305/320',
[18418] = '1/290/305/320',
[18419] = '1/290/305/320',
[18420] = '1/290/305/320',
[18421] = '1/290/305/320',
[18422] = '1/290/305/320',
[18423] = '1/295/310/325',
[18424] = '1/295/310/325',
[18434] = '1/295/310/325',
[18436] = '1/300/315/330',
[18437] = '1/300/315/330',
[18438] = '1/300/315/330',
[18439] = '1/305/320/335',
[18440] = '1/305/320/335',
[18441] = '1/305/320/335',
[18442] = '1/305/320/335',
[18444] = '1/310/325/340',
[18445] = '1/315/330/345',
[18446] = '1/315/330/345',
[18447] = '1/315/330/345',
[18448] = '1/315/330/345',
[18449] = '1/315/330/345',
[18450] = '1/315/330/345',
[18451] = '1/315/330/345',
[18452] = '1/315/330/345',
[18453] = '1/315/330/345',
[18454] = '1/315/330/345',
[18455] = '1/315/330/345',
[18456] = '1/315/330/345',
[18457] = '1/315/330/345',
[18458] = '1/315/330/345',
[18560] = '1/290/305/320',
[18629] = '1/260/290/320',
[18630] = '1/290/320/350',
[19047] = '1/250/255/260',
[19058] = '1/250/260/270',
[19048] = '1/275/285/295',
[19049] = '1/280/290/300',
[19050] = '1/280/290/300',
[19051] = '1/285/295/305',
[19052] = '1/285/295/305',
[19053] = '1/285/295/305',
[19054] = '1/320/330/340',
[19055] = '1/290/300/310',
[19059] = '1/290/300/310',
[19060] = '1/290/300/310',
[19061] = '1/290/300/310',
[19062] = '1/290/300/310',
[19063] = '1/295/305/315',
[19064] = '1/295/305/315',
[19065] = '1/295/305/315',
[19066] = '1/295/305/315',
[19067] = '1/295/305/315',
[19068] = '1/295/305/315',
[19070] = '1/300/310/320',
[19071] = '1/300/310/320',
[19072] = '1/300/310/320',
[19073] = '1/300/310/320',
[19074] = '1/305/315/325',
[19075] = '1/305/315/325',
[19076] = '1/305/315/325',
[19077] = '1/305/315/325',
[19078] = '1/305/315/325',
[19079] = '1/305/315/325',
[19080] = '1/305/315/325',
[19081] = '1/310/320/330',
[19085] = '1/310/320/330',
[19084] = '1/310/320/330',
[19086] = '1/310/320/330',
[19082] = '1/310/320/330',
[19083] = '1/310/320/330',
[19089] = '1/315/325/335',
[19087] = '1/315/325/335',
[19088] = '1/315/325/335',
[19090] = '1/315/325/335',
[19094] = '1/320/330/340',
[19097] = '1/320/330/340',
[19095] = '1/320/330/340',
[19093] = '1/320/330/340',
[19091] = '1/320/330/340',
[19092] = '1/320/330/340',
[19100] = '1/320/330/340',
[19102] = '1/320/330/340',
[19101] = '1/320/330/340',
[19098] = '1/320/330/340',
[19107] = '1/320/330/340',
[19104] = '1/320/330/340',
[19106] = '1/320/330/340',
[19103] = '1/320/330/340',
[19435] = '1/295/310/325',
[19567] = '1/270/280/290',
[19666] = '1/100/110/120',
[19667] = '1/150/160/170',
[19668] = '1/200/210/220',
[19669] = '1/275/280/285',
[19788] = '1/250/255/260',
[19790] = '1/280/290/300',
[19792] = '1/280/290/300',
[19791] = '1/280/290/300',
[19793] = '1/285/295/305',
[19794] = '1/290/300/310',
[19796] = '1/295/305/315',
[19814] = '1/295/305/315',
[19795] = '1/295/305/315',
[19815] = '1/305/315/325',
[19799] = '1/305/315/325',
[19800] = '1/305/315/325',
[19819] = '1/310/320/330',
[19831] = '1/320/330/340',
[19830] = '1/320/330/340',
[19825] = '1/310/320/330',
[19833] = '1/320/330/340',
[3175] = '1/275/295/315',
[20008] = '1/275/295/315',
[20020] = '1/280/300/320',
[20014] = '1/285/305/325',
[20017] = '1/285/305/325',
[20009] = '1/290/310/330',
[20012] = '1/290/310/330',
[20024] = '1/295/315/335',
[20026] = '1/295/315/335',
[20016] = '1/300/320/340',
[20029] = '1/305/325/345',
[20015] = '1/305/325/345',
[20028] = '1/310/330/350',
[20051] = '1/310/330/350',
[20013] = '1/315/335/355',
[20023] = '1/315/335/355',
[20010] = '1/315/335/355',
[20030] = '1/315/335/355',
[20033] = '1/315/335/355',
[20036] = '1/320/340/360',
[20031] = '1/320/340/360',
[20011] = '1/320/340/360',
[20034] = '1/320/340/360',
[20025] = '1/320/340/360',
[20032] = '1/320/340/360',
[20035] = '1/320/340/360',
[20201] = '1/275/280/285',
[20626] = '1/265/285/305',
[20648] = '1/100/105/110',
[20649] = '1/150/155/160',
[20650] = '1/200/202/205',
[20848] = '1/315/330/345',
[20849] = '1/315/330/345',
[20853] = '1/315/325/335',
[20854] = '1/320/330/340',
[20855] = '1/320/330/340',
[20874] = '1/315/325/335',
[20872] = '1/315/325/335',
[20876] = '1/320/330/340',
[20873] = '1/320/330/340',
[20897] = '1/320/330/340',
[20890] = '1/320/330/340',
[20916] = '1/215/235/255',
[21144] = '1/75/95/115',
[21143] = '1/45/65/85',
[21161] = '1/325/337/350',
[21175] = '1/240/260/280',
[21913] = '1/215/227/240',
[21923] = '1/210/230/250',
[21931] = '1/210/230/250',
[21940] = '1/190/210/230',
[21943] = '1/210/220/230',
[21945] = '1/200/205/210',
[22331] = '1/250/250/250',
[22430] = '1/315/322/330',
[22434] = '1/320/315/310',
[22480] = '1/265/285/305',
[22704] = '1/320/330/340',
[22711] = '1/210/220/230',
[22727] = '1/320/330/340',
[22732] = '1/310/320/330',
[22749] = '1/320/340/360',
[22750] = '1/320/340/360',
[22757] = '1/300/310/320',
[22759] = '1/320/335/350',
[22761] = '1/315/335/355',
[22793] = '1/320/330/340',
[22795] = '1/320/330/340',
[22797] = '1/320/330/340',
[22808] = '1/230/250/270',
[22813] = '1/285/290/295',
[22815] = '1/285/290/295',
[22866] = '1/315/330/345',
[22867] = '1/315/330/345',
[22868] = '1/315/330/345',
[22869] = '1/315/330/345',
[22870] = '1/315/330/345',
[22902] = '1/315/330/345',
[22921] = '1/320/330/340',
[22922] = '1/320/330/340',
[22923] = '1/320/330/340',
[22926] = '1/320/330/340',
[22927] = '1/320/330/340',
[22928] = '1/320/330/340',
[22967] = '1/310/315/320',
[23066] = '1/150/162/175',
[23068] = '1/150/162/175',
[23067] = '1/150/162/175',
[23069] = '1/200/210/220',
[23070] = '1/250/260/270',
[23071] = '1/270/275/280',
[23077] = '1/280/290/300',
[23078] = '1/285/295/305',
[23079] = '1/285/290/295',
[23080] = '1/275/285/295',
[23081] = '1/310/320/330',
[23082] = '1/320/330/340',
[23096] = '1/275/280/285',
[23129] = '1/260/265/270',
[23190] = '1/150/155/160',
[23399] = '1/175/185/195',
[23489] = '1/285/295/305',
[23486] = '1/285/295/305',
[23507] = '1/250/260/270',
[23628] = '1/310/320/330',
[23629] = '1/320/330/340',
[23632] = '1/310/320/330',
[23633] = '1/320/330/340',
[23636] = '1/320/330/340',
[23637] = '1/320/330/340',
[23638] = '1/320/330/340',
[23639] = '1/320/330/340',
[23650] = '1/320/330/340',
[23652] = '1/320/330/340',
[23653] = '1/320/330/340',
[23662] = '1/305/320/335',
[23664] = '1/305/320/335',
[23663] = '1/315/330/345',
[23665] = '1/315/330/345',
[23666] = '1/315/330/345',
[23667] = '1/315/330/345',
[23703] = '1/310/320/330',
[23705] = '1/310/320/330',
[23704] = '1/320/330/340',
[23706] = '1/320/330/340',
[23707] = '1/320/330/340',
[23708] = '1/320/330/340',
[23709] = '1/320/330/340',
[23710] = '1/320/330/340',
[23787] = '1/300/330/360',
[23799] = '1/310/330/350',
[23800] = '1/310/330/350',
[23801] = '1/310/330/350',
[23802] = '1/320/340/360',
[23803] = '1/320/340/360',
[23804] = '1/320/340/360',
[24093] = '1/315/330/345',
[24092] = '1/315/330/345',
[24091] = '1/315/330/345',
[24124] = '1/320/330/340',
[24125] = '1/320/330/340',
[24123] = '1/320/330/340',
[24122] = '1/320/330/340',
[24121] = '1/320/330/340',
[24136] = '1/320/330/340',
[24138] = '1/320/330/340',
[24137] = '1/320/330/340',
[24139] = '1/320/330/340',
[24140] = '1/320/330/340',
[24141] = '1/320/330/340',
[24266] = '1/315/322/330',
[24356] = '1/320/330/340',
[24357] = '1/320/330/340',
[24365] = '1/290/310/330',
[24366] = '1/290/310/330',
[24367] = '1/300/320/340',
[24368] = '1/305/325/345',
[24399] = '1/320/330/340',
[24418] = '1/160/180/200',
[24655] = '1/300/310/320',
[24654] = '1/320/330/340',
[24801] = '1/325/345/365',
[24846] = '1/320/330/340',
[24847] = '1/320/330/340',
[24848] = '1/320/330/340',
[24849] = '1/320/330/340',
[24850] = '1/320/330/340',
[24851] = '1/320/330/340',
[24902] = '1/315/330/345',
[24903] = '1/315/330/345',
[24901] = '1/315/330/345',
[24914] = '1/320/330/340',
[24912] = '1/320/330/340',
[24913] = '1/320/330/340',
[24940] = '1/125/137/150',
[24703] = '1/320/330/340',
[25072] = '1/320/340/360',
[25073] = '1/320/340/360',
[25074] = '1/320/340/360',
[25078] = '1/320/340/360',
[25079] = '1/320/340/360',
[25080] = '1/320/340/360',
[25081] = '1/320/340/360',
[25082] = '1/320/340/360',
[25083] = '1/320/340/360',
[25084] = '1/320/340/360',
[25086] = '1/320/340/360',
[25124] = '1/55/65/75',
[25125] = '1/160/170/180',
[25126] = '1/210/220/230',
[25127] = '1/260/270/280',
[25128] = '1/285/295/305',
[25129] = '1/310/320/330',
[25130] = '1/310/320/330',
[25146] = '1/301/305/310',
[25347] = '1/300/325/350',
[25659] = '1/325/345/365',
[25704] = '1/120/140/160',
[25954] = '1/215/235/255',
[26011] = '1/320/330/340',
[26085] = '1/275/290/305',
[26086] = '1/300/315/330',
[26087] = '1/315/330/345',
[26279] = '1/320/330/340',
[26277] = '1/265/285/305',
[26403] = '1/265/280/295',
[26407] = '1/265/280/295',
[26416] = '1/125/137/150',
[26417] = '1/125/137/150',
[26418] = '1/125/137/150',
[26420] = '1/175/187/200',
[26421] = '1/175/187/200',
[26422] = '1/175/187/200',
[26423] = '1/225/237/250',
[26424] = '1/225/237/250',
[26425] = '1/225/237/250',
[26426] = '1/275/280/285',
[26427] = '1/275/280/285',
[26428] = '1/275/280/285',
[26442] = '1/245/255/265',
[26443] = '1/295/305/315',
[27585] = '1/320/330/340',
[27588] = '1/320/330/340',
[27586] = '1/320/330/340',
[27589] = '1/320/330/340',
[27590] = '1/320/330/340',
[27587] = '1/320/330/340',
[27658] = '1/240/255/270',
[27659] = '1/290/305/320',
[27660] = '1/315/330/345',
[27724] = '1/290/305/320',
[27725] = '1/315/330/345',
[27830] = '1/320/330/340',
[27829] = '1/320/330/340',
[27832] = '1/320/330/340',
[27837] = '1/310/330/350',
[28210] = '1/315/330/345',
[28208] = '1/315/330/345',
[28205] = '1/315/330/345',
[28207] = '1/315/330/345',
[28209] = '1/315/330/345',
[28224] = '1/320/330/340',
[28222] = '1/320/330/340',
[28223] = '1/320/330/340',
[28221] = '1/320/330/340',
[28220] = '1/320/330/340',
[28219] = '1/320/330/340',
[28244] = '1/320/330/340',
[28242] = '1/320/330/340',
[28243] = '1/320/330/340',
[28327] = '1/295/305/315',
[28461] = '1/320/330/340',
[28462] = '1/320/330/340',
[28463] = '1/320/330/340',
[28474] = '1/320/330/340',
[28473] = '1/320/330/340',
[28472] = '1/320/330/340',
[28481] = '1/315/330/345',
[28482] = '1/315/330/345',
[28480] = '1/315/330/345',
[30021] = '1/300/330/360',
[30047] = '1/325/345/365',
[426607] = '1/90/100/110',
[427061] = '1/140/150/160',
[428424] = '1/125/137/150',
[429348] = '1/175/190/205',
[429351] = '1/150/167/185',
[429354] = '1/160/172/185',
[424641] = '1/135/140/145',
[429869] = '1/160/172/185',
[430397] = '1/100/110/120',
[430409] = '1/100/110/120',
[435481] = '1/200/217/235',
[435827] = '1/200/210/220',
[435848] = '1/170/185/200',
[435841] = '1/170/185/200',
[435903] = '1/200/220/240',
[435610] = '1/225/230/235',
[435819] = '1/200/210/220',
[435910] = '1/200/210/220',
[435969] = '1/200/210/220',
[435956] = '1/200/210/220',
[435953] = '1/225/230/235',
[435904] = '1/225/230/235',
[435951] = '1/225/230/235',
[435949] = '1/225/230/235',
[435966] = '1/225/230/235',
[435958] = '1/225/232/240',
[435964] = '1/225/230/235',
[435960] = '1/225/230/235',
[435908] = '1/225/230/235',
[435906] = '1/225/230/235',
[435971] = '1/225/230/235',
[439085] = '1/220/235/250',
[439086] = '1/220/235/250',
[439088] = '1/220/235/250',
[439091] = '1/215/230/245',
[439093] = '1/210/225/240',
[439094] = '1/205/220/235',
[439097] = '1/195/210/225',
[439098] = '1/195/210/225',
[439100] = '1/190/205/220',
[439102] = '1/185/200/215',
[439105] = '1/240/250/260',
[439108] = '1/235/245/255',
[439110] = '1/215/225/235',
[439112] = '1/190/200/210',
[439114] = '1/180/190/200',
[439116] = '1/230/240/250',
[439118] = '1/225/235/245',
[439120] = '1/225/235/245',
[439122] = '1/225/237/250',
[439124] = '1/220/232/245',
[439126] = '1/215/227/240',
[439130] = '1/200/212/225',
[439132] = '1/195/207/220',
[439128] = '1/205/217/230',
[439134] = '1/195/215/235',
[439156] = '1/225/227/230',
[439505] = '1/300/325/350',
[439503] = '1/300/325/350',
[439500] = '1/300/325/350',
[439960] = '1/210/212/215',
[446226] = '1/250/255/260',
[446243] = '1/250/255/260',
[446191] = '1/250/255/260',
[446188] = '1/250/255/260',
[446179] = '1/250/255/260',
[446186] = '1/250/255/260',
[446192] = '1/250/255/260',
[446183] = '1/250/255/260',
[446189] = '1/250/255/260',
[446185] = '1/250/255/260',
[446190] = '1/250/255/260',
[446193] = '1/250/255/260',
[446194] = '1/250/255/260',
[446195] = '1/250/255/260',
[446236] = '1/250/255/260',
[446238] = '1/250/255/260',
[446237] = '1/250/255/260',
[446851] = '1/250/255/260',
[448085] = '1/250/255/260',
[448624] = '1/120/125/130',
[451706] = '1/250/255/260',
--@end-version-classic@]====]
}
Skillet.db.global.SkillLineAbility_cata = {
--[====[@version-cata@
[2149] = '1/40/55/70',
[2153] = '30/45/60/75',
[2152] = '1/30/45/60',
[2158] = '45/120/135/150',
[2159] = '1/105/120/135',
[2160] = '50/70/85/100',
[2161] = '65/85/100/115',
[2162] = '65/90/105/120',
[2163] = '70/90/105/120',
[2164] = '70/105/120/135',
[2165] = '75/115/122/130',
[2166] = '125/145/157/170',
[2167] = '100/125/137/150',
[2168] = '110/135/147/160',
[2169] = '100/125/137/150',
[2330] = '1/55/75/95',
[2329] = '1/55/75/95',
[2331] = '30/65/85/105',
[2332] = '40/70/90/110',
[2334] = '50/80/100/120',
[2335] = '60/90/110/130',
[2337] = '80/85/105/125',
[2538] = '1/45/65/85',
[2539] = '30/50/70/90',
[2540] = '1/45/65/85',
[2541] = '65/90/110/130',
[2542] = '65/90/110/130',
[2543] = '75/115/135/155',
[2544] = '75/115/135/155',
[2545] = '85/125/145/165',
[2546] = '110/120/140/160',
[2547] = '125/135/155/175',
[2548] = '135/130/150/170',
[2549] = '135/140/160/180',
[2658] = '1/100/105/110',
[2659] = '1/50/75/100',
[2660] = '1/15/35/55',
[2661] = '55/75/95/115',
[2662] = '40/50/70/90',
[2663] = '1/20/40/60',
[2664] = '65/115/127/140',
[2665] = '75/65/72/80',
[2666] = '80/110/130/150',
[2667] = '90/120/140/160',
[2668] = '95/145/160/175',
[2670] = '105/145/160/175',
[2672] = '120/150/165/180',
[2674] = '125/125/132/140',
[2675] = '135/175/190/205',
[2737] = '30/55/75/95',
[2740] = '75/140/155/170',
[2741] = '85/145/160/175',
[2738] = '35/60/80/100',
[2739] = '40/65/85/105',
[2742] = '95/150/165/180',
[2795] = '40/60/80/100',
[2881] = '1/20/30/40',
[3115] = '1/15/35/55',
[3117] = '1/125/132/140',
[3116] = '1/65/72/80',
[3171] = '1/120/140/160',
[3172] = '1/135/155/175',
[3173] = '1/145/165/185',
[3174] = '1/145/165/185',
[3176] = '1/150/170/190',
[3177] = '1/155/175/195',
[2333] = '1/165/185/205',
[3188] = '1/175/195/215',
[3170] = '1/60/80/100',
[3230] = '1/80/100/120',
[3275] = '1/30/45/60',
[3276] = '40/50/75/100',
[3277] = '80/80/115/150',
[3278] = '115/115/150/185',
[3308] = '1/150/155/160',
[3307] = '1/100/125/150',
[3304] = '1/40/57/75',
[3292] = '1/135/155/175',
[3293] = '1/75/95/115',
[3294] = '1/110/130/150',
[3295] = '1/155/170/185',
[3296] = '1/160/175/190',
[3297] = '1/175/190/205',
[3319] = '1/60/80/100',
[3320] = '1/45/65/85',
[3321] = '1/75/95/115',
[3323] = '1/80/100/120',
[3324] = '1/85/105/125',
[3325] = '1/100/120/140',
[3326] = '1/75/87/100',
[3328] = '1/140/155/170',
[3330] = '1/155/170/185',
[3331] = '1/160/175/190',
[3333] = '1/165/180/195',
[3334] = '1/175/190/205',
[3336] = '1/180/195/210',
[3337] = '1/125/137/150',
[3370] = '1/120/140/160',
[3371] = '1/100/120/140',
[3372] = '1/130/150/170',
[3373] = '1/160/180/200',
[3376] = '1/170/190/210',
[3377] = '1/150/170/190',
[3397] = '1/150/170/190',
[3398] = '1/175/195/215',
[3399] = '1/190/210/230',
[3400] = '1/215/235/255',
[3447] = '1/135/155/175',
[3448] = '1/185/205/225',
[3449] = '1/190/210/230',
[3450] = '1/195/215/235',
[3451] = '1/200/220/240',
[3452] = '1/180/200/220',
[3453] = '1/215/235/255',
[3454] = '1/220/240/260',
[3491] = '1/135/150/165',
[3492] = '1/185/197/210',
[3493] = '1/200/212/225',
[3494] = '1/180/192/205',
[3495] = '1/195/207/220',
[3496] = '1/205/217/230',
[3497] = '1/225/237/250',
[3498] = '1/210/222/235',
[3500] = '1/225/237/250',
[3501] = '1/190/202/215',
[3502] = '1/195/207/220',
[3503] = '1/215/227/240',
[3504] = '1/185/197/210',
[3505] = '1/200/212/225',
[3506] = '1/180/192/205',
[3507] = '1/195/207/220',
[3508] = '1/205/217/230',
[3511] = '1/220/232/245',
[3513] = '1/210/222/235',
[3515] = '1/225/237/250',
[3569] = '1/125/130/135',
[3753] = '1/55/70/85',
[3756] = '1/85/100/115',
[3759] = '1/105/120/135',
[3760] = '1/170/180/190',
[3761] = '1/115/130/145',
[3762] = '1/125/137/150',
[3763] = '1/110/125/140',
[3764] = '1/170/182/195',
[3765] = '1/155/167/180',
[3766] = '1/150/162/175',
[3767] = '1/145/157/170',
[3768] = '1/155/167/180',
[3769] = '1/165/177/190',
[3770] = '1/160/172/185',
[3771] = '1/170/180/190',
[3772] = '1/175/185/195',
[3773] = '1/195/205/215',
[3774] = '1/180/190/200',
[3775] = '1/190/200/210',
[3776] = '1/200/210/220',
[3777] = '1/215/225/235',
[3778] = '1/205/215/225',
[3779] = '1/220/230/240',
[3816] = '1/55/65/75',
[3817] = '1/115/122/130',
[3818] = '1/160/165/170',
[3780] = '1/170/180/190',
[2963] = '1/25/37/50',
[2387] = '1/35/47/60',
[2385] = '1/45/57/70',
[2389] = '1/65/82/100',
[2386] = '1/90/107/125',
[2392] = '1/65/82/100',
[2393] = '1/35/47/60',
[2394] = '1/65/82/100',
[2397] = '1/85/102/120',
[2395] = '1/95/112/130',
[2396] = '1/95/112/130',
[2964] = '1/90/97/105',
[2402] = '1/100/117/135',
[2399] = '1/110/127/145',
[2401] = '1/120/137/155',
[2403] = '1/130/147/165',
[2406] = '1/110/120/130',
[3839] = '1/135/140/145',
[3865] = '1/180/182/185',
[3840] = '1/60/77/95',
[3841] = '1/85/102/120',
[3842] = '1/95/112/130',
[3843] = '1/110/127/145',
[3844] = '1/125/142/160',
[3845] = '1/105/122/140',
[3847] = '1/120/137/155',
[3848] = '1/135/152/170',
[3849] = '1/145/162/180',
[3850] = '1/135/152/170',
[3851] = '1/150/167/185',
[3852] = '1/150/165/180',
[3854] = '1/165/180/195',
[3855] = '1/150/167/185',
[3856] = '1/160/175/190',
[3857] = '1/185/200/215',
[3858] = '1/190/205/220',
[3859] = '1/170/185/200',
[3860] = '1/195/210/225',
[3861] = '1/205/220/235',
[3862] = '1/220/235/250',
[3863] = '1/200/215/230',
[3864] = '1/220/235/250',
[3866] = '1/135/152/170',
[3868] = '1/150/167/185',
[3869] = '1/145/150/155',
[3870] = '1/165/170/175',
[3871] = '1/180/185/190',
[3872] = '1/195/200/205',
[3873] = '1/210/215/220',
[3914] = '1/55/72/90',
[3915] = '1/35/47/60',
[3918] = '1/20/30/40',
[3919] = '1/30/45/60',
[3922] = '1/45/52/60',
[3923] = '1/60/75/90',
[3925] = '1/80/95/110',
[3977] = '1/90/105/120',
[3973] = '1/110/125/140',
[3928] = '1/105/120/135',
[3929] = '1/85/90/95',
[3931] = '1/95/100/105',
[3932] = '1/115/130/145',
[3933] = '1/130/145/160',
[3934] = '1/130/145/160',
[3936] = '1/130/142/155',
[3937] = '1/125/140/155',
[3938] = '1/115/135/155',
[3978] = '1/135/147/160',
[3939] = '1/145/157/170',
[3940] = '1/145/157/170',
[3941] = '1/120/145/170',
[3942] = '1/125/150/175',
[3944] = '1/125/150/175',
[3945] = '1/125/135/145',
[3946] = '1/125/135/145',
[3949] = '1/155/167/180',
[3950] = '1/140/165/190',
[3952] = '1/165/177/190',
[3953] = '1/145/170/195',
[3954] = '1/170/182/195',
[3955] = '1/175/187/200',
[3956] = '1/175/187/200',
[3957] = '1/175/185/195',
[3958] = '1/160/170/180',
[3959] = '1/180/190/200',
[3960] = '1/185/195/205',
[3961] = '1/170/190/210',
[3962] = '1/175/195/215',
[3963] = '1/175/195/215',
[3979] = '1/200/210/220',
[3965] = '1/185/205/225',
[3966] = '1/205/215/225',
[3967] = '1/190/210/230',
[3968] = '1/215/225/235',
[3969] = '1/220/230/240',
[3971] = '1/220/230/240',
[3972] = '1/200/220/240',
[4094] = '1/215/235/255',
[4097] = '1/185/195/205',
[4096] = '1/185/195/205',
[4508] = '1/80/100/120',
[4942] = '1/230/250/270',
[2657] = '1/20/40/60',
[5244] = '1/70/85/100',
[6412] = '1/50/70/90',
[6413] = '1/60/80/100',
[6414] = '1/75/95/115',
[6415] = '1/90/110/130',
[6416] = '1/90/110/130',
[6417] = '1/130/150/170',
[6418] = '1/140/160/180',
[6419] = '1/150/170/190',
[6458] = '1/160/172/185',
[6501] = '1/130/150/170',
[6500] = '1/165/185/205',
[6499] = '1/90/110/130',
[6518] = '1/170/185/200',
[6517] = '1/140/155/170',
[6521] = '1/115/132/150',
[2671] = '1/145/160/175',
[2673] = '1/160/175/190',
[3758] = '1/120/137/155',
[3755] = '1/70/87/105',
[3757] = '1/105/122/140',
[3813] = '1/170/185/200',
[6624] = '1/175/195/215',
[6618] = '1/195/215/235',
[6617] = '1/90/110/130',
[6661] = '1/210/220/230',
[6686] = '1/95/112/130',
[6688] = '1/140/157/175',
[6690] = '1/155/170/185',
[6692] = '1/170/185/200',
[6693] = '1/195/210/225',
[6695] = '1/205/220/235',
[6702] = '1/120/135/150',
[6705] = '1/210/220/230',
[6703] = '1/125/140/155',
[6704] = '1/190/200/210',
[7126] = '1/40/55/70',
[7133] = '1/130/142/155',
[7135] = '1/140/152/165',
[7147] = '1/180/190/200',
[7149] = '1/190/200/210',
[7151] = '1/195/205/215',
[7153] = '1/205/215/225',
[7156] = '1/210/220/230',
[7179] = '1/120/140/160',
[7181] = '1/175/195/215',
[7183] = '1/55/75/95',
[7213] = '1/215/235/255',
[7224] = '1/215/227/240',
[7223] = '1/210/222/235',
[7221] = '1/180/195/210',
[7222] = '1/190/202/215',
[7257] = '1/210/230/250',
[7258] = '1/205/225/245',
[7255] = '1/130/150/170',
[7259] = '1/210/230/250',
[7256] = '1/160/180/200',
[7408] = '1/105/125/145',
[7418] = '1/70/90/110',
[7420] = '1/70/90/110',
[7421] = '1/5/7/10',
[7426] = '1/90/110/130',
[7428] = '1/80/100/120',
[7430] = '1/70/80/90',
[7443] = '1/80/100/120',
[7454] = '1/95/115/135',
[7457] = '1/100/120/140',
[7623] = '1/55/72/90',
[7624] = '1/55/72/90',
[7630] = '1/80/97/115',
[7629] = '1/80/97/115',
[7633] = '1/95/112/130',
[7636] = '1/115/132/150',
[7639] = '1/125/142/160',
[7643] = '1/140/157/175',
[7748] = '1/105/125/145',
[7751] = '1/45/65/85',
[7752] = '1/45/65/85',
[7753] = '1/90/110/130',
[7754] = '1/90/110/130',
[7755] = '1/140/160/180',
[7766] = '1/105/125/145',
[7771] = '1/110/130/150',
[7776] = '1/115/135/155',
[7779] = '1/115/135/155',
[7782] = '1/115/135/155',
[7786] = '1/120/140/160',
[7788] = '1/120/140/160',
[7745] = '1/130/150/170',
[7793] = '1/130/150/170',
[7795] = '1/130/150/170',
[7817] = '1/125/140/155',
[7818] = '1/105/107/110',
[7827] = '1/90/110/130',
[7828] = '1/190/210/230',
[7836] = '1/80/90/100',
[7837] = '1/150/160/170',
[7841] = '1/130/150/170',
[7845] = '1/165/185/205',
[7857] = '1/145/165/185',
[7859] = '1/145/165/185',
[7861] = '1/150/170/190',
[7863] = '1/150/170/190',
[7867] = '1/150/170/190',
[7892] = '1/145/162/180',
[7893] = '1/145/162/180',
[7928] = '150/150/180/210',
[7929] = '180/180/210/240',
[7934] = '80/80/115/150',
[7935] = '1/130/165/200',
[7955] = '1/140/152/165',
[7953] = '1/120/135/150',
[7954] = '1/130/142/155',
[8238] = '1/125/145/165',
[8240] = '1/120/140/160',
[8243] = '1/185/205/225',
[8322] = '1/115/130/145',
[8334] = '1/115/122/130',
[8339] = '1/115/122/130',
[8366] = '1/110/130/150',
[8367] = '1/140/160/180',
[8368] = '1/170/185/200',
[8465] = '1/65/82/100',
[8467] = '1/135/152/170',
[8489] = '1/185/190/195',
[8483] = '1/170/175/180',
[8604] = '1/45/65/85',
[8607] = '1/80/100/120',
[8768] = '1/150/152/155',
[8776] = '1/50/67/85',
[8758] = '1/160/175/190',
[8760] = '1/155/160/165',
[8762] = '1/170/175/180',
[8764] = '1/190/205/220',
[8766] = '1/195/210/225',
[8770] = '1/210/225/240',
[8772] = '1/195/210/225',
[8774] = '1/200/215/230',
[8778] = '1/160/175/190',
[8780] = '1/165/180/195',
[8782] = '1/170/185/200',
[8784] = '1/185/200/215',
[8786] = '1/195/210/225',
[8789] = '1/200/215/230',
[8791] = '1/205/215/225',
[8793] = '1/210/225/240',
[8795] = '1/210/225/240',
[8797] = '1/215/230/245',
[8799] = '1/215/225/235',
[8802] = '1/220/235/250',
[8804] = '1/225/240/255',
[8880] = '1/70/90/110',
[8895] = '1/245/255/265',
[9058] = '1/40/55/70',
[9059] = '1/40/55/70',
[9064] = '1/65/80/95',
[9065] = '1/100/115/130',
[9068] = '1/125/140/155',
[9070] = '1/125/137/150',
[9072] = '1/145/157/170',
[9074] = '1/145/157/170',
[9145] = '1/150/162/175',
[9146] = '1/160/172/185',
[9147] = '1/160/172/185',
[9148] = '1/165/177/190',
[9149] = '1/170/182/195',
[9195] = '1/185/195/205',
[9196] = '1/195/205/215',
[9197] = '1/195/205/215',
[9198] = '1/200/210/220',
[9201] = '1/205/215/225',
[9202] = '1/210/220/230',
[9206] = '1/215/225/235',
[9207] = '1/220/230/240',
[9208] = '1/220/230/240',
[9269] = '1/150/162/175',
[9271] = '1/150/160/170',
[9273] = '1/160/180/200',
[9513] = '1/100/120/140',
[9811] = '1/185/197/210',
[9813] = '1/185/197/210',
[9814] = '1/200/212/225',
[9818] = '1/205/217/230',
[9820] = '1/210/222/235',
[9916] = '1/225/237/250',
[9918] = '1/200/205/210',
[9921] = '1/200/205/210',
[9920] = '1/200/205/210',
[9926] = '1/225/235/245',
[9928] = '1/225/235/245',
[9931] = '1/230/240/250',
[9933] = '1/230/240/250',
[9935] = '1/235/245/255',
[9937] = '1/235/245/255',
[9939] = '1/235/245/255',
[9942] = '1/240/250/260',
[9945] = '1/240/250/260',
[9950] = '1/240/250/260',
[9952] = '1/245/255/265',
[9954] = '1/245/255/265',
[9957] = '1/250/260/270',
[9959] = '1/250/260/270',
[9961] = '1/250/260/270',
[9964] = '1/255/265/275',
[9966] = '1/255/265/275',
[9968] = '1/255/265/275',
[9970] = '1/255/265/275',
[9972] = '1/260/270/280',
[9974] = '1/265/275/285',
[9979] = '1/265/275/285',
[9980] = '1/265/275/285',
[9983] = '1/70/90/110',
[9985] = '1/155/170/185',
[9986] = '1/160/175/190',
[9987] = '1/165/180/195',
[9993] = '1/235/247/260',
[9995] = '1/245/257/270',
[9997] = '1/250/262/275',
[10001] = '1/255/267/280',
[10003] = '1/260/272/285',
[10005] = '1/265/277/290',
[10007] = '1/270/282/295',
[10009] = '1/270/282/295',
[10011] = '1/275/287/300',
[10013] = '1/280/292/305',
[10015] = '1/285/297/310',
[10098] = '1/200/205/210',
[10097] = '1/150/175/200',
[10482] = '1/200/200/200',
[10487] = '1/220/230/240',
[10490] = '1/220/230/240',
[10499] = '1/225/235/245',
[10507] = '1/225/235/245',
[10509] = '1/225/235/245',
[10511] = '1/230/240/250',
[10516] = '1/230/240/250',
[10518] = '1/230/240/250',
[10520] = '1/235/245/255',
[10525] = '1/240/250/260',
[10529] = '1/240/250/260',
[10531] = '1/240/250/260',
[10533] = '1/240/250/260',
[10542] = '1/245/255/265',
[10544] = '1/245/255/265',
[10546] = '1/245/255/265',
[10619] = '1/245/255/265',
[10621] = '1/245/255/265',
[10548] = '1/250/260/270',
[10550] = '1/250/260/270',
[10552] = '1/250/260/270',
[10630] = '1/250/260/270',
[10554] = '1/255/265/275',
[10556] = '1/255/265/275',
[10558] = '1/255/265/275',
[10560] = '1/260/270/280',
[10562] = '1/260/270/280',
[10564] = '1/260/270/280',
[10566] = '1/265/275/285',
[10568] = '1/265/275/285',
[10570] = '1/270/280/290',
[10572] = '1/270/280/290',
[10574] = '1/270/280/290',
[10632] = '1/270/280/290',
[10647] = '1/270/280/290',
[10650] = '1/275/285/295',
[10840] = '210/210/240/270',
[10841] = '1/240/270/300',
[11449] = '1/205/225/245',
[11450] = '1/215/235/255',
[11451] = '1/220/240/260',
[11448] = '1/220/240/260',
[11452] = '1/225/245/265',
[11453] = '1/225/245/265',
[11456] = '1/225/245/265',
[11457] = '1/230/250/270',
[11458] = '1/240/260/280',
[11459] = '1/240/260/280',
[11460] = '1/245/265/285',
[11461] = '1/250/270/290',
[11464] = '1/250/270/290',
[11465] = '1/250/270/290',
[11466] = '1/255/275/295',
[11467] = '1/255/275/295',
[11468] = '1/255/275/295',
[11472] = '1/260/280/300',
[11473] = '1/260/280/300',
[11476] = '1/265/285/305',
[11477] = '1/265/285/305',
[11478] = '1/265/285/305',
[11479] = '1/240/260/280',
[11480] = '1/240/260/280',
[11643] = '1/225/235/245',
[12044] = '1/35/47/60',
[12045] = '1/50/67/85',
[12046] = '1/100/117/135',
[12047] = '1/145/162/180',
[12048] = '1/220/235/250',
[12049] = '1/220/235/250',
[12050] = '1/225/240/255',
[12052] = '1/225/240/255',
[12053] = '1/230/245/260',
[12055] = '1/230/245/260',
[12056] = '1/230/245/260',
[12059] = '1/220/225/230',
[12060] = '1/230/245/260',
[12061] = '1/220/225/230',
[12062] = '1/235/250/265',
[12063] = '1/235/250/265',
[12064] = '1/225/230/235',
[12065] = '1/240/255/270',
[12066] = '1/240/255/270',
[12067] = '1/240/255/270',
[12068] = '1/240/255/270',
[12069] = '1/240/255/270',
[12070] = '1/240/255/270',
[12071] = '1/240/255/270',
[12072] = '1/245/260/275',
[12073] = '1/245/260/275',
[12074] = '1/245/260/275',
[12075] = '1/235/240/245',
[12076] = '1/250/265/280',
[12077] = '1/240/245/250',
[12078] = '1/250/265/280',
[12079] = '1/250/265/280',
[12080] = '1/240/245/250',
[12081] = '1/255/270/285',
[12082] = '1/255/270/285',
[12083] = '1/255/270/285',
[12084] = '1/255/270/285',
[12085] = '1/245/250/255',
[12086] = '1/260/275/290',
[12087] = '1/260/275/290',
[12088] = '1/260/275/290',
[12089] = '1/250/255/260',
[12090] = '1/265/280/295',
[12091] = '1/255/260/265',
[12092] = '1/265/280/295',
[12093] = '1/265/280/295',
[12260] = '1/15/35/55',
[12259] = '1/180/192/205',
[12609] = '1/220/240/260',
[12584] = '1/150/170/190',
[12585] = '1/175/185/195',
[12586] = '1/175/185/195',
[12587] = '1/195/205/215',
[12590] = '1/175/195/215',
[12589] = '1/195/215/235',
[12591] = '1/200/220/240',
[12594] = '1/225/235/245',
[12595] = '1/225/235/245',
[12597] = '1/230/240/250',
[12599] = '1/215/235/255',
[12603] = '1/215/235/255',
[12607] = '1/240/250/260',
[12614] = '1/240/250/260',
[12615] = '1/245/255/265',
[12616] = '1/245/255/265',
[12617] = '1/250/260/270',
[12618] = '1/250/260/270',
[12619] = '1/235/255/275',
[12620] = '1/260/270/280',
[12622] = '1/265/275/285',
[12624] = '1/270/280/290',
[12715] = '1/205/205/205',
[12716] = '1/225/235/245',
[12717] = '1/225/235/245',
[12718] = '1/225/235/245',
[12760] = '1/205/225/245',
[12722] = '1/240/250/260',
[12755] = '1/230/250/270',
[12754] = '1/235/255/275',
[12759] = '1/260/270/280',
[12758] = '1/265/275/285',
[12895] = '1/195/195/195',
[12897] = '1/230/240/250',
[12899] = '1/225/235/245',
[12900] = '1/205/225/245',
[12902] = '1/230/240/250',
[12903] = '1/235/245/255',
[12904] = '1/240/250/260',
[12905] = '1/245/255/265',
[12906] = '1/250/260/270',
[12907] = '1/255/265/275',
[12908] = '1/260/270/280',
[13240] = '1/1/1/1',
[13262] = '1/20/40/60',
[13378] = '1/130/150/170',
[13380] = '1/135/155/175',
[13419] = '1/135/155/175',
[13421] = '1/140/160/180',
[13464] = '1/140/160/180',
[11454] = '1/225/237/250',
[13485] = '1/155/175/195',
[13501] = '1/155/175/195',
[13503] = '1/165/185/205',
[13522] = '1/160/180/200',
[13529] = '1/170/190/210',
[13536] = '1/165/185/205',
[13538] = '1/165/185/205',
[13607] = '1/170/190/210',
[13612] = '1/170/190/210',
[13617] = '1/170/190/210',
[13620] = '1/170/190/210',
[13622] = '1/175/195/215',
[13626] = '1/175/195/215',
[13628] = '1/175/195/215',
[13631] = '1/175/195/215',
[13635] = '1/175/195/215',
[13637] = '1/180/200/220',
[13640] = '1/180/200/220',
[13642] = '1/185/205/225',
[13644] = '1/190/210/230',
[13646] = '1/190/210/230',
[13648] = '1/190/210/230',
[13653] = '1/195/215/235',
[13655] = '1/195/215/235',
[13657] = '1/195/215/235',
[13659] = '1/200/220/240',
[13661] = '1/200/220/240',
[13663] = '1/205/225/245',
[13687] = '1/210/230/250',
[13689] = '1/215/235/255',
[13693] = '1/215/235/255',
[13695] = '1/220/240/260',
[13698] = '1/220/240/260',
[13700] = '1/220/240/260',
[13702] = '1/220/240/260',
[13746] = '1/225/245/265',
[13794] = '1/225/245/265',
[13815] = '1/230/250/270',
[13817] = '1/230/250/270',
[13822] = '1/230/250/270',
[13836] = '1/235/255/275',
[13841] = '1/235/255/275',
[13846] = '1/240/260/280',
[13858] = '1/240/260/280',
[13868] = '1/245/265/285',
[13882] = '1/245/265/285',
[13887] = '1/245/265/285',
[13890] = '1/245/265/285',
[13898] = '1/285/305/325',
[13905] = '1/250/270/290',
[13915] = '1/250/270/290',
[13917] = '1/250/270/290',
[13931] = '1/255/275/295',
[13933] = '1/255/275/295',
[13935] = '1/255/275/295',
[13937] = '1/260/280/300',
[13939] = '1/260/280/300',
[13941] = '1/265/285/305',
[13943] = '1/265/285/305',
[13945] = '1/265/285/305',
[13947] = '1/270/290/310',
[13948] = '1/270/290/310',
[14379] = '1/155/157/160',
[14380] = '1/205/207/210',
[14293] = '1/75/95/115',
[14807] = '1/110/130/150',
[14809] = '1/175/195/215',
[14810] = '1/195/215/235',
[14891] = '1/300/305/310',
[15255] = '1/200/220/240',
[15296] = '1/305/315/325',
[15293] = '1/290/300/310',
[15292] = '1/285/295/305',
[15294] = '1/295/305/315',
[15295] = '1/300/310/320',
[15596] = '1/285/305/325',
[15633] = '1/205/205/205',
[15628] = '1/205/205/205',
[15833] = '1/245/265/285',
[15935] = '1/45/65/85',
[15853] = '1/165/185/205',
[15855] = '1/215/235/255',
[15856] = '1/215/235/255',
[15861] = '1/215/235/255',
[15863] = '1/215/235/255',
[15865] = '1/215/235/255',
[15906] = '1/225/237/250',
[15910] = '1/225/237/250',
[15915] = '1/250/262/275',
[15933] = '1/250/262/275',
[15972] = '1/205/217/230',
[15973] = '1/215/227/240',
[16153] = '1/200/245/290',
[16641] = '1/255/257/260',
[16640] = '1/255/257/260',
[16639] = '1/255/257/260',
[16642] = '1/270/280/290',
[16643] = '1/270/280/290',
[16644] = '1/275/285/295',
[16645] = '1/280/290/300',
[16646] = '1/285/295/305',
[16647] = '1/285/295/305',
[16648] = '1/290/300/310',
[16649] = '1/290/300/310',
[16650] = '1/290/300/310',
[16651] = '1/295/305/315',
[16652] = '1/300/310/320',
[16653] = '1/300/310/320',
[16654] = '1/305/315/325',
[16667] = '1/305/315/325',
[16656] = '1/310/320/330',
[16660] = '1/310/320/330',
[16655] = '1/310/320/330',
[16657] = '1/315/325/335',
[16658] = '1/315/325/335',
[16659] = '1/315/325/335',
[16662] = '1/320/330/340',
[16663] = '1/320/330/340',
[16664] = '1/320/330/340',
[16665] = '1/320/330/340',
[16724] = '1/320/330/340',
[16725] = '1/320/330/340',
[16726] = '1/320/330/340',
[16730] = '1/320/330/340',
[16728] = '1/320/330/340',
[16729] = '1/320/330/340',
[16731] = '1/320/330/340',
[16732] = '1/320/330/340',
[16741] = '1/320/330/340',
[16742] = '1/320/330/340',
[16744] = '1/320/330/340',
[16745] = '1/320/330/340',
[16746] = '1/320/330/340',
[16960] = '1/285/297/310',
[16965] = '1/295/307/320',
[16967] = '1/295/307/320',
[16969] = '1/300/312/325',
[16970] = '1/300/312/325',
[16971] = '1/305/317/330',
[16973] = '1/305/317/330',
[16978] = '1/305/317/330',
[16980] = '1/310/322/335',
[16983] = '1/310/322/335',
[16984] = '1/315/327/340',
[16985] = '1/315/327/340',
[16986] = '1/325/337/350',
[16987] = '1/325/337/350',
[16988] = '1/320/330/340',
[16990] = '1/320/330/340',
[16991] = '1/320/330/340',
[16992] = '1/320/330/340',
[16993] = '1/320/330/340',
[16994] = '1/320/330/340',
[16995] = '1/320/330/340',
[16661] = '1/315/325/335',
[17181] = '1/250/255/260',
[17180] = '1/250/255/260',
[17187] = '1/275/282/290',
[17551] = '1/250/255/260',
[17552] = '1/270/290/310',
[17553] = '1/275/295/315',
[17554] = '1/280/300/320',
[17555] = '1/285/305/325',
[17556] = '1/290/310/330',
[17557] = '1/290/310/330',
[17559] = '1/275/282/290',
[17561] = '1/275/282/290',
[17566] = '1/275/282/290',
[17560] = '1/275/282/290',
[17563] = '1/275/282/290',
[17562] = '1/275/282/290',
[17564] = '1/275/282/290',
[17565] = '1/275/282/290',
[17570] = '1/295/315/335',
[17571] = '1/295/315/335',
[17572] = '1/300/320/340',
[17573] = '1/300/320/340',
[17574] = '1/305/325/345',
[17575] = '1/305/325/345',
[17576] = '1/305/325/345',
[17577] = '1/305/325/345',
[17578] = '1/305/325/345',
[17579] = '1/305/325/345',
[17580] = '1/310/330/350',
[17632] = '1/365/372/380',
[17634] = '1/315/322/330',
[17635] = '1/315/322/330',
[17636] = '1/315/322/330',
[17637] = '1/315/322/330',
[17638] = '1/315/322/330',
[18239] = '1/250/262/275',
[18238] = '1/250/262/275',
[18241] = '1/250/262/275',
[18240] = '1/265/277/290',
[18242] = '1/265/277/290',
[18243] = '1/275/285/295',
[18244] = '1/275/285/295',
[18245] = '1/300/312/325',
[18246] = '1/300/312/325',
[18247] = '1/300/312/325',
[18401] = '1/255/257/260',
[18402] = '1/270/285/300',
[18403] = '1/270/285/300',
[18404] = '1/270/285/300',
[18406] = '1/275/290/305',
[18405] = '1/275/290/305',
[18407] = '1/275/290/305',
[18408] = '1/275/290/305',
[18409] = '1/280/295/310',
[18410] = '1/280/295/310',
[18411] = '1/280/295/310',
[18412] = '1/285/300/315',
[18415] = '1/285/300/315',
[18413] = '1/285/300/315',
[18414] = '1/285/300/315',
[18416] = '1/290/305/320',
[18417] = '1/290/305/320',
[18418] = '1/290/305/320',
[18419] = '1/290/305/320',
[18420] = '1/290/305/320',
[18421] = '1/290/305/320',
[18422] = '1/290/305/320',
[18423] = '1/295/310/325',
[18424] = '1/295/310/325',
[18434] = '1/295/310/325',
[18436] = '1/300/315/330',
[18437] = '1/300/315/330',
[18438] = '1/300/315/330',
[18439] = '1/305/320/335',
[18440] = '1/305/320/335',
[18441] = '1/305/320/335',
[18442] = '1/305/320/335',
[18444] = '1/310/325/340',
[18445] = '1/315/330/345',
[18446] = '1/315/330/345',
[18447] = '1/315/330/345',
[18448] = '1/315/330/345',
[18449] = '1/315/330/345',
[18450] = '1/315/330/345',
[18451] = '1/315/330/345',
[18452] = '1/315/330/345',
[18453] = '1/315/330/345',
[18454] = '1/315/330/345',
[18455] = '1/315/330/345',
[18456] = '1/315/330/345',
[18457] = '1/315/330/345',
[18458] = '1/315/330/345',
[18560] = '1/290/305/320',
[18629] = '1/260/290/320',
[18630] = '1/290/320/350',
[19047] = '1/250/255/260',
[19058] = '1/255/265/275',
[19048] = '1/275/285/295',
[19049] = '1/280/290/300',
[19050] = '1/280/290/300',
[19051] = '1/285/295/305',
[19052] = '1/285/295/305',
[19053] = '1/285/295/305',
[19054] = '1/320/330/340',
[19055] = '1/290/300/310',
[19059] = '1/290/300/310',
[19060] = '1/290/300/310',
[19061] = '1/290/300/310',
[19062] = '1/290/300/310',
[19063] = '1/295/305/315',
[19064] = '1/295/305/315',
[19065] = '1/295/305/315',
[19066] = '1/295/305/315',
[19067] = '1/295/305/315',
[19068] = '1/295/305/315',
[19070] = '1/300/310/320',
[19071] = '1/300/310/320',
[19072] = '1/300/310/320',
[19073] = '1/300/310/320',
[19074] = '1/305/315/325',
[19075] = '1/305/315/325',
[19076] = '1/305/315/325',
[19077] = '1/305/315/325',
[19078] = '1/305/315/325',
[19079] = '1/305/315/325',
[19080] = '1/305/315/325',
[19081] = '1/310/320/330',
[19085] = '1/310/320/330',
[19084] = '1/310/320/330',
[19086] = '1/310/320/330',
[19082] = '1/310/320/330',
[19083] = '1/310/320/330',
[19089] = '1/315/325/335',
[19087] = '1/315/325/335',
[19088] = '1/315/325/335',
[19090] = '1/315/325/335',
[19094] = '1/320/330/340',
[19097] = '1/320/330/340',
[19095] = '1/320/330/340',
[19093] = '1/320/330/340',
[19091] = '1/320/330/340',
[19092] = '1/320/330/340',
[19100] = '1/320/330/340',
[19102] = '1/320/330/340',
[19101] = '1/320/330/340',
[19098] = '1/320/330/340',
[19107] = '1/320/330/340',
[19104] = '1/320/330/340',
[19106] = '1/320/330/340',
[19103] = '1/320/330/340',
[19435] = '1/295/310/325',
[19567] = '1/270/280/290',
[19666] = '1/100/110/120',
[19667] = '1/150/160/170',
[19668] = '1/200/210/220',
[19669] = '1/275/280/285',
[19788] = '1/250/255/260',
[19790] = '1/280/290/300',
[19792] = '1/280/290/300',
[19791] = '1/280/290/300',
[19793] = '1/285/295/305',
[19794] = '1/290/300/310',
[19796] = '1/295/305/315',
[19814] = '1/295/305/315',
[19795] = '1/295/305/315',
[19815] = '1/305/315/325',
[19799] = '1/305/315/325',
[19819] = '1/310/320/330',
[19831] = '1/320/330/340',
[19830] = '1/320/330/340',
[19825] = '1/310/320/330',
[19833] = '1/320/330/340',
[3175] = '1/275/295/315',
[20008] = '1/275/295/315',
[20020] = '1/280/300/320',
[20014] = '1/285/305/325',
[20017] = '1/285/305/325',
[20009] = '1/290/310/330',
[20012] = '1/290/310/330',
[20024] = '1/295/315/335',
[20026] = '1/295/315/335',
[20016] = '1/300/320/340',
[20029] = '1/300/317/335',
[20015] = '1/300/317/335',
[20028] = '1/305/322/340',
[20051] = '1/305/322/340',
[20013] = '1/310/325/340',
[20023] = '1/310/325/340',
[20010] = '1/310/325/340',
[20030] = '1/310/325/340',
[20033] = '1/310/325/340',
[20036] = '1/310/325/340',
[20031] = '1/310/325/340',
[20011] = '1/310/325/340',
[20034] = '1/310/325/340',
[20025] = '1/310/325/340',
[20032] = '1/310/325/340',
[20035] = '1/310/325/340',
[20201] = '1/275/280/285',
[20626] = '1/250/262/275',
[20648] = '1/100/105/110',
[20649] = '1/150/155/160',
[20650] = '1/200/202/205',
[20848] = '1/315/330/345',
[20849] = '1/315/330/345',
[20853] = '1/315/325/335',
[20854] = '1/320/330/340',
[20855] = '1/320/330/340',
[20874] = '1/315/325/335',
[20872] = '1/315/325/335',
[20876] = '1/320/330/340',
[20873] = '1/320/330/340',
[20897] = '1/320/330/340',
[20890] = '1/320/330/340',
[20916] = '1/215/235/255',
[21144] = '1/75/95/115',
[21143] = '1/45/65/85',
[21161] = '1/325/337/350',
[21175] = '1/225/237/250',
[21913] = '1/215/227/240',
[21923] = '1/210/230/250',
[21931] = '1/210/230/250',
[21940] = '1/190/210/230',
[21943] = '1/210/220/230',
[21945] = '1/200/205/210',
[22331] = '1/250/250/250',
[22480] = '1/250/262/275',
[22704] = '1/320/330/340',
[22711] = '1/210/220/230',
[22727] = '1/320/330/340',
[22732] = '1/310/320/330',
[22749] = '1/310/325/340',
[22750] = '1/310/325/340',
[22757] = '1/300/310/320',
[22759] = '1/320/335/350',
[22761] = '1/300/312/325',
[22793] = '1/320/330/340',
[22795] = '1/320/330/340',
[22797] = '1/320/330/340',
[22808] = '1/230/250/270',
[22813] = '1/285/290/295',
[22815] = '1/285/290/295',
[22866] = '1/315/330/345',
[22867] = '1/315/330/345',
[22868] = '1/315/330/345',
[22869] = '1/315/330/345',
[22870] = '1/315/330/345',
[22902] = '1/315/330/345',
[22921] = '1/320/330/340',
[22922] = '1/320/330/340',
[22923] = '1/320/330/340',
[22926] = '1/320/330/340',
[22927] = '1/320/330/340',
[22928] = '1/320/330/340',
[23066] = '1/150/162/175',
[23068] = '1/150/162/175',
[23067] = '1/150/162/175',
[23069] = '1/200/210/220',
[23070] = '1/250/260/270',
[23071] = '1/270/275/280',
[23077] = '1/280/290/300',
[23078] = '1/285/295/305',
[23079] = '1/285/290/295',
[23080] = '1/275/285/295',
[23081] = '1/310/320/330',
[23082] = '1/320/330/340',
[23096] = '1/275/280/285',
[23129] = '1/260/265/270',
[23190] = '1/150/155/160',
[23399] = '1/175/185/195',
[23489] = '1/285/295/305',
[23486] = '1/285/295/305',
[23507] = '1/250/260/270',
[23628] = '1/310/320/330',
[23629] = '1/320/330/340',
[23632] = '1/310/320/330',
[23633] = '1/320/330/340',
[23636] = '1/320/330/340',
[23637] = '1/320/330/340',
[23638] = '1/320/330/340',
[23639] = '1/320/330/340',
[23650] = '1/320/330/340',
[23652] = '1/320/330/340',
[23653] = '1/320/330/340',
[23662] = '1/305/320/335',
[23664] = '1/305/320/335',
[23663] = '1/315/330/345',
[23665] = '1/315/330/345',
[23666] = '1/315/330/345',
[23667] = '1/315/330/345',
[23703] = '1/310/320/330',
[23705] = '1/310/320/330',
[23704] = '1/320/330/340',
[23706] = '1/320/330/340',
[23707] = '1/320/330/340',
[23708] = '1/320/330/340',
[23709] = '1/320/330/340',
[23710] = '1/320/330/340',
[23787] = '1/300/330/360',
[23799] = '1/305/322/340',
[23800] = '1/305/322/340',
[23801] = '1/305/322/340',
[23802] = '1/310/325/340',
[23803] = '1/310/325/340',
[23804] = '1/310/325/340',
[24093] = '1/315/330/345',
[24092] = '1/315/330/345',
[24091] = '1/315/330/345',
[24124] = '1/320/330/340',
[24125] = '1/320/330/340',
[24123] = '1/320/330/340',
[24122] = '1/320/330/340',
[24121] = '1/320/330/340',
[24136] = '1/320/330/340',
[24138] = '1/320/330/340',
[24137] = '1/320/330/340',
[24139] = '1/320/330/340',
[24140] = '1/320/330/340',
[24141] = '1/320/330/340',
[24266] = '1/315/322/330',
[24356] = '1/320/330/340',
[24357] = '1/320/330/340',
[24365] = '1/290/310/330',
[24366] = '1/290/310/330',
[24367] = '1/300/320/340',
[24368] = '1/305/325/345',
[24399] = '1/320/330/340',
[24418] = '1/160/180/200',
[24655] = '1/300/310/320',
[24654] = '1/320/330/340',
[24801] = '1/310/322/335',
[24846] = '1/320/330/340',
[24847] = '1/320/330/340',
[24848] = '1/320/330/340',
[24849] = '1/320/330/340',
[24850] = '1/320/330/340',
[24851] = '1/320/330/340',
[24902] = '1/315/330/345',
[24903] = '1/315/330/345',
[24901] = '1/315/330/345',
[24914] = '1/320/330/340',
[24912] = '1/320/330/340',
[24913] = '1/320/330/340',
[24940] = '1/125/137/150',
[24703] = '1/320/330/340',
[25072] = '1/310/325/340',
[25073] = '1/310/325/340',
[25074] = '1/310/325/340',
[25078] = '1/310/325/340',
[25079] = '1/310/325/340',
[25080] = '1/310/325/340',
[25081] = '1/310/325/340',
[25082] = '1/310/325/340',
[25083] = '1/310/325/340',
[25084] = '1/310/325/340',
[25086] = '1/310/325/340',
[25124] = '1/55/65/75',
[25125] = '1/160/170/180',
[25126] = '1/210/220/230',
[25127] = '1/260/270/280',
[25128] = '1/285/295/305',
[25129] = '1/310/320/330',
[25130] = '1/310/320/330',
[25146] = '1/301/305/310',
[25278] = '1/70/80/90',
[25255] = '1/20/35/50',
[25280] = '1/80/95/110',
[25283] = '1/60/75/90',
[25284] = '1/90/105/120',
[25287] = '1/100/115/130',
[25305] = '1/120/135/150',
[25317] = '1/110/125/140',
[25318] = '1/130/145/160',
[25339] = '1/140/155/170',
[25320] = '1/180/195/210',
[25321] = '1/150/165/180',
[25323] = '1/155/170/185',
[25493] = '1/30/45/60',
[25490] = '1/80/95/110',
[25498] = '1/140/155/170',
[25610] = '1/150/165/180',
[25612] = '1/155/170/185',
[25613] = '1/165/180/195',
[25614] = '1/175/190/205',
[25615] = '1/170/180/190',
[25617] = '1/180/195/210',
[25618] = '1/190/205/220',
[25619] = '1/200/215/230',
[25620] = '1/200/215/230',
[25621] = '1/210/225/240',
[25622] = '1/220/235/250',
[25659] = '1/325/337/350',
[25704] = '1/120/140/160',
[25954] = '1/215/235/255',
[26011] = '1/320/330/340',
[26085] = '1/275/290/305',
[26086] = '1/300/315/330',
[26087] = '1/315/330/345',
[26279] = '1/320/330/340',
[26277] = '1/265/285/305',
[26403] = '1/265/280/295',
[26407] = '1/265/280/295',
[26416] = '1/125/137/150',
[26417] = '1/125/137/150',
[26418] = '1/125/137/150',
[26420] = '1/175/187/200',
[26421] = '1/175/187/200',
[26422] = '1/175/187/200',
[26423] = '1/225/237/250',
[26424] = '1/225/237/250',
[26425] = '1/225/237/250',
[26426] = '1/275/280/285',
[26427] = '1/275/280/285',
[26428] = '1/275/280/285',
[26442] = '1/245/255/265',
[26443] = '1/295/305/315',
[26745] = '1/305/315/325',
[26746] = '1/320/330/340',
[26747] = '1/330/335/340',
[26749] = '1/340/345/350',
[26750] = '1/345/350/355',
[26751] = '1/350/355/360',
[26752] = '1/365/370/375',
[26753] = '1/375/380/385',
[26754] = '1/385/390/395',
[26755] = '1/385/390/395',
[26756] = '1/365/370/375',
[26757] = '1/375/380/385',
[26758] = '1/385/390/395',
[26759] = '1/385/390/395',
[26760] = '1/365/370/375',
[26761] = '1/375/380/385',
[26762] = '1/385/390/395',
[26763] = '1/385/390/395',
[26764] = '1/320/325/330',
[26765] = '1/320/325/330',
[26770] = '1/330/335/340',
[26771] = '1/335/340/345',
[26772] = '1/345/350/355',
[26773] = '1/350/355/360',
[26774] = '1/355/360/365',
[26775] = '1/350/355/360',
[26776] = '1/360/365/370',
[26777] = '1/370/375/380',
[26778] = '1/370/375/380',
[26779] = '1/365/370/375',
[26780] = '1/375/380/385',
[26781] = '1/380/382/385',
[26782] = '1/360/365/370',
[26783] = '1/370/375/380',
[26784] = '1/380/385/390',
[26872] = '1/225/240/255',
[26873] = '1/225/240/255',
[26874] = '1/235/250/265',
[26875] = '1/240/255/270',
[26876] = '1/245/260/275',
[26878] = '1/250/265/280',
[26880] = '1/235/245/255',
[26881] = '1/250/265/280',
[26882] = '1/260/275/290',
[26883] = '1/260/275/290',
[26885] = '1/265/280/295',
[26887] = '1/270/285/300',
[26896] = '1/275/290/305',
[26897] = '1/275/290/305',
[26900] = '1/280/290/300',
[26902] = '1/280/290/300',
[26903] = '1/285/295/305',
[26906] = '1/285/295/305',
[26907] = '1/290/300/310',
[26908] = '1/290/300/310',
[26909] = '1/295/305/315',
[26910] = '1/295/305/315',
[26911] = '1/300/310/320',
[26912] = '1/310/320/330',
[26914] = '1/310/320/330',
[26915] = '1/315/325/335',
[26916] = '1/320/330/340',
[26918] = '1/325/335/345',
[26920] = '1/335/345/355',
[26925] = '1/30/45/60',
[26926] = '1/35/50/65',
[26927] = '1/80/95/110',
[26928] = '1/60/75/90',
[27032] = '1/330/347/365',
[27033] = '1/360/367/375',
[27585] = '1/320/330/340',
[27588] = '1/320/330/340',
[27586] = '1/320/330/340',
[27589] = '1/320/330/340',
[27590] = '1/320/330/340',
[27587] = '1/320/330/340',
[27658] = '1/240/255/270',
[27659] = '1/290/305/320',
[27660] = '1/315/330/345',
[27724] = '1/290/305/320',
[27725] = '1/315/330/345',
[27830] = '1/320/330/340',
[27829] = '1/320/330/340',
[27832] = '1/320/330/340',
[27837] = '1/305/322/340',
[27899] = '1/315/330/345',
[27905] = '1/325/340/355',
[27906] = '1/330/345/360',
[27911] = '1/335/350/365',
[27913] = '1/345/360/375',
[27914] = '1/370/375/380',
[27917] = '1/370/385/400',
[27920] = '1/370/377/385',
[27924] = '1/370/377/385',
[27926] = '1/380/385/390',
[27927] = '1/380/385/390',
[27944] = '1/320/335/350',
[27945] = '1/335/350/365',
[27946] = '1/350/365/380',
[27947] = '1/370/377/385',
[27948] = '1/315/330/345',
[27950] = '1/330/345/360',
[27951] = '1/350/365/380',
[27954] = '1/380/385/390',
[27957] = '1/325/340/355',
[27958] = '1/360/370/380',
[27960] = '1/355/367/380',
[27961] = '1/320/335/350',
[27962] = '1/340/355/370',
[27967] = '1/350/365/380',
[27968] = '1/350/365/380',
[27972] = '1/370/375/380',
[27971] = '1/370/375/380',
[27975] = '1/370/375/380',
[27977] = '1/370/377/385',
[28004] = '1/370/377/385',
[28003] = '1/370/377/385',
[27984] = '1/380/385/390',
[27981] = '1/390/390/390',
[27982] = '1/380/385/390',
[28016] = '1/310/320/330',
[28019] = '1/340/350/360',
[28021] = '1/335/345/355',
[28022] = '1/5/7/10',
[28210] = '1/315/330/345',
[28208] = '1/315/330/345',
[28205] = '1/315/330/345',
[28207] = '1/315/330/345',
[28209] = '1/315/330/345',
[28224] = '1/320/330/340',
[28222] = '1/320/330/340',
[28223] = '1/320/330/340',
[28221] = '1/320/330/340',
[28220] = '1/320/330/340',
[28219] = '1/320/330/340',
[28244] = '1/320/330/340',
[28242] = '1/320/330/340',
[28243] = '1/320/330/340',
[28267] = '1/100/120/140',
[28327] = '1/275/280/285',
[28461] = '1/320/330/340',
[28462] = '1/320/330/340',
[28463] = '1/320/330/340',
[28474] = '1/320/330/340',
[28473] = '1/320/330/340',
[28472] = '1/320/330/340',
[28481] = '1/315/330/345',
[28482] = '1/315/330/345',
[28480] = '1/315/330/345',
[28543] = '1/320/327/335',
[28544] = '1/320/327/335',
[28545] = '1/325/332/340',
[28546] = '1/330/337/345',
[28549] = '1/335/342/350',
[28550] = '1/335/342/350',
[28552] = '1/340/347/355',
[28551] = '1/340/347/355',
[28553] = '1/345/352/360',
[28554] = '1/350/357/365',
[28555] = '1/355/362/370',
[28556] = '1/360/367/375',
[28557] = '1/360/367/375',
[28558] = '1/365/372/380',
[28562] = '1/365/372/380',
[28563] = '1/365/372/380',
[28564] = '1/365/372/380',
[28565] = '1/365/372/380',
[28566] = '1/365/372/380',
[28567] = '1/365/372/380',
[28568] = '1/365/372/380',
[28569] = '1/365/372/380',
[28570] = '1/370/375/380',
[28575] = '1/375/377/380',
[28571] = '1/375/377/380',
[28572] = '1/375/377/380',
[28577] = '1/375/377/380',
[28573] = '1/375/377/380',
[28576] = '1/375/377/380',
[28578] = '1/375/377/380',
[28579] = '1/375/377/380',
[28585] = '1/375/377/380',
[28583] = '1/375/377/380',
[28584] = '1/375/377/380',
[28582] = '1/375/377/380',
[28580] = '1/375/377/380',
[28581] = '1/375/377/380',
[28586] = '1/375/377/380',
[28590] = '1/375/377/380',
[28587] = '1/375/377/380',
[28588] = '1/375/377/380',
[28589] = '1/375/377/380',
[28591] = '1/375/377/380',
[28903] = '1/300/320/340',
[28905] = '1/305/325/345',
[28910] = '1/300/320/340',
[28912] = '1/305/325/345',
[28914] = '1/315/335/355',
[28915] = '1/325/340/355',
[28916] = '1/300/320/340',
[28917] = '1/305/325/345',
[28918] = '1/315/335/355',
[28925] = '1/300/320/340',
[28927] = '1/305/325/345',
[28933] = '1/315/335/355',
[28936] = '1/325/340/355',
[28944] = '1/305/325/345',
[28947] = '1/315/335/355',
[28948] = '1/325/340/355',
[28950] = '1/300/320/340',
[28953] = '1/305/325/345',
[28955] = '1/315/335/355',
[29356] = '1/275/300/325',
[29358] = '1/325/332/340',
[29359] = '1/350/357/365',
[29360] = '1/340/357/375',
[29361] = '1/385/392/400',
[29686] = '1/385/392/400',
[29688] = '1/365/372/380',
[29545] = '1/310/320/330',
[29547] = '1/315/325/335',
[29548] = '1/325/335/345',
[29549] = '1/325/335/345',
[29550] = '1/335/345/355',
[29551] = '1/310/320/330',
[29552] = '1/320/330/340',
[29553] = '1/325/335/345',
[29556] = '1/330/340/350',
[29557] = '1/320/330/340',
[29558] = '1/325/335/345',
[29565] = '1/330/340/350',
[29566] = '1/335/345/355',
[29568] = '1/340/350/360',
[29569] = '1/340/350/360',
[29571] = '1/345/355/365',
[29603] = '1/345/355/365',
[29605] = '1/345/355/365',
[29606] = '1/350/360/370',
[29608] = '1/365/375/385',
[29611] = '1/365/375/385',
[29610] = '1/370/380/390',
[29613] = '1/375/385/395',
[29614] = '1/360/370/380',
[29615] = '1/365/375/385',
[29616] = '1/370/380/390',
[29617] = '1/375/385/395',
[29619] = '1/370/380/390',
[29620] = '1/370/380/390',
[29621] = '1/375/385/395',
[29628] = '1/370/380/390',
[29629] = '1/370/380/390',
[29630] = '1/375/385/395',
[29642] = '1/375/385/395',
[29643] = '1/375/385/395',
[29645] = '1/380/390/400',
[29648] = '1/380/390/400',
[29649] = '1/380/390/400',
[29654] = '1/300/305/310',
[29656] = '1/350/355/360',
[29657] = '1/370/380/390',
[29658] = '1/375/385/395',
[29622] = '1/375/385/395',
[29662] = '1/375/385/395',
[29663] = '1/375/385/395',
[29664] = '1/375/385/395',
[29668] = '1/375/385/395',
[29669] = '1/375/385/395',
[29671] = '1/375/385/395',
[29672] = '1/375/385/395',
[29692] = '1/375/385/395',
[29693] = '1/375/385/395',
[29694] = '1/375/385/395',
[29695] = '1/375/385/395',
[29696] = '1/375/385/395',
[29697] = '1/375/385/395',
[29698] = '1/375/385/395',
[29699] = '1/375/385/395',
[29700] = '1/375/385/395',
[29728] = '1/340/345/350',
[29729] = '1/375/375/375',
[30310] = '1/320/330/340',
[30311] = '1/335/345/355',
[30312] = '1/330/340/350',
[30313] = '1/360/370/380',
[30314] = '1/370/380/390',
[30315] = '1/385/395/405',
[30316] = '1/350/360/370',
[30317] = '1/350/360/370',
[30318] = '1/360/370/380',
[30325] = '1/370/380/390',
[30329] = '1/345/355/365',
[30332] = '1/370/380/390',
[30334] = '1/385/395/405',
[30337] = '1/335/345/355',
[30341] = '1/335/345/355',
[30342] = '1/335/345/355',
[30343] = '1/335/345/355',
[30344] = '1/335/345/355',
[30348] = '1/325/335/345',
[30349] = '1/425/432/440',
[30303] = '1/300/310/320',
[30304] = '1/300/310/320',
[30305] = '1/300/305/310',
[30306] = '1/325/330/335',
[30307] = '1/350/360/370',
[30308] = '1/350/360/370',
[30309] = '1/350/360/370',
[30547] = '1/350/355/360',
[30548] = '1/305/315/325',
[30549] = '1/325/335/345',
[30551] = '1/330/340/350',
[30552] = '1/345/355/365',
[30556] = '1/365/375/385',
[30558] = '1/325/335/345',
[30560] = '1/340/350/360',
[30561] = '1/325/330/335',
[30563] = '1/360/370/380',
[30565] = '1/375/385/395',
[30566] = '1/375/385/395',
[30568] = '1/335/345/355',
[30569] = '1/360/370/380',
[30570] = '1/360/370/380',
[30573] = '1/325/330/335',
[30574] = '1/375/385/395',
[30575] = '1/375/385/395',
[31112] = '1/350/365/380',
[31085] = '1/350/365/380',
[31106] = '1/350/365/380',
[31091] = '1/350/365/380',
[31109] = '1/350/365/380',
[31104] = '1/350/365/380',
[31113] = '1/350/365/380',
[31108] = '1/350/365/380',
[31101] = '1/350/365/380',
[31107] = '1/350/365/380',
[31111] = '1/350/365/380',
[31098] = '1/350/365/380',
[31088] = '1/350/365/380',
[31103] = '1/350/365/380',
[31097] = '1/350/365/380',
[31102] = '1/350/365/380',
[31092] = '1/350/365/380',
[31149] = '1/350/365/380',
[31095] = '1/350/365/380',
[31090] = '1/350/365/380',
[31084] = '1/350/365/380',
[31048] = '1/320/330/340',
[31049] = '1/320/335/350',
[31050] = '1/330/340/350',
[31051] = '1/345/355/365',
[31052] = '1/345/355/365',
[31053] = '1/360/370/380',
[31054] = '1/365/372/380',
[31055] = '1/365/372/380',
[31056] = '1/370/375/380',
[31057] = '1/370/375/380',
[31058] = '1/355/365/375',
[31060] = '1/365/375/385',
[31061] = '1/375/377/380',
[31062] = '1/370/375/380',
[31063] = '1/370/375/380',
[31064] = '1/370/375/380',
[31065] = '1/370/375/380',
[31066] = '1/370/375/380',
[31067] = '1/365/375/385',
[31068] = '1/365/375/385',
[31070] = '1/370/377/385',
[31071] = '1/370/375/380',
[31072] = '1/375/380/385',
[31076] = '1/375/380/385',
[31077] = '1/375/380/385',
[31078] = '1/375/380/385',
[31079] = '1/375/380/385',
[31080] = '1/375/380/385',
[31081] = '1/375/380/385',
[31082] = '1/375/380/385',
[31083] = '1/375/380/385',
[31430] = '1/345/350/355',
[31431] = '1/345/350/355',
[31432] = '1/385/390/395',
[31433] = '1/385/390/395',
[31434] = '1/360/365/370',
[31435] = '1/360/365/370',
[31437] = '1/360/365/370',
[31438] = '1/360/365/370',
[31440] = '1/360/365/370',
[31441] = '1/360/365/370',
[31442] = '1/375/380/385',
[31443] = '1/375/380/385',
[31444] = '1/375/380/385',
[31448] = '1/375/380/385',
[31449] = '1/375/380/385',
[31450] = '1/375/380/385',
[31451] = '1/385/390/395',
[31452] = '1/385/390/395',
[31453] = '1/385/390/395',
[31454] = '1/385/390/395',
[31455] = '1/385/390/395',
[31456] = '1/385/390/395',
[31459] = '1/350/355/360',
[31460] = '1/300/310/320',
[31461] = '1/325/330/335',
[31373] = '1/350/355/360',
[32178] = '1/50/65/80',
[32179] = '1/50/65/80',
[32259] = '1/30/40/50',
[32284] = '1/325/330/335',
[32285] = '1/350/355/360',
[32454] = '1/300/305/310',
[32455] = '1/325/330/335',
[32456] = '1/310/325/340',
[32457] = '1/335/340/345',
[32458] = '1/335/340/345',
[32461] = '1/360/370/380',
[32462] = '1/310/320/330',
[32463] = '1/320/330/340',
[32464] = '1/330/340/350',
[32465] = '1/345/355/365',
[32466] = '1/310/320/330',
[32467] = '1/320/330/340',
[32468] = '1/335/345/355',
[32469] = '1/345/355/365',
[32470] = '1/310/320/330',
[32471] = '1/325/335/345',
[32472] = '1/330/340/350',
[32473] = '1/340/350/360',
[32478] = '1/310/320/330',
[32479] = '1/320/330/340',
[32480] = '1/330/340/350',
[32481] = '1/340/350/360',
[32482] = '1/300/305/310',
[32485] = '1/360/370/380',
[32487] = '1/360/370/380',
[32489] = '1/360/370/380',
[32488] = '1/360/370/380',
[32490] = '1/350/360/370',
[32493] = '1/360/370/380',
[32494] = '1/360/370/380',
[32495] = '1/370/380/390',
[32496] = '1/365/375/385',
[32497] = '1/365/375/385',
[32498] = '1/360/370/380',
[32499] = '1/370/380/390',
[32500] = '1/370/380/390',
[32501] = '1/350/360/370',
[32502] = '1/350/360/370',
[32503] = '1/360/370/380',
[32655] = '1/300/305/310',
[32656] = '1/350/355/360',
[32657] = '1/365/370/375',
[32664] = '1/310/325/340',
[32665] = '1/370/375/380',
[32667] = '1/370/377/385',
[32765] = '1/365/372/380',
[32766] = '1/365/372/380',
[32801] = '1/70/80/90',
[32814] = '1/335/345/355',
[32807] = '1/120/130/140',
[32808] = '1/175/185/195',
[32809] = '1/225/235/245',
[32810] = '1/300/310/320',
[32867] = '1/375/377/380',
[32869] = '1/375/377/380',
[32870] = '1/375/377/380',
[32866] = '1/375/377/380',
[32868] = '1/375/377/380',
[32871] = '1/375/377/380',
[32874] = '1/375/377/380',
[32872] = '1/375/377/380',
[32873] = '1/375/377/380',
[33276] = '1/45/65/85',
[33277] = '1/45/65/85',
[33278] = '1/90/110/130',
[33279] = '1/320/330/340',
[33284] = '1/320/330/340',
[33286] = '1/335/345/355',
[33287] = '1/345/355/365',
[33288] = '1/345/355/365',
[33289] = '1/345/355/365',
[33290] = '1/320/330/340',
[33291] = '1/320/330/340',
[33292] = '1/330/340/350',
[33293] = '1/340/350/360',
[33294] = '1/340/350/360',
[33295] = '1/345/355/365',
[33296] = '1/370/375/380',
[33732] = '1/315/322/330',
[33738] = '1/315/322/330',
[33740] = '1/315/322/330',
[33733] = '1/325/332/340',
[33741] = '1/330/337/345',
[33990] = '1/330/345/360',
[33991] = '1/310/325/340',
[33992] = '1/355/367/380',
[33993] = '1/315/330/345',
[33994] = '1/370/377/385',
[33995] = '1/350/365/380',
[33996] = '1/320/335/350',
[33997] = '1/370/377/385',
[33999] = '1/370/375/380',
[34001] = '1/315/330/345',
[34002] = '1/310/325/340',
[34003] = '1/335/350/365',
[34004] = '1/320/335/350',
[34005] = '1/370/375/380',
[34006] = '1/370/375/380',
[34007] = '1/370/377/385',
[34008] = '1/370/377/385',
[34009] = '1/335/350/365',
[34010] = '1/370/375/380',
[28027] = '1/325/330/335',
[28028] = '1/370/375/380',
[34533] = '1/360/370/380',
[34545] = '1/360/370/380',
[34538] = '1/360/370/380',
[34529] = '1/360/370/380',
[34535] = '1/360/370/380',
[34541] = '1/360/370/380',
[34547] = '1/360/370/380',
[34543] = '1/360/370/380',
[34542] = '1/385/395/405',
[34534] = '1/385/395/405',
[34548] = '1/385/395/405',
[34546] = '1/385/395/405',
[34540] = '1/385/395/405',
[34544] = '1/385/395/405',
[34537] = '1/385/395/405',
[34530] = '1/385/395/405',
[34590] = '1/305/325/345',
[34607] = '1/300/305/310',
[34608] = '1/350/355/360',
[34960] = '1/290/300/310',
[34961] = '1/300/310/320',
[34955] = '1/190/200/210',
[34959] = '1/210/220/230',
[34979] = '1/130/145/160',
[34981] = '1/220/230/240',
[34982] = '1/320/330/340',
[34983] = '1/360/370/380',
[35530] = '1/335/340/345',
[35520] = '1/350/355/360',
[35521] = '1/350/355/360',
[35522] = '1/350/355/360',
[35523] = '1/350/355/360',
[35524] = '1/350/355/360',
[35527] = '1/360/370/380',
[35526] = '1/360/370/380',
[35525] = '1/360/370/380',
[35531] = '1/360/370/380',
[35528] = '1/360/370/380',
[35529] = '1/360/370/380',
[35534] = '1/360/370/380',
[35533] = '1/360/370/380',
[35532] = '1/360/370/380',
[35537] = '1/360/370/380',
[35536] = '1/360/370/380',
[35535] = '1/360/370/380',
[35538] = '1/370/377/385',
[35539] = '1/350/357/365',
[35540] = '1/340/347/355',
[35543] = '1/365/372/380',
[35544] = '1/345/352/360',
[35549] = '1/335/345/355',
[35555] = '1/335/345/355',
[35554] = '1/365/375/385',
[35557] = '1/365/375/385',
[35559] = '1/375/385/395',
[35558] = '1/375/385/395',
[35567] = '1/375/385/395',
[35562] = '1/375/385/395',
[35561] = '1/375/385/395',
[35564] = '1/375/385/395',
[35573] = '1/375/385/395',
[35572] = '1/375/385/395',
[35574] = '1/375/385/395',
[35563] = '1/375/385/395',
[35560] = '1/375/385/395',
[35568] = '1/375/385/395',
[35576] = '1/385/395/405',
[35577] = '1/385/395/405',
[35575] = '1/385/395/405',
[35582] = '1/385/395/405',
[35584] = '1/385/395/405',
[35580] = '1/385/395/405',
[35590] = '1/385/395/405',
[35591] = '1/385/395/405',
[35589] = '1/385/395/405',
[35587] = '1/385/395/405',
[35588] = '1/385/395/405',
[35585] = '1/385/395/405',
[35750] = '1/300/300/300',
[35751] = '1/300/300/300',
[36074] = '1/280/290/300',
[36076] = '1/280/290/300',
[36075] = '1/280/290/300',
[36079] = '1/350/360/370',
[36078] = '1/350/360/370',
[36077] = '1/350/360/370',
[36122] = '1/280/290/300',
[36125] = '1/280/290/300',
[36128] = '1/280/290/300',
[36126] = '1/280/290/300',
[36124] = '1/280/290/300',
[36137] = '1/340/350/360',
[36129] = '1/340/350/360',
[36136] = '1/340/350/360',
[36135] = '1/340/350/360',
[36133] = '1/340/350/360',
[36134] = '1/340/350/360',
[36130] = '1/340/350/360',
[36131] = '1/340/350/360',
[36210] = '1/320/330/340',
[36256] = '1/385/395/405',
[36257] = '1/385/395/405',
[36258] = '1/385/395/405',
[36259] = '1/385/395/405',
[36260] = '1/385/395/405',
[36261] = '1/385/395/405',
[36262] = '1/385/395/405',
[36263] = '1/385/395/405',
[36315] = '1/385/390/395',
[36317] = '1/385/390/395',
[36316] = '1/385/390/395',
[36318] = '1/385/390/395',
[36349] = '1/385/395/405',
[36351] = '1/385/395/405',
[36352] = '1/385/395/405',
[36353] = '1/385/395/405',
[36355] = '1/385/395/405',
[36357] = '1/385/395/405',
[36358] = '1/385/395/405',
[36359] = '1/385/395/405',
[36389] = '1/385/395/405',
[36390] = '1/385/395/405',
[36391] = '1/385/395/405',
[36392] = '1/385/395/405',
[36523] = '1/105/120/135',
[36524] = '1/135/150/165',
[36525] = '1/255/270/285',
[36526] = '1/285/295/305',
[36670] = '1/365/370/375',
[36672] = '1/365/370/375',
[36669] = '1/365/370/375',
[36667] = '1/365/370/375',
[36668] = '1/365/370/375',
[36665] = '1/365/370/375',
[36686] = '1/350/355/360',
[36954] = '1/350/360/370',
[36955] = '1/350/360/370',
[37818] = '1/95/110/125',
[37836] = '1/30/35/40',
[37855] = '1/370/375/380',
[37873] = '1/360/365/370',
[37882] = '1/360/365/370',
[37883] = '1/370/375/380',
[37884] = '1/380/385/390',
[38068] = '1/325/335/345',
[38070] = '1/340/347/355',
[38175] = '1/110/125/140',
[38473] = '1/385/395/405',
[38475] = '1/385/395/405',
[38476] = '1/385/395/405',
[38477] = '1/385/395/405',
[38478] = '1/385/395/405',
[38479] = '1/385/395/405',
[38503] = '1/375/380/385',
[38504] = '1/375/380/385',
[38868] = '1/355/365/375',
[38867] = '1/355/365/375',
[38960] = '1/350/357/365',
[38962] = '1/360/367/375',
[38961] = '1/375/377/380',
[39466] = '1/325/340/355',
[39467] = '1/325/340/355',
[39470] = '1/350/365/380',
[39471] = '1/350/365/380',
[39636] = '1/325/332/340',
[39637] = '1/335/342/350',
[39638] = '1/335/342/350',
[39639] = '1/345/352/360',
[39705] = '1/375/380/385',
[39706] = '1/375/380/385',
[39714] = '1/375/380/385',
[39711] = '1/375/380/385',
[39713] = '1/375/380/385',
[39715] = '1/375/380/385',
[39716] = '1/375/380/385',
[39718] = '1/375/380/385',
[39724] = '1/375/380/385',
[39721] = '1/375/380/385',
[39720] = '1/375/380/385',
[39731] = '1/375/380/385',
[39728] = '1/375/380/385',
[39727] = '1/375/380/385',
[39736] = '1/375/380/385',
[39733] = '1/375/380/385',
[39734] = '1/375/380/385',
[39737] = '1/375/380/385',
[39738] = '1/375/380/385',
[39741] = '1/375/380/385',
[39739] = '1/375/380/385',
[39742] = '1/375/380/385',
[39740] = '1/375/380/385',
[39895] = '1/275/280/285',
[39963] = '1/375/377/380',
[39961] = '1/375/377/380',
[39971] = '1/335/340/345',
[39973] = '1/345/355/365',
[39997] = '1/385/395/405',
[40001] = '1/385/395/405',
[40002] = '1/385/395/405',
[40006] = '1/385/395/405',
[40005] = '1/385/395/405',
[40003] = '1/385/395/405',
[40004] = '1/385/395/405',
[40021] = '1/385/390/395',
[40024] = '1/385/390/395',
[40023] = '1/385/390/395',
[40020] = '1/385/390/395',
[40034] = '1/385/395/405',
[40036] = '1/385/395/405',
[40035] = '1/385/395/405',
[40033] = '1/385/395/405',
[40060] = '1/385/390/395',
[40274] = '1/370/380/390',
[40514] = '1/340/355/370',
[41132] = '1/385/395/405',
[41133] = '1/385/395/405',
[41135] = '1/385/395/405',
[41134] = '1/385/395/405',
[41161] = '1/385/395/405',
[41156] = '1/385/395/405',
[41163] = '1/385/395/405',
[41164] = '1/385/395/405',
[41157] = '1/385/395/405',
[41162] = '1/385/395/405',
[41158] = '1/385/395/405',
[41160] = '1/385/395/405',
[41307] = '1/375/392/410',
[41311] = '1/370/380/390',
[41312] = '1/370/380/390',
[41314] = '1/370/380/390',
[41315] = '1/370/380/390',
[41316] = '1/370/380/390',
[41317] = '1/370/380/390',
[41318] = '1/370/380/390',
[41319] = '1/370/380/390',
[41320] = '1/370/380/390',
[41321] = '1/370/380/390',
[41418] = '1/375/380/385',
[41414] = '1/335/345/355',
[41415] = '1/340/350/360',
[41458] = '1/360/370/380',
[41500] = '1/360/370/380',
[41501] = '1/360/370/380',
[41502] = '1/360/370/380',
[41503] = '1/360/370/380',
[41207] = '1/385/390/395',
[41208] = '1/385/390/395',
[41205] = '1/385/390/395',
[41206] = '1/385/390/395',
[41420] = '1/325/332/340',
[41429] = '1/350/365/380',
[42296] = '1/335/345/355',
[42302] = '1/375/380/385',
[42305] = '1/375/380/385',
[42546] = '1/370/380/390',
[42558] = '1/365/370/375',
[42588] = '1/365/370/375',
[42589] = '1/365/370/375',
[42590] = '1/365/370/375',
[42593] = '1/365/370/375',
[42591] = '1/365/370/375',
[42592] = '1/365/370/375',
[42613] = '1/295/300/305',
[42615] = '1/315/325/335',
[42620] = '1/360/367/375',
[42662] = '1/375/385/395',
[42688] = '1/345/350/355',
[42731] = '1/375/385/395',
[42736] = '1/390/397/405',
[42974] = '1/380/385/390',
[43493] = '1/350/365/380',
[43549] = '1/75/95/115',
[43676] = '1/335/345/355',
[43707] = '1/335/345/355',
[43758] = '1/320/330/340',
[43761] = '1/320/330/340',
[43765] = '1/335/345/355',
[43779] = '1/50/62/75',
[43846] = '1/375/385/395',
[44155] = '1/330/340/350',
[44157] = '1/385/390/395',
[44383] = '1/340/355/370',
[44391] = '1/370/380/390',
[44483] = '1/415/425/435',
[44484] = '1/415/425/435',
[44488] = '1/420/430/440',
[44489] = '1/430/440/450',
[44492] = '1/405/415/425',
[44494] = '1/415/425/435',
[44508] = '1/420/430/440',
[44500] = '1/405/415/425',
[44506] = '1/370/380/390',
[44509] = '1/430/440/450',
[44510] = '1/420/430/440',
[44528] = '1/380/390/400',
[44513] = '1/405/415/425',
[44524] = '1/435/445/455',
[44555] = '1/385/392/400',
[44556] = '1/415/425/435',
[44529] = '1/425/435/445',
[44575] = '1/440/450/460',
[44576] = '1/435/445/455',
[44584] = '1/415/425/435',
[44582] = '1/395/402/410',
[44589] = '1/425/435/445',
[44588] = '1/435/445/455',
[44590] = '1/415/425/435',
[44593] = '1/430/440/450',
[44591] = '1/445/455/465',
[44612] = '1/405/412/420',
[44592] = '1/370/380/390',
[44595] = '1/440/450/460',
[44598] = '1/425/435/445',
[44596] = '1/415/425/435',
[44616] = '1/410/420/430',
[44621] = '1/440/450/460',
[44623] = '1/380/390/400',
[44625] = '1/445/455/465',
[44630] = '1/400/410/420',
[44629] = '1/405/415/425',
[44631] = '1/450/460/470',
[44633] = '1/420/430/440',
[44635] = '1/405/415/425',
[44645] = '1/400/407/415',
[44636] = '1/400/407/415',
[44359] = '1/360/370/380',
[44770] = '1/355/360/365',
[44794] = '1/375/377/380',
[44970] = '1/355/360/365',
[45061] = '1/335/342/350',
[44958] = '1/250/250/250',
[44950] = '1/250/250/250',
[44953] = '1/285/285/285',
[45022] = '1/325/325/325',
[45100] = '1/310/320/330',
[43772] = '1/345/355/365',
[45117] = '1/370/380/390',
[45382] = '1/35/40/45',
[13028] = '1/175/190/205',
[45545] = '1/375/392/410',
[45546] = '1/390/430/470',
[45695] = '1/100/105/110',
[45765] = '1/360/362/365',
[46111] = '1/390/410/430',
[46115] = '1/390/410/430',
[46109] = '1/390/410/430',
[46107] = '1/390/410/430',
[46112] = '1/390/410/430',
[46114] = '1/390/410/430',
[46108] = '1/390/410/430',
[46110] = '1/390/410/430',
[46116] = '1/390/410/430',
[46113] = '1/390/410/430',
[46106] = '1/390/410/430',
[46141] = '1/375/392/410',
[46144] = '1/375/392/410',
[46142] = '1/375/392/410',
[46140] = '1/375/392/410',
[46126] = '1/375/380/385',
[46124] = '1/375/380/385',
[46127] = '1/375/380/385',
[46122] = '1/375/380/385',
[46125] = '1/375/380/385',
[46123] = '1/375/380/385',
[46137] = '1/375/392/410',
[46138] = '1/375/392/410',
[46133] = '1/375/392/410',
[46134] = '1/375/392/410',
[46135] = '1/375/392/410',
[46139] = '1/375/392/410',
[46136] = '1/375/392/410',
[46132] = '1/375/392/410',
[46129] = '1/375/392/410',
[46131] = '1/375/392/410',
[46128] = '1/375/392/410',
[46130] = '1/375/392/410',
[46353] = '1/375/375/375',
[46403] = '1/350/365/380',
[46405] = '1/350/365/380',
[46578] = '1/350/357/365',
[46594] = '1/370/385/400',
[46597] = '1/375/377/380',
[46601] = '1/375/377/380',
[46684] = '1/275/285/295',
[46688] = '1/275/285/295',
[46697] = '1/365/375/385',
[46775] = '1/375/380/385',
[46776] = '1/375/380/385',
[46777] = '1/375/380/385',
[46778] = '1/375/380/385',
[46779] = '1/375/380/385',
[46803] = '1/350/365/380',
[47050] = '1/380/385/390',
[47046] = '1/380/385/390',
[47049] = '1/380/385/390',
[47048] = '1/380/385/390',
[47051] = '1/380/385/390',
[47053] = '1/375/380/385',
[47054] = '1/375/380/385',
[47055] = '1/375/380/385',
[47056] = '1/375/380/385',
[47280] = '1/350/365/380',
[47672] = '1/440/450/460',
[47898] = '1/440/450/460',
[47899] = '1/450/460/470',
[47901] = '1/450/460/470',
[48114] = '1/35/40/45',
[48116] = '1/35/40/45',
[48247] = '1/125/137/150',
[49252] = '1/350/362/375',
[49258] = '1/400/412/425',
[49677] = '1/255/270/285',
[50194] = '1/385/390/395',
[50612] = '1/75/80/85',
[50614] = '1/160/165/170',
[50616] = '1/210/215/220',
[50617] = '1/255/260/265',
[50618] = '1/300/305/310',
[50619] = '1/355/360/365',
[50620] = '1/405/410/415',
[50598] = '1/75/80/85',
[50599] = '1/170/175/180',
[50600] = '1/220/225/230',
[50601] = '1/265/270/275',
[50602] = '1/310/315/320',
[50603] = '1/365/370/375',
[50604] = '1/415/420/425',
[50605] = '1/75/80/85',
[50606] = '1/165/170/175',
[50607] = '1/215/220/225',
[50608] = '1/260/265/270',
[50609] = '1/305/310/315',
[50610] = '1/360/365/370',
[50611] = '1/410/415/420',
[50644] = '1/265/280/295',
[50647] = '1/250/255/260',
[50936] = '1/385/395/405',
[50962] = '1/375/380/385',
[50949] = '1/395/405/415',
[50955] = '1/385/395/405',
[50943] = '1/380/387/395',
[50963] = '1/400/402/405',
[50948] = '1/385/395/405',
[50944] = '1/385/395/405',
[50945] = '1/390/400/410',
[50947] = '1/390/400/410',
[50946] = '1/395/405/415',
[51571] = '1/400/410/420',
[52568] = '1/360/370/380',
[52569] = '1/360/370/380',
[52570] = '1/380/385/390',
[52567] = '1/375/380/385',
[52571] = '1/375/380/385',
[52572] = '1/370/375/380',
[52733] = '1/385/395/405',
[52738] = '1/15/22/30',
[52739] = '1/75/87/100',
[48248] = '1/60/67/75',
[52843] = '1/45/60/75',
[53056] = '1/375/387/400',
[53281] = '1/366/375/385',
[53323] = '1/500/505/510',
[53331] = '1/500/505/510',
[53341] = '1/500/505/510',
[53343] = '1/500/505/510',
[53342] = '1/500/505/510',
[53344] = '1/500/505/510',
[53462] = '1/75/77/80',
[53812] = '1/380/385/390',
[53836] = '1/410/417/425',
[53837] = '1/415/422/430',
[53838] = '1/360/370/380',
[53840] = '1/400/407/415',
[53842] = '1/375/382/390',
[53847] = '1/390/395/400',
[53895] = '1/415/422/430',
[53898] = '1/395/400/405',
[53900] = '1/385/390/395',
[53905] = '1/415/422/430',
[53904] = '1/415/422/430',
[53903] = '1/450/457/465',
[53902] = '1/450/457/465',
[53901] = '1/450/457/465',
[53899] = '1/380/385/390',
[53848] = '1/380/385/390',
[53841] = '1/365/375/385',
[53839] = '1/365/375/385',
[53777] = '1/405/415/425',
[53776] = '1/405/415/425',
[53781] = '1/405/415/425',
[53782] = '1/405/415/425',
[53775] = '1/405/415/425',
[53774] = '1/405/415/425',
[53773] = '1/405/415/425',
[53771] = '1/405/415/425',
[53779] = '1/405/415/425',
[53780] = '1/405/415/425',
[53783] = '1/405/415/425',
[53784] = '1/405/415/425',
[53942] = '1/410/415/420',
[53936] = '1/410/415/420',
[53937] = '1/410/415/420',
[53938] = '1/410/415/420',
[53939] = '1/410/415/420',
[53831] = '1/375/395/415',
[53832] = '1/375/395/415',
[53843] = '1/375/395/415',
[53844] = '1/375/395/415',
[53845] = '1/375/395/415',
[54017] = '1/375/395/415',
[53934] = '1/375/395/415',
[53941] = '1/375/395/415',
[53943] = '1/375/395/415',
[53852] = '1/375/395/415',
[53854] = '1/375/395/415',
[53857] = '1/375/395/415',
[53856] = '1/375/395/415',
[53859] = '1/375/395/415',
[53860] = '1/375/395/415',
[53861] = '1/375/395/415',
[53865] = '1/375/395/415',
[53869] = '1/375/395/415',
[53870] = '1/375/395/415',
[53871] = '1/375/395/415',
[53872] = '1/375/395/415',
[53873] = '1/375/395/415',
[53874] = '1/375/395/415',
[53875] = '1/375/395/415',
[53876] = '1/375/395/415',
[53877] = '1/375/395/415',
[53879] = '1/375/395/415',
[53880] = '1/375/395/415',
[53882] = '1/375/395/415',
[53883] = '1/375/395/415',
[53884] = '1/375/395/415',
[53885] = '1/375/395/415',
[53891] = '1/375/395/415',
[53892] = '1/375/395/415',
[53893] = '1/375/395/415',
[53894] = '1/375/395/415',
[53917] = '1/375/395/415',
[53918] = '1/375/395/415',
[53919] = '1/375/395/415',
[53920] = '1/375/395/415',
[53921] = '1/375/395/415',
[53922] = '1/375/395/415',
[53923] = '1/375/395/415',
[53924] = '1/375/395/415',
[53925] = '1/375/395/415',
[53932] = '1/375/395/415',
[53933] = '1/375/395/415',
[53830] = '1/410/425/440',
[53945] = '1/410/425/440',
[53946] = '1/410/425/440',
[53948] = '1/410/425/440',
[53949] = '1/410/425/440',
[53951] = '1/410/425/440',
[53952] = '1/410/425/440',
[53954] = '1/410/425/440',
[53955] = '1/410/425/440',
[53957] = '1/410/425/440',
[53958] = '1/410/425/440',
[53960] = '1/410/425/440',
[53961] = '1/410/425/440',
[53962] = '1/410/425/440',
[53963] = '1/410/425/440',
[53965] = '1/410/425/440',
[53966] = '1/410/425/440',
[53968] = '1/410/425/440',
[53972] = '1/410/425/440',
[53974] = '1/410/425/440',
[53975] = '1/410/425/440',
[53976] = '1/410/425/440',
[53977] = '1/410/425/440',
[53978] = '1/410/425/440',
[53980] = '1/410/425/440',
[53981] = '1/410/425/440',
[53984] = '1/410/425/440',
[53985] = '1/410/425/440',
[53986] = '1/410/425/440',
[53987] = '1/410/425/440',
[53988] = '1/410/425/440',
[53991] = '1/410/425/440',
[53993] = '1/410/425/440',
[53994] = '1/410/425/440',
[54020] = '1/445/452/460',
[54019] = '1/410/425/440',
[54023] = '1/410/425/440',
[54011] = '1/410/425/440',
[54012] = '1/410/425/440',
[54014] = '1/410/425/440',
[53996] = '1/410/425/440',
[53997] = '1/410/425/440',
[53998] = '1/410/425/440',
[54000] = '1/410/425/440',
[54001] = '1/410/425/440',
[54003] = '1/410/425/440',
[54005] = '1/410/425/440',
[54009] = '1/410/425/440',
[54213] = '1/450/457/465',
[54218] = '1/390/395/400',
[54220] = '1/415/422/430',
[54221] = '1/415/422/430',
[54222] = '1/415/422/430',
[54353] = '1/405/410/415',
[54447] = '1/500/505/510',
[54446] = '1/500/505/510',
[54550] = '1/370/375/380',
[54551] = '1/400/405/410',
[54552] = '1/405/410/415',
[54553] = '1/405/410/415',
[54554] = '1/400/405/410',
[54555] = '1/410/415/420',
[54556] = '1/410/415/420',
[54557] = '1/395/400/405',
[54917] = '1/380/385/390',
[54918] = '1/385/390/395',
[54941] = '1/390/395/400',
[54944] = '1/390/395/400',
[54945] = '1/395/400/405',
[54946] = '1/400/405/410',
[54947] = '1/400/405/410',
[54948] = '1/405/410/415',
[54949] = '1/405/410/415',
[54978] = '1/395/400/405',
[54979] = '1/405/410/415',
[54980] = '1/410/415/420',
[54981] = '1/415/420/425',
[55013] = '1/395/400/405',
[55017] = '1/415/420/425',
[55014] = '1/415/420/425',
[55015] = '1/420/425/430',
[55055] = '1/400/405/410',
[55056] = '1/405/410/415',
[55057] = '1/410/415/420',
[55058] = '1/420/425/430',
[55174] = '1/395/400/405',
[55177] = '1/400/405/410',
[55179] = '1/405/410/415',
[55181] = '1/410/415/420',
[55182] = '1/415/420/425',
[55183] = '1/420/425/430',
[55184] = '1/420/425/430',
[55185] = '1/420/425/430',
[55186] = '1/420/425/430',
[55187] = '1/420/425/430',
[55199] = '1/405/415/425',
[55200] = '1/385/390/395',
[55201] = '1/385/390/395',
[55203] = '1/390/395/400',
[55204] = '1/395/400/405',
[55202] = '1/390/395/400',
[55206] = '1/415/420/425',
[55208] = '1/450/450/450',
[55211] = '1/450/450/450',
[55252] = '1/415/417/420',
[55298] = '1/425/430/435',
[55300] = '1/430/440/450',
[55301] = '1/430/440/450',
[55302] = '1/435/445/455',
[55303] = '1/435/445/455',
[55304] = '1/435/445/455',
[55305] = '1/425/430/435',
[55306] = '1/430/440/450',
[55307] = '1/430/440/450',
[55308] = '1/430/440/450',
[55309] = '1/430/440/450',
[55311] = '1/435/445/455',
[55310] = '1/435/445/455',
[55312] = '1/435/445/455',
[55371] = '1/450/460/470',
[55372] = '1/450/460/470',
[55373] = '1/450/460/470',
[55374] = '1/450/460/470',
[55375] = '1/450/460/470',
[55376] = '1/450/460/470',
[55369] = '1/450/460/470',
[55370] = '1/450/460/470',
[55377] = '1/450/460/470',
[55384] = '1/440/450/460',
[55386] = '1/440/450/460',
[55387] = '1/440/450/460',
[55388] = '1/440/450/460',
[55390] = '1/440/450/460',
[55392] = '1/440/450/460',
[55393] = '1/440/450/460',
[55394] = '1/440/450/460',
[55395] = '1/440/450/460',
[55407] = '1/440/450/460',
[55396] = '1/440/450/460',
[55397] = '1/440/450/460',
[55398] = '1/440/450/460',
[55399] = '1/440/450/460',
[55400] = '1/440/450/460',
[55401] = '1/440/450/460',
[55402] = '1/440/450/460',
[55403] = '1/440/450/460',
[55404] = '1/440/450/460',
[55405] = '1/440/450/460',
[55428] = '75/1/1/1',
[55480] = '150/1/1/1',
[55500] = '225/1/1/1',
[55501] = '300/1/1/1',
[55502] = '375/1/1/1',
[55503] = '450/1/1/1',
[55389] = '1/440/450/460',
[55628] = '1/400/400/400',
[55641] = '1/400/400/400',
[55642] = '1/400/402/405',
[55656] = '1/420/425/430',
[55732] = '1/425/430/435',
[47766] = '1/410/420/430',
[55769] = '1/400/402/405',
[55777] = '1/400/402/405',
[55834] = '1/370/375/380',
[55835] = '1/380/385/390',
[55839] = '1/425/430/435',
[55898] = '1/370/375/380',
[55899] = '1/370/372/375',
[55900] = '1/400/402/405',
[55902] = '1/360/370/380',
[55903] = '1/370/380/390',
[55904] = '1/370/380/390',
[56030] = '1/390/400/410',
[55906] = '1/385/395/405',
[55907] = '1/390/400/410',
[55908] = '1/380/390/400',
[55910] = '1/395/405/415',
[55911] = '1/400/410/420',
[55913] = '1/395/405/415',
[55901] = '1/405/410/415',
[55914] = '1/400/405/410',
[55921] = '1/415/420/425',
[55922] = '1/415/420/425',
[55919] = '1/405/410/415',
[55924] = '1/420/425/430',
[55925] = '1/425/430/435',
[55920] = '1/410/415/420',
[55923] = '1/420/425/430',
[55941] = '1/430/435/440',
[55943] = '1/425/430/435',
[55993] = '1/400/405/410',
[55994] = '1/400/405/410',
[55995] = '1/400/405/410',
[55996] = '1/400/405/410',
[55997] = '1/400/405/410',
[55998] = '1/400/405/410',
[55999] = '1/400/405/410',
[56000] = '1/400/405/410',
[56002] = '1/425/430/435',
[56001] = '1/425/430/435',
[56003] = '1/425/430/435',
[56004] = '1/440/445/450',
[56005] = '1/450/455/460',
[56006] = '1/445/450/455',
[56007] = '1/430/440/450',
[56008] = '1/400/405/410',
[56009] = '1/435/440/445',
[56010] = '1/400/405/410',
[56011] = '1/435/440/445',
[56014] = '1/395/400/405',
[56015] = '1/400/405/410',
[56017] = '1/435/445/455',
[56016] = '1/435/445/455',
[56018] = '1/435/440/445',
[56019] = '1/430/440/450',
[56020] = '1/430/440/450',
[56021] = '1/435/440/445',
[56022] = '1/430/440/450',
[56023] = '1/430/440/450',
[56024] = '1/450/455/460',
[56025] = '1/445/450/455',
[56026] = '1/450/455/460',
[56027] = '1/445/450/455',
[56028] = '1/450/455/460',
[56029] = '1/445/450/455',
[56031] = '1/360/370/380',
[56034] = '1/405/405/405',
[56039] = '1/405/405/405',
[56048] = '1/400/410/420',
[56049] = '1/390/415/440',
[56052] = '1/390/415/440',
[56053] = '1/390/415/440',
[56055] = '1/390/415/440',
[56056] = '1/390/415/440',
[56079] = '1/390/415/440',
[56081] = '1/390/415/440',
[56083] = '1/390/415/440',
[56084] = '1/390/415/440',
[56085] = '1/390/415/440',
[56087] = '1/390/415/440',
[56088] = '1/390/415/440',
[56086] = '1/390/415/440',
[56193] = '1/380/400/420',
[56194] = '1/380/400/420',
[56195] = '1/400/410/420',
[56196] = '1/400/410/420',
[56197] = '1/440/450/460',
[56199] = '1/430/440/450',
[56201] = '1/430/440/450',
[56202] = '1/430/440/450',
[56203] = '1/430/440/450',
[56205] = '1/360/370/380',
[56206] = '1/370/380/390',
[56208] = '1/380/390/400',
[56234] = '1/450/460/470',
[56280] = '1/415/420/425',
[56349] = '1/360/370/380',
[54736] = '1/390/392/395',
[56357] = '1/425/430/435',
[54998] = '1/400/402/405',
[54999] = '1/400/402/405',
[55002] = '1/380/382/385',
[54793] = '1/380/382/385',
[55016] = '1/400/405/410',
[56400] = '1/450/460/470',
[56496] = '1/450/455/460',
[56497] = '1/450/455/460',
[56498] = '1/450/455/460',
[56499] = '1/450/455/460',
[56500] = '1/450/455/460',
[56501] = '1/450/455/460',
[56460] = '1/375/382/390',
[56459] = '1/380/385/390',
[56461] = '1/380/385/390',
[56464] = '1/380/385/390',
[56463] = '1/385/390/395',
[56465] = '1/425/432/440',
[56471] = '1/395/400/405',
[56466] = '1/435/440/445',
[56467] = '1/435/440/445',
[56468] = '1/410/415/420',
[56470] = '1/430/432/435',
[56472] = '1/430/432/435',
[56514] = '1/425/430/435',
[56473] = '1/430/435/440',
[56462] = '1/440/445/450',
[56476] = '1/415/420/425',
[56477] = '1/420/425/430',
[56469] = '1/430/435/440',
[56478] = '1/435/445/455',
[56479] = '1/455/460/465',
[56480] = '1/450/455/460',
[56519] = '1/415/422/430',
[56530] = '1/380/400/420',
[56531] = '1/410/425/440',
[56549] = '1/425/430/435',
[56550] = '1/430/440/450',
[56551] = '1/430/440/450',
[56552] = '1/430/440/450',
[56553] = '1/430/440/450',
[56554] = '1/435/445/455',
[56555] = '1/435/445/455',
[56556] = '1/435/445/455',
[56481] = '1/450/455/460',
[56574] = '1/450/455/460',
[56483] = '1/450/455/460',
[56484] = '1/450/455/460',
[56486] = '1/450/455/460',
[56487] = '1/450/455/460',
[57207] = '1/390/397/405',
[57208] = '1/390/397/405',
[57209] = '1/295/300/305',
[57210] = '1/270/275/280',
[57211] = '1/390/397/405',
[57213] = '1/290/295/300',
[57214] = '1/390/397/405',
[57215] = '1/295/300/305',
[57216] = '1/275/280/285',
[57217] = '1/295/300/305',
[57219] = '1/285/290/295',
[57220] = '1/390/397/405',
[57221] = '1/305/310/315',
[57222] = '1/355/360/365',
[57223] = '1/390/397/405',
[57224] = '1/335/340/345',
[57225] = '1/380/385/390',
[57226] = '1/310/315/320',
[57227] = '1/350/355/360',
[57228] = '1/295/300/305',
[57229] = '1/295/300/305',
[57230] = '1/295/300/305',
[57425] = '1/440/445/450',
[57427] = '1/435/440/445',
[45560] = '1/350/365/380',
[45561] = '1/350/365/380',
[45562] = '1/350/365/380',
[45563] = '1/350/382/415',
[45564] = '1/350/382/415',
[45565] = '1/350/382/415',
[45569] = '1/350/382/415',
[45566] = '1/350/382/415',
[57421] = '1/350/365/380',
[45549] = '1/350/382/415',
[45550] = '1/350/382/415',
[45551] = '1/350/382/415',
[45552] = '1/350/382/415',
[45553] = '1/350/382/415',
[45554] = '1/375/400/425',
[57423] = '1/455/460/465',
[45555] = '1/425/450/475',
[45556] = '1/425/450/475',
[45557] = '1/425/450/475',
[45558] = '1/425/450/475',
[45559] = '1/425/450/475',
[45567] = '1/425/450/475',
[45568] = '1/425/450/475',
[45571] = '1/425/450/475',
[45570] = '1/425/450/475',
[57433] = '1/425/450/475',
[57434] = '1/425/450/475',
[57435] = '1/425/450/475',
[57436] = '1/425/450/475',
[57437] = '1/425/450/475',
[57438] = '1/425/450/475',
[57439] = '1/425/450/475',
[57440] = '1/425/450/475',
[57441] = '1/425/450/475',
[57442] = '1/425/450/475',
[57443] = '1/425/450/475',
[57683] = '1/425/430/435',
[57699] = '1/425/430/435',
[57691] = '1/425/430/435',
[57694] = '1/425/430/435',
[57692] = '1/425/430/435',
[57690] = '1/425/430/435',
[57701] = '1/425/430/435',
[57696] = '1/425/430/435',
[57703] = '1/85/90/95',
[57704] = '1/95/100/105',
[57706] = '1/125/130/135',
[57707] = '1/145/150/155',
[57708] = '1/170/175/180',
[57709] = '1/195/200/205',
[57710] = '1/220/225/230',
[57711] = '1/245/250/255',
[57712] = '1/290/295/300',
[57713] = '1/295/300/305',
[57714] = '1/320/325/330',
[57715] = '1/345/350/355',
[57716] = '1/370/375/380',
[56955] = '1/90/100/110',
[56963] = '1/95/105/115',
[56961] = '1/100/110/120',
[48121] = '1/105/110/115',
[56945] = '1/120/125/130',
[56951] = '1/135/140/145',
[56948] = '1/155/160/165',
[56953] = '1/175/180/185',
[56956] = '1/205/210/215',
[56959] = '1/225/230/235',
[56957] = '1/265/270/275',
[56952] = '1/315/320/325',
[56943] = '1/355/360/365',
[56946] = '1/390/397/405',
[56947] = '1/390/397/405',
[56960] = '1/390/397/405',
[56950] = '1/390/397/405',
[56944] = '1/390/397/405',
[56954] = '1/390/397/405',
[56958] = '1/390/397/405',
[56949] = '1/390/397/405',
[57004] = '1/90/100/110',
[57009] = '1/100/110/120',
[56995] = '1/105/110/115',
[56997] = '1/120/125/130',
[57005] = '1/135/140/145',
[57007] = '1/155/160/165',
[56994] = '1/180/185/190',
[57000] = '1/205/210/215',
[57001] = '1/230/235/240',
[57002] = '1/265/270/275',
[57008] = '1/320/325/330',
[57003] = '1/355/360/365',
[56996] = '1/390/397/405',
[56999] = '1/390/397/405',
[57012] = '1/390/397/405',
[57006] = '1/380/385/390',
[57011] = '1/390/397/405',
[56998] = '1/390/397/405',
[57010] = '1/390/397/405',
[56976] = '1/90/100/110',
[56978] = '1/100/110/120',
[56971] = '1/120/125/130',
[56973] = '1/135/140/145',
[56974] = '1/160/165/170',
[56981] = '1/180/185/190',
[56979] = '1/230/235/240',
[56972] = '1/340/345/350',
[56989] = '1/390/397/405',
[56986] = '1/390/397/405',
[56980] = '1/380/385/390',
[56983] = '1/390/397/405',
[56975] = '1/390/397/405',
[56977] = '1/390/397/405',
[56987] = '1/390/397/405',
[56988] = '1/390/397/405',
[57022] = '1/90/100/110',
[57027] = '1/100/110/120',
[57029] = '1/110/115/120',
[57030] = '1/125/130/135',
[57031] = '1/140/145/150',
[57032] = '1/155/160/165',
[57020] = '1/185/190/195',
[57023] = '1/210/215/220',
[57024] = '1/235/240/245',
[57025] = '1/270/275/280',
[57026] = '1/305/310/315',
[57033] = '1/340/345/350',
[57036] = '1/380/385/390',
[57034] = '1/390/397/405',
[57035] = '1/390/397/405',
[57021] = '1/390/397/405',
[57028] = '1/390/397/405',
[57019] = '1/390/397/405',
[57194] = '1/90/100/110',
[57196] = '1/105/115/125',
[57184] = '1/110/115/120',
[57186] = '1/125/130/135',
[57188] = '1/140/145/150',
[57197] = '1/165/170/175',
[57200] = '1/185/190/195',
[57201] = '1/215/220/225',
[57183] = '1/235/240/245',
[57185] = '1/275/280/285',
[57187] = '1/320/325/330',
[57192] = '1/355/360/365',
[57193] = '1/390/397/405',
[57198] = '1/380/385/390',
[57191] = '1/390/397/405',
[57195] = '1/390/397/405',
[57202] = '1/390/397/405',
[57189] = '1/390/397/405',
[57181] = '1/390/397/405',
[57199] = '1/390/397/405',
[57190] = '1/390/397/405',
[57114] = '1/90/100/110',
[57119] = '1/105/115/125',
[57120] = '1/110/115/120',
[57121] = '1/125/130/135',
[57123] = '1/140/145/150',
[57125] = '1/165/170/175',
[57129] = '1/190/195/200',
[57131] = '1/215/220/225',
[57132] = '1/240/245/250',
[57133] = '1/290/295/300',
[57122] = '1/310/315/320',
[57113] = '1/345/350/355',
[57116] = '1/390/397/405',
[57124] = '1/390/397/405',
[57128] = '1/390/397/405',
[57115] = '1/390/397/405',
[57126] = '1/390/397/405',
[57127] = '1/390/397/405',
[57112] = '1/390/397/405',
[57117] = '1/390/397/405',
[57130] = '1/390/397/405',
[57239] = '1/95/105/115',
[57246] = '1/105/115/125',
[57238] = '1/115/120/125',
[57240] = '1/130/135/140',
[57245] = '1/145/150/155',
[57249] = '1/170/175/180',
[57241] = '1/190/195/200',
[57242] = '1/220/225/230',
[57244] = '1/240/245/250',
[57251] = '1/280/285/290',
[57236] = '1/305/310/315',
[57252] = '1/335/340/345',
[57233] = '1/390/397/405',
[57232] = '1/390/397/405',
[57247] = '1/390/397/405',
[57248] = '1/380/385/390',
[57235] = '1/390/397/405',
[57243] = '1/390/397/405',
[57250] = '1/390/397/405',
[57234] = '1/390/395/400',
[57237] = '1/390/397/405',
[57259] = '1/95/105/115',
[57266] = '1/105/115/125',
[57265] = '1/115/120/125',
[57262] = '1/130/135/140',
[57269] = '1/145/150/155',
[57271] = '1/170/175/180',
[57277] = '1/195/200/205',
[57270] = '1/220/225/230',
[57274] = '1/245/250/255',
[57272] = '1/280/285/290',
[57275] = '1/330/335/340',
[57257] = '1/355/360/365',
[57264] = '1/390/397/405',
[57258] = '1/390/397/405',
[57267] = '1/390/397/405',
[57260] = '1/390/397/405',
[57268] = '1/390/397/405',
[57261] = '1/390/397/405',
[57263] = '1/390/397/405',
[57276] = '1/390/397/405',
[58065] = '1/350/382/415',
[58141] = '1/380/400/420',
[58142] = '1/380/400/420',
[58143] = '1/390/405/420',
[58144] = '1/390/405/420',
[58145] = '1/410/420/430',
[58146] = '1/410/420/430',
[58147] = '1/440/450/460',
[58148] = '1/440/450/460',
[58149] = '1/440/450/460',
[58150] = '1/440/450/460',
[58484] = '1/35/40/45',
[58485] = '1/80/85/90',
[58486] = '1/175/180/185',
[58487] = '1/225/230/235',
[58488] = '1/270/275/280',
[58489] = '1/315/320/325',
[58490] = '1/370/375/380',
[58491] = '1/420/425/430',
[58472] = '1/35/40/45',
[58473] = '1/85/90/95',
[58476] = '1/180/185/190',
[58478] = '1/230/235/240',
[58480] = '1/275/280/285',
[58481] = '1/320/325/330',
[58482] = '1/375/380/385',
[58483] = '1/425/430/435',
[58512] = '1/350/357/365',
[58521] = '1/350/357/365',
[58523] = '1/350/357/365',
[58525] = '1/350/357/365',
[58527] = '1/435/455/475',
[58528] = '1/435/455/475',
[58565] = '1/125/137/150',
[58868] = '1/415/417/420',
[58871] = '1/410/412/415',
[58507] = '1/440/450/460',
[58492] = '1/440/450/460',
[58954] = '1/440/450/460',
[59405] = '1/360/365/370',
[59406] = '1/435/440/445',
[59436] = '1/400/405/410',
[59438] = '1/405/410/415',
[59440] = '1/410/415/420',
[59441] = '1/420/425/430',
[59442] = '1/415/420/425',
[59582] = '1/425/435/445',
[59583] = '1/425/435/445',
[59584] = '1/430/440/450',
[59585] = '1/430/440/450',
[59586] = '1/430/440/450',
[59587] = '1/430/440/450',
[59588] = '1/430/440/450',
[59589] = '1/430/440/450',
[59759] = '1/430/440/450',
[59480] = '1/150/162/175',
[59487] = '1/200/205/210',
[59491] = '1/250/255/260',
[59502] = '1/290/295/300',
[59503] = '1/350/365/380',
[59504] = '1/450/462/475',
[60403] = '1/420/425/430',
[60396] = '1/420/425/430',
[60405] = '1/420/425/430',
[60354] = '1/415/422/430',
[60355] = '1/415/422/430',
[60356] = '1/415/422/430',
[60357] = '1/415/422/430',
[60365] = '1/415/422/430',
[60366] = '1/415/422/430',
[60367] = '1/400/407/415',
[60350] = '1/420/430/440',
[60583] = '1/400/405/410',
[60584] = '1/395/400/405',
[50967] = '1/435/440/445',
[50965] = '1/435/440/445',
[60867] = '1/480/485/490',
[60866] = '1/480/485/490',
[60874] = '1/455/460/465',
[51572] = '1/400/410/420',
[51570] = '1/410/420/430',
[51569] = '1/410/420/430',
[51568] = '1/415/425/435',
[50951] = '1/385/395/405',
[50950] = '1/390/400/410',
[50952] = '1/390/400/410',
[50953] = '1/395/405/415',
[50954] = '1/395/405/415',
[60599] = '1/400/410/420',
[60600] = '1/400/410/420',
[60601] = '1/410/420/430',
[60604] = '1/410/420/430',
[60605] = '1/415/425/435',
[50941] = '1/385/395/405',
[50939] = '1/385/395/405',
[50938] = '1/390/400/410',
[50942] = '1/390/400/410',
[50940] = '1/395/405/415',
[60607] = '1/400/410/420',
[60608] = '1/400/410/420',
[60611] = '1/410/420/430',
[60613] = '1/410/420/430',
[60620] = '1/415/425/435',
[50957] = '1/385/395/405',
[50959] = '1/385/395/405',
[50956] = '1/390/400/410',
[50961] = '1/390/400/410',
[50960] = '1/395/405/415',
[50958] = '1/395/405/415',
[60622] = '1/400/410/420',
[60624] = '1/400/410/420',
[60627] = '1/410/420/430',
[60629] = '1/410/420/430',
[60630] = '1/415/425/435',
[60631] = '1/390/400/410',
[60637] = '1/450/455/460',
[60640] = '1/450/455/460',
[50966] = '1/405/410/415',
[50964] = '1/410/415/420',
[50970] = '1/420/422/425',
[50971] = '1/420/422/425',
[60643] = '1/420/422/425',
[60649] = '1/430/435/440',
[60651] = '1/425/430/435',
[60652] = '1/425/430/435',
[60655] = '1/430/435/440',
[60658] = '1/425/430/435',
[60660] = '1/430/435/440',
[60665] = '1/425/430/435',
[60666] = '1/425/430/435',
[60669] = '1/430/435/440',
[60671] = '1/425/430/435',
[60697] = '1/425/430/435',
[60702] = '1/425/430/435',
[60703] = '1/425/430/435',
[60704] = '1/425/430/435',
[60705] = '1/430/435/440',
[60706] = '1/430/435/440',
[60711] = '1/430/435/440',
[60712] = '1/430/435/440',
[60715] = '1/425/430/435',
[60716] = '1/425/430/435',
[60718] = '1/425/430/435',
[60720] = '1/425/430/435',
[60721] = '1/430/435/440',
[60723] = '1/430/435/440',
[60725] = '1/430/435/440',
[60727] = '1/430/435/440',
[60728] = '1/425/430/435',
[60729] = '1/425/430/435',
[60730] = '1/425/430/435',
[60731] = '1/425/430/435',
[60732] = '1/430/435/440',
[60734] = '1/430/435/440',
[60735] = '1/430/435/440',
[60737] = '1/430/435/440',
[60743] = '1/425/430/435',
[60746] = '1/425/430/435',
[60747] = '1/425/430/435',
[60748] = '1/425/430/435',
[60749] = '1/430/435/440',
[60750] = '1/430/435/440',
[60751] = '1/430/435/440',
[60752] = '1/430/435/440',
[60893] = '1/415/422/430',
[60754] = '1/450/455/460',
[60755] = '1/450/455/460',
[60756] = '1/450/455/460',
[60757] = '1/450/455/460',
[60758] = '1/450/455/460',
[60759] = '1/450/455/460',
[60761] = '1/450/455/460',
[60760] = '1/450/455/460',
[60969] = '1/340/345/350',
[60971] = '1/435/445/455',
[60993] = '1/435/445/455',
[60994] = '1/430/440/450',
[60990] = '1/430/440/450',
[60998] = '1/430/440/450',
[60997] = '1/430/440/450',
[60996] = '1/435/445/455',
[61000] = '1/430/440/450',
[61002] = '1/430/440/450',
[60999] = '1/435/445/455',
[61008] = '1/435/445/455',
[61009] = '1/430/440/450',
[61010] = '1/430/440/450',
[61117] = '1/395/400/405',
[61119] = '1/395/400/405',
[61120] = '1/395/400/405',
[61118] = '1/395/400/405',
[60609] = '1/360/370/380',
[60616] = '1/370/380/390',
[60606] = '1/385/395/405',
[60621] = '1/390/400/410',
[60623] = '1/395/405/415',
[60653] = '1/405/415/425',
[59636] = '1/400/407/415',
[60663] = '1/430/440/450',
[47900] = '1/435/445/455',
[60668] = '1/435/445/455',
[60619] = '1/435/445/455',
[60691] = '1/440/450/460',
[60707] = '1/445/455/465',
[60714] = '1/445/455/465',
[60692] = '1/450/460/470',
[60763] = '1/450/460/470',
[59621] = '1/450/460/470',
[59625] = '1/450/460/470',
[59619] = '1/450/460/470',
[60767] = '1/450/460/470',
[61177] = '1/425/437/450',
[61288] = '1/125/137/150',
[58296] = '1/80/85/90',
[58289] = '1/80/85/90',
[58299] = '1/80/85/90',
[58301] = '1/80/85/90',
[58298] = '1/80/85/90',
[58303] = '1/80/85/90',
[58306] = '1/80/85/90',
[58310] = '1/80/85/90',
[58308] = '1/80/85/90',
[58314] = '1/80/85/90',
[58313] = '1/80/85/90',
[58312] = '1/80/85/90',
[58318] = '1/80/85/90',
[58317] = '1/80/85/90',
[58326] = '1/80/85/90',
[58323] = '1/80/85/90',
[58337] = '1/80/85/90',
[58342] = '1/80/85/90',
[58344] = '1/80/85/90',
[58346] = '1/80/85/90',
[58343] = '1/80/85/90',
[58286] = '1/105/110/115',
[58288] = '1/105/110/115',
[58311] = '1/105/110/115',
[58315] = '1/105/110/115',
[58320] = '1/105/110/115',
[58325] = '1/105/110/115',
[58332] = '1/105/110/115',
[59326] = '1/105/110/115',
[58336] = '1/105/110/115',
[58345] = '1/105/110/115',
[58307] = '1/130/135/140',
[58324] = '1/130/135/140',
[58328] = '1/130/135/140',
[58331] = '1/130/135/140',
[58340] = '1/130/135/140',
[59315] = '1/155/160/165',
[58287] = '1/155/160/165',
[58302] = '1/155/160/165',
[58316] = '1/155/160/165',
[58321] = '1/155/160/165',
[58333] = '1/155/160/165',
[58329] = '1/155/160/165',
[58330] = '1/155/160/165',
[58338] = '1/155/160/165',
[58339] = '1/155/160/165',
[58319] = '1/155/160/165',
[58297] = '1/205/210/215',
[58327] = '1/205/210/215',
[58347] = '1/295/300/305',
[58322] = '1/355/360/365',
[58341] = '1/355/360/365',
[57162] = '1/95/105/115',
[57158] = '1/105/115/125',
[59475] = '1/150/162/175',
[59478] = '1/150/162/175',
[57163] = '1/115/120/125',
[57157] = '1/130/135/140',
[57167] = '1/145/150/155',
[59484] = '1/200/205/210',
[59486] = '1/200/205/210',
[57161] = '1/175/180/185',
[57165] = '1/195/200/205',
[59387] = '1/205/210/215',
[60336] = '1/215/220/225',
[59489] = '1/250/255/260',
[59490] = '1/250/255/260',
[57154] = '1/245/250/255',
[59493] = '1/290/295/300',
[59494] = '1/290/295/300',
[57156] = '1/290/295/300',
[59495] = '1/340/345/350',
[59496] = '1/340/345/350',
[59338] = '1/315/320/325',
[57168] = '1/325/330/335',
[59339] = '1/325/330/335',
[59340] = '1/345/350/355',
[57172] = '1/350/355/360',
[60337] = '1/355/360/365',
[59497] = '1/425/437/450',
[59498] = '1/425/437/450',
[57159] = '1/390/397/405',
[57170] = '1/390/397/405',
[57152] = '1/390/397/405',
[57160] = '1/390/397/405',
[59559] = '1/390/397/405',
[57155] = '1/390/397/405',
[59561] = '1/390/397/405',
[57153] = '1/355/360/365',
[57164] = '1/390/397/405',
[59560] = '1/390/397/405',
[61471] = '1/400/407/415',
[61481] = '1/425/432/440',
[61482] = '1/425/432/440',
[61483] = '1/425/432/440',
[22967] = '1/350/362/375',
[57014] = '1/390/397/405',
[61677] = '1/390/397/405',
[62045] = '1/405/417/430',
[62044] = '1/150/162/175',
[62051] = '1/270/282/295',
[62050] = '1/90/102/115',
[62049] = '1/210/222/235',
[56990] = '1/355/360/365',
[57253] = '1/355/360/365',
[56965] = '1/355/360/365',
[62158] = '1/500/505/510',
[62162] = '1/380/385/390',
[62176] = '1/450/455/460',
[62177] = '1/450/455/460',
[62202] = '1/455/460/465',
[62213] = '1/390/395/400',
[62242] = '1/445/457/470',
[62256] = '1/460/470/480',
[62257] = '1/460/470/480',
[62271] = '1/450/455/460',
[62350] = '1/350/405/460',
[56991] = '1/320/325/330',
[62409] = '1/380/385/390',
[62410] = '1/415/422/430',
[62448] = '1/435/440/445',
[62941] = '1/310/315/320',
[62948] = '1/455/460/465',
[62959] = '1/395/405/415',
[63182] = '1/450/460/470',
[63190] = '1/455/465/475',
[63191] = '1/455/465/475',
[63189] = '1/455/465/475',
[63187] = '1/455/465/475',
[63188] = '1/455/465/475',
[63192] = '1/455/465/475',
[63194] = '1/455/465/475',
[63195] = '1/455/465/475',
[63196] = '1/455/465/475',
[63201] = '1/455/465/475',
[63198] = '1/455/465/475',
[63199] = '1/455/465/475',
[63200] = '1/455/465/475',
[63197] = '1/455/465/475',
[63732] = '1/160/180/200',
[63742] = '1/150/167/185',
[63743] = '1/210/220/230',
[63746] = '1/245/265/285',
[63750] = '1/270/280/290',
[63770] = '1/400/402/405',
[63924] = '1/440/445/450',
[64051] = '1/375/387/400',
[64053] = '1/375/387/400',
[64054] = '1/250/275/300',
[64248] = '1/430/435/440',
[64246] = '1/430/435/440',
[64247] = '1/430/435/440',
[64249] = '1/430/435/440',
[64250] = '1/430/435/440',
[64251] = '1/430/435/440',
[64252] = '1/430/435/440',
[64253] = '1/430/435/440',
[64254] = '1/430/435/440',
[64255] = '1/355/360/365',
[64256] = '1/430/435/440',
[64257] = '1/430/435/440',
[64261] = '1/255/262/270',
[64258] = '1/255/262/270',
[64260] = '1/255/262/270',
[64259] = '1/255/262/270',
[64262] = '1/255/262/270',
[64266] = '1/280/287/295',
[64276] = '1/430/435/440',
[64277] = '1/430/435/440',
[64268] = '1/430/435/440',
[64295] = '1/430/435/440',
[64294] = '1/430/435/440',
[64271] = '1/430/435/440',
[64297] = '1/430/435/440',
[64274] = '1/430/435/440',
[64280] = '1/430/435/440',
[64279] = '1/430/435/440',
[64273] = '1/430/435/440',
[64288] = '1/430/435/440',
[64281] = '1/430/435/440',
[64278] = '1/430/435/440',
[64291] = '1/430/435/440',
[64300] = '1/430/435/440',
[64284] = '1/430/435/440',
[64298] = '1/430/435/440',
[64283] = '1/430/435/440',
[64285] = '1/430/435/440',
[64275] = '1/430/435/440',
[64318] = '1/430/435/440',
[64282] = '1/430/435/440',
[64289] = '1/430/435/440',
[64286] = '1/430/435/440',
[64296] = '1/430/435/440',
[64287] = '1/430/435/440',
[64270] = '1/430/435/440',
[64302] = '1/430/435/440',
[64303] = '1/430/435/440',
[64305] = '1/430/435/440',
[64304] = '1/430/435/440',
[64312] = '1/355/360/365',
[64309] = '1/430/435/440',
[64307] = '1/430/435/440',
[64311] = '1/430/435/440',
[64308] = '1/430/435/440',
[64310] = '1/430/435/440',
[64317] = '1/430/435/440',
[64315] = '1/430/435/440',
[64316] = '1/430/435/440',
[64314] = '1/430/435/440',
[64313] = '1/430/435/440',
[64358] = '1/400/412/425',
[64441] = '1/455/460/465',
[64579] = '1/455/460/465',
[64661] = '1/350/362/375',
[63206] = '1/455/460/465',
[63205] = '1/455/460/465',
[63204] = '1/455/460/465',
[63203] = '1/455/460/465',
[64725] = '1/440/450/460',
[64726] = '1/440/450/460',
[64727] = '1/440/450/460',
[64728] = '1/440/450/460',
[64729] = '1/405/410/415',
[64730] = '1/410/415/420',
[65454] = '1/30/35/40',
[66034] = '1/270/282/295',
[66035] = '1/210/222/235',
[66036] = '1/150/162/175',
[66037] = '1/405/417/430',
[66038] = '1/90/102/115',
[66428] = '1/440/452/465',
[66429] = '1/440/452/465',
[66431] = '1/440/452/465',
[66432] = '1/440/452/465',
[66434] = '1/440/452/465',
[66435] = '1/440/452/465',
[66439] = '1/440/452/465',
[66441] = '1/440/452/465',
[66442] = '1/440/452/465',
[66443] = '1/440/452/465',
[66445] = '1/440/452/465',
[66446] = '1/440/452/465',
[66447] = '1/440/452/465',
[66448] = '1/440/452/465',
[66450] = '1/440/452/465',
[66452] = '1/440/452/465',
[66453] = '1/440/452/465',
[66497] = '1/440/452/465',
[66498] = '1/440/452/465',
[66499] = '1/440/452/465',
[66501] = '1/440/452/465',
[66502] = '1/440/452/465',
[66505] = '1/440/452/465',
[66506] = '1/440/452/465',
[66554] = '1/440/452/465',
[66556] = '1/440/452/465',
[66557] = '1/440/452/465',
[66560] = '1/440/452/465',
[66561] = '1/440/452/465',
[66562] = '1/440/452/465',
[66567] = '1/440/452/465',
[66568] = '1/440/452/465',
[66569] = '1/440/452/465',
[66570] = '1/440/452/465',
[66571] = '1/440/452/465',
[66572] = '1/440/452/465',
[66573] = '1/440/452/465',
[66574] = '1/440/452/465',
[66576] = '1/440/452/465',
[66579] = '1/440/452/465',
[66581] = '1/440/452/465',
[66582] = '1/440/452/465',
[66583] = '1/440/452/465',
[66584] = '1/440/452/465',
[66585] = '1/440/452/465',
[66586] = '1/440/452/465',
[66587] = '1/440/452/465',
[66338] = '1/440/452/465',
[66664] = '1/440/452/465',
[66658] = '1/440/452/465',
[66659] = '1/440/452/465',
[66660] = '1/440/452/465',
[66662] = '1/440/452/465',
[66663] = '1/440/452/465',
[67025] = '1/440/445/450',
[67091] = '1/460/467/475',
[67092] = '1/460/467/475',
[67093] = '1/460/467/475',
[67094] = '1/460/467/475',
[67095] = '1/460/467/475',
[67096] = '1/460/467/475',
[67131] = '1/460/467/475',
[67132] = '1/460/467/475',
[67133] = '1/460/467/475',
[67134] = '1/460/467/475',
[67135] = '1/460/467/475',
[67130] = '1/460/467/475',
[67080] = '1/460/467/475',
[67081] = '1/460/467/475',
[67087] = '1/460/467/475',
[67086] = '1/460/467/475',
[67085] = '1/460/467/475',
[67084] = '1/460/467/475',
[67083] = '1/460/467/475',
[67082] = '1/460/467/475',
[67136] = '1/460/467/475',
[67142] = '1/460/467/475',
[67141] = '1/460/467/475',
[67140] = '1/460/467/475',
[67139] = '1/460/467/475',
[67138] = '1/460/467/475',
[67137] = '1/460/467/475',
[67143] = '1/460/467/475',
[67064] = '1/460/467/475',
[67065] = '1/460/467/475',
[67066] = '1/460/467/475',
[67079] = '1/460/467/475',
[67144] = '1/460/467/475',
[67145] = '1/460/467/475',
[67146] = '1/460/467/475',
[67147] = '1/460/467/475',
[67326] = '1/415/420/425',
[67600] = '1/105/110/115',
[67920] = '1/450/455/460',
[68067] = '1/480/485/490',
[68166] = '1/355/360/365',
[67839] = '1/410/415/420',
[68253] = '1/440/452/465',
[69386] = '1/440/455/470',
[69388] = '1/440/455/470',
[69385] = '1/425/442/460',
[69412] = '1/445/447/450',
[70164] = '1/500/505/510',
[70524] = '1/250/270/290',
[70562] = '1/475/487/500',
[70563] = '1/475/487/500',
[70565] = '1/475/487/500',
[70567] = '1/475/487/500',
[70568] = '1/475/487/500',
[70566] = '1/475/487/500',
[70554] = '1/475/487/500',
[70555] = '1/475/487/500',
[70556] = '1/475/487/500',
[70557] = '1/475/487/500',
[70558] = '1/475/487/500',
[70559] = '1/475/487/500',
[70560] = '1/475/487/500',
[70561] = '1/475/487/500',
[70550] = '1/475/487/500',
[70551] = '1/475/487/500',
[70552] = '1/475/487/500',
[70553] = '1/475/487/500',
[71692] = '1/385/392/400',
[71101] = '1/255/260/265',
[71102] = '1/380/382/385',
[73222] = '1/450/467/485',
[73223] = '1/450/467/485',
[73224] = '1/450/467/485',
[73225] = '1/450/467/485',
[73226] = '1/450/467/485',
[73227] = '1/450/467/485',
[73228] = '1/450/467/485',
[73229] = '1/450/467/485',
[73230] = '1/450/467/485',
[73231] = '1/450/467/485',
[73232] = '1/450/467/485',
[73233] = '1/450/467/485',
[73234] = '1/450/467/485',
[73239] = '1/450/467/485',
[73240] = '1/450/467/485',
[73241] = '1/450/467/485',
[73242] = '1/450/467/485',
[73243] = '1/450/467/485',
[73244] = '1/450/467/485',
[73245] = '1/450/467/485',
[73246] = '1/450/467/485',
[73247] = '1/450/467/485',
[73248] = '1/450/467/485',
[73249] = '1/450/467/485',
[73250] = '1/450/467/485',
[73258] = '1/450/467/485',
[73259] = '1/450/467/485',
[73260] = '1/450/467/485',
[73262] = '1/450/467/485',
[73263] = '1/450/467/485',
[73264] = '1/450/467/485',
[73265] = '1/450/467/485',
[73266] = '1/450/467/485',
[73267] = '1/450/467/485',
[73268] = '1/450/467/485',
[73269] = '1/450/467/485',
[73270] = '1/450/467/485',
[73271] = '1/450/467/485',
[73272] = '1/450/467/485',
[73273] = '1/450/467/485',
[73274] = '1/450/467/485',
[73275] = '1/450/467/485',
[73276] = '1/450/467/485',
[73277] = '1/450/467/485',
[73278] = '1/450/467/485',
[73279] = '1/450/467/485',
[73280] = '1/450/467/485',
[73281] = '1/450/467/485',
[73335] = '1/500/507/515',
[73336] = '1/500/507/515',
[73337] = '1/500/507/515',
[73338] = '1/500/507/515',
[73339] = '1/500/507/515',
[73340] = '1/500/507/515',
[73341] = '1/500/507/515',
[73343] = '1/500/507/515',
[73344] = '1/500/507/515',
[73345] = '1/500/507/515',
[73346] = '1/500/507/515',
[73347] = '1/500/507/515',
[73348] = '1/500/507/515',
[73349] = '1/500/507/515',
[73350] = '1/500/507/515',
[73351] = '1/500/507/515',
[73352] = '1/500/507/515',
[73353] = '1/500/507/515',
[73354] = '1/500/507/515',
[73355] = '1/500/507/515',
[73356] = '1/500/507/515',
[73357] = '1/500/507/515',
[73358] = '1/500/507/515',
[73359] = '1/500/507/515',
[73360] = '1/500/507/515',
[73361] = '1/500/507/515',
[73362] = '1/500/507/515',
[73364] = '1/500/507/515',
[73365] = '1/500/507/515',
[73366] = '1/500/507/515',
[73367] = '1/500/507/515',
[73368] = '1/500/507/515',
[73369] = '1/500/507/515',
[73370] = '1/500/507/515',
[73371] = '1/500/507/515',
[73372] = '1/500/507/515',
[73373] = '1/500/507/515',
[73374] = '1/500/507/515',
[73375] = '1/500/507/515',
[73376] = '1/500/507/515',
[73377] = '1/500/507/515',
[73378] = '1/500/507/515',
[73379] = '1/500/507/515',
[73380] = '1/500/507/515',
[73381] = '1/500/507/515',
[73382] = '1/500/507/515',
[73383] = '1/500/507/515',
[73384] = '1/500/507/515',
[73396] = '1/505/507/510',
[73399] = '1/505/507/510',
[73397] = '1/505/507/510',
[73398] = '1/505/507/510',
[73409] = '1/505/507/510',
[73407] = '1/505/507/510',
[73400] = '1/505/507/510',
[73408] = '1/505/507/510',
[73404] = '1/505/507/510',
[73406] = '1/505/507/510',
[73401] = '1/505/507/510',
[73402] = '1/505/507/510',
[73403] = '1/505/507/510',
[73405] = '1/505/507/510',
[73468] = '1/515/520/525',
[73466] = '1/515/520/525',
[73465] = '1/515/520/525',
[73472] = '1/515/520/525',
[73469] = '1/515/520/525',
[73470] = '1/515/520/525',
[73474] = '1/515/520/525',
[73467] = '1/515/520/525',
[73464] = '1/515/520/525',
[73476] = '1/515/520/525',
[73475] = '1/515/520/525',
[73473] = '1/515/520/525',
[73471] = '1/515/520/525',
[73478] = '1/525/525/525',
[73627] = '1/490/500/510',
[73626] = '1/485/495/505',
[73625] = '1/480/490/500',
[73623] = '1/525/530/535',
[73622] = '1/450/457/465',
[73621] = '1/500/505/510',
[73620] = '1/470/475/480',
[73979] = '1/50/50/50',
[74132] = '1/440/450/460',
[74189] = '1/440/450/460',
[74191] = '1/440/450/460',
[74192] = '1/450/460/470',
[74193] = '1/450/460/470',
[74195] = '1/460/462/465',
[74197] = '1/460/462/465',
[74198] = '1/465/475/485',
[74199] = '1/465/475/485',
[74200] = '1/470/480/490',
[74201] = '1/470/480/490',
[74202] = '1/475/485/495',
[74207] = '1/475/485/495',
[74211] = '1/480/490/500',
[74212] = '1/480/490/500',
[74213] = '1/485/495/505',
[74214] = '1/485/495/505',
[74215] = '1/455/475/495',
[74216] = '1/455/475/495',
[74217] = '1/455/475/495',
[74218] = '1/455/475/495',
[74220] = '1/490/500/510',
[74223] = '1/490/500/510',
[74225] = '1/495/505/515',
[74226] = '1/495/505/515',
[74229] = '1/500/510/520',
[74230] = '1/500/510/520',
[74231] = '1/505/515/525',
[74232] = '1/505/515/525',
[74234] = '1/510/520/530',
[74235] = '1/510/520/530',
[74236] = '1/510/512/515',
[74237] = '1/515/525/535',
[74238] = '1/520/530/540',
[74239] = '1/520/530/540',
[74240] = '1/520/530/540',
[74242] = '1/525/532/540',
[74244] = '1/525/532/540',
[74246] = '1/525/532/540',
[74247] = '1/525/532/540',
[74248] = '1/525/532/540',
[74250] = '1/525/532/540',
[74251] = '1/525/532/540',
[74252] = '1/525/532/540',
[74253] = '1/525/532/540',
[74254] = '1/525/532/540',
[74255] = '1/525/532/540',
[74256] = '1/525/532/540',
[74497] = '525/1/1/1',
[74537] = '1/475/500/525',
[74530] = '1/450/475/500',
[74529] = '1/525/525/525',
[74556] = '1/450/467/485',
[74557] = '1/485/505/525',
[74558] = '1/525/530/535',
[75298] = '1/525/530/535',
[75288] = '1/505/510/515',
[74964] = '1/440/445/450',
[75300] = '1/525/530/535',
[75248] = '1/455/460/465',
[75252] = '1/460/465/470',
[75249] = '1/455/460/465',
[75256] = '1/470/475/480',
[75253] = '1/470/472/475',
[75254] = '1/465/470/475',
[75257] = '1/475/477/480',
[75251] = '1/460/465/470',
[75141] = '1/525/530/535',
[75142] = '1/525/530/535',
[75145] = '1/525/530/535',
[75144] = '1/525/530/535',
[75146] = '1/525/530/535',
[75299] = '1/525/530/535',
[75293] = '1/515/520/525',
[75297] = '1/525/530/535',
[75270] = '1/505/510/515',
[75306] = '1/525/530/535',
[75295] = '1/520/525/530',
[75307] = '1/525/530/535',
[75305] = '1/525/530/535',
[75291] = '1/510/515/520',
[75264] = '1/490/492/495',
[75247] = '1/435/445/455',
[75250] = '1/465/467/470',
[75269] = '1/515/520/525',
[75294] = '1/520/525/530',
[75290] = '1/505/510/515',
[75304] = '1/525/530/535',
[75296] = '1/525/530/535',
[75302] = '1/525/530/535',
[75303] = '1/525/530/535',
[75292] = '1/515/520/525',
[75301] = '1/525/530/535',
[75255] = '1/470/472/475',
[75289] = '1/530/535/540',
[75268] = '1/500/502/505',
[75308] = '1/525/530/535',
[75154] = '1/475/475/475',
[75265] = '1/490/492/495',
[75309] = '1/525/530/535',
[75310] = '1/525/530/535',
[75155] = '1/475/475/475',
[75258] = '1/475/480/485',
[75261] = '1/480/485/490',
[75259] = '1/475/480/485',
[75266] = '1/500/502/505',
[75262] = '1/485/490/495',
[75263] = '1/485/490/495',
[75267] = '1/500/502/505',
[75260] = '1/485/487/490',
[75175] = '1/500/500/500',
[75172] = '1/500/500/500',
[75178] = '1/500/500/500',
[75597] = '1/435/445/455',
[76179] = '1/460/462/465',
[76180] = '1/460/462/465',
[76181] = '1/470/472/475',
[76182] = '1/480/482/485',
[76258] = '1/490/492/495',
[76259] = '1/500/502/505',
[76260] = '1/500/502/505',
[76261] = '1/510/512/515',
[76262] = '1/460/462/465',
[76263] = '1/460/462/465',
[76264] = '1/470/472/475',
[76265] = '1/480/482/485',
[76266] = '1/490/492/495',
[76267] = '1/500/502/505',
[76269] = '1/510/512/515',
[76270] = '1/510/512/515',
[76280] = '1/460/462/465',
[76281] = '1/460/462/465',
[76283] = '1/470/472/475',
[76285] = '1/480/482/485',
[76286] = '1/490/492/495',
[76287] = '1/490/492/495',
[76288] = '1/500/502/505',
[76289] = '1/510/512/515',
[76291] = '1/460/462/465',
[76293] = '1/480/482/485',
[76433] = '1/475/477/480',
[76434] = '1/480/482/485',
[76435] = '1/490/492/495',
[76436] = '1/490/492/495',
[76437] = '1/490/492/495',
[76438] = '1/480/485/490',
[76439] = '1/525/525/525',
[76440] = '1/530/535/540',
[76441] = '1/500/502/505',
[76442] = '1/505/510/515',
[76443] = '1/525/525/525',
[76444] = '1/520/522/525',
[76445] = '1/525/525/525',
[76446] = '1/520/522/525',
[76447] = '1/525/525/525',
[76448] = '1/520/522/525',
[76449] = '1/525/525/525',
[76450] = '1/525/525/525',
[76451] = '1/525/525/525',
[76452] = '1/525/525/525',
[76453] = '1/525/525/525',
[76454] = '1/525/525/525',
[76455] = '1/525/525/525',
[76456] = '1/510/512/515',
[76457] = '1/515/517/520',
[76458] = '1/520/522/525',
[76459] = '1/525/527/530',
[76461] = '1/530/532/535',
[76462] = '1/535/537/540',
[76463] = '1/535/537/540',
[76464] = '1/535/537/540',
[76465] = '1/510/512/515',
[76466] = '1/515/517/520',
[76467] = '1/520/522/525',
[76468] = '1/525/527/530',
[76469] = '1/530/532/535',
[76470] = '1/535/537/540',
[76471] = '1/535/537/540',
[76472] = '1/535/537/540',
[76474] = '1/480/482/485',
[74493] = '1/435/442/450',
[78670] = '1/1/1/1',
[80479] = '1/460/465/470',
[80486] = '1/475/480/485',
[80478] = '1/455/460/465',
[80488] = '1/480/485/490',
[80491] = '1/485/490/495',
[80493] = '1/495/500/505',
[80484] = '1/470/475/480',
[80497] = '1/500/505/510',
[80480] = '1/460/465/470',
[80724] = '1/505/510/515',
[80719] = '1/505/510/515',
[80720] = '1/510/515/520',
[80721] = '1/515/520/525',
[80723] = '1/515/520/525',
[80477] = '1/455/460/465',
[80496] = '1/495/500/505',
[80508] = '1/510/512/515',
[80490] = '1/480/485/490',
[80487] = '1/475/480/485',
[80498] = '1/500/505/510',
[80494] = '1/490/495/500',
[80482] = '1/470/475/480',
[80725] = '1/525/530/535',
[80269] = '1/470/475/480',
[80495] = '1/490/495/500',
[80726] = '1/525/530/535',
[80492] = '1/485/490/495',
[80247] = '1/525/530/535',
[80248] = '1/520/525/530',
[80251] = '1/510/515/520',
[80250] = '1/515/520/525',
[80245] = '1/525/530/535',
[80243] = '1/525/530/535',
[78866] = '1/510/515/520',
[80246] = '1/520/525/530',
[80244] = '1/525/530/535',
[80237] = '1/525/530/535',
[80481] = '1/465/470/475',
[80451] = '1/1/1/1',
[81708] = '1/1/1/1',
[81725] = '1/525/530/535',
[81722] = '1/525/530/535',
[81724] = '1/525/530/535',
[81716] = '1/525/530/535',
[81720] = '1/525/530/535',
[81715] = '1/525/530/535',
[81714] = '1/525/530/535',
[84038] = '1/400/437/475',
[84432] = '1/525/525/525',
[84431] = '1/525/530/535',
[84430] = '1/500/520/540',
[84429] = '1/490/502/515',
[84428] = '1/525/530/535',
[84427] = '1/425/437/450',
[84425] = '1/425/437/450',
[84421] = '1/495/497/500',
[84420] = '1/510/512/515',
[84418] = '1/505/507/510',
[84417] = '1/515/517/520',
[84416] = '1/495/497/500',
[84415] = '1/490/492/495',
[84413] = '1/495/497/500',
[84412] = '1/495/497/500',
[84411] = '1/480/480/480',
[84410] = '1/470/472/475',
[84409] = '1/460/467/475',
[84408] = '1/470/472/475',
[84406] = '1/455/457/460',
[84403] = '1/435/442/450',
[82201] = '1/425/437/450',
[82200] = '1/425/437/450',
[82180] = '1/425/437/450',
[82177] = '1/425/437/450',
[82175] = '1/425/437/450',
[85007] = '1/490/497/505',
[85008] = '1/490/497/505',
[85009] = '1/490/497/505',
[85010] = '1/490/497/505',
[78379] = '1/450/452/455',
[78380] = '1/470/475/480',
[78388] = '1/470/475/480',
[78396] = '1/480/485/490',
[78398] = '1/460/465/470',
[78399] = '1/475/480/485',
[78405] = '1/475/480/485',
[78406] = '1/485/490/495',
[78407] = '1/475/480/485',
[78410] = '1/460/465/470',
[78411] = '1/485/490/495',
[78415] = '1/465/470/475',
[78416] = '1/465/470/475',
[78419] = '1/485/490/495',
[78420] = '1/490/495/500',
[78423] = '1/510/512/515',
[78424] = '1/505/507/510',
[78427] = '1/490/495/500',
[78428] = '1/490/495/500',
[78432] = '1/495/500/505',
[78433] = '1/495/500/505',
[78436] = '1/485/487/490',
[78437] = '1/490/495/500',
[78438] = '1/510/512/515',
[78439] = '1/510/512/515',
[78444] = '1/515/520/525',
[78445] = '1/515/520/525',
[78446] = '1/515/520/525',
[78447] = '1/515/520/525',
[78448] = '1/515/520/525',
[78449] = '1/515/520/525',
[78450] = '1/515/520/525',
[78451] = '1/515/520/525',
[78452] = '1/520/525/530',
[78453] = '1/520/525/530',
[78454] = '1/520/525/530',
[78455] = '1/520/525/530',
[78456] = '1/520/525/530',
[78457] = '1/520/525/530',
[78458] = '1/520/525/530',
[78459] = '1/520/525/530',
[78460] = '1/520/525/530',
[78461] = '1/520/525/530',
[78462] = '1/520/525/530',
[78463] = '1/520/525/530',
[78464] = '1/525/530/535',
[78467] = '1/525/530/535',
[78468] = '1/525/530/535',
[78469] = '1/525/530/535',
[78470] = '1/525/530/535',
[78471] = '1/525/530/535',
[78473] = '1/525/530/535',
[78474] = '1/525/530/535',
[78475] = '1/530/535/540',
[78476] = '1/530/535/540',
[78477] = '1/530/535/540',
[78478] = '1/530/535/540',
[78479] = '1/530/535/540',
[78480] = '1/530/535/540',
[78481] = '1/530/535/540',
[78482] = '1/530/535/540',
[78483] = '1/530/535/540',
[78484] = '1/530/535/540',
[78485] = '1/530/535/540',
[78486] = '1/530/535/540',
[78487] = '1/530/535/540',
[78488] = '1/530/535/540',
[78489] = '1/530/535/540',
[78490] = '1/530/535/540',
[84950] = '1/435/442/450',
[85067] = '1/460/465/470',
[85068] = '1/460/465/470',
[85785] = '1/505/510/515',
[86005] = '1/480/482/485',
[86004] = '1/440/445/450',
[86857] = '1/525/525/525',
[86866] = '1/525/525/525',
[86865] = '1/525/525/525',
[86864] = '1/525/525/525',
[88003] = '1/515/520/525',
[88004] = '1/515/520/525',
[88005] = '1/515/520/525',
[88034] = '1/515/520/525',
[88006] = '1/450/457/465',
[88011] = '1/525/525/525',
[88012] = '1/465/477/490',
[88013] = '1/510/512/515',
[88014] = '1/515/520/525',
[88015] = '1/430/435/440',
[88016] = '1/515/520/525',
[88017] = '1/440/455/470',
[88018] = '1/490/500/510',
[88019] = '1/525/525/525',
[88020] = '1/515/520/525',
[88021] = '1/490/497/505',
[88022] = '1/455/460/465',
[88024] = '1/465/477/490',
[88025] = '1/515/520/525',
[88028] = '1/465/477/490',
[88030] = '1/465/477/490',
[88031] = '1/515/520/525',
[88033] = '1/490/497/505',
[88035] = '1/465/477/490',
[88036] = '1/525/525/525',
[88037] = '1/465/477/490',
[88039] = '1/515/520/525',
[88042] = '1/515/520/525',
[88044] = '1/525/525/525',
[88045] = '1/455/460/465',
[88046] = '1/490/497/505',
[88047] = '1/465/477/490',
[88181] = '1/525/525/525',
[88180] = '1/525/525/525',
[88893] = '1/525/530/535',
[88262] = '1/525/525/525',
[88908] = '1/525/525/525',
[88907] = '1/525/525/525',
[88910] = '1/525/525/525',
[88909] = '1/525/525/525',
[88930] = '1/525/525/525',
[88929] = '1/525/525/525',
[88961] = '1/1/1/1',
[89014] = '1/525/525/525',
[89012] = '1/525/525/525',
[89009] = '1/525/525/525',
[89244] = '1/525/530/535',
[86654] = '1/525/530/535',
[86375] = '1/490/497/505',
[86401] = '1/490/497/505',
[86402] = '1/490/497/505',
[86403] = '1/490/497/505',
[86609] = '1/460/467/475',
[86615] = '1/525/530/535',
[86616] = '1/485/487/490',
[86640] = '1/485/487/490',
[86641] = '1/520/525/530',
[86642] = '1/520/525/530',
[86643] = '1/520/525/530',
[86644] = '1/470/480/490',
[86645] = '1/480/490/500',
[86646] = '1/490/500/510',
[86647] = '1/500/502/505',
[86648] = '1/500/502/505',
[86649] = '1/515/520/525',
[86650] = '1/525/530/535',
[86652] = '1/525/530/535',
[86653] = '1/525/530/535',
[89367] = '1/475/480/485',
[89368] = '1/450/455/460',
[89369] = '1/470/475/480',
[89370] = '1/475/480/485',
[89371] = '1/460/465/470',
[89372] = '1/465/470/475',
[89373] = '1/455/460/465',
[89693] = '1/525/525/525',
[89696] = '1/525/525/525',
[89701] = '1/525/525/525',
[89711] = '1/525/525/525',
[89717] = '1/525/525/525',
[89718] = '1/1/1/1',
[89719] = '1/1/1/1',
[89720] = '1/1/1/1',
[89721] = '1/1/1/1',
[89722] = '1/1/1/1',
[89815] = '1/470/477/485',
[89890] = '1/525/525/525',
[89891] = '1/525/525/525',
[89893] = '1/525/525/525',
[89894] = '1/525/525/525',
[89896] = '1/525/525/525',
[89964] = '1/1/1/1',
[90410] = '1/525/525/525',
[90411] = '1/525/525/525',
[90412] = '1/525/525/525',
[90413] = '1/525/525/525',
[90415] = '1/525/525/525',
[90419] = '1/525/525/525',
[90420] = '1/525/525/525',
[90421] = '1/525/525/525',
[90423] = '1/525/525/525',
[90429] = '1/525/525/525',
[90458] = '1/525/525/525',
[90453] = '1/525/525/525',
[90452] = '1/525/525/525',
[90451] = '1/525/525/525',
[90433] = '1/525/525/525',
[90432] = '1/525/525/525',
[90504] = '1/525/525/525',
[90493] = '1/525/525/525',
[90506] = '1/525/525/525',
[90509] = '1/525/525/525',
[90518] = '1/525/525/525',
[90519] = '1/525/525/525',
[90521] = '1/525/525/525',
[90553] = '1/525/525/525',
[90616] = '1/525/525/525',
[90614] = '1/525/525/525',
[90612] = '1/525/525/525',
[90611] = '1/525/525/525',
[90610] = '1/525/525/525',
[90609] = '1/525/525/525',
[90608] = '1/525/525/525',
[90581] = '1/525/525/525',
[90558] = '1/525/525/525',
[90619] = '1/525/525/525',
[90618] = '1/525/525/525',
[90617] = '1/525/525/525',
[90647] = '1/1/1/1',
[90720] = '1/525/525/525',
[90622] = '1/525/525/525',
[90732] = '1/525/525/525',
[90730] = '1/525/525/525',
[90728] = '1/525/525/525',
[90734] = '1/525/525/525',
[90833] = '1/525/525/525',
[90832] = '1/525/525/525',
[90831] = '1/525/525/525',
[90843] = '1/525/525/525',
[90860] = '1/525/525/525',
[90853] = '1/525/525/525',
[90864] = '1/525/525/525',
[90861] = '1/525/525/525',
[90987] = '1/525/525/525',
[90984] = '1/525/525/525',
[90983] = '1/525/525/525',
[90975] = '1/525/525/525',
[90974] = '1/525/525/525',
[90968] = '1/525/525/525',
[91084] = '1/525/525/525',
[91014] = '1/525/525/525',
[91012] = '1/525/525/525',
[91008] = '1/525/525/525',
[90997] = '1/525/525/525',
[90988] = '1/525/525/525',
[91132] = '1/525/525/525',
[91089] = '1/525/525/525',
[91215] = '1/525/525/525',
[91214] = '1/525/525/525',
[91211] = '1/525/525/525',
[91209] = '1/525/525/525',
[91197] = '1/525/525/525',
[91191] = '1/525/525/525',
[91188] = '1/525/525/525',
[91170] = '1/525/525/525',
[91133] = '1/525/525/525',
[91225] = '1/525/525/525',
[91224] = '1/525/525/525',
[91223] = '1/525/525/525',
[91221] = '1/525/525/525',
[91219] = '1/525/525/525',
[91227] = '1/525/525/525',
[91226] = '1/525/525/525',
[91757] = '1/525/525/525',
[91761] = '1/525/525/525',
[91762] = '1/525/525/525',
[91766] = '1/525/525/525',
[91769] = '1/525/525/525',
[91773] = '1/525/525/525',
[91792] = '1/525/525/525',
[91790] = '1/525/525/525',
[91785] = '1/525/525/525',
[91782] = '1/525/525/525',
[91780] = '1/525/525/525',
[91779] = '1/525/525/525',
[91775] = '1/525/525/525',
[91793] = '1/525/525/525',
[92026] = '1/90/100/110',
[92027] = '1/475/487/500',
[92168] = '1/525/525/525',
[92163] = '1/525/525/525',
[92148] = '1/525/525/525',
[92145] = '1/525/525/525',
[92139] = '1/525/525/525',
[92137] = '1/525/525/525',
[92370] = '1/525/525/525',
[92375] = '1/480/485/490',
[76178] = '1/450/452/455',
[92579] = '1/185/190/195',
[92643] = '1/525/525/525',
[92688] = '1/525/525/525',
[93440] = '1/525/525/525',
[93441] = '1/525/525/525',
[93444] = '1/525/525/525',
[93443] = '1/525/525/525',
[93442] = '1/525/525/525',
[89895] = '1/525/525/525',
[93741] = '1/80/100/120',
[94000] = '1/390/397/405',
[73495] = '1/485/495/505',
[94162] = '1/505/510/515',
[73494] = '1/450/467/485',
[73496] = '1/450/467/485',
[73497] = '1/495/505/515',
[73520] = '1/525/525/525',
[73503] = '1/525/525/525',
[73502] = '1/525/525/525',
[73498] = '1/525/525/525',
[73521] = '1/525/525/525',
[73506] = '1/525/525/525',
[73505] = '1/525/525/525',
[73504] = '1/525/525/525',
[94406] = '1/255/260/265',
[94405] = '1/155/160/165',
[94404] = '1/155/160/165',
[94403] = '1/125/130/135',
[94402] = '1/335/340/345',
[94401] = '1/125/130/135',
[90464] = '1/525/525/525',
[93935] = '1/440/450/460',
[93328] = '1/525/530/535',
[93841] = '1/525/525/525',
[93843] = '1/525/525/525',
[94711] = '1/430/435/440',
[94718] = '1/525/525/525',
[94732] = '1/525/525/525',
[94743] = '1/525/530/535',
[84424] = '1/425/437/450',
[95215] = '1/155/160/165',
[95471] = '1/480/490/500',
[56984] = '1/330/335/340',
[95703] = '1/450/452/455',
[94748] = '1/455/460/465',
[82207] = '1/425/452/480',
[95710] = '1/155/160/165',
[95756] = '1/500/507/515',
[95755] = '1/500/507/515',
[95754] = '1/500/507/515',
[95825] = '1/390/397/405',
[95707] = '1/505/507/510',
[95705] = '1/505/505/505',
[96133] = '1/490/500/510',
[96253] = '1/510/512/515',
[96254] = '1/510/512/515',
[96252] = '1/510/512/515',
[96257] = '1/515/520/525',
[96256] = '1/515/520/525',
[96255] = '1/515/520/525',
[96264] = '1/525/532/540',
[96262] = '1/525/532/540',
[96261] = '1/525/532/540',
[96284] = '1/280/287/295',
[96226] = '1/500/507/515',
[98398] = '1/430/435/440',
[98921] = '1/525/525/525',
[99439] = '1/525/527/530',
[99440] = '1/525/527/530',
[99441] = '1/525/527/530',
[99452] = '1/525/527/530',
[99453] = '1/525/527/530',
[99454] = '1/525/527/530',
[99443] = '1/525/527/530',
[99445] = '1/525/527/530',
[99446] = '1/525/527/530',
[99447] = '1/525/527/530',
[99455] = '1/525/527/530',
[99456] = '1/525/527/530',
[99457] = '1/525/527/530',
[99458] = '1/525/527/530',
[99448] = '1/525/527/530',
[99449] = '1/525/527/530',
[99459] = '1/525/527/530',
[99460] = '1/525/527/530',
[99536] = '1/510/512/515',
[99535] = '1/510/512/515',
[99537] = '1/500/502/505',
[99549] = '1/520/525/530',
[99548] = '1/520/525/530',
[99547] = '1/520/525/530',
[99544] = '1/525/530/535',
[99543] = '1/525/530/535',
[99542] = '1/525/530/535',
[99541] = '1/515/520/525',
[99540] = '1/515/520/525',
[99539] = '1/515/520/525',
[100587] = '1/525/530/535',
[100586] = '1/520/527/535',
[98560] = '1/525/525/525',
[98582] = '1/525/525/525',
[98556] = '1/525/525/525',
[98588] = '1/525/525/525',
[98569] = '1/525/525/525',
[98533] = '1/525/525/525',
[99652] = '1/525/527/530',
[99653] = '1/525/527/530',
[99654] = '1/525/527/530',
[99655] = '1/525/527/530',
[99656] = '1/525/527/530',
[99657] = '1/525/527/530',
[99658] = '1/525/527/530',
[99660] = '1/525/527/530',
[100687] = '1/525/525/525',
[101057] = '1/430/435/440',
[100583] = '1/520/527/535',
[100585] = '1/490/492/495',
[101599] = '1/530/535/540',
[101600] = '1/460/465/470',
[101735] = '1/525/530/535',
[101740] = '1/525/530/535',
[101741] = '1/525/530/535',
[101742] = '1/525/530/535',
[101743] = '1/525/530/535',
[101744] = '1/525/530/535',
[101745] = '1/525/530/535',
[101746] = '1/525/530/535',
[101747] = '1/525/530/535',
[101748] = '1/525/530/535',
[101749] = '1/525/530/535',
[101750] = '1/525/530/535',
[101751] = '1/525/530/535',
[101752] = '1/525/530/535',
[101753] = '1/525/530/535',
[101754] = '1/525/530/535',
[101755] = '1/525/530/535',
[101756] = '1/525/530/535',
[101757] = '1/525/530/535',
[101758] = '1/525/530/535',
[101759] = '1/525/530/535',
[101760] = '1/525/530/535',
[101761] = '1/525/530/535',
[101762] = '1/525/530/535',
[101763] = '1/525/530/535',
[101764] = '1/525/530/535',
[101765] = '1/525/530/535',
[101766] = '1/525/530/535',
[101767] = '1/525/530/535',
[101768] = '1/525/530/535',
[101769] = '1/525/530/535',
[101770] = '1/525/530/535',
[101771] = '1/525/530/535',
[101772] = '1/525/530/535',
[101773] = '1/525/530/535',
[101774] = '1/525/530/535',
[101775] = '1/525/530/535',
[101776] = '1/525/530/535',
[101777] = '1/525/530/535',
[101778] = '1/525/530/535',
[101779] = '1/525/530/535',
[101780] = '1/525/530/535',
[101781] = '1/525/530/535',
[101782] = '1/525/530/535',
[101783] = '1/525/530/535',
[101784] = '1/525/530/535',
[101785] = '1/525/530/535',
[101786] = '1/525/530/535',
[101787] = '1/525/530/535',
[101788] = '1/525/530/535',
[101789] = '1/525/530/535',
[101790] = '1/525/530/535',
[101791] = '1/525/530/535',
[101792] = '1/525/530/535',
[101793] = '1/525/530/535',
[101794] = '1/525/530/535',
[101795] = '1/525/530/535',
[101796] = '1/525/530/535',
[101797] = '1/525/530/535',
[101798] = '1/525/530/535',
[101799] = '1/525/530/535',
[101800] = '1/525/530/535',
[101801] = '1/525/530/535',
[101802] = '1/525/530/535',
[101803] = '1/525/530/535',
[101804] = '1/525/530/535',
[101828] = '1/525/530/535',
[101827] = '1/525/530/535',
[101826] = '1/525/530/535',
[101825] = '1/525/530/535',
[101824] = '1/525/530/535',
[101823] = '1/525/530/535',
[101924] = '1/525/530/535',
[101925] = '1/525/530/535',
[101928] = '1/525/530/535',
[101929] = '1/525/530/535',
[101931] = '1/525/530/535',
[101932] = '1/525/530/535',
[101933] = '1/525/530/535',
[101934] = '1/525/530/535',
[101935] = '1/525/530/535',
[101936] = '1/525/530/535',
[101937] = '1/525/530/535',
[101939] = '1/525/530/535',
[101940] = '1/525/530/535',
[101941] = '1/525/530/535',
[101920] = '1/525/530/535',
[101921] = '1/525/530/535',
[101922] = '1/525/530/535',
[101923] = '1/525/530/535',
[102171] = '1/170/185/200',
[104698] = '1/525/530/535',
[105518] = '1/115/122/130',
[107907] = '1/105/110/115',
[351766] = '1/340/347/355',
[351768] = '1/345/352/360',
[351769] = '1/350/357/365',
[351770] = '1/370/377/385',
[351771] = '1/365/372/380',
[405005] = '1/390/397/405',
[413897] = '1/390/397/405',
[414814] = '1/390/397/405',
--@end-version-cata@]====]
}
Skillet.db.global.SkillLineAbility_retail = {
--@version-retail@
[2018] = '1/1/1/1',
[2108] = '1/1/1/1',
[2149] = '1/40/55/70',
[2153] = '30/45/60/75',
[2152] = '1/30/45/60',
[2158] = '45/120/135/150',
[2159] = '1/105/120/135',
[2160] = '50/70/85/100',
[2161] = '65/85/100/115',
[2162] = '65/90/105/120',
[2163] = '70/90/105/120',
[2164] = '70/105/120/135',
[2165] = '75/115/122/130',
[2166] = '125/145/157/170',
[2167] = '100/125/137/150',
[2168] = '1/135/147/160',
[2169] = '100/125/137/150',
[2259] = '1/1/1/1',
[2330] = '1/55/75/95',
[2329] = '1/55/75/95',
[2331] = '30/65/85/105',
[2332] = '1/70/90/110',
[2334] = '50/80/100/120',
[2335] = '1/90/110/130',
[2337] = '80/85/105/125',
[2366] = '1/1/1/1',
[2368] = '1/1/1/1',
[2383] = '1/1/1/1',
[2550] = '1/1/1/1',
[2538] = '1/45/65/85',
[2539] = '1/50/70/90',
[2540] = '1/45/65/85',
[2541] = '65/90/110/130',
[2542] = '65/90/110/130',
[2543] = '75/115/135/155',
[2544] = '75/115/135/155',
[2545] = '85/125/145/165',
[2546] = '110/120/140/160',
[2547] = '125/135/155/175',
[2548] = '135/130/150/170',
[2549] = '135/140/160/180',
[2580] = '1/1/1/1',
[2575] = '1/1/1/1',
[2576] = '1/1/1/1',
[2656] = '1/1/1/1',
[2658] = '1/100/105/110',
[2659] = '1/50/75/100',
[2660] = '1/15/35/55',
[2661] = '55/75/95/115',
[2662] = '1/50/70/90',
[2663] = '1/20/40/60',
[2664] = '65/115/127/140',
[2665] = '75/65/72/80',
[2666] = '1/110/130/150',
[2667] = '1/120/140/160',
[2668] = '1/145/160/175',
[2670] = '105/145/160/175',
[2672] = '120/150/165/180',
[2674] = '1/125/132/140',
[2675] = '135/175/190/205',
[2737] = '30/55/75/95',
[2740] = '75/140/155/170',
[2741] = '85/145/160/175',
[2738] = '35/60/80/100',
[2739] = '40/65/85/105',
[2742] = '1/150/165/180',
[2795] = '40/60/80/100',
[2881] = '1/20/30/40',
[3100] = '1/1/1/1',
[3101] = '1/1/1/1',
[3102] = '1/1/1/1',
[3104] = '1/1/1/1',
[3115] = '1/15/35/55',
[3117] = '1/125/132/140',
[3116] = '1/65/72/80',
[3171] = '1/120/140/160',
[3173] = '1/145/165/185',
[3174] = '1/145/165/185',
[3176] = '1/150/170/190',
[3177] = '1/155/175/195',
[2333] = '1/165/185/205',
[3188] = '1/175/195/215',
[3170] = '1/60/80/100',
[3230] = '1/80/100/120',
[3308] = '1/150/155/160',
[3307] = '1/100/125/150',
[3304] = '1/40/57/75',
[3292] = '1/135/155/175',
[3293] = '1/75/95/115',
[3294] = '1/110/130/150',
[3295] = '1/155/170/185',
[3296] = '1/160/175/190',
[3297] = '1/175/190/205',
[3319] = '1/60/80/100',
[3320] = '1/45/65/85',
[3321] = '1/75/95/115',
[3323] = '1/80/100/120',
[3324] = '1/85/105/125',
[3325] = '1/100/120/140',
[3326] = '1/75/87/100',
[3328] = '1/140/155/170',
[3330] = '1/155/170/185',
[3331] = '1/160/175/190',
[3333] = '1/165/180/195',
[3334] = '1/175/190/205',
[3336] = '1/180/195/210',
[3337] = '1/125/137/150',
[3370] = '1/120/140/160',
[3371] = '1/100/120/140',
[3372] = '1/130/150/170',
[3373] = '1/160/180/200',
[3376] = '1/170/190/210',
[3377] = '1/150/170/190',
[3397] = '1/150/170/190',
[3398] = '1/175/195/215',
[3399] = '1/190/210/230',
[3400] = '1/215/235/255',
[3413] = '1/1/1/1',
[3447] = '1/135/155/175',
[3448] = '1/185/205/225',
[3449] = '1/190/210/230',
[3450] = '1/195/215/235',
[3451] = '1/200/220/240',
[3452] = '1/180/200/220',
[3453] = '1/215/235/255',
[3454] = '1/220/240/260',
[3464] = '1/1/1/1',
[3491] = '1/135/150/165',
[3492] = '1/185/197/210',
[3493] = '1/200/212/225',
[3494] = '1/180/192/205',
[3495] = '1/195/207/220',
[3496] = '1/205/217/230',
[3497] = '1/225/237/250',
[3498] = '1/210/222/235',
[3500] = '1/225/237/250',
[3501] = '1/190/202/215',
[3502] = '1/195/207/220',
[3503] = '1/215/227/240',
[3504] = '1/185/197/210',
[3505] = '1/200/212/225',
[3506] = '1/180/192/205',
[3507] = '1/195/207/220',
[3508] = '1/205/217/230',
[3511] = '1/220/232/245',
[3513] = '1/210/222/235',
[3515] = '1/225/237/250',
[3538] = '1/1/1/1',
[3564] = '1/1/1/1',
[3569] = '1/125/130/135',
[3570] = '1/1/1/1',
[3811] = '1/1/1/1',
[3753] = '1/55/70/85',
[3756] = '1/85/100/115',
[3759] = '1/105/120/135',
[3760] = '1/170/180/190',
[3761] = '1/115/130/145',
[3762] = '1/125/137/150',
[3763] = '1/110/125/140',
[3764] = '1/170/182/195',
[3765] = '1/155/167/180',
[3766] = '1/150/162/175',
[3767] = '1/145/157/170',
[3768] = '1/155/167/180',
[3769] = '1/165/177/190',
[3770] = '1/160/172/185',
[3771] = '1/170/180/190',
[3772] = '1/175/185/195',
[3773] = '1/195/205/215',
[3774] = '1/180/190/200',
[3775] = '1/190/200/210',
[3776] = '1/200/210/220',
[3777] = '1/215/225/235',
[3778] = '1/205/215/225',
[3779] = '1/220/230/240',
[3816] = '1/55/65/75',
[3817] = '1/115/122/130',
[3818] = '1/160/165/170',
[3780] = '1/170/180/190',
[3908] = '1/1/1/1',
[3909] = '1/1/1/1',
[3910] = '1/1/1/1',
[2963] = '1/25/37/50',
[2387] = '1/35/47/60',
[2385] = '1/45/57/70',
[2389] = '1/65/82/100',
[2386] = '1/90/107/125',
[2392] = '1/65/82/100',
[2393] = '1/35/47/60',
[2394] = '1/65/82/100',
[2397] = '1/85/102/120',
[2395] = '1/95/112/130',
[2396] = '1/95/112/130',
[2964] = '1/90/97/105',
[2402] = '1/100/117/135',
[2399] = '1/110/127/145',
[2401] = '1/120/137/155',
[2403] = '1/130/147/165',
[2406] = '1/110/120/130',
[3839] = '1/135/140/145',
[3865] = '1/180/182/185',
[3840] = '1/60/77/95',
[3841] = '1/85/102/120',
[3842] = '1/95/112/130',
[3843] = '1/110/127/145',
[3844] = '1/125/142/160',
[3845] = '1/105/122/140',
[3847] = '1/120/137/155',
[3848] = '1/135/152/170',
[3849] = '1/145/162/180',
[3850] = '1/135/152/170',
[3851] = '1/150/167/185',
[3852] = '1/150/165/180',
[3854] = '1/165/180/195',
[3855] = '1/150/167/185',
[3856] = '1/160/175/190',
[3857] = '1/185/200/215',
[3858] = '1/190/205/220',
[3859] = '1/170/185/200',
[3860] = '1/195/210/225',
[3861] = '1/205/220/235',
[3862] = '1/220/235/250',
[3863] = '1/200/215/230',
[3864] = '1/220/235/250',
[3866] = '1/135/152/170',
[3868] = '1/150/167/185',
[3869] = '1/145/150/155',
[3870] = '1/165/170/175',
[3871] = '1/180/185/190',
[3872] = '1/195/200/205',
[3873] = '1/210/215/220',
[3914] = '1/55/72/90',
[3915] = '1/35/47/60',
[4036] = '1/1/1/1',
[4037] = '1/1/1/1',
[4038] = '1/1/1/1',
[3918] = '1/20/30/40',
[3919] = '1/30/45/60',
[3922] = '1/45/52/60',
[3923] = '1/60/75/90',
[3925] = '1/80/95/110',
[3977] = '1/90/105/120',
[3973] = '1/110/125/140',
[3928] = '1/105/120/135',
[3929] = '1/85/90/95',
[3931] = '1/95/100/105',
[3932] = '1/115/130/145',
[3933] = '1/130/145/160',
[3934] = '1/130/145/160',
[3936] = '1/130/142/155',
[3937] = '1/125/140/155',
[3938] = '1/115/135/155',
[3978] = '1/135/147/160',
[3939] = '1/145/157/170',
[3940] = '1/145/157/170',
[3941] = '1/120/145/170',
[3942] = '1/125/150/175',
[3944] = '1/125/150/175',
[3945] = '1/125/135/145',
[3946] = '1/125/135/145',
[3949] = '1/155/167/180',
[3950] = '1/140/165/190',
[3952] = '1/165/177/190',
[3953] = '1/145/170/195',
[3954] = '1/170/182/195',
[3955] = '1/175/187/200',
[3956] = '1/175/187/200',
[3957] = '1/175/185/195',
[3958] = '1/160/170/180',
[3959] = '1/180/190/200',
[3960] = '1/185/195/205',
[3961] = '1/170/190/210',
[3962] = '1/175/195/215',
[3963] = '1/175/195/215',
[3979] = '1/200/210/220',
[3965] = '1/185/205/225',
[3966] = '1/205/215/225',
[3967] = '1/190/210/230',
[3968] = '1/215/225/235',
[3969] = '1/220/230/240',
[3971] = '1/220/230/240',
[3972] = '1/200/220/240',
[4094] = '1/215/235/255',
[4097] = '1/185/195/205',
[4096] = '1/185/195/205',
[4508] = '1/80/100/120',
[4942] = '1/230/250/270',
[2657] = '1/20/40/60',
[5244] = '1/70/85/100',
[6412] = '1/50/70/90',
[6413] = '1/60/80/100',
[6414] = '1/75/95/115',
[6415] = '1/90/110/130',
[6416] = '1/90/110/130',
[6417] = '1/130/150/170',
[6418] = '1/140/160/180',
[6419] = '1/150/170/190',
[6458] = '1/160/172/185',
[6501] = '1/130/150/170',
[6500] = '1/165/185/205',
[6499] = '1/90/110/130',
[6518] = '1/170/185/200',
[6517] = '1/140/155/170',
[6521] = '1/115/132/150',
[2671] = '1/145/160/175',
[2673] = '1/160/175/190',
[3758] = '1/120/137/155',
[3755] = '1/70/87/105',
[3757] = '1/105/122/140',
[3813] = '1/170/185/200',
[6624] = '1/175/195/215',
[6618] = '1/195/215/235',
[6617] = '1/90/110/130',
[6661] = '1/210/220/230',
[6686] = '1/95/112/130',
[6688] = '1/140/157/175',
[6690] = '1/155/170/185',
[6692] = '1/170/185/200',
[6693] = '1/195/210/225',
[6695] = '1/205/220/235',
[6702] = '1/120/135/150',
[6705] = '1/210/220/230',
[6703] = '1/125/140/155',
[6704] = '1/190/200/210',
[7126] = '1/40/55/70',
[7133] = '1/130/142/155',
[7135] = '1/140/152/165',
[7147] = '1/180/190/200',
[7149] = '1/190/200/210',
[7151] = '1/195/205/215',
[7153] = '1/205/215/225',
[7156] = '1/210/220/230',
[7179] = '1/120/140/160',
[7181] = '1/175/195/215',
[7183] = '1/55/75/95',
[7213] = '1/215/235/255',
[7224] = '1/215/227/240',
[7223] = '1/210/222/235',
[7221] = '1/180/195/210',
[7222] = '1/190/202/215',
[7257] = '1/210/230/250',
[7258] = '1/205/225/245',
[7255] = '1/130/150/170',
[7259] = '1/210/230/250',
[7256] = '1/160/180/200',
[7408] = '1/105/125/145',
[7411] = '1/1/1/1',
[7412] = '1/1/1/1',
[7413] = '1/1/1/1',
[7418] = '1/70/90/110',
[7420] = '1/70/90/110',
[7421] = '1/5/7/10',
[7426] = '1/90/110/130',
[7428] = '1/80/100/120',
[7430] = '1/70/80/90',
[7443] = '1/80/100/120',
[7457] = '1/100/120/140',
[7623] = '1/55/72/90',
[7624] = '1/55/72/90',
[7630] = '1/80/97/115',
[7629] = '1/80/97/115',
[7633] = '1/95/112/130',
[7636] = '1/115/132/150',
[7639] = '1/125/142/160',
[7643] = '1/140/157/175',
[7738] = '1/1/1/1',
[7748] = '1/105/125/145',
[7751] = '1/45/65/85',
[7752] = '1/45/65/85',
[7753] = '1/90/110/130',
[7754] = '1/90/110/130',
[7755] = '1/140/160/180',
[7766] = '1/105/125/145',
[7771] = '1/110/130/150',
[7776] = '1/115/135/155',
[7779] = '1/115/135/155',
[7782] = '1/115/135/155',
[7786] = '1/120/140/160',
[7788] = '1/120/140/160',
[7745] = '1/130/150/170',
[7793] = '1/130/150/170',
[7817] = '1/125/140/155',
[7827] = '1/90/110/130',
[7828] = '1/190/210/230',
[7836] = '1/80/90/100',
[7837] = '1/150/160/170',
[7841] = '1/130/150/170',
[7845] = '1/165/185/205',
[7857] = '1/145/165/185',
[7859] = '1/145/165/185',
[7863] = '1/150/170/190',
[7867] = '1/150/170/190',
[7892] = '1/145/162/180',
[7893] = '1/145/162/180',
[7955] = '1/140/152/165',
[7953] = '1/120/135/150',
[7954] = '1/130/142/155',
[8238] = '1/125/145/165',
[8240] = '1/120/140/160',
[8243] = '1/185/205/225',
[8322] = '1/115/130/145',
[8334] = '1/125/125/125',
[8339] = '1/115/122/130',
[8366] = '1/110/130/150',
[8367] = '1/140/160/180',
[8368] = '1/170/185/200',
[8388] = '1/1/1/1',
[8465] = '1/65/82/100',
[8467] = '1/135/152/170',
[8489] = '1/185/190/195',
[8483] = '1/170/175/180',
[8604] = '1/45/65/85',
[8607] = '1/80/100/120',
[8768] = '1/150/152/155',
[8776] = '1/50/67/85',
[8758] = '1/160/175/190',
[8760] = '1/155/160/165',
[8762] = '1/170/175/180',
[8764] = '1/190/205/220',
[8766] = '1/195/210/225',
[8770] = '1/210/225/240',
[8772] = '1/195/210/225',
[8774] = '1/200/215/230',
[8778] = '1/160/175/190',
[8780] = '1/165/180/195',
[8782] = '1/170/185/200',
[8784] = '1/185/200/215',
[8786] = '1/195/210/225',
[8789] = '1/200/215/230',
[8791] = '1/205/215/225',
[8793] = '1/210/225/240',
[8795] = '1/210/225/240',
[8797] = '1/215/230/245',
[8799] = '1/215/225/235',
[8802] = '1/220/235/250',
[8804] = '1/225/240/255',
[8880] = '1/70/90/110',
[8895] = '1/245/255/265',
[9058] = '1/40/55/70',
[9059] = '1/40/55/70',
[9064] = '1/65/80/95',
[9065] = '1/100/115/130',
[9068] = '1/125/140/155',
[9070] = '1/125/137/150',
[9072] = '1/145/157/170',
[9074] = '1/145/157/170',
[9145] = '1/150/162/175',
[9146] = '1/160/172/185',
[9147] = '1/160/172/185',
[9148] = '1/165/177/190',
[9149] = '1/170/182/195',
[9195] = '1/185/195/205',
[9196] = '1/195/205/215',
[9197] = '1/195/205/215',
[9198] = '1/200/210/220',
[9201] = '1/205/215/225',
[9202] = '1/210/220/230',
[9206] = '1/215/225/235',
[9207] = '1/220/230/240',
[9208] = '1/220/230/240',
[9269] = '1/150/162/175',
[9271] = '1/150/160/170',
[9273] = '1/160/180/200',
[9513] = '1/100/120/140',
[9785] = '1/1/1/1',
[9811] = '1/185/197/210',
[9813] = '1/185/197/210',
[9814] = '1/200/212/225',
[9818] = '1/205/217/230',
[9820] = '1/210/222/235',
[9916] = '1/225/237/250',
[9918] = '1/200/205/210',
[9921] = '1/200/205/210',
[9920] = '1/200/205/210',
[9926] = '1/225/235/245',
[9928] = '1/225/235/245',
[9931] = '1/230/240/250',
[9933] = '1/230/240/250',
[9935] = '1/235/245/255',
[9937] = '1/235/245/255',
[9939] = '1/235/245/255',
[9942] = '1/240/250/260',
[9945] = '1/240/250/260',
[9950] = '1/240/250/260',
[9952] = '1/245/255/265',
[9954] = '1/245/255/265',
[9957] = '1/250/260/270',
[9959] = '1/250/260/270',
[9961] = '1/250/260/270',
[9964] = '1/255/265/275',
[9966] = '1/255/265/275',
[9968] = '1/255/265/275',
[9970] = '1/255/265/275',
[9972] = '1/260/270/280',
[9974] = '1/265/275/285',
[9979] = '1/265/275/285',
[9980] = '1/265/275/285',
[9983] = '1/70/90/110',
[9985] = '1/155/170/185',
[9986] = '1/160/175/190',
[9987] = '1/165/180/195',
[9993] = '1/235/247/260',
[9995] = '1/245/257/270',
[9997] = '1/250/262/275',
[10001] = '1/255/267/280',
[10003] = '1/260/272/285',
[10005] = '1/265/277/290',
[10007] = '1/270/282/295',
[10009] = '1/270/282/295',
[10011] = '1/275/287/300',
[10013] = '1/280/290/300',
[10015] = '1/285/292/300',
[10098] = '1/200/205/210',
[10097] = '1/150/175/200',
[10248] = '1/1/1/1',
[10482] = '1/200/200/200',
[10487] = '1/220/230/240',
[10490] = '1/220/230/240',
[10499] = '1/225/235/245',
[10507] = '1/225/235/245',
[10509] = '1/225/235/245',
[10511] = '1/230/240/250',
[10516] = '1/230/240/250',
[10518] = '1/230/240/250',
[10520] = '1/235/245/255',
[10525] = '1/240/250/260',
[10529] = '1/240/250/260',
[10531] = '1/240/250/260',
[10533] = '1/240/250/260',
[10542] = '1/245/255/265',
[10544] = '1/245/255/265',
[10546] = '1/245/255/265',
[10619] = '1/245/255/265',
[10621] = '1/245/255/265',
[10548] = '1/250/260/270',
[10550] = '1/250/260/270',
[10552] = '1/250/260/270',
[10630] = '1/250/260/270',
[10554] = '1/255/265/275',
[10556] = '1/255/265/275',
[10558] = '1/255/265/275',
[10560] = '1/260/270/280',
[10562] = '1/260/270/280',
[10564] = '1/260/270/280',
[10566] = '1/265/275/285',
[10568] = '1/265/275/285',
[10570] = '1/270/280/290',
[10572] = '1/270/280/290',
[10574] = '1/270/280/290',
[10632] = '1/270/280/290',
[10647] = '1/270/280/290',
[10650] = '1/275/285/295',
[10662] = '1/1/1/1',
[11449] = '1/205/225/245',
[11450] = '1/215/235/255',
[11451] = '1/220/240/260',
[11448] = '1/220/240/260',
[11452] = '1/225/245/265',
[11456] = '1/225/245/265',
[11457] = '1/230/250/270',
[11458] = '1/240/260/280',
[11459] = '1/240/260/280',
[11460] = '1/245/265/285',
[11461] = '1/250/270/290',
[11464] = '1/250/270/290',
[11465] = '1/250/270/290',
[11466] = '1/255/275/295',
[11467] = '1/255/275/295',
[11468] = '1/255/275/295',
[11472] = '1/260/280/300',
[11473] = '1/260/280/300',
[11476] = '1/265/282/300',
[11477] = '1/265/282/300',
[11478] = '1/265/282/300',
[11479] = '1/240/260/280',
[11480] = '1/240/260/280',
[11611] = '1/1/1/1',
[11643] = '1/225/235/245',
[11993] = '1/1/1/1',
[12044] = '1/35/47/60',
[12045] = '1/50/67/85',
[12046] = '1/100/117/135',
[12047] = '1/145/162/180',
[12048] = '1/220/235/250',
[12049] = '1/220/235/250',
[12050] = '1/225/240/255',
[12052] = '1/225/240/255',
[12053] = '1/230/245/260',
[12055] = '1/230/245/260',
[12056] = '1/230/245/260',
[12059] = '1/220/225/230',
[12060] = '1/230/245/260',
[12061] = '1/220/225/230',
[12062] = '1/235/250/265',
[12063] = '1/235/250/265',
[12064] = '1/225/230/235',
[12065] = '1/240/255/270',
[12066] = '1/240/255/270',
[12067] = '1/240/255/270',
[12068] = '1/240/255/270',
[12069] = '1/240/255/270',
[12070] = '1/240/255/270',
[12071] = '1/240/255/270',
[12072] = '1/245/260/275',
[12073] = '1/245/260/275',
[12074] = '1/245/260/275',
[12075] = '1/235/240/245',
[12076] = '1/250/265/280',
[12077] = '1/240/245/250',
[12078] = '1/250/265/280',
[12079] = '1/250/265/280',
[12080] = '1/240/245/250',
[12081] = '1/255/270/285',
[12082] = '1/255/270/285',
[12083] = '1/255/270/285',
[12084] = '1/255/270/285',
[12085] = '1/245/250/255',
[12086] = '1/260/275/290',
[12087] = '1/260/275/290',
[12088] = '1/260/275/290',
[12089] = '1/250/255/260',
[12090] = '1/265/280/295',
[12091] = '1/255/260/265',
[12092] = '1/265/280/295',
[12093] = '1/265/280/295',
[12180] = '1/1/1/1',
[12260] = '1/15/35/55',
[12259] = '1/180/192/205',
[12609] = '1/220/240/260',
[12584] = '1/150/170/190',
[12585] = '1/175/185/195',
[12586] = '1/175/185/195',
[12587] = '1/195/205/215',
[12590] = '1/175/195/215',
[12589] = '1/195/215/235',
[12591] = '1/200/220/240',
[12594] = '1/225/235/245',
[12595] = '1/225/235/245',
[12597] = '1/230/240/250',
[12599] = '1/215/235/255',
[12603] = '1/215/235/255',
[12607] = '1/240/250/260',
[12614] = '1/240/250/260',
[12615] = '1/245/255/265',
[12616] = '1/245/255/265',
[12617] = '1/250/260/270',
[12618] = '1/250/260/270',
[12619] = '1/235/255/275',
[12620] = '1/260/270/280',
[12622] = '1/265/275/285',
[12624] = '1/270/280/290',
[12656] = '1/1/1/1',
[12715] = '1/205/205/205',
[12716] = '1/225/235/245',
[12717] = '1/225/235/245',
[12718] = '1/225/235/245',
[12760] = '1/205/225/245',
[12755] = '1/230/250/270',
[12754] = '1/235/255/275',
[12759] = '1/260/270/280',
[12758] = '1/265/275/285',
[12895] = '1/195/195/195',
[12897] = '1/230/240/250',
[12899] = '1/225/235/245',
[12900] = '1/205/225/245',
[12902] = '1/230/240/250',
[12903] = '1/235/245/255',
[12905] = '1/245/255/265',
[12906] = '1/250/260/270',
[12907] = '1/255/265/275',
[12908] = '1/260/270/280',
[13240] = '1/1/1/1',
[13262] = '1/1/1/1',
[13378] = '1/130/150/170',
[13380] = '1/135/155/175',
[13419] = '1/135/155/175',
[13421] = '1/140/160/180',
[13464] = '1/140/160/180',
[11454] = '1/225/237/250',
[13485] = '1/155/175/195',
[13501] = '1/155/175/195',
[13503] = '1/165/185/205',
[13529] = '1/170/190/210',
[13536] = '1/165/185/205',
[13538] = '1/165/185/205',
[13607] = '1/170/190/210',
[13612] = '1/170/190/210',
[13617] = '1/170/190/210',
[13620] = '1/170/190/210',
[13622] = '1/175/195/215',
[13626] = '1/175/195/215',
[13631] = '1/175/195/215',
[13635] = '1/175/195/215',
[13637] = '1/180/200/220',
[13640] = '1/180/200/220',
[13642] = '1/185/205/225',
[13644] = '1/190/210/230',
[13646] = '1/190/210/230',
[13648] = '1/190/210/230',
[13653] = '1/195/215/235',
[13655] = '1/195/215/235',
[13659] = '1/200/220/240',
[13661] = '1/200/220/240',
[13663] = '1/205/225/245',
[13687] = '1/210/230/250',
[13689] = '1/215/235/255',
[13693] = '1/215/235/255',
[13695] = '1/220/240/260',
[13698] = '1/220/240/260',
[13700] = '1/220/240/260',
[13920] = '1/1/1/1',
[13746] = '1/225/245/265',
[13815] = '1/230/250/270',
[13817] = '1/230/250/270',
[13822] = '1/230/250/270',
[13836] = '1/235/255/275',
[13841] = '1/235/255/275',
[13846] = '1/240/260/280',
[13858] = '1/240/260/280',
[13868] = '1/245/265/285',
[13882] = '1/245/265/285',
[13887] = '1/245/265/285',
[13890] = '1/245/265/285',
[13898] = '1/285/292/300',
[13905] = '1/250/270/290',
[13915] = '1/250/270/290',
[13917] = '1/250/270/290',
[13931] = '1/255/275/295',
[13935] = '1/255/275/295',
[13937] = '1/260/280/300',
[13939] = '1/260/280/300',
[13941] = '1/265/282/300',
[13943] = '1/265/282/300',
[13945] = '1/265/282/300',
[13947] = '1/270/285/300',
[13948] = '1/270/285/300',
[14293] = '1/75/95/115',
[14807] = '1/110/130/150',
[14809] = '1/175/195/215',
[14810] = '1/195/215/235',
[14891] = '1/300/305/310',
[15255] = '1/200/220/240',
[15296] = '1/300/300/300',
[15293] = '1/290/295/300',
[15292] = '1/285/292/300',
[15294] = '1/295/297/300',
[15295] = '1/300/300/300',
[15596] = '1/285/292/300',
[15633] = '1/205/205/205',
[15628] = '1/205/205/205',
[15833] = '1/245/265/285',
[15935] = '1/45/65/85',
[15853] = '1/165/185/205',
[15855] = '1/215/235/255',
[15856] = '1/215/235/255',
[15861] = '1/215/235/255',
[15863] = '1/215/235/255',
[15865] = '1/215/235/255',
[15906] = '1/225/237/250',
[15910] = '1/225/237/250',
[15915] = '1/250/262/275',
[15933] = '1/250/262/275',
[15972] = '1/205/217/230',
[15973] = '1/215/227/240',
[818] = '1/1/1/1',
[16153] = '1/200/245/290',
[16641] = '1/255/257/260',
[16640] = '1/255/257/260',
[16639] = '1/255/257/260',
[16642] = '1/270/280/290',
[16643] = '1/270/280/290',
[16644] = '1/275/285/295',
[16645] = '1/280/290/300',
[16646] = '1/285/292/300',
[16647] = '1/285/292/300',
[16648] = '1/290/295/300',
[16649] = '1/290/295/300',
[16650] = '1/290/295/300',
[16651] = '1/295/297/300',
[16652] = '1/300/300/300',
[16653] = '1/300/300/300',
[16654] = '1/300/300/300',
[16667] = '1/300/300/300',
[16656] = '1/300/300/300',
[16660] = '1/300/300/300',
[16655] = '1/300/300/300',
[16657] = '1/300/300/300',
[16658] = '1/300/300/300',
[16659] = '1/300/300/300',
[16662] = '1/300/300/300',
[16663] = '1/300/300/300',
[16664] = '1/300/300/300',
[16665] = '1/300/300/300',
[16724] = '1/300/300/300',
[16725] = '1/300/300/300',
[16726] = '1/300/300/300',
[16730] = '1/300/300/300',
[16728] = '1/300/300/300',
[16729] = '1/300/300/300',
[16731] = '1/300/300/300',
[16732] = '1/300/300/300',
[16741] = '1/300/300/300',
[16742] = '1/300/300/300',
[16744] = '1/300/300/300',
[16745] = '1/300/300/300',
[16746] = '1/300/300/300',
[16960] = '1/285/292/300',
[16965] = '1/295/297/300',
[16967] = '1/295/297/300',
[16969] = '1/300/300/300',
[16970] = '1/300/300/300',
[16971] = '1/300/300/300',
[16973] = '1/300/300/300',
[16978] = '1/300/300/300',
[16980] = '1/300/300/300',
[16983] = '1/300/300/300',
[16984] = '1/300/300/300',
[16985] = '1/300/300/300',
[16986] = '1/300/300/300',
[16987] = '1/300/300/300',
[16988] = '1/300/300/300',
[16990] = '1/300/300/300',
[16991] = '1/300/300/300',
[16992] = '1/300/300/300',
[16993] = '1/300/300/300',
[16994] = '1/300/300/300',
[16995] = '1/300/300/300',
[16661] = '1/300/300/300',
[17181] = '1/250/255/260',
[17180] = '1/250/255/260',
[17187] = '1/275/282/290',
[17551] = '1/250/255/260',
[17552] = '1/270/285/300',
[17553] = '1/275/287/300',
[17554] = '1/280/290/300',
[17555] = '1/285/292/300',
[17556] = '1/290/295/300',
[17557] = '1/290/295/300',
[17559] = '1/275/282/290',
[17561] = '1/275/282/290',
[17566] = '1/275/282/290',
[17560] = '1/275/282/290',
[17563] = '1/275/282/290',
[17562] = '1/275/282/290',
[17564] = '1/275/282/290',
[17565] = '1/275/282/290',
[17570] = '1/295/297/300',
[17571] = '1/295/297/300',
[17572] = '1/300/300/300',
[17573] = '1/300/300/300',
[17574] = '1/300/300/300',
[17575] = '1/300/300/300',
[17576] = '1/300/300/300',
[17577] = '1/300/300/300',
[17578] = '1/300/300/300',
[17579] = '1/300/300/300',
[17580] = '1/300/300/300',
[17632] = '1/1/25/50',
[17634] = '1/300/300/300',
[17635] = '1/300/300/300',
[17636] = '1/300/300/300',
[17637] = '1/300/300/300',
[18239] = '1/250/262/275',
[18238] = '1/250/262/275',
[18241] = '1/250/262/275',
[18240] = '1/265/277/290',
[18242] = '1/265/277/290',
[18243] = '1/275/285/295',
[18244] = '1/275/285/295',
[18245] = '1/300/300/300',
[18246] = '1/300/300/300',
[18247] = '1/300/300/300',
[18260] = '1/1/1/1',
[18401] = '1/255/257/260',
[18402] = '1/270/285/300',
[18403] = '1/270/285/300',
[18404] = '1/270/285/300',
[18406] = '1/275/287/300',
[18405] = '1/275/287/300',
[18407] = '1/275/287/300',
[18408] = '1/275/287/300',
[18409] = '1/280/290/300',
[18410] = '1/280/290/300',
[18411] = '1/280/290/300',
[18412] = '1/285/292/300',
[18415] = '1/285/292/300',
[18413] = '1/285/292/300',
[18414] = '1/285/292/300',
[18416] = '1/290/295/300',
[18417] = '1/290/295/300',
[18418] = '1/290/295/300',
[18419] = '1/290/295/300',
[18420] = '1/290/295/300',
[18421] = '1/290/295/300',
[18422] = '1/290/295/300',
[18423] = '1/295/297/300',
[18424] = '1/295/297/300',
[18434] = '1/295/297/300',
[18436] = '1/300/300/300',
[18437] = '1/300/300/300',
[18438] = '1/300/300/300',
[18439] = '1/300/300/300',
[18440] = '1/300/300/300',
[18441] = '1/300/300/300',
[18442] = '1/300/300/300',
[18444] = '1/300/300/300',
[18445] = '1/300/300/300',
[18446] = '1/300/300/300',
[18447] = '1/300/300/300',
[18448] = '1/300/300/300',
[18449] = '1/300/300/300',
[18450] = '1/300/300/300',
[18451] = '1/300/300/300',
[18452] = '1/300/300/300',
[18453] = '1/300/300/300',
[18454] = '1/300/300/300',
[18455] = '1/300/300/300',
[18456] = '1/300/300/300',
[18457] = '1/300/300/300',
[18458] = '1/300/300/300',
[18560] = '1/290/295/300',
[19047] = '1/250/255/260',
[19058] = '1/255/265/275',
[19048] = '1/275/285/295',
[19049] = '1/280/290/300',
[19050] = '1/280/290/300',
[19051] = '1/285/295/305',
[19052] = '1/285/295/305',
[19053] = '1/285/295/305',
[19054] = '1/320/330/340',
[19055] = '1/290/300/310',
[19059] = '1/290/300/310',
[19060] = '1/290/300/310',
[19061] = '1/290/300/310',
[19062] = '1/290/300/310',
[19063] = '1/295/305/315',
[19064] = '1/295/305/315',
[19065] = '1/295/305/315',
[19066] = '1/295/305/315',
[19067] = '1/295/305/315',
[19068] = '1/295/305/315',
[19070] = '1/300/310/320',
[19071] = '1/300/310/320',
[19072] = '1/300/310/320',
[19073] = '1/300/310/320',
[19074] = '1/305/315/325',
[19075] = '1/305/315/325',
[19076] = '1/305/315/325',
[19077] = '1/305/315/325',
[19078] = '1/305/315/325',
[19079] = '1/305/315/325',
[19080] = '1/305/315/325',
[19081] = '1/310/320/330',
[19085] = '1/310/320/330',
[19084] = '1/310/320/330',
[19086] = '1/310/320/330',
[19082] = '1/310/320/330',
[19083] = '1/310/320/330',
[19089] = '1/315/325/335',
[19087] = '1/315/325/335',
[19088] = '1/315/325/335',
[19090] = '1/315/325/335',
[19094] = '1/320/330/340',
[19097] = '1/320/330/340',
[19095] = '1/320/330/340',
[19093] = '1/320/330/340',
[19091] = '1/320/330/340',
[19092] = '1/320/330/340',
[19100] = '1/320/330/340',
[19102] = '1/320/330/340',
[19101] = '1/320/330/340',
[19098] = '1/320/330/340',
[19107] = '1/320/330/340',
[19104] = '1/320/330/340',
[19106] = '1/320/330/340',
[19103] = '1/320/330/340',
[19435] = '1/295/297/300',
[19666] = '1/100/110/120',
[19667] = '1/150/160/170',
[19668] = '1/200/210/220',
[19669] = '1/275/280/285',
[19788] = '1/250/255/260',
[19790] = '1/280/290/300',
[19792] = '1/280/290/300',
[19791] = '1/280/290/300',
[19793] = '1/285/292/300',
[19794] = '1/290/295/300',
[19796] = '1/295/297/300',
[19814] = '1/295/297/300',
[19795] = '1/295/297/300',
[19815] = '1/300/300/300',
[19799] = '1/300/300/300',
[19819] = '1/300/300/300',
[19831] = '1/300/300/300',
[19830] = '1/300/300/300',
[19825] = '1/300/300/300',
[19833] = '1/300/300/300',
[3175] = '1/275/287/300',
[20008] = '1/275/287/300',
[20020] = '1/280/290/300',
[20017] = '1/285/292/300',
[20009] = '1/290/295/300',
[20012] = '1/290/295/300',
[20024] = '1/295/297/300',
[20026] = '1/295/297/300',
[20016] = '1/300/300/300',
[20029] = '1/300/300/300',
[20015] = '1/300/300/300',
[20028] = '1/300/300/300',
[20013] = '1/300/300/300',
[20023] = '1/300/300/300',
[20010] = '1/300/300/300',
[20030] = '1/300/300/300',
[20033] = '1/300/300/300',
[20036] = '1/300/300/300',
[20031] = '1/300/300/300',
[20011] = '1/300/300/300',
[20034] = '1/300/300/300',
[20025] = '1/300/300/300',
[20032] = '1/300/300/300',
[20035] = '1/300/300/300',
[20222] = '1/1/1/1',
[20219] = '1/1/1/1',
[20626] = '1/250/262/275',
[20648] = '1/100/105/110',
[20649] = '1/150/155/160',
[20650] = '1/200/202/205',
[20848] = '1/300/300/300',
[20849] = '1/300/300/300',
[20853] = '1/315/325/335',
[20854] = '1/320/330/340',
[20855] = '1/320/330/340',
[20874] = '1/300/300/300',
[20872] = '1/300/300/300',
[20876] = '1/300/300/300',
[20873] = '1/300/300/300',
[20897] = '1/300/300/300',
[20890] = '1/300/300/300',
[20916] = '1/215/235/255',
[21144] = '1/75/95/115',
[21143] = '1/45/65/85',
[21161] = '1/300/300/300',
[21175] = '1/225/237/250',
[21913] = '1/215/227/240',
[21923] = '1/210/230/250',
[21931] = '1/210/230/250',
[21940] = '1/190/210/230',
[21943] = '1/210/220/230',
[21945] = '1/200/205/210',
[22331] = '1/250/250/250',
[22480] = '1/250/262/275',
[22704] = '1/300/300/300',
[22711] = '1/210/220/230',
[22727] = '1/320/330/340',
[22732] = '1/300/300/300',
[22749] = '1/300/300/300',
[22750] = '1/300/300/300',
[22757] = '1/300/300/300',
[22759] = '1/300/300/300',
[22761] = '1/300/300/300',
[22793] = '1/300/300/300',
[22795] = '1/300/300/300',
[22797] = '1/300/300/300',
[22808] = '1/230/250/270',
[22813] = '1/285/290/295',
[22815] = '1/285/290/295',
[22866] = '1/300/300/300',
[22867] = '1/300/300/300',
[22868] = '1/300/300/300',
[22869] = '1/300/300/300',
[22870] = '1/300/300/300',
[22902] = '1/300/300/300',
[22921] = '1/320/330/340',
[22922] = '1/320/330/340',
[22923] = '1/320/330/340',
[22926] = '1/320/330/340',
[22927] = '1/320/330/340',
[22928] = '1/320/330/340',
[23066] = '1/150/162/175',
[23068] = '1/150/162/175',
[23067] = '1/150/162/175',
[23069] = '1/200/210/220',
[23070] = '1/250/260/270',
[23071] = '1/270/275/280',
[23077] = '1/280/290/300',
[23078] = '1/285/292/300',
[23079] = '1/285/290/295',
[23080] = '1/275/285/295',
[23081] = '1/300/300/300',
[23082] = '1/300/300/300',
[23096] = '1/275/280/285',
[23129] = '1/260/265/270',
[23190] = '1/150/155/160',
[23399] = '1/175/185/195',
[23489] = '1/285/292/300',
[23486] = '1/285/292/300',
[23507] = '1/250/260/270',
[23628] = '1/300/300/300',
[23629] = '1/300/300/300',
[23632] = '1/300/300/300',
[23633] = '1/300/300/300',
[23636] = '1/300/300/300',
[23637] = '1/300/300/300',
[23638] = '1/300/300/300',
[23639] = '1/300/300/300',
[23650] = '1/300/300/300',
[23652] = '1/300/300/300',
[23653] = '1/300/300/300',
[23662] = '1/300/300/300',
[23664] = '1/300/300/300',
[23663] = '1/300/300/300',
[23665] = '1/300/300/300',
[23666] = '1/300/300/300',
[23667] = '1/300/300/300',
[23703] = '1/310/320/330',
[23705] = '1/310/320/330',
[23704] = '1/320/330/340',
[23706] = '1/320/330/340',
[23707] = '1/320/330/340',
[23708] = '1/320/330/340',
[23709] = '1/320/330/340',
[23710] = '1/320/330/340',
[23799] = '1/300/300/300',
[23800] = '1/300/300/300',
[23801] = '1/300/300/300',
[23802] = '1/300/300/300',
[23803] = '1/300/300/300',
[23804] = '1/300/300/300',
[24093] = '1/300/300/300',
[24092] = '1/300/300/300',
[24091] = '1/300/300/300',
[24124] = '1/320/330/340',
[24125] = '1/320/330/340',
[24123] = '1/320/330/340',
[24122] = '1/320/330/340',
[24121] = '1/320/330/340',
[24136] = '1/300/300/300',
[24138] = '1/300/300/300',
[24137] = '1/300/300/300',
[24139] = '1/300/300/300',
[24140] = '1/300/300/300',
[24141] = '1/300/300/300',
[24266] = '1/300/300/300',
[24356] = '1/300/300/300',
[24357] = '1/300/300/300',
[24365] = '1/290/295/300',
[24366] = '1/290/295/300',
[24367] = '1/300/300/300',
[24368] = '1/300/300/300',
[24399] = '1/300/300/300',
[24418] = '1/160/180/200',
[24655] = '1/300/310/320',
[24654] = '1/320/330/340',
[24801] = '1/300/300/300',
[24846] = '1/320/330/340',
[24847] = '1/320/330/340',
[24848] = '1/320/330/340',
[24849] = '1/320/330/340',
[24850] = '1/320/330/340',
[24851] = '1/320/330/340',
[24902] = '1/300/300/300',
[24903] = '1/300/300/300',
[24901] = '1/300/300/300',
[24914] = '1/300/300/300',
[24912] = '1/300/300/300',
[24913] = '1/300/300/300',
[24940] = '1/125/137/150',
[24703] = '1/320/330/340',
[25072] = '1/1/25/50',
[25073] = '1/300/300/300',
[25074] = '1/300/300/300',
[25078] = '1/300/300/300',
[25079] = '1/300/300/300',
[25080] = '1/1/25/50',
[25083] = '1/1/25/50',
[25084] = '1/1/25/50',
[25086] = '1/1/25/50',
[25124] = '1/55/65/75',
[25125] = '1/160/170/180',
[25126] = '1/210/220/230',
[25127] = '1/260/270/280',
[25128] = '1/285/292/300',
[25129] = '1/300/300/300',
[25130] = '1/300/300/300',
[25146] = '1/300/300/300',
[25229] = '1/1/1/1',
[25230] = '1/1/1/1',
[25278] = '1/70/80/90',
[25255] = '1/20/35/50',
[25280] = '1/80/95/110',
[25283] = '1/60/75/90',
[25284] = '1/90/105/120',
[25287] = '1/100/115/130',
[25305] = '1/120/135/150',
[25317] = '1/110/125/140',
[25318] = '1/130/145/160',
[25339] = '1/140/155/170',
[25320] = '1/180/195/210',
[25321] = '1/150/165/180',
[25323] = '1/155/170/185',
[25493] = '1/30/45/60',
[25490] = '1/80/95/110',
[25498] = '1/140/155/170',
[25610] = '1/150/165/180',
[25612] = '1/155/170/185',
[25613] = '1/165/180/195',
[25614] = '1/175/190/205',
[25615] = '1/170/180/190',
[25617] = '1/180/195/210',
[25618] = '1/190/205/220',
[25619] = '1/200/215/230',
[25620] = '1/200/215/230',
[25621] = '1/210/225/240',
[25622] = '1/220/235/250',
[25659] = '1/300/300/300',
[25704] = '1/120/140/160',
[25954] = '1/215/235/255',
[26011] = '1/300/300/300',
[26085] = '1/275/287/300',
[26086] = '1/300/300/300',
[26087] = '1/300/300/300',
[26279] = '1/320/330/340',
[26277] = '1/265/282/300',
[26403] = '1/265/280/295',
[26407] = '1/265/280/295',
[26416] = '1/125/137/150',
[26417] = '1/125/137/150',
[26418] = '1/125/137/150',
[26420] = '1/175/187/200',
[26421] = '1/175/187/200',
[26422] = '1/175/187/200',
[26423] = '1/225/237/250',
[26424] = '1/225/237/250',
[26425] = '1/225/237/250',
[26426] = '1/275/280/285',
[26427] = '1/275/280/285',
[26428] = '1/275/280/285',
[26442] = '1/245/255/265',
[26443] = '1/295/297/300',
[26745] = '1/5/15/25',
[26746] = '1/20/30/40',
[26747] = '1/30/35/40',
[26749] = '1/40/45/50',
[26750] = '1/45/50/55',
[26751] = '1/50/55/60',
[26752] = '1/65/70/75',
[26753] = '1/75/75/75',
[26754] = '1/75/75/75',
[26755] = '1/75/75/75',
[26756] = '1/65/70/75',
[26757] = '1/75/75/75',
[26758] = '1/75/75/75',
[26759] = '1/75/75/75',
[26760] = '1/65/70/75',
[26761] = '1/75/75/75',
[26762] = '1/75/75/75',
[26763] = '1/75/75/75',
[26764] = '1/20/25/30',
[26765] = '1/20/25/30',
[26770] = '1/30/35/40',
[26771] = '1/35/40/45',
[26772] = '1/45/50/55',
[26773] = '1/50/55/60',
[26774] = '1/55/60/65',
[26775] = '1/50/55/60',
[26776] = '1/60/65/70',
[26777] = '1/70/72/75',
[26778] = '1/70/72/75',
[26779] = '1/65/70/75',
[26780] = '1/75/75/75',
[26781] = '1/75/75/75',
[26782] = '1/60/65/70',
[26783] = '1/70/72/75',
[26784] = '1/75/75/75',
[26872] = '1/225/240/255',
[26873] = '1/225/240/255',
[26874] = '1/235/250/265',
[26875] = '1/240/255/270',
[26876] = '1/245/260/275',
[26878] = '1/250/265/280',
[26880] = '1/235/245/255',
[26881] = '1/250/265/280',
[26882] = '1/260/275/290',
[26883] = '1/260/275/290',
[26885] = '1/265/280/295',
[26887] = '1/270/285/300',
[26896] = '1/275/287/300',
[26897] = '1/275/287/300',
[26900] = '1/280/290/300',
[26902] = '1/280/290/300',
[26903] = '1/285/292/300',
[26906] = '1/285/292/300',
[26907] = '1/290/295/300',
[26908] = '1/290/295/300',
[26909] = '1/295/297/300',
[26910] = '1/295/297/300',
[26911] = '1/300/300/300',
[26912] = '1/300/300/300',
[26914] = '1/300/300/300',
[26915] = '1/15/25/35',
[26916] = '1/20/30/40',
[26918] = '1/25/35/45',
[26920] = '1/35/45/55',
[26925] = '1/30/45/60',
[26926] = '1/35/50/65',
[26927] = '1/80/95/110',
[26928] = '1/60/75/90',
[26790] = '1/1/1/1',
[27585] = '1/300/300/300',
[27588] = '1/300/300/300',
[27586] = '1/300/300/300',
[27589] = '1/300/300/300',
[27590] = '1/300/300/300',
[27587] = '1/300/300/300',
[27658] = '1/240/255/270',
[27659] = '1/290/295/300',
[27660] = '1/15/30/45',
[27724] = '1/290/295/300',
[27725] = '1/15/30/45',
[27830] = '1/300/300/300',
[27829] = '1/300/300/300',
[27832] = '1/300/300/300',
[27837] = '1/300/300/300',
[28029] = '1/1/1/1',
[27899] = '1/15/30/45',
[27905] = '1/25/40/55',
[27906] = '1/30/45/60',
[27911] = '1/35/50/65',
[27913] = '1/45/55/65',
[27914] = '1/70/72/75',
[27917] = '1/70/72/75',
[27944] = '1/20/35/50',
[27945] = '1/35/50/65',
[27946] = '1/50/62/75',
[27948] = '1/15/30/45',
[27950] = '1/30/45/60',
[27951] = '1/50/62/75',
[27954] = '1/75/75/75',
[27957] = '1/25/40/55',
[27958] = '1/1/5/10',
[27960] = '1/55/65/75',
[27961] = '1/20/35/50',
[27967] = '1/50/62/75',
[27968] = '1/50/62/75',
[27972] = '1/70/72/75',
[27971] = '1/70/72/75',
[27975] = '1/70/72/75',
[27977] = '1/70/72/75',
[28004] = '1/70/72/75',
[28003] = '1/70/72/75',
[27984] = '1/75/75/75',
[27981] = '1/75/75/75',
[27982] = '1/75/75/75',
[28016] = '1/10/20/30',
[28019] = '1/40/50/60',
[28021] = '1/35/45/55',
[28022] = '1/1/3/5',
[28210] = '1/300/300/300',
[28208] = '1/320/330/340',
[28205] = '1/320/330/340',
[28207] = '1/320/330/340',
[28209] = '1/320/330/340',
[28224] = '1/320/330/340',
[28222] = '1/320/330/340',
[28223] = '1/320/330/340',
[28221] = '1/320/330/340',
[28220] = '1/320/330/340',
[28219] = '1/320/330/340',
[28244] = '1/320/330/340',
[28242] = '1/320/330/340',
[28243] = '1/320/330/340',
[28267] = '1/100/120/140',
[28327] = '1/275/280/285',
[28461] = '1/300/300/300',
[28462] = '1/300/300/300',
[28463] = '1/300/300/300',
[28474] = '1/320/330/340',
[28473] = '1/320/330/340',
[28472] = '1/320/330/340',
[28481] = '1/300/300/300',
[28482] = '1/300/300/300',
[28480] = '1/300/300/300',
[28596] = '1/1/1/1',
[28543] = '1/20/27/35',
[28544] = '1/20/27/35',
[28545] = '1/25/32/40',
[28546] = '1/30/37/45',
[28549] = '1/35/42/50',
[28550] = '1/35/42/50',
[28552] = '1/40/47/55',
[28551] = '1/40/47/55',
[28553] = '1/45/52/60',
[28554] = '1/50/57/65',
[28555] = '1/55/62/70',
[28556] = '1/60/67/75',
[28557] = '1/60/67/75',
[28558] = '1/65/70/75',
[28562] = '1/65/70/75',
[28563] = '1/65/70/75',
[28564] = '1/65/70/75',
[28565] = '1/65/70/75',
[28566] = '1/65/70/75',
[28567] = '1/65/70/75',
[28568] = '1/65/70/75',
[28569] = '1/65/70/75',
[28570] = '1/70/72/75',
[28575] = '1/75/75/75',
[28571] = '1/75/75/75',
[28572] = '1/75/75/75',
[28577] = '1/75/75/75',
[28573] = '1/75/75/75',
[28576] = '1/75/75/75',
[28578] = '1/75/75/75',
[28579] = '1/75/75/75',
[28585] = '1/75/75/75',
[28583] = '1/75/75/75',
[28584] = '1/75/75/75',
[28582] = '1/75/75/75',
[28580] = '1/75/75/75',
[28581] = '1/75/75/75',
[28586] = '1/75/75/75',
[28590] = '1/75/75/75',
[28587] = '1/75/75/75',
[28588] = '1/75/75/75',
[28589] = '1/75/75/75',
[28591] = '1/75/75/75',
[28677] = '1/1/1/1',
[28675] = '1/1/1/1',
[28672] = '1/1/1/1',
[28695] = '1/1/1/1',
[28894] = '1/1/1/1',
[28895] = '1/1/1/1',
[28897] = '1/1/1/1',
[28903] = '1/1/13/25',
[28905] = '1/5/25/45',
[28910] = '1/1/20/40',
[28912] = '1/5/25/45',
[28914] = '1/15/35/55',
[28915] = '1/25/40/55',
[28916] = '1/1/20/40',
[28917] = '1/5/25/45',
[28918] = '1/15/35/55',
[28925] = '1/1/13/25',
[28927] = '1/5/25/45',
[28933] = '1/15/35/55',
[28936] = '1/25/40/55',
[28944] = '1/5/25/45',
[28947] = '1/15/35/55',
[28948] = '1/25/40/55',
[28950] = '1/1/20/40',
[28953] = '1/5/25/45',
[28955] = '1/15/35/55',
[29354] = '1/1/1/1',
[29356] = '1/1/13/25',
[29358] = '1/25/32/40',
[29359] = '1/50/57/65',
[29360] = '1/40/57/75',
[29361] = '1/75/75/75',
[29686] = '1/75/75/75',
[29688] = '1/65/70/75',
[29545] = '1/10/20/30',
[29547] = '1/15/25/35',
[29548] = '1/25/35/45',
[29549] = '1/25/35/45',
[29550] = '1/35/45/55',
[29551] = '1/10/20/30',
[29552] = '1/20/30/40',
[29553] = '1/25/35/45',
[29556] = '1/30/40/50',
[29557] = '1/20/30/40',
[29558] = '1/25/35/45',
[29565] = '1/30/40/50',
[29566] = '1/35/45/55',
[29568] = '1/40/50/60',
[29569] = '1/40/50/60',
[29571] = '1/45/55/65',
[29603] = '1/45/55/65',
[29605] = '1/45/55/65',
[29606] = '1/50/60/70',
[29608] = '1/65/67/70',
[29611] = '1/65/67/70',
[29610] = '1/70/72/75',
[29613] = '1/70/72/75',
[29614] = '1/60/65/70',
[29615] = '1/65/67/70',
[29616] = '1/70/72/75',
[29617] = '1/70/72/75',
[29619] = '1/70/72/75',
[29620] = '1/70/72/75',
[29621] = '1/70/72/75',
[29628] = '1/70/72/75',
[29629] = '1/70/72/75',
[29630] = '1/70/72/75',
[29642] = '1/70/72/75',
[29643] = '1/70/72/75',
[29645] = '1/70/72/75',
[29648] = '1/70/72/75',
[29649] = '1/70/72/75',
[29654] = '1/1/5/10',
[29656] = '1/50/55/60',
[29657] = '1/70/72/75',
[29658] = '1/70/72/75',
[29622] = '1/70/72/75',
[29662] = '1/70/72/75',
[29663] = '1/70/72/75',
[29664] = '1/70/72/75',
[29668] = '1/70/72/75',
[29669] = '1/70/72/75',
[29671] = '1/70/72/75',
[29672] = '1/70/72/75',
[29692] = '1/70/72/75',
[29693] = '1/70/72/75',
[29694] = '1/70/72/75',
[29695] = '1/70/72/75',
[29696] = '1/70/72/75',
[29697] = '1/70/72/75',
[29698] = '1/70/72/75',
[29699] = '1/70/72/75',
[29700] = '1/70/72/75',
[29728] = '1/40/45/50',
[29729] = '1/70/72/75',
[29844] = '1/1/1/1',
[30350] = '1/1/1/1',
[30310] = '1/20/30/40',
[30311] = '1/35/45/55',
[30312] = '1/30/40/50',
[30313] = '1/60/65/70',
[30314] = '1/70/72/75',
[30315] = '1/75/75/75',
[30316] = '1/50/60/70',
[30317] = '1/50/60/70',
[30318] = '1/60/65/70',
[30325] = '1/70/72/75',
[30329] = '1/45/55/65',
[30332] = '1/70/72/75',
[30334] = '1/75/75/75',
[30337] = '1/35/45/55',
[30341] = '1/35/45/55',
[30342] = '1/35/45/55',
[30343] = '1/35/45/55',
[30344] = '1/35/45/55',
[30348] = '1/25/35/45',
[30349] = '1/50/57/65',
[30303] = '1/1/10/20',
[30304] = '1/1/10/20',
[30305] = '1/1/5/10',
[30306] = '1/25/30/35',
[30307] = '1/50/60/70',
[30308] = '1/50/60/70',
[30309] = '1/50/60/70',
[30547] = '1/50/55/60',
[30548] = '1/5/15/25',
[30551] = '1/30/40/50',
[30552] = '1/45/55/65',
[30556] = '1/65/67/70',
[30558] = '1/25/35/45',
[30560] = '1/40/50/60',
[30563] = '1/60/65/70',
[30565] = '1/75/75/75',
[30566] = '1/75/75/75',
[30568] = '1/35/45/55',
[30569] = '1/60/65/70',
[30570] = '1/60/65/70',
[30574] = '1/75/75/75',
[30575] = '1/75/75/75',
[31112] = '1/50/60/70',
[31085] = '1/50/60/70',
[31106] = '1/50/60/70',
[31091] = '1/50/60/70',
[31109] = '1/50/60/70',
[31104] = '1/50/60/70',
[31113] = '1/50/60/70',
[31108] = '1/50/60/70',
[31101] = '1/50/60/70',
[31107] = '1/50/60/70',
[31111] = '1/50/60/70',
[31098] = '1/50/60/70',
[31088] = '1/50/60/70',
[31103] = '1/50/60/70',
[31097] = '1/50/60/70',
[31102] = '1/50/60/70',
[31092] = '1/50/60/70',
[31149] = '1/50/60/70',
[31095] = '1/50/60/70',
[31090] = '1/50/60/70',
[31084] = '1/50/60/70',
[31048] = '1/20/30/40',
[31049] = '1/20/35/50',
[31050] = '1/30/40/50',
[31051] = '1/45/55/65',
[31052] = '1/45/55/65',
[31053] = '1/60/67/75',
[31054] = '1/65/70/75',
[31055] = '1/65/70/75',
[31056] = '1/70/72/75',
[31057] = '1/70/72/75',
[31058] = '1/55/65/75',
[31060] = '1/65/70/75',
[31061] = '1/75/75/75',
[31062] = '1/70/72/75',
[31063] = '1/70/72/75',
[31064] = '1/70/72/75',
[31065] = '1/70/72/75',
[31066] = '1/70/72/75',
[31067] = '1/65/70/75',
[31068] = '1/65/70/75',
[31070] = '1/70/72/75',
[31071] = '1/70/72/75',
[31072] = '1/75/75/75',
[31076] = '1/75/75/75',
[31077] = '1/75/75/75',
[31078] = '1/75/75/75',
[31079] = '1/75/75/75',
[31080] = '1/75/75/75',
[31081] = '1/75/75/75',
[31082] = '1/75/75/75',
[31083] = '1/75/75/75',
[31430] = '1/45/50/55',
[31431] = '1/45/50/55',
[31432] = '1/75/75/75',
[31433] = '1/75/75/75',
[31434] = '1/60/65/70',
[31435] = '1/60/65/70',
[31437] = '1/60/65/70',
[31438] = '1/60/65/70',
[31440] = '1/60/65/70',
[31441] = '1/60/65/70',
[31442] = '1/75/75/75',
[31443] = '1/75/75/75',
[31444] = '1/75/75/75',
[31448] = '1/75/75/75',
[31449] = '1/75/75/75',
[31450] = '1/75/75/75',
[31451] = '1/75/75/75',
[31452] = '1/75/75/75',
[31453] = '1/75/75/75',
[31454] = '1/75/75/75',
[31455] = '1/75/75/75',
[31456] = '1/75/75/75',
[31459] = '1/50/55/60',
[31460] = '1/1/10/20',
[31373] = '1/50/55/60',
[32178] = '1/50/65/80',
[32179] = '1/50/65/80',
[32259] = '1/30/40/50',
[32284] = '1/25/30/35',
[32285] = '1/50/55/60',
[32454] = '1/1/5/10',
[32455] = '1/25/30/35',
[32456] = '1/10/25/40',
[32457] = '1/35/40/45',
[32458] = '1/35/40/45',
[32461] = '1/60/67/75',
[32462] = '1/10/20/30',
[32463] = '1/20/30/40',
[32464] = '1/30/40/50',
[32465] = '1/45/55/65',
[32466] = '1/10/20/30',
[32467] = '1/20/30/40',
[32468] = '1/35/45/55',
[32469] = '1/45/55/65',
[32470] = '1/10/20/30',
[32471] = '1/25/35/45',
[32472] = '1/30/40/50',
[32473] = '1/40/50/60',
[32478] = '1/10/20/30',
[32479] = '1/20/30/40',
[32480] = '1/30/40/50',
[32481] = '1/40/50/60',
[32482] = '1/1/5/10',
[32485] = '1/60/67/75',
[32487] = '1/60/67/75',
[32489] = '1/60/67/75',
[32488] = '1/60/67/75',
[32490] = '1/50/60/70',
[32493] = '1/60/67/75',
[32494] = '1/60/67/75',
[32495] = '1/70/72/75',
[32496] = '1/65/70/75',
[32497] = '1/65/70/75',
[32498] = '1/60/67/75',
[32499] = '1/70/72/75',
[32500] = '1/70/72/75',
[32501] = '1/50/60/70',
[32502] = '1/50/60/70',
[32503] = '1/60/67/75',
[32549] = '1/1/1/1',
[32605] = '1/1/1/1',
[32606] = '1/1/1/1',
[32765] = '1/65/70/75',
[32766] = '1/65/70/75',
[32801] = '1/70/80/90',
[32814] = '1/35/45/55',
[32807] = '1/120/130/140',
[32808] = '1/175/185/195',
[32809] = '1/225/235/245',
[32810] = '1/1/10/20',
[32867] = '1/75/75/75',
[32869] = '1/75/75/75',
[32870] = '1/75/75/75',
[32866] = '1/75/75/75',
[32868] = '1/75/75/75',
[32871] = '1/75/75/75',
[32874] = '1/75/75/75',
[32872] = '1/75/75/75',
[32873] = '1/75/75/75',
[33276] = '1/45/65/85',
[33277] = '1/45/65/85',
[33278] = '1/90/110/130',
[33279] = '1/20/30/40',
[33284] = '1/20/30/40',
[33286] = '1/35/45/55',
[33287] = '1/45/55/65',
[33288] = '1/45/55/65',
[33289] = '1/45/55/65',
[33290] = '1/20/30/40',
[33291] = '1/20/30/40',
[33292] = '1/30/40/50',
[33293] = '1/40/50/60',
[33294] = '1/40/50/60',
[33295] = '1/45/55/65',
[33296] = '1/70/72/75',
[33359] = '1/1/1/1',
[33732] = '1/15/22/30',
[33738] = '1/15/22/30',
[33740] = '1/15/22/30',
[33733] = '1/25/32/40',
[33741] = '1/30/37/45',
[33990] = '1/30/45/60',
[33991] = '1/10/25/40',
[33992] = '1/55/65/75',
[33993] = '1/15/30/45',
[33994] = '1/70/72/75',
[33995] = '1/50/62/75',
[33996] = '1/20/35/50',
[33997] = '1/70/72/75',
[33999] = '1/70/72/75',
[34001] = '1/15/30/45',
[34002] = '1/10/25/40',
[34003] = '1/35/50/65',
[34004] = '1/20/35/50',
[34007] = '1/70/72/75',
[34008] = '1/70/72/75',
[34009] = '1/35/50/65',
[34010] = '1/70/72/75',
[28027] = '1/25/30/35',
[28028] = '1/70/72/75',
[34533] = '1/60/65/70',
[34545] = '1/60/65/70',
[34538] = '1/60/65/70',
[34529] = '1/60/65/70',
[34535] = '1/60/65/70',
[34541] = '1/60/65/70',
[34547] = '1/60/65/70',
[34543] = '1/60/65/70',
[34542] = '1/70/72/75',
[34534] = '1/70/72/75',
[34548] = '1/70/72/75',
[34546] = '1/70/72/75',
[34540] = '1/70/72/75',
[34544] = '1/70/72/75',
[34537] = '1/70/72/75',
[34530] = '1/70/72/75',
[34590] = '1/5/25/45',
[34607] = '1/1/5/10',
[34608] = '1/50/55/60',
[34960] = '1/290/295/300',
[34961] = '1/300/300/300',
[34955] = '1/190/200/210',
[34959] = '1/210/220/230',
[35530] = '1/35/40/45',
[35527] = '1/60/67/75',
[35526] = '1/60/67/75',
[35525] = '1/60/67/75',
[35531] = '1/60/67/75',
[35528] = '1/60/67/75',
[35529] = '1/60/67/75',
[35534] = '1/60/67/75',
[35533] = '1/60/67/75',
[35532] = '1/60/67/75',
[35537] = '1/60/67/75',
[35536] = '1/60/67/75',
[35535] = '1/60/67/75',
[35538] = '1/70/72/75',
[35539] = '1/50/57/65',
[35540] = '1/40/47/55',
[35543] = '1/65/70/75',
[35544] = '1/45/52/60',
[35549] = '1/35/45/55',
[35555] = '1/35/45/55',
[35554] = '1/65/70/75',
[35557] = '1/65/70/75',
[35559] = '1/75/75/75',
[35558] = '1/75/75/75',
[35567] = '1/75/75/75',
[35562] = '1/75/75/75',
[35561] = '1/75/75/75',
[35564] = '1/75/75/75',
[35573] = '1/75/75/75',
[35572] = '1/75/75/75',
[35574] = '1/75/75/75',
[35563] = '1/75/75/75',
[35560] = '1/75/75/75',
[35568] = '1/75/75/75',
[35576] = '1/75/75/75',
[35577] = '1/75/75/75',
[35575] = '1/75/75/75',
[35582] = '1/75/75/75',
[35584] = '1/75/75/75',
[35580] = '1/75/75/75',
[35590] = '1/75/75/75',
[35591] = '1/75/75/75',
[35589] = '1/75/75/75',
[35587] = '1/75/75/75',
[35588] = '1/75/75/75',
[35585] = '1/75/75/75',
[35750] = '1/1/5/10',
[35751] = '1/1/5/10',
[36074] = '1/300/300/300',
[36076] = '1/300/300/300',
[36075] = '1/300/300/300',
[36079] = '1/50/60/70',
[36078] = '1/50/60/70',
[36077] = '1/50/60/70',
[36122] = '1/1/3/5',
[36125] = '1/300/300/300',
[36128] = '1/1/3/5',
[36126] = '1/1/3/5',
[36124] = '1/1/3/5',
[36137] = '1/40/50/60',
[36129] = '1/40/50/60',
[36136] = '1/40/50/60',
[36135] = '1/40/50/60',
[36133] = '1/40/50/60',
[36134] = '1/40/50/60',
[36130] = '1/40/50/60',
[36131] = '1/40/50/60',
[36210] = '1/20/30/40',
[36256] = '1/70/72/75',
[36257] = '1/70/72/75',
[36258] = '1/70/72/75',
[36259] = '1/70/72/75',
[36260] = '1/70/72/75',
[36261] = '1/70/72/75',
[36262] = '1/70/72/75',
[36263] = '1/70/72/75',
[36315] = '1/75/75/75',
[36317] = '1/75/75/75',
[36316] = '1/75/75/75',
[36318] = '1/75/75/75',
[36349] = '1/75/75/75',
[36351] = '1/75/75/75',
[36352] = '1/75/75/75',
[36353] = '1/75/75/75',
[36355] = '1/75/75/75',
[36357] = '1/75/75/75',
[36358] = '1/75/75/75',
[36359] = '1/75/75/75',
[36389] = '1/70/72/75',
[36390] = '1/70/72/75',
[36391] = '1/70/72/75',
[36392] = '1/70/72/75',
[36523] = '1/105/120/135',
[36524] = '1/135/150/165',
[36525] = '1/255/270/285',
[36526] = '1/285/292/300',
[36670] = '1/65/70/75',
[36672] = '1/65/70/75',
[36669] = '1/65/70/75',
[36667] = '1/65/70/75',
[36668] = '1/65/70/75',
[36665] = '1/65/70/75',
[36686] = '1/50/55/60',
[36954] = '1/50/60/70',
[36955] = '1/50/60/70',
[37818] = '1/95/110/125',
[37836] = '1/30/35/40',
[37855] = '1/70/72/75',
[37873] = '1/60/65/70',
[37882] = '1/60/65/70',
[37883] = '1/70/72/75',
[37884] = '1/75/75/75',
[38068] = '1/25/35/45',
[38070] = '1/40/47/55',
[38175] = '1/110/125/140',
[38473] = '1/70/72/75',
[38475] = '1/70/72/75',
[38476] = '1/70/72/75',
[38477] = '1/70/72/75',
[38478] = '1/70/72/75',
[38479] = '1/70/72/75',
[38503] = '1/75/75/75',
[38504] = '1/75/75/75',
[38868] = '1/55/65/75',
[38867] = '1/55/65/75',
[38960] = '1/50/57/65',
[38962] = '1/60/67/75',
[38961] = '1/75/75/75',
[39466] = '1/25/40/55',
[39467] = '1/25/40/55',
[39470] = '1/50/60/70',
[39471] = '1/50/60/70',
[39636] = '1/25/32/40',
[39637] = '1/35/42/50',
[39638] = '1/35/42/50',
[39639] = '1/45/52/60',
[39705] = '1/75/75/75',
[39706] = '1/75/75/75',
[39714] = '1/75/75/75',
[39711] = '1/75/75/75',
[39713] = '1/75/75/75',
[39715] = '1/75/75/75',
[39716] = '1/75/75/75',
[39718] = '1/75/75/75',
[39724] = '1/75/75/75',
[39721] = '1/75/75/75',
[39720] = '1/75/75/75',
[39731] = '1/75/75/75',
[39728] = '1/75/75/75',
[39727] = '1/75/75/75',
[39736] = '1/75/75/75',
[39733] = '1/75/75/75',
[39734] = '1/75/75/75',
[39737] = '1/75/75/75',
[39738] = '1/75/75/75',
[39741] = '1/75/75/75',
[39739] = '1/75/75/75',
[39742] = '1/75/75/75',
[39740] = '1/75/75/75',
[39895] = '1/275/280/285',
[39963] = '1/75/75/75',
[39961] = '1/75/75/75',
[39971] = '1/35/40/45',
[39973] = '1/45/55/65',
[39997] = '1/75/75/75',
[40001] = '1/75/75/75',
[40002] = '1/75/75/75',
[40006] = '1/75/75/75',
[40005] = '1/75/75/75',
[40003] = '1/75/75/75',
[40004] = '1/75/75/75',
[40021] = '1/75/75/75',
[40024] = '1/75/75/75',
[40023] = '1/75/75/75',
[40020] = '1/75/75/75',
[40034] = '1/70/72/75',
[40036] = '1/70/72/75',
[40035] = '1/70/72/75',
[40033] = '1/70/72/75',
[40060] = '1/75/75/75',
[40274] = '1/70/72/75',
[40514] = '1/40/55/70',
[41132] = '1/70/72/75',
[41133] = '1/70/72/75',
[41135] = '1/70/72/75',
[41134] = '1/70/72/75',
[41161] = '1/75/75/75',
[41156] = '1/75/75/75',
[41163] = '1/75/75/75',
[41164] = '1/75/75/75',
[41157] = '1/75/75/75',
[41162] = '1/75/75/75',
[41158] = '1/75/75/75',
[41160] = '1/75/75/75',
[41307] = '1/75/75/75',
[41311] = '1/70/72/75',
[41312] = '1/70/72/75',
[41314] = '1/70/72/75',
[41315] = '1/70/72/75',
[41316] = '1/70/72/75',
[41317] = '1/70/72/75',
[41318] = '1/70/72/75',
[41319] = '1/70/72/75',
[41320] = '1/70/72/75',
[41321] = '1/70/72/75',
[41418] = '1/75/75/75',
[41414] = '1/35/45/55',
[41415] = '1/40/50/60',
[41458] = '1/60/67/75',
[41500] = '1/60/67/75',
[41501] = '1/60/67/75',
[41502] = '1/60/67/75',
[41503] = '1/60/67/75',
[41207] = '1/75/75/75',
[41208] = '1/75/75/75',
[41205] = '1/75/75/75',
[41206] = '1/75/75/75',
[41420] = '1/25/32/40',
[41429] = '1/50/60/70',
[42296] = '1/35/45/55',
[42302] = '1/75/75/75',
[42305] = '1/75/75/75',
[42546] = '1/70/72/75',
[42558] = '1/65/70/75',
[42588] = '1/65/70/75',
[42589] = '1/65/70/75',
[42590] = '1/65/70/75',
[42593] = '1/65/70/75',
[42591] = '1/65/70/75',
[42592] = '1/65/70/75',
[42615] = '1/15/25/35',
[42620] = '1/60/67/75',
[42662] = '1/70/72/75',
[42688] = '1/45/50/55',
[42731] = '1/75/75/75',
[42974] = '1/75/75/75',
[43493] = '1/50/60/70',
[43549] = '1/75/95/115',
[43707] = '1/35/45/55',
[43758] = '1/20/30/40',
[43761] = '1/20/30/40',
[43765] = '1/35/45/55',
[43779] = '1/50/62/75',
[43846] = '1/70/72/75',
[44155] = '1/1/38/75',
[44157] = '1/75/75/75',
[43308] = '1/1/1/1',
[44383] = '1/40/52/65',
[44391] = '1/70/72/75',
[44484] = '1/40/50/60',
[44488] = '1/50/57/65',
[44489] = '1/55/65/75',
[44492] = '1/30/40/50',
[44508] = '1/50/57/65',
[44500] = '1/30/40/50',
[44506] = '1/15/20/25',
[44509] = '1/55/65/75',
[44510] = '1/50/57/65',
[44528] = '1/25/30/35',
[44513] = '1/30/40/50',
[44524] = '1/60/67/75',
[44555] = '1/10/17/25',
[44529] = '1/50/60/70',
[44575] = '1/65/70/75',
[44576] = '1/60/67/75',
[44584] = '1/40/50/60',
[44582] = '1/20/27/35',
[44589] = '1/50/60/70',
[44588] = '1/60/67/75',
[44593] = '1/55/65/75',
[44591] = '1/70/72/75',
[44612] = '1/30/37/45',
[44592] = '1/1/5/10',
[44595] = '1/65/70/75',
[44598] = '1/50/60/70',
[44616] = '1/35/45/55',
[44621] = '1/65/70/75',
[44623] = '1/5/15/25',
[44625] = '1/70/72/75',
[44630] = '1/25/35/45',
[44629] = '1/30/40/50',
[44631] = '1/75/75/75',
[44633] = '1/50/57/65',
[44635] = '1/30/40/50',
[44359] = '1/60/67/75',
[44770] = '1/55/60/65',
[44794] = '1/75/75/75',
[44970] = '1/55/60/65',
[45061] = '1/35/42/50',
[44958] = '1/250/250/250',
[44950] = '1/250/250/250',
[44953] = '1/300/300/300',
[45022] = '1/300/300/300',
[45100] = '1/10/20/30',
[43772] = '1/45/55/65',
[45117] = '1/70/72/75',
[45357] = '1/1/1/1',
[45358] = '1/1/1/1',
[45359] = '1/1/1/1',
[45360] = '1/1/1/1',
[45361] = '1/1/1/1',
[45363] = '1/1/1/1',
[45382] = '1/65/70/75',
[13028] = '1/175/190/205',
[45695] = '1/100/105/110',
[45765] = '1/60/62/65',
[46111] = '1/75/75/75',
[46115] = '1/75/75/75',
[46109] = '1/75/75/75',
[46107] = '1/75/75/75',
[46112] = '1/75/75/75',
[46114] = '1/75/75/75',
[46108] = '1/75/75/75',
[46110] = '1/75/75/75',
[46116] = '1/75/75/75',
[46113] = '1/15/35/55',
[46106] = '1/75/75/75',
[46141] = '1/70/72/75',
[46144] = '1/70/72/75',
[46142] = '1/70/72/75',
[46140] = '1/70/72/75',
[46126] = '1/75/75/75',
[46124] = '1/75/75/75',
[46127] = '1/75/75/75',
[46122] = '1/75/75/75',
[46125] = '1/75/75/75',
[46123] = '1/75/75/75',
[46137] = '1/75/75/75',
[46138] = '1/75/75/75',
[46133] = '1/75/75/75',
[46134] = '1/75/75/75',
[46135] = '1/75/75/75',
[46139] = '1/75/75/75',
[46136] = '1/75/75/75',
[46132] = '1/75/75/75',
[46129] = '1/75/75/75',
[46131] = '1/75/75/75',
[46128] = '1/75/75/75',
[46130] = '1/75/75/75',
[46353] = '1/75/75/75',
[46403] = '1/50/60/70',
[46405] = '1/50/60/70',
[46578] = '1/50/57/65',
[46594] = '1/70/72/75',
[46597] = '1/75/75/75',
[46601] = '1/75/75/75',
[46684] = '1/275/285/295',
[46688] = '1/275/285/295',
[46697] = '1/65/67/70',
[46775] = '1/75/75/75',
[46776] = '1/75/75/75',
[46777] = '1/75/75/75',
[46778] = '1/75/75/75',
[46779] = '1/75/75/75',
[46803] = '1/50/60/70',
[47050] = '1/75/75/75',
[47046] = '1/75/75/75',
[47049] = '1/75/75/75',
[47048] = '1/75/75/75',
[47051] = '1/75/75/75',
[47053] = '1/75/75/75',
[47054] = '1/75/75/75',
[47055] = '1/75/75/75',
[47056] = '1/75/75/75',
[47280] = '1/50/60/70',
[47672] = '1/65/70/75',
[47898] = '1/65/70/75',
[47899] = '1/75/75/75',
[47901] = '1/75/75/75',
[48114] = '1/65/70/75',
[48116] = '1/65/70/75',
[48247] = '1/125/137/150',
[49252] = '1/1/13/25',
[49258] = '1/50/62/75',
[49383] = '1/1/1/1',
[49677] = '1/255/270/285',
[50194] = '1/75/75/75',
[50300] = '1/1/1/1',
[50310] = '1/1/1/1',
[50612] = '1/75/80/85',
[50614] = '1/160/165/170',
[50616] = '1/210/215/220',
[50617] = '1/255/260/265',
[50618] = '1/300/300/300',
[50619] = '1/1/10/20',
[50620] = '1/30/35/40',
[50598] = '1/75/80/85',
[50599] = '1/170/175/180',
[50600] = '1/220/225/230',
[50601] = '1/265/270/275',
[50602] = '1/10/15/20',
[50603] = '1/1/10/20',
[50604] = '1/40/45/50',
[50605] = '1/75/80/85',
[50606] = '1/165/170/175',
[50607] = '1/215/220/225',
[50608] = '1/260/265/270',
[50609] = '1/300/300/300',
[50610] = '1/1/10/20',
[50611] = '1/35/40/45',
[50644] = '1/265/280/295',
[50647] = '1/250/255/260',
[50936] = '1/10/20/30',
[50962] = '1/1/5/10',
[50949] = '1/20/30/40',
[50955] = '1/10/20/30',
[50943] = '1/5/12/20',
[51296] = '1/1/1/1',
[51304] = '1/1/1/1',
[51300] = '1/1/1/1',
[51313] = '1/1/1/1',
[51306] = '1/1/1/1',
[51311] = '1/1/1/1',
[51302] = '1/1/1/1',
[51309] = '1/1/1/1',
[50963] = '1/25/27/30',
[50948] = '1/10/20/30',
[50944] = '1/10/20/30',
[50945] = '1/15/25/35',
[50947] = '1/15/25/35',
[50946] = '1/20/30/40',
[51571] = '1/25/35/45',
[52568] = '1/1/3/5',
[52569] = '1/1/3/5',
[52570] = '1/5/10/15',
[52567] = '1/1/5/10',
[52571] = '1/1/5/10',
[52572] = '1/1/3/5',
[52733] = '1/75/75/75',
[52739] = '1/75/87/100',
[48248] = '1/75/80/85',
[52843] = '1/45/60/75',
[53056] = '1/1/13/25',
[53281] = '1/1/5/10',
[53462] = '1/75/77/80',
[53812] = '1/5/10/15',
[53836] = '1/35/42/50',
[53837] = '1/40/47/55',
[53838] = '1/1/3/5',
[53840] = '1/25/32/40',
[53842] = '1/1/8/15',
[53847] = '1/15/20/25',
[53895] = '1/40/47/55',
[53898] = '1/20/25/30',
[53900] = '1/10/15/20',
[53905] = '1/40/47/55',
[53904] = '1/40/47/55',
[53903] = '1/75/75/75',
[53902] = '1/75/75/75',
[53901] = '1/75/75/75',
[53899] = '1/5/10/15',
[53848] = '1/5/10/15',
[53841] = '1/1/5/10',
[53839] = '1/1/5/10',
[53777] = '1/30/40/50',
[53776] = '1/30/40/50',
[53781] = '1/30/40/50',
[53782] = '1/30/40/50',
[53775] = '1/30/40/50',
[53774] = '1/30/40/50',
[53773] = '1/30/40/50',
[53771] = '1/30/40/50',
[53779] = '1/30/40/50',
[53780] = '1/30/40/50',
[53783] = '1/30/40/50',
[53784] = '1/30/40/50',
[53942] = '1/35/40/45',
[53936] = '1/35/40/45',
[53937] = '1/35/40/45',
[53938] = '1/35/40/45',
[53939] = '1/35/40/45',
[53831] = '1/1/20/40',
[53832] = '1/1/20/40',
[53843] = '1/1/20/40',
[53844] = '1/1/20/40',
[53845] = '1/1/20/40',
[54017] = '1/1/20/40',
[53934] = '1/1/20/40',
[53941] = '1/1/20/40',
[53943] = '1/1/20/40',
[53852] = '1/1/20/40',
[53854] = '1/1/20/40',
[53857] = '1/1/20/40',
[53856] = '1/1/20/40',
[53859] = '1/1/20/40',
[53860] = '1/1/20/40',
[53861] = '1/1/20/40',
[53865] = '1/1/20/40',
[53869] = '1/1/20/40',
[53870] = '1/1/20/40',
[53871] = '1/1/20/40',
[53872] = '1/1/20/40',
[53873] = '1/1/20/40',
[53874] = '1/1/20/40',
[53875] = '1/1/20/40',
[53876] = '1/1/20/40',
[53877] = '1/1/20/40',
[53879] = '1/1/20/40',
[53880] = '1/1/20/40',
[53882] = '1/1/20/40',
[53883] = '1/1/20/40',
[53884] = '1/1/20/40',
[53885] = '1/1/20/40',
[53891] = '1/1/20/40',
[53892] = '1/1/20/40',
[53893] = '1/1/20/40',
[53894] = '1/1/20/40',
[53917] = '1/1/20/40',
[53918] = '1/1/20/40',
[53919] = '1/1/20/40',
[53920] = '1/1/20/40',
[53921] = '1/1/20/40',
[53922] = '1/1/20/40',
[53923] = '1/1/20/40',
[53924] = '1/1/20/40',
[53925] = '1/1/20/40',
[53932] = '1/1/20/40',
[53933] = '1/1/20/40',
[53830] = '1/35/50/65',
[53945] = '1/35/50/65',
[53946] = '1/35/50/65',
[53948] = '1/35/50/65',
[53949] = '1/35/50/65',
[53951] = '1/35/50/65',
[53952] = '1/35/50/65',
[53954] = '1/35/50/65',
[53955] = '1/35/50/65',
[53957] = '1/35/50/65',
[53958] = '1/35/50/65',
[53960] = '1/35/50/65',
[53961] = '1/35/50/65',
[53962] = '1/35/50/65',
[53963] = '1/35/50/65',
[53965] = '1/35/50/65',
[53966] = '1/35/50/65',
[53968] = '1/35/50/65',
[53972] = '1/35/50/65',
[53974] = '1/35/50/65',
[53975] = '1/35/50/65',
[53976] = '1/35/50/65',
[53977] = '1/35/50/65',
[53978] = '1/35/50/65',
[53980] = '1/35/50/65',
[53981] = '1/35/50/65',
[53984] = '1/35/50/65',
[53985] = '1/35/50/65',
[53986] = '1/35/50/65',
[53987] = '1/35/50/65',
[53988] = '1/35/50/65',
[53991] = '1/35/50/65',
[53993] = '1/35/50/65',
[53994] = '1/35/50/65',
[54020] = '1/70/72/75',
[54019] = '1/35/50/65',
[54023] = '1/35/50/65',
[54011] = '1/35/50/65',
[54012] = '1/35/50/65',
[54014] = '1/35/50/65',
[53996] = '1/35/50/65',
[53997] = '1/35/50/65',
[53998] = '1/35/50/65',
[54000] = '1/35/50/65',
[54001] = '1/35/50/65',
[54003] = '1/35/50/65',
[54005] = '1/35/50/65',
[54009] = '1/35/50/65',
[54213] = '1/75/75/75',
[54218] = '1/15/20/25',
[54220] = '1/40/47/55',
[54221] = '1/40/47/55',
[54222] = '1/40/47/55',
[54353] = '1/30/35/40',
[54550] = '1/1/3/5',
[54551] = '1/25/30/35',
[54552] = '1/30/35/40',
[54553] = '1/30/35/40',
[54554] = '1/25/30/35',
[54555] = '1/35/40/45',
[54556] = '1/35/40/45',
[54557] = '1/20/25/30',
[54917] = '1/5/10/15',
[54918] = '1/10/15/20',
[54941] = '1/15/20/25',
[54944] = '1/15/20/25',
[54945] = '1/20/25/30',
[54946] = '1/25/30/35',
[54947] = '1/25/30/35',
[54948] = '1/30/35/40',
[54949] = '1/30/35/40',
[54978] = '1/20/25/30',
[54979] = '1/30/35/40',
[54980] = '1/35/40/45',
[54981] = '1/40/45/50',
[55013] = '1/20/25/30',
[55017] = '1/40/45/50',
[55014] = '1/40/45/50',
[55015] = '1/45/50/55',
[55055] = '1/25/30/35',
[55056] = '1/30/35/40',
[55057] = '1/35/40/45',
[55058] = '1/45/50/55',
[55174] = '1/20/25/30',
[55177] = '1/25/30/35',
[55179] = '1/30/35/40',
[55181] = '1/35/40/45',
[55182] = '1/40/45/50',
[55183] = '1/45/50/55',
[55184] = '1/45/50/55',
[55185] = '1/45/50/55',
[55186] = '1/45/50/55',
[55187] = '1/45/50/55',
[55199] = '1/30/40/50',
[55200] = '1/10/15/20',
[55201] = '1/10/15/20',
[55203] = '1/15/20/25',
[55204] = '1/20/25/30',
[55206] = '1/40/45/50',
[55208] = '1/75/75/75',
[55211] = '1/75/75/75',
[55252] = '1/40/42/45',
[55298] = '1/50/55/60',
[55300] = '1/55/65/75',
[55301] = '1/55/65/75',
[55302] = '1/60/70/80',
[55303] = '1/60/70/80',
[55304] = '1/60/70/80',
[55305] = '1/50/55/60',
[55306] = '1/55/65/75',
[55307] = '1/55/65/75',
[55308] = '1/55/65/75',
[55309] = '1/55/65/75',
[55311] = '1/60/70/80',
[55310] = '1/60/70/80',
[55312] = '1/60/70/80',
[55371] = '1/75/75/75',
[55372] = '1/75/75/75',
[55373] = '1/75/75/75',
[55374] = '1/75/75/75',
[55375] = '1/75/75/75',
[55376] = '1/75/75/75',
[55369] = '1/75/75/75',
[55370] = '1/75/75/75',
[55377] = '1/75/75/75',
[55384] = '1/65/70/75',
[55386] = '1/65/70/75',
[55387] = '1/65/70/75',
[55388] = '1/65/70/75',
[55390] = '1/65/70/75',
[55392] = '1/65/70/75',
[55393] = '1/65/70/75',
[55394] = '1/65/70/75',
[55395] = '1/65/70/75',
[55407] = '1/65/70/75',
[55396] = '1/65/70/75',
[55397] = '1/65/70/75',
[55398] = '1/65/70/75',
[55399] = '1/65/70/75',
[55400] = '1/65/70/75',
[55401] = '1/65/70/75',
[55402] = '1/65/70/75',
[55403] = '1/65/70/75',
[55404] = '1/65/70/75',
[55405] = '1/65/70/75',
[55389] = '1/65/70/75',
[55656] = '1/45/50/55',
[47766] = '1/35/45/55',
[55834] = '1/1/3/5',
[55835] = '1/5/10/15',
[55839] = '1/50/55/60',
[55898] = '1/1/3/5',
[55899] = '1/1/3/5',
[55900] = '1/25/27/30',
[55902] = '1/1/3/5',
[55903] = '1/1/8/15',
[55904] = '1/1/8/15',
[56030] = '1/15/25/35',
[55906] = '1/10/20/30',
[55907] = '1/15/25/35',
[55908] = '1/5/15/25',
[55910] = '1/20/30/40',
[55911] = '1/25/35/45',
[55913] = '1/20/30/40',
[55901] = '1/30/35/40',
[55914] = '1/25/30/35',
[55921] = '1/40/45/50',
[55922] = '1/40/45/50',
[55919] = '1/30/35/40',
[55924] = '1/45/50/55',
[55925] = '1/50/55/60',
[55920] = '1/35/40/45',
[55923] = '1/45/50/55',
[55941] = '1/55/60/65',
[55943] = '1/50/55/60',
[55993] = '1/25/30/35',
[55994] = '1/25/30/35',
[55995] = '1/25/30/35',
[55996] = '1/25/30/35',
[55997] = '1/25/30/35',
[55998] = '1/25/30/35',
[55999] = '1/25/30/35',
[56000] = '1/25/30/35',
[56002] = '1/50/55/60',
[56001] = '1/50/55/60',
[56003] = '1/50/55/60',
[56004] = '1/65/70/75',
[56005] = '1/75/75/75',
[56006] = '1/70/72/75',
[56007] = '1/55/65/75',
[56008] = '1/25/30/35',
[56009] = '1/60/65/70',
[56010] = '1/25/30/35',
[56011] = '1/60/65/70',
[56014] = '1/20/25/30',
[56015] = '1/25/30/35',
[56017] = '1/60/67/75',
[56016] = '1/60/67/75',
[56018] = '1/60/65/70',
[56019] = '1/55/65/75',
[56020] = '1/55/65/75',
[56021] = '1/60/65/70',
[56022] = '1/55/65/75',
[56023] = '1/55/65/75',
[56024] = '1/75/75/75',
[56025] = '1/70/72/75',
[56026] = '1/75/75/75',
[56027] = '1/70/72/75',
[56028] = '1/75/75/75',
[56029] = '1/70/72/75',
[56031] = '1/1/3/5',
[56049] = '1/15/40/65',
[56052] = '1/15/40/65',
[56053] = '1/15/40/65',
[56055] = '1/15/40/65',
[56056] = '1/15/40/65',
[56079] = '1/15/40/65',
[56081] = '1/15/40/65',
[56083] = '1/15/40/65',
[56084] = '1/15/40/65',
[56085] = '1/15/40/65',
[56087] = '1/15/40/65',
[56088] = '1/15/40/65',
[56086] = '1/15/40/65',
[56193] = '1/5/25/45',
[56194] = '1/5/25/45',
[56195] = '1/25/35/45',
[56196] = '1/25/35/45',
[56197] = '1/65/70/75',
[56199] = '1/55/65/75',
[56201] = '1/55/65/75',
[56202] = '1/55/65/75',
[56203] = '1/55/65/75',
[56205] = '1/1/3/5',
[56206] = '1/1/8/15',
[56208] = '1/5/15/25',
[56234] = '1/75/75/75',
[56280] = '1/40/45/50',
[56349] = '1/1/3/5',
[54736] = '1/15/17/20',
[56357] = '1/50/55/60',
[55002] = '1/5/7/10',
[54793] = '1/5/7/10',
[55016] = '1/25/30/35',
[56400] = '1/75/75/75',
[56496] = '1/75/75/75',
[56497] = '1/75/75/75',
[56498] = '1/75/75/75',
[56499] = '1/75/75/75',
[56500] = '1/75/75/75',
[56501] = '1/75/75/75',
[56460] = '1/1/8/15',
[56459] = '1/5/10/15',
[56461] = '1/5/10/15',
[56464] = '1/5/10/15',
[56463] = '1/10/15/20',
[56465] = '1/50/57/65',
[56471] = '1/20/25/30',
[56466] = '1/60/65/70',
[56467] = '1/60/65/70',
[56468] = '1/35/40/45',
[56470] = '1/55/57/60',
[56472] = '1/55/57/60',
[56514] = '1/50/55/60',
[56473] = '1/55/60/65',
[56462] = '1/65/70/75',
[56476] = '1/40/45/50',
[56477] = '1/45/50/55',
[56469] = '1/55/60/65',
[56478] = '1/60/67/75',
[56479] = '1/75/75/75',
[56480] = '1/75/75/75',
[56519] = '1/40/47/55',
[56530] = '1/5/25/45',
[56531] = '1/35/50/65',
[56549] = '1/50/55/60',
[56550] = '1/55/65/75',
[56551] = '1/55/65/75',
[56552] = '1/55/65/75',
[56553] = '1/55/65/75',
[56554] = '1/60/70/80',
[56555] = '1/60/70/80',
[56556] = '1/60/70/80',
[56481] = '1/75/75/75',
[56574] = '1/75/75/75',
[56483] = '1/75/75/75',
[56484] = '1/75/75/75',
[56486] = '1/75/75/75',
[56487] = '1/75/75/75',
[57209] = '1/300/300/300',
[57224] = '1/300/300/300',
[57425] = '1/65/70/75',
[57427] = '1/60/65/70',
[45560] = '1/1/3/5',
[45561] = '1/1/3/5',
[45562] = '1/1/3/5',
[45563] = '1/1/20/40',
[45564] = '1/1/20/40',
[45565] = '1/1/20/40',
[45569] = '1/1/20/40',
[45566] = '1/1/20/40',
[57421] = '1/1/3/5',
[45549] = '1/1/20/40',
[45550] = '1/1/20/40',
[45551] = '1/1/20/40',
[45552] = '1/1/20/40',
[45553] = '1/1/20/40',
[45554] = '1/1/25/50',
[57423] = '1/75/75/75',
[45555] = '1/50/62/75',
[45556] = '1/50/62/75',
[45557] = '1/50/62/75',
[45558] = '1/50/62/75',
[45559] = '1/50/62/75',
[45567] = '1/50/62/75',
[45568] = '1/50/62/75',
[45571] = '1/50/62/75',
[45570] = '1/50/62/75',
[57433] = '1/50/62/75',
[57434] = '1/50/62/75',
[57435] = '1/50/62/75',
[57436] = '1/50/62/75',
[57437] = '1/50/62/75',
[57438] = '1/50/62/75',
[57439] = '1/50/62/75',
[57440] = '1/50/62/75',
[57441] = '1/50/62/75',
[57442] = '1/50/62/75',
[57443] = '1/50/62/75',
[57703] = '1/85/90/95',
[57704] = '1/95/100/105',
[57706] = '1/125/130/135',
[57707] = '1/145/150/155',
[57708] = '1/170/175/180',
[57709] = '1/195/200/205',
[57710] = '1/220/225/230',
[57711] = '1/245/250/255',
[57712] = '1/290/295/300',
[57713] = '1/1/3/5',
[57714] = '1/20/25/30',
[57715] = '1/1/10/20',
[57716] = '1/1/10/20',
[56948] = '1/1/10/20',
[56986] = '1/1/10/20',
[57032] = '1/300/300/300',
[57263] = '1/1/38/75',
[58065] = '1/1/20/40',
[58141] = '1/5/25/45',
[58142] = '1/5/25/45',
[58143] = '1/15/30/45',
[58144] = '1/15/30/45',
[58145] = '1/35/45/55',
[58146] = '1/35/45/55',
[58147] = '1/65/70/75',
[58148] = '1/65/70/75',
[58149] = '1/65/70/75',
[58150] = '1/65/70/75',
[58484] = '1/65/70/75',
[58485] = '1/80/85/90',
[58486] = '1/175/180/185',
[58487] = '1/225/230/235',
[58488] = '1/270/275/280',
[58489] = '1/15/20/25',
[58490] = '1/1/10/20',
[58491] = '1/45/50/55',
[58472] = '1/65/70/75',
[58473] = '1/85/90/95',
[58476] = '1/180/185/190',
[58478] = '1/230/235/240',
[58480] = '1/275/280/285',
[58481] = '1/20/25/30',
[58482] = '1/1/10/20',
[58483] = '1/50/55/60',
[58512] = '1/1/3/5',
[58521] = '1/1/3/5',
[58523] = '1/1/8/15',
[58525] = '1/1/3/5',
[58527] = '1/60/67/75',
[58528] = '1/75/75/75',
[58565] = '1/125/137/150',
[58868] = '1/40/42/45',
[58871] = '1/35/37/40',
[58507] = '1/65/70/75',
[58492] = '1/65/70/75',
[58954] = '1/65/70/75',
[59390] = '1/1/1/1',
[59405] = '1/1/3/5',
[59406] = '1/60/65/70',
[59436] = '1/25/30/35',
[59438] = '1/30/35/40',
[59440] = '1/35/40/45',
[59441] = '1/45/50/55',
[59442] = '1/40/45/50',
[59582] = '1/50/60/70',
[59583] = '1/50/60/70',
[59584] = '1/55/65/75',
[59585] = '1/55/65/75',
[59586] = '1/55/65/75',
[59587] = '1/55/65/75',
[59588] = '1/55/65/75',
[59589] = '1/55/65/75',
[59759] = '1/55/65/75',
[59480] = '1/150/162/175',
[59487] = '1/200/205/210',
[59491] = '1/250/255/260',
[59502] = '1/290/295/300',
[59503] = '1/50/62/75',
[59504] = '1/75/75/75',
[60403] = '1/45/50/55',
[60396] = '1/45/50/55',
[60405] = '1/45/50/55',
[60354] = '1/40/47/55',
[60355] = '1/40/47/55',
[60356] = '1/40/47/55',
[60357] = '1/40/47/55',
[60365] = '1/40/47/55',
[60366] = '1/40/47/55',
[60367] = '1/25/32/40',
[60350] = '1/45/55/65',
[50967] = '1/60/65/70',
[50965] = '1/60/65/70',
[60867] = '1/75/75/75',
[60866] = '1/75/75/75',
[60874] = '1/75/75/75',
[51572] = '1/25/35/45',
[51570] = '1/35/45/55',
[51569] = '1/35/45/55',
[51568] = '1/40/50/60',
[50951] = '1/10/20/30',
[50950] = '1/15/25/35',
[50952] = '1/15/25/35',
[50953] = '1/20/30/40',
[50954] = '1/20/30/40',
[60599] = '1/25/35/45',
[60600] = '1/25/35/45',
[60601] = '1/35/45/55',
[60604] = '1/35/45/55',
[60605] = '1/40/50/60',
[50941] = '1/10/20/30',
[50939] = '1/10/20/30',
[50938] = '1/15/25/35',
[50942] = '1/15/25/35',
[50940] = '1/20/30/40',
[60607] = '1/25/35/45',
[60608] = '1/25/35/45',
[60611] = '1/35/45/55',
[60613] = '1/35/45/55',
[60620] = '1/40/50/60',
[50957] = '1/10/20/30',
[50959] = '1/10/20/30',
[50956] = '1/15/25/35',
[50961] = '1/15/25/35',
[50960] = '1/20/30/40',
[50958] = '1/20/30/40',
[60622] = '1/25/35/45',
[60624] = '1/25/35/45',
[60627] = '1/35/45/55',
[60629] = '1/35/45/55',
[60630] = '1/40/50/60',
[60631] = '1/15/25/35',
[60637] = '1/75/75/75',
[60640] = '1/75/75/75',
[50966] = '1/30/35/40',
[50964] = '1/35/40/45',
[50970] = '1/45/47/50',
[50971] = '1/45/47/50',
[60643] = '1/45/47/50',
[60649] = '1/55/60/65',
[60651] = '1/50/55/60',
[60652] = '1/50/55/60',
[60655] = '1/55/60/65',
[60658] = '1/50/55/60',
[60660] = '1/55/60/65',
[60665] = '1/50/55/60',
[60666] = '1/50/55/60',
[60669] = '1/55/60/65',
[60671] = '1/50/55/60',
[60697] = '1/50/55/60',
[60702] = '1/50/55/60',
[60703] = '1/50/55/60',
[60704] = '1/50/55/60',
[60705] = '1/55/60/65',
[60706] = '1/55/60/65',
[60711] = '1/55/60/65',
[60712] = '1/55/60/65',
[60715] = '1/50/55/60',
[60716] = '1/50/55/60',
[60718] = '1/50/55/60',
[60720] = '1/50/55/60',
[60721] = '1/55/60/65',
[60723] = '1/55/60/65',
[60725] = '1/55/60/65',
[60727] = '1/55/60/65',
[60728] = '1/50/55/60',
[60729] = '1/50/55/60',
[60730] = '1/50/55/60',
[60731] = '1/50/55/60',
[60732] = '1/55/60/65',
[60734] = '1/55/60/65',
[60735] = '1/55/60/65',
[60737] = '1/55/60/65',
[60743] = '1/50/55/60',
[60746] = '1/50/55/60',
[60747] = '1/50/55/60',
[60748] = '1/50/55/60',
[60749] = '1/55/60/65',
[60750] = '1/55/60/65',
[60751] = '1/55/60/65',
[60752] = '1/55/60/65',
[60893] = '1/40/47/55',
[60754] = '1/75/75/75',
[60755] = '1/75/75/75',
[60756] = '1/75/75/75',
[60757] = '1/75/75/75',
[60758] = '1/75/75/75',
[60759] = '1/75/75/75',
[60761] = '1/75/75/75',
[60760] = '1/75/75/75',
[60969] = '1/1/3/5',
[60971] = '1/60/67/75',
[60993] = '1/60/67/75',
[60994] = '1/55/65/75',
[60990] = '1/55/65/75',
[60998] = '1/55/65/75',
[60997] = '1/55/65/75',
[60996] = '1/60/67/75',
[61000] = '1/55/65/75',
[61002] = '1/55/65/75',
[60999] = '1/60/67/75',
[61008] = '1/60/70/80',
[61009] = '1/55/65/75',
[61010] = '1/55/65/75',
[61117] = '1/20/25/30',
[61119] = '1/20/25/30',
[61120] = '1/20/25/30',
[61118] = '1/20/25/30',
[60609] = '1/1/5/10',
[60616] = '1/1/5/10',
[60606] = '1/10/20/30',
[60621] = '1/15/25/35',
[60623] = '1/20/30/40',
[60653] = '1/30/40/50',
[60663] = '1/55/65/75',
[47900] = '1/60/67/75',
[60668] = '1/60/67/75',
[60691] = '1/65/70/75',
[60707] = '1/70/72/75',
[60714] = '1/70/72/75',
[60692] = '1/75/75/75',
[60763] = '1/75/75/75',
[59621] = '1/75/75/75',
[59625] = '1/75/75/75',
[59619] = '1/75/75/75',
[60767] = '1/75/75/75',
[58301] = '1/1/10/20',
[182125] = '1/100/100/100',
[58312] = '1/300/300/300',
[58320] = '1/300/300/300',
[58332] = '1/300/300/300',
[58345] = '1/300/300/300',
[58287] = '1/1/10/20',
[58316] = '1/300/300/300',
[58347] = '1/300/300/300',
[58341] = '1/300/300/300',
[59475] = '1/150/162/175',
[59478] = '1/150/162/175',
[59484] = '1/200/205/210',
[59486] = '1/200/205/210',
[59387] = '1/205/210/215',
[60336] = '1/215/220/225',
[59489] = '1/250/255/260',
[59490] = '1/250/255/260',
[59493] = '1/290/295/300',
[59494] = '1/290/295/300',
[59495] = '1/40/45/50',
[59496] = '1/40/45/50',
[60337] = '1/1/10/20',
[59497] = '1/50/62/75',
[59498] = '1/50/62/75',
[61471] = '1/25/32/40',
[61481] = '1/50/57/65',
[61482] = '1/50/57/65',
[61483] = '1/50/57/65',
[22967] = '1/300/300/300',
[62045] = '1/205/217/230',
[62044] = '1/150/162/175',
[62051] = '1/270/282/295',
[62050] = '1/90/102/115',
[62049] = '1/210/222/235',
[56965] = '1/300/300/300',
[62176] = '1/75/75/75',
[62177] = '1/75/75/75',
[62202] = '1/75/75/75',
[62242] = '1/70/72/75',
[62256] = '1/75/75/75',
[62257] = '1/75/75/75',
[62271] = '1/75/75/75',
[62350] = '1/1/43/85',
[62409] = '1/5/10/15',
[62410] = '1/40/47/55',
[62448] = '1/60/65/70',
[62941] = '1/10/15/20',
[62948] = '1/75/75/75',
[62959] = '1/20/30/40',
[63182] = '1/75/75/75',
[63190] = '1/75/75/75',
[63191] = '1/75/75/75',
[63189] = '1/75/75/75',
[63187] = '1/75/75/75',
[63188] = '1/75/75/75',
[63192] = '1/75/75/75',
[63194] = '1/75/75/75',
[63195] = '1/75/75/75',
[63196] = '1/75/75/75',
[63201] = '1/75/75/75',
[63198] = '1/75/75/75',
[63199] = '1/75/75/75',
[63200] = '1/75/75/75',
[63197] = '1/75/75/75',
[63732] = '1/160/180/200',
[63742] = '1/150/167/185',
[63743] = '1/210/220/230',
[63746] = '1/245/265/285',
[63750] = '1/270/280/290',
[63924] = '1/65/70/75',
[64051] = '1/1/10/20',
[64053] = '1/1/10/20',
[64054] = '1/250/275/300',
[64250] = '1/300/300/300',
[64260] = '1/1/10/20',
[64358] = '1/25/37/50',
[64441] = '1/75/75/75',
[64579] = '1/75/75/75',
[64661] = '1/1/3/5',
[63206] = '1/75/75/75',
[63205] = '1/75/75/75',
[63204] = '1/75/75/75',
[63203] = '1/75/75/75',
[64725] = '1/65/70/75',
[64726] = '1/65/70/75',
[64727] = '1/65/70/75',
[64728] = '1/65/70/75',
[64729] = '1/30/35/40',
[64730] = '1/35/40/45',
[65454] = '1/30/35/40',
[66034] = '1/270/282/295',
[66035] = '1/210/222/235',
[66036] = '1/150/162/175',
[66037] = '1/205/217/230',
[66038] = '1/90/102/115',
[66428] = '1/65/70/75',
[66429] = '1/65/70/75',
[66431] = '1/65/70/75',
[66432] = '1/65/70/75',
[66434] = '1/65/70/75',
[66435] = '1/65/70/75',
[66439] = '1/65/70/75',
[66441] = '1/65/70/75',
[66442] = '1/65/70/75',
[66443] = '1/65/70/75',
[66445] = '1/65/70/75',
[66446] = '1/65/70/75',
[66447] = '1/65/70/75',
[66448] = '1/65/70/75',
[66450] = '1/65/70/75',
[66452] = '1/65/70/75',
[66453] = '1/65/70/75',
[66497] = '1/65/70/75',
[66498] = '1/65/70/75',
[66499] = '1/65/70/75',
[66501] = '1/65/70/75',
[66502] = '1/65/70/75',
[66505] = '1/65/70/75',
[66506] = '1/65/70/75',
[66554] = '1/65/70/75',
[66556] = '1/65/70/75',
[66557] = '1/65/70/75',
[66560] = '1/65/70/75',
[66561] = '1/65/70/75',
[66562] = '1/65/70/75',
[66567] = '1/65/70/75',
[66568] = '1/65/70/75',
[66569] = '1/65/70/75',
[66570] = '1/65/70/75',
[66571] = '1/65/70/75',
[66572] = '1/65/70/75',
[66573] = '1/65/70/75',
[66574] = '1/65/70/75',
[66576] = '1/65/70/75',
[66579] = '1/65/70/75',
[66581] = '1/65/70/75',
[66582] = '1/65/70/75',
[66583] = '1/65/70/75',
[66584] = '1/65/70/75',
[66585] = '1/65/70/75',
[66586] = '1/65/70/75',
[66338] = '1/65/70/75',
[66664] = '1/65/70/75',
[66658] = '1/65/70/75',
[66659] = '1/65/70/75',
[66660] = '1/65/70/75',
[66662] = '1/65/70/75',
[66663] = '1/65/70/75',
[67091] = '1/75/75/75',
[67092] = '1/75/75/75',
[67093] = '1/75/75/75',
[67094] = '1/75/75/75',
[67095] = '1/75/75/75',
[67096] = '1/75/75/75',
[67131] = '1/75/75/75',
[67132] = '1/75/75/75',
[67133] = '1/75/75/75',
[67134] = '1/75/75/75',
[67135] = '1/75/75/75',
[67130] = '1/75/75/75',
[67080] = '1/75/75/75',
[67081] = '1/75/75/75',
[67087] = '1/75/75/75',
[67086] = '1/75/75/75',
[67085] = '1/75/75/75',
[67084] = '1/75/75/75',
[67083] = '1/75/75/75',
[67082] = '1/75/75/75',
[67136] = '1/75/75/75',
[67142] = '1/75/75/75',
[67141] = '1/75/75/75',
[67140] = '1/75/75/75',
[67139] = '1/75/75/75',
[67138] = '1/75/75/75',
[67137] = '1/75/75/75',
[67143] = '1/75/75/75',
[67064] = '1/75/75/75',
[67065] = '1/75/75/75',
[67066] = '1/75/75/75',
[67079] = '1/75/75/75',
[67144] = '1/75/75/75',
[67145] = '1/75/75/75',
[67146] = '1/75/75/75',
[67147] = '1/75/75/75',
[67326] = '1/40/45/50',
[67920] = '1/75/75/75',
[68067] = '1/75/75/75',
[68166] = '1/1/10/20',
[67839] = '1/35/40/45',
[68253] = '1/65/70/75',
[69386] = '1/65/70/75',
[69388] = '1/65/70/75',
[69385] = '1/50/62/75',
[69412] = '1/25/30/35',
[70524] = '1/250/270/290',
[70562] = '1/100/100/100',
[70563] = '1/100/100/100',
[70565] = '1/100/100/100',
[70567] = '1/100/100/100',
[70568] = '1/100/100/100',
[70566] = '1/100/100/100',
[70554] = '1/75/75/75',
[70555] = '1/75/75/75',
[70556] = '1/75/75/75',
[70557] = '1/75/75/75',
[70558] = '1/75/75/75',
[70559] = '1/75/75/75',
[70560] = '1/75/75/75',
[70561] = '1/75/75/75',
[70550] = '1/75/75/75',
[70551] = '1/75/75/75',
[70552] = '1/75/75/75',
[70553] = '1/75/75/75',
[71692] = '1/1/13/25',
[73222] = '1/1/18/35',
[73223] = '1/1/18/35',
[73224] = '1/1/18/35',
[73225] = '1/1/18/35',
[73226] = '1/1/18/35',
[73227] = '1/1/18/35',
[73228] = '1/1/18/35',
[73229] = '1/1/18/35',
[73230] = '1/1/18/35',
[73231] = '1/1/18/35',
[73232] = '1/1/18/35',
[73233] = '1/1/18/35',
[73234] = '1/1/18/35',
[73239] = '1/1/18/35',
[73240] = '1/1/18/35',
[73241] = '1/1/18/35',
[73242] = '1/1/18/35',
[73243] = '1/1/18/35',
[73244] = '1/1/18/35',
[73245] = '1/1/18/35',
[73246] = '1/1/18/35',
[73247] = '1/1/18/35',
[73248] = '1/1/18/35',
[73249] = '1/1/18/35',
[73250] = '1/1/18/35',
[73258] = '1/1/18/35',
[73259] = '1/1/18/35',
[73260] = '1/1/18/35',
[73262] = '1/1/18/35',
[73263] = '1/1/18/35',
[73264] = '1/1/18/35',
[73265] = '1/1/18/35',
[73266] = '1/1/18/35',
[73267] = '1/1/18/35',
[73268] = '1/1/18/35',
[73269] = '1/1/18/35',
[73270] = '1/1/18/35',
[73271] = '1/1/18/35',
[73272] = '1/1/18/35',
[73273] = '1/1/18/35',
[73274] = '1/1/18/35',
[73275] = '1/1/18/35',
[73276] = '1/1/18/35',
[73277] = '1/1/18/35',
[73278] = '1/1/18/35',
[73279] = '1/1/18/35',
[73280] = '1/1/18/35',
[73281] = '1/1/18/35',
[73318] = '1/1/1/1',
[73335] = '1/50/57/65',
[73336] = '1/50/57/65',
[73337] = '1/50/57/65',
[73338] = '1/50/57/65',
[73339] = '1/50/57/65',
[73340] = '1/50/57/65',
[73341] = '1/50/57/65',
[73343] = '1/50/57/65',
[73344] = '1/50/57/65',
[73345] = '1/50/57/65',
[73346] = '1/50/57/65',
[73347] = '1/50/57/65',
[73348] = '1/50/57/65',
[73349] = '1/50/57/65',
[73350] = '1/50/57/65',
[73351] = '1/50/57/65',
[73352] = '1/50/57/65',
[73353] = '1/50/57/65',
[73354] = '1/50/57/65',
[73355] = '1/50/57/65',
[73356] = '1/50/57/65',
[73357] = '1/50/57/65',
[73358] = '1/50/57/65',
[73359] = '1/50/57/65',
[73360] = '1/50/57/65',
[73361] = '1/50/57/65',
[73362] = '1/50/57/65',
[73364] = '1/50/57/65',
[73365] = '1/50/57/65',
[73366] = '1/50/57/65',
[73367] = '1/50/57/65',
[73368] = '1/50/57/65',
[73369] = '1/50/57/65',
[73370] = '1/50/57/65',
[73371] = '1/50/57/65',
[73372] = '1/50/57/65',
[73373] = '1/50/57/65',
[73374] = '1/50/57/65',
[73375] = '1/50/57/65',
[73376] = '1/50/57/65',
[73377] = '1/50/57/65',
[73378] = '1/50/57/65',
[73379] = '1/50/57/65',
[73380] = '1/50/57/65',
[73381] = '1/50/57/65',
[73382] = '1/50/57/65',
[73383] = '1/50/57/65',
[73384] = '1/50/57/65',
[73396] = '1/55/57/60',
[73399] = '1/55/57/60',
[73397] = '1/55/57/60',
[73398] = '1/55/57/60',
[73409] = '1/55/57/60',
[73407] = '1/55/57/60',
[73400] = '1/55/57/60',
[73408] = '1/55/57/60',
[73404] = '1/55/57/60',
[73406] = '1/55/57/60',
[73401] = '1/55/57/60',
[73402] = '1/55/57/60',
[73403] = '1/55/57/60',
[73405] = '1/55/57/60',
[73468] = '1/65/70/75',
[73466] = '1/65/70/75',
[73465] = '1/65/70/75',
[73472] = '1/65/70/75',
[73469] = '1/65/70/75',
[73470] = '1/65/70/75',
[73474] = '1/65/70/75',
[73467] = '1/65/70/75',
[73464] = '1/65/70/75',
[73476] = '1/65/70/75',
[73475] = '1/65/70/75',
[73473] = '1/65/70/75',
[73471] = '1/65/70/75',
[73478] = '1/75/75/75',
[73627] = '1/40/50/60',
[73626] = '1/35/45/55',
[73625] = '1/30/40/50',
[73623] = '1/75/75/75',
[73622] = '1/1/8/15',
[73621] = '1/50/55/60',
[73620] = '1/20/25/30',
[73979] = '1/5000/5000/5000',
[74132] = '1/1/5/10',
[74189] = '1/1/5/10',
[74191] = '1/1/5/10',
[74192] = '1/1/10/20',
[74193] = '1/1/10/20',
[74195] = '1/10/12/15',
[74197] = '1/10/12/15',
[74198] = '1/15/25/35',
[74199] = '1/15/25/35',
[74200] = '1/20/30/40',
[74201] = '1/20/30/40',
[74202] = '1/25/35/45',
[74207] = '1/25/35/45',
[74211] = '1/30/40/50',
[74212] = '1/30/40/50',
[74213] = '1/35/45/55',
[74214] = '1/35/45/55',
[74220] = '1/40/50/60',
[74223] = '1/40/50/60',
[74225] = '1/45/55/65',
[74226] = '1/45/55/65',
[74229] = '1/50/60/70',
[74230] = '1/50/60/70',
[74231] = '1/55/65/75',
[74232] = '1/55/65/75',
[74234] = '1/60/67/75',
[74235] = '1/60/67/75',
[74236] = '1/60/62/65',
[74237] = '1/65/70/75',
[74238] = '1/70/72/75',
[74239] = '1/70/72/75',
[74240] = '1/70/72/75',
[74242] = '1/75/75/75',
[74244] = '1/75/75/75',
[74246] = '1/75/75/75',
[74247] = '1/75/75/75',
[74248] = '1/75/75/75',
[74250] = '1/75/75/75',
[74251] = '1/75/75/75',
[74252] = '1/75/75/75',
[74253] = '1/75/75/75',
[74254] = '1/75/75/75',
[74255] = '1/75/75/75',
[74256] = '1/75/75/75',
[74258] = '1/1/1/1',
[74519] = '1/1/1/1',
[74517] = '1/1/1/1',
[74537] = '1/50/62/75',
[74530] = '1/1/25/50',
[74529] = '1/75/75/75',
[75156] = '1/1/1/1',
[75298] = '1/75/75/75',
[75288] = '1/55/60/65',
[74964] = '1/1/3/5',
[75300] = '1/75/75/75',
[75248] = '1/5/10/15',
[75252] = '1/10/15/20',
[75249] = '1/5/10/15',
[75256] = '1/20/25/30',
[75253] = '1/20/22/25',
[75254] = '1/15/20/25',
[75257] = '1/25/27/30',
[75251] = '1/10/15/20',
[75141] = '1/75/75/75',
[75142] = '1/75/75/75',
[75145] = '1/75/75/75',
[75144] = '1/75/75/75',
[75146] = '1/75/75/75',
[75299] = '1/75/75/75',
[75293] = '1/65/70/75',
[75297] = '1/75/75/75',
[75270] = '1/55/60/65',
[75306] = '1/75/75/75',
[75295] = '1/70/72/75',
[75307] = '1/75/75/75',
[75305] = '1/75/75/75',
[75291] = '1/60/65/70',
[75264] = '1/40/42/45',
[75247] = '1/1/3/5',
[75250] = '1/15/17/20',
[75269] = '1/65/70/75',
[75294] = '1/70/72/75',
[75290] = '1/55/60/65',
[75304] = '1/75/75/75',
[75296] = '1/75/75/75',
[75302] = '1/75/75/75',
[75303] = '1/75/75/75',
[75292] = '1/65/70/75',
[75301] = '1/75/75/75',
[75255] = '1/20/22/25',
[75289] = '1/75/75/75',
[75268] = '1/50/52/55',
[75308] = '1/75/75/75',
[75265] = '1/40/42/45',
[75309] = '1/75/75/75',
[75310] = '1/75/75/75',
[75258] = '1/25/30/35',
[75261] = '1/30/35/40',
[75259] = '1/25/30/35',
[75266] = '1/50/52/55',
[75262] = '1/35/40/45',
[75263] = '1/35/40/45',
[75267] = '1/50/52/55',
[75260] = '1/35/37/40',
[75597] = '1/60/67/75',
[76179] = '1/10/12/15',
[76180] = '1/10/12/15',
[76181] = '1/20/22/25',
[76182] = '1/30/32/35',
[76258] = '1/40/42/45',
[76259] = '1/50/52/55',
[76260] = '1/50/52/55',
[76261] = '1/60/62/65',
[76262] = '1/10/12/15',
[76263] = '1/10/12/15',
[76264] = '1/20/22/25',
[76265] = '1/30/32/35',
[76266] = '1/40/42/45',
[76267] = '1/50/52/55',
[76269] = '1/60/62/65',
[76270] = '1/60/62/65',
[76280] = '1/10/12/15',
[76281] = '1/10/12/15',
[76283] = '1/20/22/25',
[76285] = '1/30/32/35',
[76286] = '1/40/42/45',
[76287] = '1/40/42/45',
[76288] = '1/50/52/55',
[76289] = '1/60/62/65',
[76291] = '1/10/12/15',
[76293] = '1/30/32/35',
[76433] = '1/25/27/30',
[76434] = '1/30/32/35',
[76435] = '1/40/42/45',
[76436] = '1/40/42/45',
[76437] = '1/40/42/45',
[76438] = '1/30/35/40',
[76439] = '1/75/75/75',
[76440] = '1/75/75/75',
[76441] = '1/50/52/55',
[76442] = '1/55/60/65',
[76443] = '1/75/75/75',
[76444] = '1/70/72/75',
[76445] = '1/75/75/75',
[76446] = '1/70/72/75',
[76447] = '1/75/75/75',
[76448] = '1/70/72/75',
[76449] = '1/75/75/75',
[76450] = '1/75/75/75',
[76451] = '1/75/75/75',
[76452] = '1/75/75/75',
[76453] = '1/75/75/75',
[76454] = '1/75/75/75',
[76455] = '1/75/75/75',
[76456] = '1/60/62/65',
[76457] = '1/65/67/70',
[76458] = '1/70/72/75',
[76459] = '1/75/75/75',
[76461] = '1/80/82/85',
[76462] = '1/75/75/75',
[76463] = '1/75/75/75',
[76464] = '1/75/75/75',
[76465] = '1/60/62/65',
[76466] = '1/65/67/70',
[76467] = '1/70/72/75',
[76468] = '1/75/75/75',
[76469] = '1/80/82/85',
[76470] = '1/75/75/75',
[76471] = '1/75/75/75',
[76472] = '1/75/75/75',
[76474] = '1/30/32/35',
[76666] = '1/1/1/1',
[74493] = '1/1/3/5',
[78670] = '1/1/1/1',
[80479] = '1/10/15/20',
[80486] = '1/25/30/35',
[80478] = '1/5/10/15',
[80488] = '1/30/35/40',
[80491] = '1/35/40/45',
[80493] = '1/45/50/55',
[80484] = '1/20/25/30',
[80497] = '1/50/55/60',
[80480] = '1/10/15/20',
[80719] = '1/55/60/65',
[80720] = '1/60/65/70',
[80721] = '1/65/70/75',
[80723] = '1/65/70/75',
[80477] = '1/5/10/15',
[80496] = '1/45/50/55',
[80508] = '1/60/62/65',
[80490] = '1/30/35/40',
[80487] = '1/25/30/35',
[80498] = '1/50/55/60',
[80494] = '1/40/45/50',
[80482] = '1/20/25/30',
[80725] = '1/75/75/75',
[80269] = '1/20/25/30',
[80495] = '1/40/45/50',
[80726] = '1/75/75/75',
[80492] = '1/35/40/45',
[80247] = '1/75/75/75',
[80248] = '1/70/72/75',
[80251] = '1/60/65/70',
[80250] = '1/65/70/75',
[80245] = '1/75/75/75',
[80243] = '1/75/75/75',
[78866] = '1/60/65/70',
[80246] = '1/70/72/75',
[80244] = '1/75/75/75',
[80237] = '1/75/75/75',
[80481] = '1/15/20/25',
[80731] = '1/1/1/1',
[80451] = '1/1/1/1',
[81199] = '1/1/1/1',
[81725] = '1/75/75/75',
[81722] = '1/75/75/75',
[81724] = '1/75/75/75',
[81716] = '1/75/75/75',
[81720] = '1/75/75/75',
[81715] = '1/75/75/75',
[81714] = '1/75/75/75',
[82774] = '1/1/1/1',
[84038] = '1/1/13/25',
[84432] = '1/75/75/75',
[84431] = '1/75/75/75',
[84430] = '1/75/75/75',
[84429] = '1/65/70/75',
[84428] = '1/75/75/75',
[84427] = '1/1/13/25',
[84425] = '1/1/13/25',
[84421] = '1/70/72/75',
[84420] = '1/75/75/75',
[84418] = '1/75/75/75',
[84417] = '1/75/75/75',
[84416] = '1/70/72/75',
[84415] = '1/65/67/70',
[84413] = '1/70/72/75',
[84412] = '1/70/72/75',
[84411] = '1/55/55/55',
[84410] = '1/45/47/50',
[84409] = '1/35/42/50',
[84408] = '1/45/47/50',
[84406] = '1/30/32/35',
[84403] = '1/10/17/25',
[82200] = '1/1/13/25',
[78379] = '1/1/3/5',
[78380] = '1/20/25/30',
[78388] = '1/20/25/30',
[78396] = '1/30/35/40',
[78398] = '1/10/15/20',
[78399] = '1/25/30/35',
[78405] = '1/25/30/35',
[78406] = '1/35/40/45',
[78407] = '1/25/30/35',
[78410] = '1/10/15/20',
[78411] = '1/35/40/45',
[78415] = '1/15/20/25',
[78416] = '1/15/20/25',
[78419] = '1/35/40/45',
[78420] = '1/40/45/50',
[78423] = '1/60/62/65',
[78424] = '1/55/57/60',
[78427] = '1/40/45/50',
[78428] = '1/40/45/50',
[78432] = '1/45/50/55',
[78433] = '1/45/50/55',
[78436] = '1/35/37/40',
[78437] = '1/40/45/50',
[78438] = '1/60/62/65',
[78439] = '1/60/62/65',
[78444] = '1/65/70/75',
[78445] = '1/65/70/75',
[78446] = '1/65/70/75',
[78447] = '1/65/70/75',
[78448] = '1/65/70/75',
[78449] = '1/65/70/75',
[78450] = '1/65/70/75',
[78451] = '1/65/70/75',
[78452] = '1/70/72/75',
[78453] = '1/70/72/75',
[78454] = '1/70/72/75',
[78455] = '1/70/72/75',
[78456] = '1/70/72/75',
[78457] = '1/70/72/75',
[78458] = '1/70/72/75',
[78459] = '1/70/72/75',
[78460] = '1/70/72/75',
[78461] = '1/70/72/75',
[78462] = '1/70/72/75',
[78463] = '1/70/72/75',
[78464] = '1/75/75/75',
[78467] = '1/75/75/75',
[78468] = '1/75/75/75',
[78469] = '1/75/75/75',
[78470] = '1/75/75/75',
[78471] = '1/75/75/75',
[78473] = '1/75/75/75',
[78474] = '1/75/75/75',
[78475] = '1/75/75/75',
[78476] = '1/75/75/75',
[78477] = '1/75/75/75',
[78478] = '1/75/75/75',
[78479] = '1/75/75/75',
[78480] = '1/75/75/75',
[78481] = '1/75/75/75',
[78482] = '1/75/75/75',
[78483] = '1/75/75/75',
[78484] = '1/75/75/75',
[78485] = '1/75/75/75',
[78486] = '1/75/75/75',
[78487] = '1/75/75/75',
[78488] = '1/75/75/75',
[78489] = '1/75/75/75',
[78490] = '1/75/75/75',
[84950] = '1/1/3/5',
[85785] = '1/55/60/65',
[86005] = '1/30/32/35',
[86004] = '1/1/1/1',
[86008] = '1/1/1/1',
[86857] = '1/525/525/525',
[86866] = '1/525/525/525',
[86865] = '1/525/525/525',
[86864] = '1/525/525/525',
[88003] = '1/65/70/75',
[88004] = '1/65/70/75',
[88005] = '1/65/70/75',
[88034] = '1/65/70/75',
[88006] = '1/1/8/15',
[88011] = '1/75/75/75',
[88012] = '1/15/27/40',
[88013] = '1/60/62/65',
[88014] = '1/65/70/75',
[88015] = '1/1/5/10',
[88016] = '1/65/70/75',
[88017] = '1/1/10/20',
[88018] = '1/40/50/60',
[88019] = '1/75/75/75',
[88020] = '1/65/70/75',
[88021] = '1/40/47/55',
[88022] = '1/5/10/15',
[88024] = '1/15/27/40',
[88025] = '1/65/70/75',
[88028] = '1/15/27/40',
[88030] = '1/15/27/40',
[88031] = '1/65/70/75',
[88033] = '1/40/47/55',
[88035] = '1/15/27/40',
[88036] = '1/75/75/75',
[88037] = '1/15/27/40',
[88039] = '1/65/70/75',
[88042] = '1/65/70/75',
[88044] = '1/75/75/75',
[88045] = '1/5/10/15',
[88046] = '1/40/47/55',
[88047] = '1/15/27/40',
[88053] = '1/1/1/1',
[88181] = '1/525/525/525',
[88180] = '1/525/525/525',
[88262] = '1/525/525/525',
[88908] = '1/525/525/525',
[88907] = '1/525/525/525',
[88910] = '1/525/525/525',
[88909] = '1/525/525/525',
[88930] = '1/525/525/525',
[88929] = '1/525/525/525',
[88961] = '1/1/1/1',
[89014] = '1/525/525/525',
[89012] = '1/525/525/525',
[89009] = '1/525/525/525',
[89244] = '1/75/75/75',
[86654] = '1/75/75/75',
[86375] = '1/40/47/55',
[86401] = '1/40/47/55',
[86402] = '1/40/47/55',
[86403] = '1/40/47/55',
[86609] = '1/10/17/25',
[86615] = '1/75/75/75',
[86616] = '1/35/37/40',
[86640] = '1/35/37/40',
[86641] = '1/70/72/75',
[86642] = '1/70/72/75',
[86643] = '1/70/72/75',
[86644] = '1/20/30/40',
[86645] = '1/30/40/50',
[86646] = '1/40/50/60',
[86648] = '1/50/52/55',
[86649] = '1/65/70/75',
[86652] = '1/75/75/75',
[86653] = '1/75/75/75',
[89368] = '1/1/5/10',
[89369] = '1/20/25/30',
[89370] = '1/25/30/35',
[89371] = '1/10/15/20',
[89372] = '1/15/20/25',
[89373] = '1/5/10/15',
[89693] = '1/525/525/525',
[89696] = '1/525/525/525',
[89701] = '1/525/525/525',
[89711] = '1/525/525/525',
[89717] = '1/525/525/525',
[89718] = '1/1/1/1',
[89719] = '1/1/1/1',
[89720] = '1/1/1/1',
[89721] = '1/1/1/1',
[89722] = '1/1/1/1',
[89890] = '1/525/525/525',
[89891] = '1/525/525/525',
[89893] = '1/525/525/525',
[89894] = '1/525/525/525',
[89896] = '1/525/525/525',
[89964] = '1/1/1/1',
[90410] = '1/525/525/525',
[90411] = '1/525/525/525',
[90412] = '1/525/525/525',
[90413] = '1/525/525/525',
[90415] = '1/525/525/525',
[90419] = '1/525/525/525',
[90420] = '1/525/525/525',
[90421] = '1/525/525/525',
[90423] = '1/525/525/525',
[90429] = '1/525/525/525',
[90458] = '1/525/525/525',
[90453] = '1/525/525/525',
[90452] = '1/525/525/525',
[90451] = '1/525/525/525',
[90433] = '1/525/525/525',
[90432] = '1/525/525/525',
[90504] = '1/525/525/525',
[90493] = '1/525/525/525',
[90506] = '1/525/525/525',
[90509] = '1/525/525/525',
[90518] = '1/525/525/525',
[90519] = '1/525/525/525',
[90521] = '1/525/525/525',
[90553] = '1/525/525/525',
[90616] = '1/525/525/525',
[90614] = '1/525/525/525',
[90612] = '1/525/525/525',
[90611] = '1/525/525/525',
[90610] = '1/525/525/525',
[90609] = '1/525/525/525',
[90608] = '1/525/525/525',
[90581] = '1/525/525/525',
[90558] = '1/525/525/525',
[90619] = '1/525/525/525',
[90618] = '1/525/525/525',
[90617] = '1/525/525/525',
[90647] = '1/1/1/1',
[90720] = '1/525/525/525',
[90622] = '1/525/525/525',
[90732] = '1/525/525/525',
[90730] = '1/525/525/525',
[90728] = '1/525/525/525',
[90734] = '1/525/525/525',
[90833] = '1/525/525/525',
[90832] = '1/525/525/525',
[90831] = '1/525/525/525',
[90843] = '1/525/525/525',
[90860] = '1/525/525/525',
[90853] = '1/525/525/525',
[90864] = '1/525/525/525',
[90861] = '1/525/525/525',
[90987] = '1/525/525/525',
[90984] = '1/525/525/525',
[90983] = '1/525/525/525',
[90975] = '1/525/525/525',
[90974] = '1/525/525/525',
[90968] = '1/525/525/525',
[91084] = '1/525/525/525',
[91014] = '1/525/525/525',
[91012] = '1/525/525/525',
[91008] = '1/525/525/525',
[90997] = '1/525/525/525',
[90988] = '1/525/525/525',
[91132] = '1/525/525/525',
[91089] = '1/525/525/525',
[91215] = '1/525/525/525',
[91214] = '1/525/525/525',
[91211] = '1/525/525/525',
[91209] = '1/525/525/525',
[91197] = '1/525/525/525',
[91191] = '1/525/525/525',
[91188] = '1/525/525/525',
[91170] = '1/525/525/525',
[91133] = '1/525/525/525',
[91225] = '1/525/525/525',
[91224] = '1/525/525/525',
[91223] = '1/525/525/525',
[91221] = '1/525/525/525',
[91219] = '1/525/525/525',
[91227] = '1/525/525/525',
[91226] = '1/525/525/525',
[91757] = '1/525/525/525',
[91761] = '1/525/525/525',
[91762] = '1/525/525/525',
[91766] = '1/525/525/525',
[91769] = '1/525/525/525',
[91773] = '1/525/525/525',
[91792] = '1/525/525/525',
[91790] = '1/525/525/525',
[91785] = '1/525/525/525',
[91782] = '1/525/525/525',
[91780] = '1/525/525/525',
[91779] = '1/525/525/525',
[91775] = '1/525/525/525',
[91793] = '1/525/525/525',
[92026] = '1/90/100/110',
[92168] = '1/525/525/525',
[92163] = '1/525/525/525',
[92148] = '1/525/525/525',
[92145] = '1/525/525/525',
[92139] = '1/525/525/525',
[92137] = '1/525/525/525',
[76178] = '1/1/3/5',
[92643] = '1/75/75/75',
[92688] = '1/75/75/75',
[92806] = '75/1/1/1',
[92807] = '150/1/1/1',
[92808] = '225/1/1/1',
[92809] = '300/1/1/1',
[92810] = '375/1/1/1',
[92811] = '450/1/1/1',
[92812] = '525/1/1/1',
[74268] = '1/1/1/1',
[93440] = '1/525/525/525',
[93441] = '1/525/525/525',
[93444] = '1/525/525/525',
[93443] = '1/525/525/525',
[93442] = '1/525/525/525',
[89895] = '1/525/525/525',
[93741] = '1/80/100/120',
[73495] = '1/35/45/55',
[94162] = '1/55/60/65',
[73494] = '1/1/18/35',
[73496] = '1/1/18/35',
[73497] = '1/45/55/65',
[73520] = '1/75/75/75',
[73503] = '1/75/75/75',
[73502] = '1/75/75/75',
[73498] = '1/75/75/75',
[73521] = '1/75/75/75',
[73506] = '1/75/75/75',
[73505] = '1/75/75/75',
[73504] = '1/75/75/75',
[90464] = '1/525/525/525',
[93935] = '1/1/5/10',
[93328] = '1/75/75/75',
[93841] = '1/75/75/75',
[93843] = '1/75/75/75',
[94718] = '1/75/75/75',
[94732] = '1/75/75/75',
[94743] = '1/75/75/75',
[84424] = '1/1/13/25',
[95471] = '1/30/40/50',
[95703] = '1/25/27/30',
[94748] = '1/30/35/40',
[82207] = '1/425/452/480',
[95756] = '1/50/57/65',
[95755] = '1/50/57/65',
[95754] = '1/50/57/65',
[95707] = '1/75/75/75',
[95705] = '1/75/75/75',
[96133] = '1/40/50/60',
[96253] = '1/60/62/65',
[96254] = '1/60/62/65',
[96252] = '1/60/62/65',
[96257] = '1/65/70/75',
[96256] = '1/65/70/75',
[96255] = '1/65/70/75',
[96264] = '1/75/75/75',
[96262] = '1/75/75/75',
[96261] = '1/75/75/75',
[96226] = '1/50/57/65',
[98921] = '1/75/75/75',
[99439] = '1/75/75/75',
[99440] = '1/75/75/75',
[99441] = '1/75/75/75',
[99452] = '1/75/75/75',
[99453] = '1/75/75/75',
[99454] = '1/75/75/75',
[99443] = '1/75/75/75',
[99445] = '1/75/75/75',
[99446] = '1/75/75/75',
[99447] = '1/75/75/75',
[99455] = '1/75/75/75',
[99456] = '1/75/75/75',
[99457] = '1/75/75/75',
[99458] = '1/75/75/75',
[99448] = '1/75/75/75',
[99449] = '1/75/75/75',
[99459] = '1/75/75/75',
[99460] = '1/75/75/75',
[99536] = '1/60/62/65',
[99535] = '1/60/62/65',
[99537] = '1/50/52/55',
[99544] = '1/75/75/75',
[99543] = '1/75/75/75',
[99542] = '1/75/75/75',
[99541] = '1/65/70/75',
[99540] = '1/65/70/75',
[99539] = '1/65/70/75',
[100587] = '1/75/75/75',
[100586] = '1/70/72/75',
[98560] = '1/525/525/525',
[98582] = '1/525/525/525',
[98556] = '1/525/525/525',
[98588] = '1/525/525/525',
[98569] = '1/525/525/525',
[98533] = '1/525/525/525',
[99652] = '1/75/75/75',
[99653] = '1/75/75/75',
[99654] = '1/75/75/75',
[99655] = '1/75/75/75',
[99656] = '1/75/75/75',
[99657] = '1/75/75/75',
[99658] = '1/75/75/75',
[99660] = '1/75/75/75',
[100687] = '1/75/75/75',
[100583] = '1/70/72/75',
[100585] = '1/40/42/45',
[101599] = '1/75/75/75',
[101735] = '1/75/75/75',
[101740] = '1/75/75/75',
[101741] = '1/75/75/75',
[101742] = '1/75/75/75',
[101743] = '1/75/75/75',
[101744] = '1/75/75/75',
[101745] = '1/75/75/75',
[101746] = '1/75/75/75',
[101747] = '1/75/75/75',
[101748] = '1/75/75/75',
[101749] = '1/75/75/75',
[101750] = '1/75/75/75',
[101751] = '1/75/75/75',
[101752] = '1/75/75/75',
[101753] = '1/75/75/75',
[101754] = '1/75/75/75',
[101755] = '1/75/75/75',
[101756] = '1/75/75/75',
[101757] = '1/75/75/75',
[101758] = '1/75/75/75',
[101759] = '1/75/75/75',
[101760] = '1/75/75/75',
[101761] = '1/75/75/75',
[101762] = '1/75/75/75',
[101763] = '1/75/75/75',
[101764] = '1/75/75/75',
[101765] = '1/75/75/75',
[101766] = '1/75/75/75',
[101767] = '1/75/75/75',
[101768] = '1/75/75/75',
[101769] = '1/75/75/75',
[101770] = '1/75/75/75',
[101771] = '1/75/75/75',
[101772] = '1/75/75/75',
[101773] = '1/75/75/75',
[101774] = '1/75/75/75',
[101775] = '1/75/75/75',
[101776] = '1/75/75/75',
[101777] = '1/75/75/75',
[101778] = '1/75/75/75',
[101779] = '1/75/75/75',
[101780] = '1/75/75/75',
[101781] = '1/75/75/75',
[101782] = '1/75/75/75',
[101783] = '1/75/75/75',
[101784] = '1/75/75/75',
[101785] = '1/75/75/75',
[101786] = '1/75/75/75',
[101787] = '1/75/75/75',
[101788] = '1/75/75/75',
[101789] = '1/75/75/75',
[101790] = '1/75/75/75',
[101791] = '1/75/75/75',
[101792] = '1/75/75/75',
[101793] = '1/75/75/75',
[101794] = '1/75/75/75',
[101795] = '1/75/75/75',
[101796] = '1/75/75/75',
[101797] = '1/75/75/75',
[101798] = '1/75/75/75',
[101799] = '1/75/75/75',
[101800] = '1/75/75/75',
[101801] = '1/75/75/75',
[101802] = '1/75/75/75',
[101803] = '1/75/75/75',
[101804] = '1/75/75/75',
[101924] = '1/75/75/75',
[101925] = '1/75/75/75',
[101928] = '1/75/75/75',
[101929] = '1/75/75/75',
[101931] = '1/75/75/75',
[101932] = '1/75/75/75',
[101933] = '1/75/75/75',
[101934] = '1/75/75/75',
[101935] = '1/75/75/75',
[101936] = '1/75/75/75',
[101937] = '1/75/75/75',
[101939] = '1/75/75/75',
[101940] = '1/75/75/75',
[101941] = '1/75/75/75',
[101920] = '1/75/75/75',
[101921] = '1/75/75/75',
[101922] = '1/75/75/75',
[101923] = '1/75/75/75',
[102161] = '1/1/1/1',
[102167] = '1/75/75/75',
[102165] = '1/1/25/50',
[102366] = '1/1/5/10',
[104115] = '1/75/75/75',
[104237] = '1/1/5/10',
[104297] = '1/1/5/10',
[104381] = '1/1/1/1',
[104698] = '1/15/32/50',
[105190] = '1/75/75/75',
[105194] = '1/75/75/75',
[105206] = '1/1/1/1',
[105518] = '1/120/122/125',
[106947] = '1/75/75/75',
[107907] = '1/300/300/300',
[110393] = '1/1/1/1',
[110396] = '1/1/1/1',
[110400] = '1/1/1/1',
[110403] = '1/1/1/1',
[110413] = '1/1/1/1',
[110417] = '1/1/1/1',
[110420] = '1/1/1/1',
[110423] = '1/1/1/1',
[110426] = '1/1/1/1',
[111621] = '1/1/1/1',
[114764] = '1/40/52/65',
[114765] = '1/40/52/65',
[114766] = '1/75/75/75',
[114767] = '1/75/75/75',
[114774] = '1/40/52/65',
[114775] = '1/75/75/75',
[114776] = '1/75/75/75',
[114777] = '1/75/75/75',
[114778] = '1/75/75/75',
[114779] = '1/75/75/75',
[114780] = '1/75/75/75',
[114781] = '1/75/75/75',
[114782] = '1/40/52/65',
[114783] = '1/75/75/75',
[114784] = '1/75/75/75',
[114752] = '1/1/5/10',
[114753] = '1/15/27/40',
[114754] = '1/15/27/40',
[114755] = '1/15/27/40',
[114756] = '1/15/27/40',
[114757] = '1/15/27/40',
[114758] = '1/15/27/40',
[114759] = '1/40/52/65',
[114760] = '1/40/52/65',
[114761] = '1/15/27/40',
[114762] = '1/40/52/65',
[114763] = '1/40/52/65',
[114751] = '1/1/5/10',
[113968] = '1/600/600/600',
[113971] = '1/600/600/600',
[113972] = '1/600/600/600',
[113973] = '1/600/600/600',
[113974] = '1/600/600/600',
[113975] = '1/600/600/600',
[113976] = '1/600/600/600',
[113977] = '1/600/600/600',
[113978] = '1/600/600/600',
[113979] = '1/600/600/600',
[113980] = '1/600/600/600',
[113981] = '1/600/600/600',
[113982] = '1/600/600/600',
[113983] = '1/600/600/600',
[113984] = '1/600/600/600',
[113985] = '1/600/600/600',
[113986] = '1/600/600/600',
[113987] = '1/600/600/600',
[113988] = '1/600/600/600',
[113989] = '1/600/600/600',
[113990] = '1/600/600/600',
[113991] = '1/600/600/600',
[113992] = '1/600/600/600',
[113993] = '1/600/600/600',
[116497] = '1/1/3/5',
[116498] = '1/1/3/5',
[116499] = '1/1/3/5',
[114773] = '1/75/75/75',
[114772] = '1/75/75/75',
[114771] = '1/75/75/75',
[114770] = '1/75/75/75',
[114769] = '1/75/75/75',
[53344] = '1/500/505/510',
[53343] = '1/500/505/510',
[62158] = '1/500/505/510',
[104409] = '1/50/62/75',
[104407] = '1/50/62/75',
[104408] = '1/25/42/60',
[104414] = '1/75/75/75',
[104390] = '1/75/75/75',
[104391] = '1/75/75/75',
[104338] = '1/1/5/10',
[104389] = '1/75/75/75',
[104385] = '1/25/42/60',
[104395] = '1/75/75/75',
[104393] = '1/25/42/60',
[104392] = '1/25/42/60',
[104397] = '1/50/62/75',
[104398] = '1/50/62/75',
[104401] = '1/75/75/75',
[104404] = '1/1/5/10',
[104403] = '1/25/42/60',
[104416] = '1/25/42/60',
[104419] = '1/75/75/75',
[104417] = '1/50/62/75',
[104420] = '1/75/75/75',
[104445] = '1/75/75/75',
[104440] = '1/75/75/75',
[104434] = '1/75/75/75',
[104430] = '1/25/42/60',
[104442] = '1/75/75/75',
[104427] = '1/75/75/75',
[104425] = '1/50/62/75',
[120045] = '1/75/75/75',
[122633] = '1/1/3/5',
[122589] = '1/1/38/75',
[122573] = '1/1/38/75',
[122581] = '1/1/38/75',
[122590] = '1/20/47/75',
[122591] = '1/15/45/75',
[122571] = '1/15/45/75',
[122574] = '1/20/47/75',
[122575] = '1/15/45/75',
[122579] = '1/15/45/75',
[122582] = '1/20/47/75',
[122583] = '1/15/45/75',
[122587] = '1/15/45/75',
[122572] = '1/20/47/75',
[122580] = '1/20/47/75',
[122588] = '1/20/47/75',
[122569] = '1/25/50/75',
[122577] = '1/25/50/75',
[122585] = '1/25/50/75',
[122635] = '1/25/50/75',
[122613] = '1/30/52/75',
[122597] = '1/75/75/75',
[122605] = '1/30/52/75',
[122636] = '1/30/52/75',
[122637] = '1/35/55/75',
[122614] = '1/40/57/75',
[122615] = '1/40/57/75',
[122595] = '1/75/75/75',
[122598] = '1/75/75/75',
[122599] = '1/75/75/75',
[122603] = '1/40/57/75',
[122606] = '1/40/57/75',
[122607] = '1/40/57/75',
[122611] = '1/40/57/75',
[122638] = '1/40/57/75',
[122612] = '1/40/57/75',
[122596] = '1/75/75/75',
[122604] = '1/40/57/75',
[122568] = '1/40/57/75',
[122570] = '1/40/57/75',
[122576] = '1/40/57/75',
[122578] = '1/40/57/75',
[122584] = '1/40/57/75',
[122586] = '1/40/57/75',
[122621] = '1/75/75/75',
[122629] = '1/75/75/75',
[122639] = '1/45/60/75',
[122593] = '1/75/75/75',
[122601] = '1/50/62/75',
[122609] = '1/50/62/75',
[122640] = '1/50/62/75',
[122619] = '1/75/75/75',
[122622] = '1/75/75/75',
[122623] = '1/75/75/75',
[122627] = '1/75/75/75',
[122630] = '1/75/75/75',
[122631] = '1/75/75/75',
[122641] = '1/50/62/75',
[122620] = '1/75/75/75',
[122628] = '1/75/75/75',
[122617] = '1/75/75/75',
[122625] = '1/75/75/75',
[122592] = '1/75/75/75',
[122594] = '1/75/75/75',
[122600] = '1/65/70/75',
[122602] = '1/65/70/75',
[122608] = '1/65/70/75',
[122610] = '1/65/70/75',
[122642] = '1/75/75/75',
[122643] = '1/75/75/75',
[122644] = '1/75/75/75',
[122645] = '1/75/75/75',
[122646] = '1/75/75/75',
[122647] = '1/75/75/75',
[122648] = '1/75/75/75',
[122616] = '1/75/75/75',
[122618] = '1/75/75/75',
[122624] = '1/75/75/75',
[122626] = '1/75/75/75',
[122632] = '1/75/75/75',
[122649] = '1/75/75/75',
[122650] = '1/75/75/75',
[122651] = '1/75/75/75',
[122652] = '1/75/75/75',
[122653] = '1/75/75/75',
[122654] = '1/75/75/75',
[107693] = '1/75/75/75',
[107627] = '1/50/55/60',
[107645] = '1/50/55/60',
[107715] = '1/75/75/75',
[107753] = '1/75/75/75',
[122662] = '1/50/55/60',
[107646] = '1/50/55/60',
[107716] = '1/75/75/75',
[107754] = '1/75/75/75',
[107598] = '1/50/55/60',
[106960] = '1/75/75/75',
[122668] = '1/75/75/75',
[107622] = '1/50/55/60',
[107705] = '1/75/75/75',
[122675] = '1/50/55/60',
[107623] = '1/50/55/60',
[107706] = '1/75/75/75',
[122676] = '1/50/55/60',
[107756] = '1/75/75/75',
[107647] = '1/50/55/60',
[107717] = '1/75/75/75',
[107648] = '1/50/55/60',
[107718] = '1/75/75/75',
[121843] = '1/75/75/75',
[107649] = '1/50/55/60',
[107719] = '1/75/75/75',
[107694] = '1/75/75/75',
[107628] = '1/50/55/60',
[107650] = '1/50/55/60',
[107720] = '1/75/75/75',
[107624] = '1/50/55/60',
[107707] = '1/75/75/75',
[122674] = '1/50/55/60',
[107757] = '1/75/75/75',
[107599] = '1/50/55/60',
[107758] = '1/75/75/75',
[106957] = '1/75/75/75',
[107759] = '1/75/75/75',
[121844] = '1/75/75/75',
[107600] = '1/50/55/60',
[107737] = '1/75/75/75',
[107760] = '1/75/75/75',
[107695] = '1/75/75/75',
[107630] = '1/50/55/60',
[107762] = '1/75/75/75',
[107651] = '1/50/55/60',
[107721] = '1/75/75/75',
[107652] = '1/50/55/60',
[107722] = '1/75/75/75',
[107625] = '1/50/55/60',
[107708] = '1/75/75/75',
[122685] = '1/50/55/60',
[107763] = '1/75/75/75',
[107601] = '1/50/55/60',
[107738] = '1/75/75/75',
[107764] = '1/75/75/75',
[122684] = '1/50/55/60',
[107710] = '1/75/75/75',
[107640] = '1/50/55/60',
[107696] = '1/75/75/75',
[107631] = '1/50/55/60',
[122670] = '1/75/75/75',
[107697] = '1/75/75/75',
[107632] = '1/50/55/60',
[122664] = '1/75/75/75',
[107765] = '1/75/75/75',
[107653] = '1/50/55/60',
[107723] = '1/75/75/75',
[107602] = '1/50/55/60',
[107739] = '1/75/75/75',
[107654] = '1/50/55/60',
[107724] = '1/75/75/75',
[122661] = '1/50/55/60',
[107604] = '1/50/55/60',
[106955] = '1/75/75/75',
[122667] = '1/75/75/75',
[122666] = '1/75/75/75',
[107655] = '1/50/55/60',
[107725] = '1/75/75/75',
[107605] = '1/50/55/60',
[106953] = '1/75/75/75',
[107698] = '1/75/75/75',
[107633] = '1/50/55/60',
[107711] = '1/75/75/75',
[107641] = '1/50/55/60',
[107606] = '1/50/55/60',
[107740] = '1/75/75/75',
[107607] = '1/50/55/60',
[106954] = '1/75/75/75',
[107656] = '1/50/55/60',
[107726] = '1/75/75/75',
[107657] = '1/50/55/60',
[107727] = '1/75/75/75',
[107766] = '1/75/75/75',
[107626] = '1/50/55/60',
[107709] = '1/75/75/75',
[122683] = '1/50/55/60',
[107608] = '1/50/55/60',
[107742] = '1/75/75/75',
[107699] = '1/75/75/75',
[107634] = '1/50/55/60',
[122682] = '1/50/55/60',
[107712] = '1/75/75/75',
[107642] = '1/50/55/60',
[107609] = '1/50/55/60',
[107743] = '1/75/75/75',
[107658] = '1/50/55/60',
[107728] = '1/75/75/75',
[122669] = '1/75/75/75',
[107610] = '1/50/55/60',
[107744] = '1/75/75/75',
[107659] = '1/50/55/60',
[107729] = '1/75/75/75',
[107660] = '1/50/55/60',
[107730] = '1/75/75/75',
[107700] = '1/75/75/75',
[107635] = '1/50/55/60',
[107767] = '1/75/75/75',
[107768] = '1/75/75/75',
[107617] = '1/50/55/60',
[122681] = '1/50/55/60',
[122665] = '1/75/75/75',
[121841] = '1/75/75/75',
[121842] = '1/75/75/75',
[122663] = '1/50/55/60',
[107611] = '1/50/55/60',
[106956] = '1/75/75/75',
[107612] = '1/50/55/60',
[107745] = '1/75/75/75',
[107701] = '1/75/75/75',
[107636] = '1/50/55/60',
[107661] = '1/50/55/60',
[107731] = '1/75/75/75',
[122672] = '1/75/75/75',
[122680] = '1/50/55/60',
[107713] = '1/75/75/75',
[107643] = '1/50/55/60',
[107619] = '1/50/55/60',
[106950] = '1/75/75/75',
[122678] = '1/50/55/60',
[107702] = '1/75/75/75',
[107637] = '1/50/55/60',
[107620] = '1/50/55/60',
[106949] = '1/75/75/75',
[122677] = '1/50/55/60',
[107662] = '1/50/55/60',
[107732] = '1/75/75/75',
[107663] = '1/50/55/60',
[107733] = '1/75/75/75',
[107613] = '1/50/55/60',
[107746] = '1/75/75/75',
[107621] = '1/50/55/60',
[106948] = '1/75/75/75',
[122679] = '1/50/55/60',
[107714] = '1/75/75/75',
[107644] = '1/50/55/60',
[107665] = '1/50/55/60',
[107734] = '1/75/75/75',
[122673] = '1/75/75/75',
[107703] = '1/75/75/75',
[107638] = '1/50/55/60',
[107614] = '1/50/55/60',
[106962] = '1/75/75/75',
[107704] = '1/75/75/75',
[107639] = '1/50/55/60',
[107615] = '1/50/55/60',
[106961] = '1/75/75/75',
[107666] = '1/50/55/60',
[107735] = '1/75/75/75',
[122671] = '1/75/75/75',
[107667] = '1/50/55/60',
[107736] = '1/75/75/75',
[107616] = '1/50/55/60',
[106958] = '1/75/75/75',
[118239] = '1/1/3/5',
[118238] = '1/1/3/5',
[118237] = '1/1/3/5',
[124032] = '1/5/15/25',
[124029] = '1/5/15/25',
[124124] = '1/35/50/65',
[124125] = '1/45/57/70',
[124126] = '1/25/40/55',
[124127] = '1/75/75/75',
[124128] = '1/75/75/75',
[124129] = '1/75/75/75',
[124223] = '1/1/5/10',
[124224] = '1/1/5/10',
[124225] = '1/1/5/10',
[124226] = '1/1/5/10',
[124227] = '1/1/5/10',
[124228] = '1/1/5/10',
[124229] = '1/1/5/10',
[124230] = '1/1/5/10',
[124231] = '1/1/5/10',
[124232] = '1/1/5/10',
[124233] = '1/1/5/10',
[124234] = '1/1/5/10',
[104298] = '1/25/27/30',
[104299] = '1/50/50/50',
[104300] = '1/75/75/75',
[124466] = '1/1/10/20',
[112430] = '1/1/10/20',
[112429] = '1/300/300/300',
[123781] = '1/300/300/300',
[104301] = '1/25/27/30',
[104302] = '1/50/50/50',
[104303] = '1/75/75/75',
[124052] = '1/25/27/30',
[124053] = '1/50/50/50',
[124054] = '1/75/75/75',
[104310] = '1/25/27/30',
[104311] = '1/50/50/50',
[104312] = '1/75/75/75',
[104304] = '1/25/27/30',
[104305] = '1/50/50/50',
[104306] = '1/75/75/75',
[104307] = '1/25/27/30',
[104308] = '1/50/50/50',
[104309] = '1/75/75/75',
[124559] = '1/1/3/5',
[124561] = '1/1/3/5',
[124563] = '1/1/3/5',
[124627] = '1/1/5/10',
[124584] = '1/15/30/45',
[124576] = '1/20/35/50',
[124628] = '1/10/15/20',
[124585] = '1/25/40/55',
[124586] = '1/20/35/50',
[124574] = '1/35/50/65',
[124577] = '1/15/30/45',
[124578] = '1/25/40/55',
[124582] = '1/30/45/60',
[124575] = '1/40/55/70',
[124583] = '1/50/62/75',
[124635] = '1/45/57/70',
[124572] = '1/30/45/60',
[124580] = '1/35/50/65',
[124571] = '1/45/57/70',
[124573] = '1/50/62/75',
[124579] = '1/40/55/70',
[124581] = '1/45/57/70',
[124608] = '1/75/75/75',
[124616] = '1/75/75/75',
[124592] = '1/75/75/75',
[124600] = '1/75/75/75',
[124606] = '1/75/75/75',
[124609] = '1/75/75/75',
[124610] = '1/75/75/75',
[124614] = '1/75/75/75',
[124617] = '1/75/75/75',
[124618] = '1/75/75/75',
[124590] = '1/75/75/75',
[124593] = '1/75/75/75',
[124594] = '1/75/75/75',
[124598] = '1/75/75/75',
[124601] = '1/75/75/75',
[124602] = '1/75/75/75',
[124607] = '1/75/75/75',
[124615] = '1/75/75/75',
[124591] = '1/75/75/75',
[124599] = '1/75/75/75',
[124636] = '1/50/62/75',
[124612] = '1/75/75/75',
[124588] = '1/75/75/75',
[124596] = '1/75/75/75',
[124604] = '1/75/75/75',
[124637] = '1/50/62/75',
[124605] = '1/75/75/75',
[124611] = '1/75/75/75',
[124613] = '1/75/75/75',
[124587] = '1/75/75/75',
[124589] = '1/75/75/75',
[124595] = '1/75/75/75',
[124597] = '1/75/75/75',
[124603] = '1/75/75/75',
[124625] = '1/75/75/75',
[124626] = '1/75/75/75',
[124638] = '1/75/75/75',
[124639] = '1/75/75/75',
[124640] = '1/75/75/75',
[124641] = '1/75/75/75',
[124642] = '1/75/75/75',
[124643] = '1/75/75/75',
[124644] = '1/75/75/75',
[124645] = '1/75/75/75',
[124619] = '1/75/75/75',
[124620] = '1/75/75/75',
[124621] = '1/75/75/75',
[124622] = '1/75/75/75',
[124623] = '1/75/75/75',
[124624] = '1/75/75/75',
[125117] = '1/1/5/10',
[125067] = '1/1/5/10',
[125078] = '1/1/5/10',
[125080] = '1/1/5/10',
[125122] = '1/5/15/25',
[125121] = '1/1/5/10',
[125142] = '1/75/75/75',
[125141] = '1/75/75/75',
[125496] = '1/1/1/1',
[125497] = '1/1/1/1',
[125558] = '1/75/75/75',
[125559] = '1/75/75/75',
[125560] = '1/75/75/75',
[125561] = '1/75/75/75',
[125550] = '1/75/75/75',
[125547] = '1/75/75/75',
[125548] = '1/75/75/75',
[125549] = '1/75/75/75',
[125556] = '1/75/75/75',
[125555] = '1/75/75/75',
[125533] = '1/75/75/75',
[125531] = '1/75/75/75',
[125541] = '1/75/75/75',
[125539] = '1/75/75/75',
[125532] = '1/75/75/75',
[125540] = '1/75/75/75',
[125535] = '1/75/75/75',
[125543] = '1/75/75/75',
[125542] = '1/75/75/75',
[125545] = '1/75/75/75',
[125546] = '1/75/75/75',
[125534] = '1/75/75/75',
[125537] = '1/75/75/75',
[125538] = '1/75/75/75',
[125536] = '1/75/75/75',
[125544] = '1/75/75/75',
[125554] = '1/75/75/75',
[125525] = '1/50/60/70',
[125523] = '1/50/60/70',
[125552] = '1/25/35/45',
[125553] = '1/35/45/55',
[125524] = '1/30/40/50',
[125557] = '1/45/55/65',
[125527] = '1/40/50/60',
[125526] = '1/20/30/40',
[125529] = '1/40/50/60',
[125530] = '1/30/40/50',
[125528] = '1/20/30/40',
[125551] = '1/1/5/10',
[125602] = '1/75/75/75',
[125603] = '1/75/75/75',
[125600] = '1/75/75/75',
[125601] = '1/75/75/75',
[125596] = '1/75/75/75',
[125597] = '1/75/75/75',
[125598] = '1/75/75/75',
[125599] = '1/75/75/75',
[125594] = '1/75/75/75',
[125595] = '1/75/75/75',
[125589] = '1/5/5/5',
[124694] = '1/5/5/5',
[125588] = '1/5/5/5',
[125586] = '1/5/5/5',
[125587] = '1/5/5/5',
[125584] = '1/5/5/5',
[126392] = '1/25/25/25',
[126696] = '1/1/10/20',
[126800] = '1/1/10/20',
[126855] = '1/75/75/75',
[126854] = '1/75/75/75',
[126853] = '1/75/75/75',
[126852] = '1/75/75/75',
[126851] = '1/75/75/75',
[126850] = '1/75/75/75',
[125123] = '1/75/75/75',
[125120] = '1/75/75/75',
[112462] = '1/1/10/20',
[112469] = '1/1/10/20',
[112464] = '1/1/10/20',
[112466] = '1/300/300/300',
[128262] = '1/1/13/25',
[128260] = '1/1/13/25',
[128261] = '1/1/13/25',
[112996] = '1/75/75/75',
[111921] = '1/75/75/75',
[127475] = '1/75/75/75',
[111920] = '1/45/50/55',
[112045] = '1/75/75/75',
[127391] = '1/75/75/75',
[127481] = '1/75/75/75',
[111830] = '1/75/75/75',
[111645] = '1/10/15/20',
[111646] = '1/10/15/20',
[111919] = '1/75/75/75',
[111908] = '1/45/50/55',
[111918] = '1/75/75/75',
[111909] = '1/75/75/75',
[111910] = '1/75/75/75',
[127017] = '1/25/25/25',
[126996] = '1/75/75/75',
[127021] = '1/75/75/75',
[127019] = '1/25/25/25',
[127024] = '1/75/75/75',
[127018] = '1/25/25/25',
[126995] = '1/75/75/75',
[127023] = '1/75/75/75',
[126994] = '1/75/75/75',
[127016] = '1/25/25/25',
[126997] = '1/75/75/75',
[127020] = '1/75/75/75',
[127009] = '1/75/75/75',
[126988] = '1/75/75/75',
[126989] = '1/75/75/75',
[127007] = '1/75/75/75',
[127378] = '1/75/75/75',
[111917] = '1/45/50/55',
[127118] = '1/75/75/75',
[127136] = '1/40/45/50',
[127129] = '1/75/75/75',
[127119] = '1/75/75/75',
[127120] = '1/75/75/75',
[127138] = '1/75/75/75',
[127121] = '1/75/75/75',
[127127] = '1/25/37/50',
[127139] = '1/75/75/75',
[127113] = '1/1/13/25',
[127134] = '1/50/62/75',
[127128] = '1/40/45/50',
[127114] = '1/1/13/25',
[127117] = '1/75/75/75',
[127124] = '1/1/3/5',
[127137] = '1/75/75/75',
[127115] = '1/75/75/75',
[127135] = '1/75/75/75',
[127116] = '1/50/62/75',
[127130] = '1/75/75/75',
[127123] = '1/75/75/75',
[127122] = '1/75/75/75',
[127131] = '1/50/62/75',
[109099] = '1/25/25/25',
[127132] = '1/75/75/75',
[128922] = '1/75/75/75',
[114786] = '1/300/300/300',
[130325] = '1/75/75/75',
[130326] = '1/75/75/75',
[130407] = '1/75/75/75',
[130656] = '1/50/55/60',
[130655] = '1/50/55/60',
[130657] = '1/75/75/75',
[130658] = '1/75/75/75',
[130758] = '1/75/75/75',
[131152] = '1/300/300/300',
[131211] = '1/10/22/35',
[131212] = '1/10/22/35',
[131213] = '1/10/22/35',
[131214] = '1/10/22/35',
[131215] = '1/10/22/35',
[131216] = '1/10/22/35',
[131217] = '1/10/22/35',
[131218] = '1/10/22/35',
[131256] = '1/1/13/25',
[131258] = '1/1/13/25',
[131353] = '1/1/13/25',
[131563] = '1/50/55/60',
[131593] = '1/75/75/75',
[131688] = '1/75/75/75',
[131690] = '1/75/75/75',
[131691] = '1/75/75/75',
[131686] = '1/75/75/75',
[131695] = '1/75/75/75',
[131759] = '1/75/75/75',
[131865] = '1/25/40/55',
[131897] = '1/75/75/75',
[131898] = '1/75/75/75',
[131929] = '1/75/75/75',
[131928] = '1/25/32/40',
[126654] = '1/75/75/75',
[126655] = '1/75/75/75',
[134585] = '1/1/3/5',
[136197] = '1/1/5/10',
[136274] = '1/50/55/60',
[136269] = '1/50/55/60',
[136270] = '1/50/55/60',
[136272] = '1/50/55/60',
[136273] = '1/50/55/60',
[136275] = '1/50/55/60',
[138597] = '1/75/75/75',
[138598] = '1/75/75/75',
[138600] = '1/75/75/75',
[137907] = '1/75/75/75',
[137908] = '1/75/75/75',
[138599] = '1/75/75/75',
[137918] = '1/75/75/75',
[137919] = '1/75/75/75',
[137920] = '1/75/75/75',
[137936] = '1/75/75/75',
[137937] = '1/75/75/75',
[137909] = '1/75/75/75',
[137910] = '1/75/75/75',
[137911] = '1/75/75/75',
[137912] = '1/75/75/75',
[137913] = '1/75/75/75',
[137914] = '1/75/75/75',
[137924] = '1/75/75/75',
[137929] = '1/75/75/75',
[137934] = '1/75/75/75',
[137941] = '1/75/75/75',
[137915] = '1/75/75/75',
[137916] = '1/75/75/75',
[137921] = '1/75/75/75',
[137926] = '1/75/75/75',
[137931] = '1/75/75/75',
[137938] = '1/75/75/75',
[137922] = '1/75/75/75',
[137927] = '1/75/75/75',
[137932] = '1/75/75/75',
[137939] = '1/75/75/75',
[137923] = '1/75/75/75',
[137928] = '1/75/75/75',
[137933] = '1/75/75/75',
[137940] = '1/75/75/75',
[137925] = '1/75/75/75',
[137930] = '1/75/75/75',
[137935] = '1/75/75/75',
[137942] = '1/75/75/75',
[138646] = '1/75/75/75',
[137917] = '1/75/75/75',
[138876] = '1/75/75/75',
[138879] = '1/75/75/75',
[138881] = '1/75/75/75',
[138889] = '1/75/75/75',
[138891] = '1/75/75/75',
[138893] = '1/75/75/75',
[138883] = '1/75/75/75',
[138884] = '1/75/75/75',
[138887] = '1/75/75/75',
[138888] = '1/75/75/75',
[138890] = '1/75/75/75',
[138892] = '1/75/75/75',
[138882] = '1/75/75/75',
[138885] = '1/75/75/75',
[138886] = '1/75/75/75',
[138878] = '1/75/75/75',
[138880] = '1/75/75/75',
[138877] = '1/75/75/75',
[137772] = '1/75/75/75',
[137783] = '1/75/75/75',
[137794] = '1/75/75/75',
[137773] = '1/75/75/75',
[137784] = '1/75/75/75',
[137795] = '1/75/75/75',
[137774] = '1/75/75/75',
[137785] = '1/75/75/75',
[137796] = '1/75/75/75',
[137775] = '1/75/75/75',
[137786] = '1/75/75/75',
[137797] = '1/75/75/75',
[137776] = '1/75/75/75',
[137777] = '1/75/75/75',
[137787] = '1/75/75/75',
[137788] = '1/75/75/75',
[137778] = '1/75/75/75',
[137779] = '1/75/75/75',
[137789] = '1/75/75/75',
[137790] = '1/75/75/75',
[137780] = '1/75/75/75',
[137781] = '1/75/75/75',
[137791] = '1/75/75/75',
[137792] = '1/75/75/75',
[137782] = '1/75/75/75',
[137793] = '1/75/75/75',
[137809] = '1/75/75/75',
[137817] = '1/75/75/75',
[137825] = '1/75/75/75',
[137858] = '1/75/75/75',
[137833] = '1/75/75/75',
[137838] = '1/75/75/75',
[137847] = '1/75/75/75',
[137868] = '1/75/75/75',
[137873] = '1/75/75/75',
[137879] = '1/75/75/75',
[137810] = '1/75/75/75',
[137818] = '1/75/75/75',
[137826] = '1/75/75/75',
[137859] = '1/75/75/75',
[137834] = '1/75/75/75',
[137839] = '1/75/75/75',
[137848] = '1/75/75/75',
[137869] = '1/75/75/75',
[137874] = '1/75/75/75',
[137880] = '1/75/75/75',
[137811] = '1/75/75/75',
[137819] = '1/75/75/75',
[137827] = '1/75/75/75',
[137860] = '1/75/75/75',
[137835] = '1/75/75/75',
[137840] = '1/75/75/75',
[137849] = '1/75/75/75',
[137870] = '1/75/75/75',
[137875] = '1/75/75/75',
[137881] = '1/75/75/75',
[137812] = '1/75/75/75',
[137820] = '1/75/75/75',
[137828] = '1/75/75/75',
[137813] = '1/75/75/75',
[137821] = '1/75/75/75',
[137829] = '1/75/75/75',
[137861] = '1/75/75/75',
[137836] = '1/75/75/75',
[137841] = '1/75/75/75',
[137850] = '1/75/75/75',
[137871] = '1/75/75/75',
[137876] = '1/75/75/75',
[137882] = '1/75/75/75',
[137814] = '1/75/75/75',
[137822] = '1/75/75/75',
[137851] = '1/75/75/75',
[137852] = '1/75/75/75',
[137830] = '1/75/75/75',
[137843] = '1/75/75/75',
[137862] = '1/75/75/75',
[137877] = '1/75/75/75',
[137857] = '1/75/75/75',
[137846] = '1/75/75/75',
[137867] = '1/75/75/75',
[137872] = '1/75/75/75',
[137878] = '1/75/75/75',
[140040] = '1/75/75/75',
[140041] = '1/75/75/75',
[140060] = '1/75/75/75',
[140050] = '1/75/75/75',
[140185] = '1/70/72/75',
[139196] = '1/75/75/75',
[139192] = '1/75/75/75',
[139197] = '1/75/75/75',
[138589] = '1/75/75/75',
[138591] = '1/75/75/75',
[138593] = '1/75/75/75',
[138595] = '1/75/75/75',
[138590] = '1/75/75/75',
[138592] = '1/75/75/75',
[138594] = '1/75/75/75',
[138596] = '1/75/75/75',
[137766] = '1/75/75/75',
[137768] = '1/75/75/75',
[137770] = '1/75/75/75',
[137767] = '1/75/75/75',
[137769] = '1/75/75/75',
[137771] = '1/75/75/75',
[140841] = '1/75/75/75',
[140842] = '1/75/75/75',
[140843] = '1/75/75/75',
[140844] = '1/75/75/75',
[140845] = '1/75/75/75',
[140846] = '1/75/75/75',
[137815] = '1/75/75/75',
[137823] = '1/75/75/75',
[137853] = '1/75/75/75',
[137854] = '1/75/75/75',
[137831] = '1/75/75/75',
[137844] = '1/75/75/75',
[137863] = '1/75/75/75',
[137864] = '1/75/75/75',
[137816] = '1/75/75/75',
[137824] = '1/75/75/75',
[137855] = '1/75/75/75',
[137856] = '1/75/75/75',
[137832] = '1/75/75/75',
[137845] = '1/75/75/75',
[137865] = '1/75/75/75',
[137866] = '1/75/75/75',
[137837] = '1/75/75/75',
[137842] = '1/75/75/75',
[139176] = '1/75/75/75',
[142954] = '1/75/75/75',
[142958] = '1/75/75/75',
[142959] = '1/75/75/75',
[142963] = '1/75/75/75',
[142967] = '1/75/75/75',
[142968] = '1/75/75/75',
[142951] = '1/75/75/75',
[142955] = '1/75/75/75',
[142960] = '1/75/75/75',
[142964] = '1/75/75/75',
[142952] = '1/75/75/75',
[142953] = '1/75/75/75',
[142956] = '1/75/75/75',
[142957] = '1/75/75/75',
[142961] = '1/75/75/75',
[142962] = '1/75/75/75',
[142965] = '1/75/75/75',
[142966] = '1/75/75/75',
[142976] = '1/75/75/75',
[143166] = '1/75/75/75',
[143171] = '1/75/75/75',
[143182] = '1/75/75/75',
[143193] = '1/75/75/75',
[143165] = '1/75/75/75',
[143170] = '1/75/75/75',
[143181] = '1/75/75/75',
[143192] = '1/75/75/75',
[143167] = '1/75/75/75',
[143172] = '1/75/75/75',
[143183] = '1/75/75/75',
[143194] = '1/75/75/75',
[143163] = '1/75/75/75',
[143168] = '1/75/75/75',
[143179] = '1/75/75/75',
[143190] = '1/75/75/75',
[143164] = '1/75/75/75',
[143169] = '1/75/75/75',
[143180] = '1/75/75/75',
[143191] = '1/75/75/75',
[143175] = '1/75/75/75',
[143176] = '1/75/75/75',
[143186] = '1/75/75/75',
[143187] = '1/75/75/75',
[143173] = '1/75/75/75',
[143174] = '1/75/75/75',
[143184] = '1/75/75/75',
[143185] = '1/75/75/75',
[143177] = '1/75/75/75',
[143178] = '1/75/75/75',
[143188] = '1/75/75/75',
[143189] = '1/75/75/75',
[143195] = '1/75/75/75',
[143196] = '1/75/75/75',
[143197] = '1/75/75/75',
[143053] = '1/75/75/75',
[143054] = '1/75/75/75',
[143064] = '1/75/75/75',
[143065] = '1/75/75/75',
[143066] = '1/75/75/75',
[143082] = '1/75/75/75',
[143083] = '1/75/75/75',
[143055] = '1/75/75/75',
[143056] = '1/75/75/75',
[143057] = '1/75/75/75',
[143058] = '1/75/75/75',
[143059] = '1/75/75/75',
[143060] = '1/75/75/75',
[143061] = '1/75/75/75',
[143062] = '1/75/75/75',
[143063] = '1/75/75/75',
[143067] = '1/75/75/75',
[143072] = '1/75/75/75',
[143077] = '1/75/75/75',
[143084] = '1/75/75/75',
[143068] = '1/75/75/75',
[143073] = '1/75/75/75',
[143078] = '1/75/75/75',
[143085] = '1/75/75/75',
[143069] = '1/75/75/75',
[143074] = '1/75/75/75',
[143079] = '1/75/75/75',
[143086] = '1/75/75/75',
[143071] = '1/75/75/75',
[143076] = '1/75/75/75',
[143081] = '1/75/75/75',
[143088] = '1/75/75/75',
[143070] = '1/75/75/75',
[143075] = '1/75/75/75',
[143080] = '1/75/75/75',
[143087] = '1/75/75/75',
[143089] = '1/75/75/75',
[143097] = '1/75/75/75',
[143105] = '1/75/75/75',
[143138] = '1/75/75/75',
[143113] = '1/75/75/75',
[143118] = '1/75/75/75',
[143127] = '1/75/75/75',
[143148] = '1/75/75/75',
[143153] = '1/75/75/75',
[143159] = '1/75/75/75',
[143090] = '1/75/75/75',
[143098] = '1/75/75/75',
[143106] = '1/75/75/75',
[143139] = '1/75/75/75',
[143114] = '1/75/75/75',
[143119] = '1/75/75/75',
[143128] = '1/75/75/75',
[143149] = '1/75/75/75',
[143154] = '1/75/75/75',
[143160] = '1/75/75/75',
[143091] = '1/75/75/75',
[143099] = '1/75/75/75',
[143107] = '1/75/75/75',
[143140] = '1/75/75/75',
[143115] = '1/75/75/75',
[143120] = '1/75/75/75',
[143129] = '1/75/75/75',
[143150] = '1/75/75/75',
[143155] = '1/75/75/75',
[143161] = '1/75/75/75',
[143092] = '1/75/75/75',
[143100] = '1/75/75/75',
[143108] = '1/75/75/75',
[143093] = '1/75/75/75',
[143101] = '1/75/75/75',
[143109] = '1/75/75/75',
[143141] = '1/75/75/75',
[143116] = '1/75/75/75',
[143121] = '1/75/75/75',
[143130] = '1/75/75/75',
[143151] = '1/75/75/75',
[143156] = '1/75/75/75',
[143162] = '1/75/75/75',
[143094] = '1/75/75/75',
[143102] = '1/75/75/75',
[143131] = '1/75/75/75',
[143132] = '1/75/75/75',
[143110] = '1/75/75/75',
[143123] = '1/75/75/75',
[143142] = '1/75/75/75',
[143157] = '1/75/75/75',
[143095] = '1/75/75/75',
[143103] = '1/75/75/75',
[143133] = '1/75/75/75',
[143134] = '1/75/75/75',
[143111] = '1/75/75/75',
[143124] = '1/75/75/75',
[143143] = '1/75/75/75',
[143144] = '1/75/75/75',
[143096] = '1/75/75/75',
[143104] = '1/75/75/75',
[143135] = '1/75/75/75',
[143136] = '1/75/75/75',
[143112] = '1/75/75/75',
[143125] = '1/75/75/75',
[143145] = '1/75/75/75',
[143146] = '1/75/75/75',
[143117] = '1/75/75/75',
[143122] = '1/75/75/75',
[143126] = '1/75/75/75',
[143137] = '1/75/75/75',
[143147] = '1/75/75/75',
[143152] = '1/75/75/75',
[143158] = '1/75/75/75',
[143011] = '1/75/75/75',
[143255] = '1/75/75/75',
[143714] = '1/75/75/75',
[145038] = '1/75/75/75',
[145061] = '1/75/75/75',
[145062] = '1/75/75/75',
[145167] = '1/75/75/75',
[145170] = '1/75/75/75',
[145197] = '1/75/75/75',
[146613] = '1/70/72/75',
[146638] = '1/70/72/75',
[146921] = '1/75/75/75',
[146923] = '1/75/75/75',
[146925] = '1/75/75/75',
[145309] = '1/75/75/75',
[145305] = '1/75/75/75',
[145310] = '1/75/75/75',
[145307] = '1/75/75/75',
[145311] = '1/75/75/75',
[145308] = '1/75/75/75',
[148266] = '1/300/300/300',
[148270] = '1/300/300/300',
[148271] = '1/300/300/300',
[148274] = '1/1/10/20',
[148276] = '1/1/38/75',
[148278] = '1/300/300/300',
[148281] = '1/300/300/300',
[148282] = '1/300/300/300',
[148292] = '1/300/300/300',
[153605] = '1/1/50/100',
[153606] = '1/1/50/100',
[153607] = '1/1/50/100',
[153608] = '1/1/50/100',
[153609] = '1/1/50/100',
[153610] = '1/1/50/100',
[153611] = '1/1/50/100',
[153612] = '1/1/50/100',
[153627] = '1/1/50/100',
[153628] = '1/1/50/100',
[153629] = '1/1/50/100',
[153630] = '1/1/50/100',
[153631] = '1/1/50/100',
[153643] = '1/1/50/100',
[153644] = '1/1/50/100',
[153645] = '1/1/50/100',
[153646] = '1/1/50/100',
[153647] = '1/1/50/100',
[153648] = '1/1/50/100',
[153649] = '1/1/50/100',
[153650] = '1/1/50/100',
[153651] = '1/1/50/100',
[153652] = '1/1/50/100',
[153653] = '1/1/50/100',
[153654] = '1/1/50/100',
[153655] = '1/1/50/100',
[153656] = '1/1/50/100',
[153657] = '1/1/50/100',
[153658] = '1/1/50/100',
[153659] = '1/1/50/100',
[153660] = '1/1/50/100',
[153661] = '1/1/50/100',
[153663] = '1/1/50/100',
[153664] = '1/1/50/100',
[153665] = '1/1/50/100',
[153666] = '1/1/50/100',
[153667] = '1/1/50/100',
[153668] = '1/1/50/100',
[177169] = '1/100/100/100',
[156585] = '1/50/55/60',
[156587] = '1/1/50/100',
[156588] = '1/1/5/10',
[156589] = '1/1/5/10',
[156590] = '1/1/5/10',
[156592] = '1/1/5/10',
[156593] = '1/1/5/10',
[156560] = '1/100/100/100',
[156561] = '1/100/100/100',
[156563] = '1/100/100/100',
[156564] = '1/100/100/100',
[156567] = '1/100/100/100',
[156568] = '1/100/100/100',
[156569] = '1/100/100/100',
[156571] = '1/100/100/100',
[156572] = '1/100/100/100',
[156576] = '1/100/100/100',
[156577] = '1/50/55/60',
[156578] = '1/50/55/60',
[156579] = '1/50/55/60',
[156580] = '1/50/55/60',
[156581] = '1/50/55/60',
[156582] = '1/50/55/60',
[162403] = '1/50/55/60',
[156584] = '1/50/55/60',
[156606] = '1/1/1/1',
[158762] = '1/1/1/1',
[158737] = '1/1/1/1',
[158716] = '1/1/1/1',
[158739] = '1/1/1/1',
[158745] = '1/1/1/1',
[158748] = '1/1/1/1',
[158750] = '1/1/1/1',
[158752] = '1/1/1/1',
[158754] = '1/1/1/1',
[158758] = '1/1/1/1',
[159673] = '1/100/100/100',
[158877] = '1/25/27/30',
[158878] = '1/25/27/30',
[158879] = '1/25/27/30',
[158881] = '1/25/27/30',
[159672] = '1/100/100/100',
[158884] = '1/100/100/100',
[158885] = '1/100/100/100',
[158886] = '1/100/100/100',
[158889] = '1/100/100/100',
[159236] = '1/100/100/100',
[159235] = '1/100/100/100',
[158892] = '1/25/27/30',
[158893] = '1/25/27/30',
[158894] = '1/25/27/30',
[158896] = '1/25/27/30',
[159671] = '1/100/100/100',
[158899] = '1/100/100/100',
[158900] = '1/100/100/100',
[158901] = '1/100/100/100',
[158903] = '1/100/100/100',
[158907] = '1/25/27/30',
[158908] = '1/25/27/30',
[158909] = '1/25/27/30',
[158911] = '1/25/27/30',
[158914] = '1/100/100/100',
[158915] = '1/100/100/100',
[158916] = '1/100/100/100',
[158918] = '1/100/100/100',
[160958] = '1/50/75/100',
[173978] = '1/100/100/100',
[160962] = '1/50/75/100',
[160966] = '1/50/75/100',
[160968] = '1/50/75/100',
[160969] = '1/50/75/100',
[160971] = '1/50/75/100',
[160973] = '1/50/75/100',
[173979] = '1/100/100/100',
[160978] = '1/50/75/100',
[160979] = '1/50/75/100',
[160981] = '1/50/75/100',
[160982] = '1/50/75/100',
[160983] = '1/50/75/100',
[160984] = '1/75/87/100',
[160986] = '1/75/87/100',
[160987] = '1/75/87/100',
[160989] = '1/75/87/100',
[160999] = '1/75/87/100',
[161000] = '1/75/87/100',
[161001] = '1/1/25/50',
[161002] = '1/1/25/50',
[158765] = '1/1/1/1',
[162195] = '1/100/100/100',
[162196] = '1/100/100/100',
[162197] = '1/100/100/100',
[162198] = '1/100/100/100',
[162199] = '1/100/100/100',
[162202] = '1/100/100/100',
[162203] = '1/100/100/100',
[162204] = '1/25/27/30',
[162205] = '1/100/100/100',
[162206] = '1/100/100/100',
[162207] = '1/25/27/30',
[162208] = '1/100/100/100',
[162209] = '1/100/100/100',
[162210] = '1/100/100/100',
[169078] = '1/100/100/100',
[162214] = '1/100/100/100',
[162216] = '1/100/100/100',
[162217] = '1/100/100/100',
[162218] = '1/100/100/100',
[169080] = '1/1/50/100',
[159674] = '1/100/100/100',
[162948] = '1/50/75/100',
[163216] = '1/1/3/5',
[163218] = '1/1/3/5',
[163220] = '1/1/5/10',
[163222] = '1/1/3/5',
[163223] = '1/1/3/5',
[163224] = '1/1/3/5',
[163225] = '1/1/5/10',
[163226] = '1/1/5/10',
[163228] = '1/1/5/10',
[163229] = '1/1/5/10',
[163230] = '1/1/5/10',
[163231] = '1/1/5/10',
[163232] = '1/1/5/10',
[163294] = '1/100/100/100',
[165304] = '75/175/225/275',
[165456] = '100/200/250/300',
[165460] = '150/250/275/300',
[165461] = '200/300/300/300',
[165463] = '250/300/300/300',
[165464] = '1/75/75/75',
[165465] = '1/75/75/75',
[165466] = '1/75/75/75',
[165467] = '1/70/72/75',
[182158] = '1/1/1/1',
[165564] = '25/125/175/225',
[165804] = '1/100/100/100',
[166356] = '1/100/100/100',
[166359] = '1/100/100/100',
[166363] = '1/100/100/100',
[166432] = '1/100/100/100',
[166669] = '1/100/100/100',
[167950] = '1/1/3/5',
[168042] = '700/1/50/100',
[167895] = '1/600/600/600',
[168835] = '1/1/50/100',
[168836] = '1/100/100/100',
[168837] = '1/100/100/100',
[168838] = '1/100/100/100',
[168839] = '1/100/100/100',
[168840] = '1/100/100/100',
[168841] = '1/100/100/100',
[168842] = '1/100/100/100',
[168843] = '1/100/100/100',
[168844] = '1/100/100/100',
[168845] = '1/100/100/100',
[168846] = '1/100/100/100',
[168847] = '1/100/100/100',
[168848] = '1/100/100/100',
[168849] = '1/100/100/100',
[168850] = '1/100/100/100',
[168851] = '1/100/100/100',
[168852] = '1/50/55/60',
[168853] = '1/50/55/60',
[168854] = '1/50/55/60',
[169140] = '1/100/100/100',
[169669] = '700/1/50/100',
[169696] = '1/50/50/50',
[169693] = '1/50/50/50',
[169699] = '1/50/50/50',
[170700] = '1/1/50/100',
[170701] = '1/100/100/100',
[170704] = '1/50/55/60',
[170705] = '1/50/55/60',
[170706] = '1/50/55/60',
[170707] = '1/50/55/60',
[170708] = '1/50/55/60',
[170709] = '1/50/55/60',
[170710] = '1/50/55/60',
[170711] = '1/50/55/60',
[170712] = '1/50/55/60',
[170713] = '1/100/100/100',
[170714] = '1/100/100/100',
[170715] = '1/100/100/100',
[170716] = '1/100/100/100',
[170717] = '1/100/100/100',
[170718] = '1/100/100/100',
[170719] = '1/100/100/100',
[170720] = '1/100/100/100',
[170721] = '1/100/100/100',
[170723] = '1/100/100/100',
[170724] = '1/100/100/100',
[170725] = '1/100/100/100',
[170726] = '1/100/100/100',
[170727] = '1/100/100/100',
[170729] = '1/100/100/100',
[170730] = '1/100/100/100',
[170731] = '1/50/55/60',
[170732] = '1/50/55/60',
[171072] = '1/1/3/5',
[171073] = '1/1/3/5',
[171074] = '1/1/3/5',
[182120] = '1/100/100/100',
[171391] = '1/1/50/100',
[171260] = '1/50/55/60',
[171263] = '1/50/55/60',
[171261] = '1/50/55/60',
[171264] = '1/50/55/60',
[171262] = '1/50/55/60',
[171265] = '1/50/55/60',
[171266] = '1/100/100/100',
[171267] = '1/100/100/100',
[171268] = '1/100/100/100',
[171269] = '1/100/100/100',
[171270] = '1/100/100/100',
[171271] = '1/100/100/100',
[171272] = '1/100/100/100',
[171273] = '1/100/100/100',
[171274] = '1/100/100/100',
[171275] = '1/100/100/100',
[171276] = '1/100/100/100',
[171277] = '1/100/100/100',
[171278] = '1/100/100/100',
[171279] = '1/100/100/100',
[171280] = '1/100/100/100',
[171281] = '1/100/100/100',
[171282] = '1/100/100/100',
[171283] = '1/100/100/100',
[171284] = '1/100/100/100',
[171285] = '1/100/100/100',
[171288] = '1/100/100/100',
[171289] = '1/100/100/100',
[171290] = '1/100/100/100',
[171291] = '1/100/100/100',
[171713] = '700/1/50/100',
[171690] = '1/1/50/100',
[171691] = '1/50/55/60',
[171692] = '1/50/55/60',
[171693] = '1/50/55/60',
[171694] = '1/100/100/100',
[171695] = '1/100/100/100',
[171696] = '1/100/100/100',
[171697] = '1/100/100/100',
[171698] = '1/100/100/100',
[171699] = '1/100/100/100',
[171700] = '1/100/100/101',
[171701] = '1/100/100/101',
[171702] = '1/100/100/101',
[171703] = '1/100/100/101',
[171704] = '1/100/100/101',
[171705] = '1/100/100/101',
[171706] = '1/100/100/101',
[171707] = '1/100/100/101',
[173289] = '1/100/100/100',
[173309] = '1/25/27/30',
[173308] = '1/25/27/30',
[173323] = '1/100/100/100',
[173355] = '1/100/100/100',
[173416] = '1/650/652/655',
[173415] = '1/650/652/655',
[175392] = '1/1/3/5',
[175390] = '1/1/3/5',
[175389] = '1/1/3/5',
[175086] = '1/1/1/1',
[175853] = '1/50/55/60',
[175865] = '1/50/55/60',
[175866] = '1/50/55/60',
[175867] = '1/50/55/60',
[175868] = '1/50/55/60',
[175869] = '1/50/55/60',
[173716] = '1/1/1/1',
[173717] = '1/1/1/1',
[173718] = '1/1/1/1',
[174979] = '1/1/1/1',
[173719] = '1/1/1/1',
[173720] = '1/1/1/1',
[175076] = '1/1/1/1',
[173721] = '1/1/1/1',
[173722] = '1/1/1/1',
[173723] = '1/1/1/1',
[175072] = '1/1/1/1',
[175071] = '1/1/1/1',
[173724] = '1/1/1/1',
[175070] = '1/1/1/1',
[173725] = '1/1/1/1',
[173726] = '1/1/1/1',
[175085] = '1/1/1/1',
[173727] = '1/1/1/1',
[173728] = '1/1/1/1',
[173729] = '1/1/1/1',
[175078] = '1/1/1/1',
[173730] = '1/1/1/1',
[173731] = '1/1/1/1',
[173732] = '1/1/1/1',
[175074] = '1/1/1/1',
[175880] = '1/1/50/100',
[176058] = '1/1/50/100',
[176087] = '1/1/50/100',
[176089] = '1/1/50/100',
[176090] = '1/1/50/100',
[176316] = '1/1/1/1',
[176315] = '1/1/1/1',
[176314] = '1/1/1/1',
[176313] = '1/1/1/1',
[176392] = '1/1/1/1',
[176397] = '1/1/1/1',
[176399] = '1/1/1/1',
[176401] = '1/1/1/1',
[176402] = '1/1/1/1',
[176404] = '1/1/1/1',
[176405] = '1/1/1/1',
[176408] = '1/1/1/1',
[176409] = '1/1/1/1',
[176411] = '1/1/1/1',
[176412] = '1/1/1/1',
[176413] = '1/1/1/1',
[176414] = '1/1/1/1',
[176415] = '1/1/1/1',
[176416] = '1/1/1/1',
[176417] = '1/1/1/1',
[176418] = '1/1/1/1',
[176420] = '1/1/1/1',
[176421] = '1/1/1/1',
[176422] = '1/1/1/1',
[176424] = '1/1/1/1',
[176425] = '1/1/1/1',
[176426] = '1/1/1/1',
[176732] = '1/100/100/100',
[176513] = '1/1/1/1',
[177043] = '1/1/50/100',
[177045] = '1/1/50/100',
[177054] = '1/1/50/100',
[177355] = '1/1/1/1',
[178208] = '1/50/55/60',
[178241] = '700/100/100/100',
[169092] = '1/1/50/100',
[178242] = '700/100/100/100',
[169081] = '1/1/50/100',
[178240] = '700/100/100/100',
[178243] = '1/100/100/100',
[178245] = '1/100/100/100',
[182129] = '1/100/100/100',
[169091] = '1/25/27/30',
[178550] = '1/1/1/1',
[178497] = '1/1/1/1',
[168290] = '1/700/700/700',
[168291] = '1/700/700/700',
[168292] = '1/700/700/700',
[168293] = '1/700/700/700',
[168294] = '1/700/700/700',
[168295] = '1/700/700/700',
[168296] = '1/700/700/700',
[168297] = '1/700/700/700',
[168298] = '1/700/700/700',
[168299] = '1/700/700/700',
[168300] = '1/700/700/700',
[168301] = '1/700/700/700',
[168302] = '1/700/700/700',
[168303] = '1/700/700/700',
[168304] = '1/700/700/700',
[168305] = '1/700/700/700',
[168306] = '1/700/700/700',
[168307] = '1/700/700/700',
[168308] = '1/700/700/700',
[168309] = '1/700/700/700',
[168310] = '1/700/700/700',
[168311] = '1/700/700/700',
[168312] = '1/700/700/700',
[168313] = '1/700/700/700',
[168314] = '1/700/700/700',
[168315] = '1/700/700/700',
[168316] = '1/700/700/700',
[168317] = '1/700/700/700',
[168318] = '1/700/700/700',
[168321] = '1/700/700/700',
[168322] = '1/700/700/700',
[168323] = '1/700/700/700',
[168324] = '1/700/700/700',
[168325] = '1/700/700/700',
[168326] = '1/700/700/700',
[168327] = '1/700/700/700',
[168328] = '1/700/700/700',
[168329] = '1/700/700/700',
[168330] = '1/700/700/700',
[168319] = '1/700/700/700',
[168320] = '1/700/700/700',
[168331] = '1/700/700/700',
[172459] = '1/700/700/700',
[172460] = '1/700/700/700',
[172466] = '1/700/700/700',
[180757] = '1/1/8/15',
[180760] = '1/1/8/15',
[180762] = '1/1/8/15',
[180759] = '1/1/8/15',
[180761] = '1/1/8/15',
[180758] = '1/1/8/15',
[181631] = '1/100/100/100',
[181633] = '1/100/100/100',
[181630] = '1/100/100/100',
[181634] = '1/100/100/100',
[181628] = '1/100/100/100',
[181627] = '1/100/100/100',
[181625] = '1/100/100/100',
[181635] = '1/100/100/100',
[181636] = '1/100/100/100',
[181632] = '1/100/100/100',
[181629] = '1/100/100/100',
[181637] = '1/1/3/5',
[181643] = '1/5/7/10',
[181647] = '1/1/3/5',
[181648] = '1/2/3/5',
[181649] = '1/3/4/5',
[181650] = '1/4/4/5',
[181870] = '1/1/1/1',
[182116] = '1/100/100/100',
[156591] = '1/1/1/1',
[182127] = '1/100/100/100',
[182121] = '1/100/100/100',
[182123] = '1/100/100/100',
[182928] = '1/20/30/40',
[182999] = '1/20/32/45',
[182989] = '1/100/100/100',
[182988] = '1/100/100/100',
[182987] = '1/100/100/100',
[182986] = '1/100/100/100',
[182985] = '1/100/100/100',
[182984] = '1/100/100/100',
[182983] = '1/100/100/100',
[182982] = '1/100/100/100',
[182981] = '1/80/90/100',
[182980] = '1/80/90/100',
[182979] = '1/80/90/100',
[182978] = '1/80/90/100',
[182977] = '1/80/90/100',
[182976] = '1/80/90/100',
[182975] = '1/80/90/100',
[182974] = '1/80/90/100',
[182973] = '1/60/70/80',
[182972] = '1/60/70/80',
[182971] = '1/60/70/80',
[182970] = '1/60/70/80',
[182969] = '1/40/50/60',
[182968] = '1/40/50/60',
[182967] = '1/40/50/60',
[182966] = '1/40/50/60',
[182965] = '1/40/50/60',
[182964] = '1/40/50/60',
[182963] = '1/40/50/60',
[182962] = '1/40/50/60',
[182951] = '1/60/70/80',
[182950] = '1/60/70/80',
[182949] = '1/60/70/80',
[182948] = '1/60/70/80',
[182947] = '1/60/70/80',
[182946] = '1/60/70/80',
[182945] = '1/60/70/80',
[182944] = '1/60/70/80',
[182935] = '1/20/30/40',
[182934] = '1/20/30/40',
[182933] = '1/20/30/40',
[182932] = '1/20/30/40',
[182931] = '1/20/30/40',
[182930] = '1/20/30/40',
[182929] = '1/20/30/40',
[183283] = '1/1/1/1',
[183281] = '1/1/1/1',
[183280] = '1/1/1/1',
[183279] = '1/1/1/1',
[183278] = '1/1/1/1',
[183562] = '1/1/1/1',
[184185] = '1/1/1/1',
[184184] = '1/1/1/1',
[184183] = '1/1/1/1',
[184182] = '1/1/1/1',
[184181] = '1/1/1/1',
[184214] = '1/1/1/1',
[184215] = '1/1/1/1',
[184216] = '1/1/1/1',
[184217] = '1/1/1/1',
[184218] = '1/1/1/1',
[184219] = '1/1/1/1',
[184220] = '1/1/1/1',
[184308] = '1/1/1/1',
[184309] = '1/1/1/1',
[184310] = '1/1/1/1',
[184312] = '1/1/1/1',
[184313] = '1/1/1/1',
[184314] = '1/1/1/1',
[184315] = '1/1/1/1',
[184336] = '1/1/1/1',
[184337] = '1/1/1/1',
[184338] = '1/1/1/1',
[184339] = '1/1/1/1',
[184340] = '1/1/1/1',
[184341] = '1/1/1/1',
[184342] = '1/1/1/1',
[184343] = '1/1/1/1',
[184344] = '1/1/1/1',
[184345] = '1/1/1/1',
[184403] = '1/1/1/1',
[184404] = '1/1/1/1',
[184405] = '1/1/1/1',
[184407] = '1/1/1/1',
[184408] = '1/1/1/1',
[184454] = '1/1/1/1',
[184456] = '1/1/1/1',
[184457] = '1/1/1/1',
[184484] = '1/1/1/1',
[184485] = '1/1/1/1',
[184486] = '1/1/1/1',
[184488] = '1/1/1/1',
[184489] = '1/1/1/1',
[184490] = '1/1/1/1',
[184492] = '1/1/1/1',
[184493] = '1/1/1/1',
[184494] = '1/1/1/1',
[184496] = '1/1/1/1',
[184497] = '1/1/1/1',
[184498] = '1/1/1/1',
[184500] = '1/1/1/1',
[184501] = '1/1/1/1',
[184502] = '1/1/1/1',
[184504] = '1/1/1/1',
[184505] = '1/1/1/1',
[184442] = '1/60/67/75',
[185704] = '1/50/75/100',
[185708] = '1/125/150/175',
[185705] = '1/245/265/285',
[185918] = '1/20/30/40',
[185919] = '1/20/30/40',
[185920] = '1/20/30/40',
[185921] = '1/20/30/40',
[185922] = '1/20/30/40',
[185923] = '1/20/30/40',
[185924] = '1/20/30/40',
[185925] = '1/20/30/40',
[185926] = '1/60/70/80',
[185927] = '1/60/70/80',
[185928] = '1/60/70/80',
[185929] = '1/60/70/80',
[185930] = '1/60/70/80',
[185931] = '1/60/70/80',
[185932] = '1/60/70/80',
[185933] = '1/60/70/80',
[185934] = '1/40/50/60',
[185935] = '1/40/50/60',
[185936] = '1/40/50/60',
[185937] = '1/40/50/60',
[185938] = '1/40/50/60',
[185939] = '1/40/50/60',
[185940] = '1/40/50/60',
[185941] = '1/40/50/60',
[185942] = '1/60/70/80',
[185943] = '1/60/70/80',
[185944] = '1/60/70/80',
[185945] = '1/60/70/80',
[185946] = '1/80/90/100',
[185947] = '1/80/90/100',
[185948] = '1/80/90/100',
[185949] = '1/80/90/100',
[185950] = '1/80/90/100',
[185951] = '1/80/90/100',
[185952] = '1/80/90/100',
[185953] = '1/80/90/100',
[185954] = '1/100/100/100',
[185955] = '1/100/100/100',
[185956] = '1/100/100/100',
[185957] = '1/100/100/100',
[185958] = '1/100/100/100',
[185959] = '1/100/100/100',
[185960] = '1/100/100/100',
[185961] = '1/100/100/100',
[185962] = '1/60/70/80',
[186091] = '1/20/40/60',
[186094] = '1/20/40/60',
[186097] = '1/20/40/60',
[186100] = '1/20/40/60',
[186106] = '1/60/70/80',
[186107] = '1/80/90/100',
[186108] = '1/100/100/100',
[186109] = '1/60/70/80',
[186110] = '1/80/90/100',
[186111] = '1/100/100/100',
[186112] = '1/60/70/80',
[186113] = '1/80/90/100',
[186114] = '1/100/100/100',
[186115] = '1/60/70/80',
[186116] = '1/80/90/100',
[186117] = '1/100/100/100',
[186738] = '1/1/1/1',
[186763] = '1/1/1/1',
[186764] = '1/1/1/1',
[186799] = '1/1/1/1',
[186801] = '1/1/1/1',
[186803] = '1/1/1/1',
[187058] = '1/1/1/1',
[187059] = '1/1/1/1',
[187060] = '1/1/1/1',
[187064] = '1/1/1/1',
[187065] = '1/1/1/1',
[187066] = '1/1/1/1',
[187634] = '1/100/100/100',
[187635] = '1/100/100/100',
[187636] = '1/100/100/100',
[187639] = '1/100/100/100',
[187640] = '1/100/100/100',
[188297] = '1/20/30/40',
[188299] = '1/40/50/60',
[188300] = '1/60/70/80',
[188301] = '1/20/30/40',
[188302] = '1/40/50/60',
[188303] = '1/60/70/80',
[188304] = '1/20/30/40',
[188305] = '1/40/50/60',
[188306] = '1/60/70/80',
[188307] = '1/20/30/40',
[188308] = '1/40/50/60',
[188309] = '1/60/70/80',
[188310] = '1/20/30/40',
[188311] = '1/40/50/60',
[188312] = '1/60/70/80',
[188313] = '1/20/30/40',
[188314] = '1/40/50/60',
[188315] = '1/60/70/80',
[188316] = '1/20/30/40',
[188317] = '1/40/50/60',
[188318] = '1/60/70/80',
[188319] = '1/20/30/40',
[188320] = '1/40/50/60',
[188321] = '1/60/70/80',
[188322] = '1/40/50/60',
[188323] = '1/60/70/80',
[188324] = '1/80/90/100',
[188325] = '1/40/50/60',
[188326] = '1/60/70/80',
[188327] = '1/80/90/100',
[188328] = '1/40/50/60',
[188329] = '1/60/70/80',
[188330] = '1/80/90/100',
[188331] = '1/40/50/60',
[188332] = '1/60/70/80',
[188333] = '1/80/90/100',
[188334] = '1/40/50/60',
[188335] = '1/60/70/80',
[188336] = '1/80/90/100',
[188337] = '1/60/70/80',
[188338] = '1/80/90/100',
[188339] = '1/100/100/100',
[188340] = '1/60/70/80',
[188341] = '1/80/90/100',
[188342] = '1/100/100/100',
[188343] = '1/60/70/80',
[188344] = '1/80/90/100',
[188345] = '1/100/100/100',
[188346] = '1/60/70/80',
[188347] = '1/80/90/100',
[188348] = '1/100/100/100',
[188349] = '1/60/70/80',
[188350] = '1/80/90/100',
[188351] = '1/100/100/100',
[188800] = '1/20/50/80',
[188801] = '1/20/50/80',
[188802] = '1/20/50/80',
[190381] = '1/1/8/15',
[190382] = '1/1/8/15',
[190383] = '1/1/8/15',
[190384] = '1/1/8/15',
[190385] = '1/1/8/15',
[190386] = '1/1/8/15',
[186388] = '1/20/40/60',
[190788] = '1/1/8/15',
[190866] = '1/20/30/40',
[190867] = '1/20/30/40',
[190868] = '1/20/30/40',
[190869] = '1/20/30/40',
[190870] = '1/60/70/80',
[190871] = '1/60/70/80',
[190872] = '1/60/70/80',
[190873] = '1/60/70/80',
[190874] = '1/20/30/40',
[190875] = '1/20/30/40',
[190876] = '1/20/30/40',
[190877] = '1/60/70/80',
[190878] = '1/60/70/80',
[190879] = '1/60/70/80',
[190892] = '1/40/50/60',
[190893] = '1/40/50/60',
[190894] = '1/40/50/60',
[190954] = '1/20/40/60',
[190988] = '1/20/45/70',
[190989] = '1/20/45/70',
[190990] = '1/20/45/70',
[190991] = '1/20/45/70',
[190992] = '1/40/50/60',
[190993] = '1/40/50/60',
[190994] = '1/40/50/60',
[190995] = '1/40/50/60',
[190996] = '1/80/90/100',
[190997] = '1/80/90/100',
[190998] = '1/80/90/100',
[190999] = '1/80/90/100',
[191000] = '1/40/50/60',
[191001] = '1/40/50/60',
[191002] = '1/40/50/60',
[191003] = '1/80/90/100',
[191004] = '1/80/90/100',
[191005] = '1/80/90/100',
[191006] = '1/60/70/80',
[191007] = '1/60/70/80',
[191008] = '1/60/70/80',
[191009] = '1/60/70/80',
[191010] = '1/60/70/80',
[191011] = '1/60/70/80',
[191012] = '1/60/70/80',
[191013] = '1/100/100/100',
[191014] = '1/100/100/100',
[191015] = '1/100/100/100',
[191016] = '1/100/100/100',
[191017] = '1/60/70/80',
[191018] = '1/60/70/80',
[191019] = '1/60/70/80',
[191020] = '1/100/100/100',
[191021] = '1/100/100/100',
[191022] = '1/100/100/100',
[191023] = '1/80/90/100',
[191024] = '1/80/90/100',
[191025] = '1/80/90/100',
[191074] = '1/20/40/60',
[191075] = '1/20/40/60',
[191076] = '1/20/40/60',
[191078] = '1/20/40/60',
[191928] = '1/60/70/80',
[191929] = '1/60/70/80',
[191930] = '1/60/70/80',
[191931] = '1/60/70/80',
[191970] = '1/1/1/1',
[191659] = '1/40/50/60',
[192854] = '1/60/70/80',
[192855] = '1/80/90/100',
[192856] = '1/100/100/100',
[192808] = '1/40/50/60',
[192809] = '1/40/50/60',
[192810] = '1/40/50/60',
[192811] = '1/40/50/60',
[192812] = '1/40/50/60',
[192813] = '1/40/50/60',
[192814] = '1/40/50/60',
[192815] = '1/60/70/80',
[192816] = '1/60/70/80',
[192817] = '1/60/70/80',
[192818] = '1/60/70/80',
[192819] = '1/60/70/80',
[192820] = '1/60/70/80',
[192821] = '1/60/70/80',
[192822] = '1/60/70/80',
[192823] = '1/60/70/80',
[192824] = '1/60/70/80',
[222408] = '1/20/50/80',
[192802] = '1/20/40/60',
[192838] = '1/20/45/70',
[192839] = '1/20/45/70',
[192840] = '1/20/45/70',
[192841] = '1/20/45/70',
[192842] = '1/20/45/70',
[192843] = '1/20/45/70',
[192844] = '1/20/45/70',
[192845] = '1/20/45/70',
[192846] = '1/20/45/70',
[228381] = '1/20/45/70',
[192849] = '1/20/45/70',
[192850] = '1/20/45/70',
[192851] = '1/20/45/70',
[192852] = '1/20/45/70',
[192804] = '1/20/40/60',
[192859] = '1/60/70/80',
[192860] = '1/60/70/80',
[192861] = '1/60/70/80',
[192862] = '1/60/70/80',
[192863] = '1/60/70/80',
[192864] = '1/60/70/80',
[192865] = '1/60/70/80',
[192866] = '1/60/70/80',
[192867] = '1/80/90/100',
[192868] = '1/80/90/100',
[192869] = '1/80/90/100',
[192870] = '1/80/90/100',
[192871] = '1/80/90/100',
[192872] = '1/80/90/100',
[192873] = '1/80/90/100',
[192874] = '1/80/90/100',
[192875] = '1/80/90/100',
[192876] = '1/80/90/100',
[192890] = '1/80/90/100',
[192891] = '1/80/90/100',
[192892] = '1/80/90/100',
[192893] = '1/80/90/100',
[192894] = '1/80/90/100',
[192895] = '1/80/90/100',
[192896] = '1/80/90/100',
[192897] = '1/80/90/100',
[192898] = '1/100/100/100',
[192899] = '1/100/100/100',
[192900] = '1/100/100/100',
[192901] = '1/100/100/100',
[192902] = '1/100/100/100',
[192903] = '1/100/100/100',
[192904] = '1/100/100/100',
[192905] = '1/100/100/100',
[192906] = '1/100/100/100',
[192907] = '1/100/100/100',
[194695] = '1/20/30/40',
[194696] = '1/20/30/40',
[194697] = '1/20/30/40',
[194698] = '1/20/30/40',
[194699] = '1/20/30/40',
[194700] = '1/20/30/40',
[194701] = '1/20/30/40',
[194702] = '1/20/30/40',
[194703] = '1/40/50/60',
[194704] = '1/40/50/60',
[194705] = '1/40/50/60',
[194706] = '1/40/50/60',
[194707] = '1/40/50/60',
[194708] = '1/40/50/60',
[194709] = '1/40/50/60',
[194710] = '1/40/50/60',
[194711] = '1/60/70/80',
[194712] = '1/60/70/80',
[194713] = '1/60/70/80',
[194714] = '1/60/70/80',
[194715] = '1/60/70/80',
[194716] = '1/60/70/80',
[194717] = '1/60/70/80',
[194718] = '1/60/70/80',
[194719] = '1/80/90/100',
[194720] = '1/80/90/100',
[194721] = '1/80/90/100',
[194722] = '1/80/90/100',
[194723] = '1/80/90/100',
[194724] = '1/80/90/100',
[194725] = '1/80/90/100',
[194726] = '1/80/90/100',
[194727] = '1/100/100/100',
[194728] = '1/100/100/100',
[194729] = '1/100/100/100',
[194730] = '1/100/100/100',
[194731] = '1/100/100/100',
[194732] = '1/100/100/100',
[194733] = '1/100/100/100',
[194734] = '1/100/100/100',
[194784] = '1/60/70/80',
[194785] = '1/60/70/80',
[194786] = '1/60/70/80',
[194787] = '1/60/70/80',
[194788] = '1/60/70/80',
[194789] = '1/60/70/80',
[194790] = '1/60/70/80',
[194791] = '1/60/70/80',
[194735] = '1/20/30/40',
[194736] = '1/20/30/40',
[194737] = '1/20/30/40',
[194738] = '1/20/30/40',
[194739] = '1/20/30/40',
[194740] = '1/20/30/40',
[194741] = '1/20/30/40',
[194742] = '1/20/30/40',
[194743] = '1/40/50/60',
[194744] = '1/40/50/60',
[194745] = '1/40/50/60',
[194746] = '1/40/50/60',
[194747] = '1/40/50/60',
[194748] = '1/40/50/60',
[194749] = '1/40/50/60',
[194750] = '1/40/50/60',
[194751] = '1/60/70/80',
[194752] = '1/60/70/80',
[194753] = '1/60/70/80',
[194754] = '1/60/70/80',
[194755] = '1/60/70/80',
[194756] = '1/60/70/80',
[194757] = '1/60/70/80',
[194758] = '1/60/70/80',
[194759] = '1/80/90/100',
[194760] = '1/80/90/100',
[194761] = '1/80/90/100',
[194762] = '1/80/90/100',
[194763] = '1/80/90/100',
[194764] = '1/80/90/100',
[194765] = '1/80/90/100',
[194766] = '1/80/90/100',
[194767] = '1/100/100/100',
[194768] = '1/100/100/100',
[194769] = '1/100/100/100',
[194770] = '1/100/100/100',
[194771] = '1/100/100/100',
[194772] = '1/100/100/100',
[194773] = '1/100/100/100',
[194774] = '1/100/100/100',
[194792] = '1/60/70/80',
[194793] = '1/60/70/80',
[194794] = '1/60/70/80',
[194795] = '1/60/70/80',
[194796] = '1/60/70/80',
[194797] = '1/60/70/80',
[194798] = '1/60/70/80',
[194799] = '1/60/70/80',
[194775] = '1/20/45/70',
[194776] = '1/20/45/70',
[194778] = '1/20/32/45',
[194779] = '1/20/45/70',
[194780] = '1/100/100/100',
[195856] = '1/20/30/40',
[195857] = '1/20/30/40',
[195858] = '1/20/30/40',
[195859] = '1/40/50/60',
[195860] = '1/40/50/60',
[195861] = '1/40/50/60',
[195862] = '1/40/50/60',
[195863] = '1/40/50/60',
[195864] = '1/40/50/60',
[195865] = '1/60/70/80',
[195866] = '1/60/70/80',
[195867] = '1/60/70/80',
[195868] = '1/60/70/80',
[195869] = '1/60/70/80',
[195870] = '1/60/70/80',
[195871] = '1/60/70/80',
[195872] = '1/60/70/80',
[195873] = '1/60/70/80',
[195874] = '1/60/70/80',
[195875] = '1/60/70/80',
[195876] = '1/60/70/80',
[195877] = '1/70/80/90',
[195878] = '1/80/90/100',
[195879] = '1/80/90/100',
[195880] = '1/80/90/100',
[195881] = '1/20/40/60',
[195882] = '1/100/100/100',
[195883] = '1/20/40/60',
[195902] = '1/40/50/60',
[195903] = '1/40/50/60',
[195904] = '1/40/50/60',
[195905] = '1/60/70/80',
[195906] = '1/60/70/80',
[195907] = '1/60/70/80',
[195908] = '1/60/70/80',
[195909] = '1/60/70/80',
[195910] = '1/60/70/80',
[195911] = '1/80/90/100',
[195912] = '1/80/90/100',
[195913] = '1/80/90/100',
[195914] = '1/80/90/100',
[195915] = '1/80/90/100',
[195916] = '1/80/90/100',
[195917] = '1/80/90/100',
[195918] = '1/80/90/100',
[195919] = '1/80/90/100',
[195920] = '1/80/90/100',
[195921] = '1/80/90/100',
[195922] = '1/80/90/100',
[195923] = '1/60/70/80',
[195924] = '1/60/70/80',
[195925] = '1/60/70/80',
[195926] = '1/80/90/100',
[195927] = '1/80/90/100',
[195928] = '1/80/90/100',
[195929] = '1/80/90/100',
[195930] = '1/80/90/100',
[195931] = '1/80/90/100',
[195932] = '1/100/100/100',
[195933] = '1/100/100/100',
[195934] = '1/100/100/100',
[195935] = '1/100/100/100',
[195936] = '1/100/100/100',
[195937] = '1/100/100/100',
[195938] = '1/100/100/100',
[195939] = '1/100/100/100',
[195940] = '1/100/100/100',
[195941] = '1/100/100/100',
[195942] = '1/100/100/100',
[195943] = '1/100/100/100',
[195848] = '1/20/35/50',
[195849] = '1/20/35/50',
[195850] = '1/20/35/50',
[195851] = '1/20/35/50',
[195852] = '1/40/55/70',
[195853] = '1/40/55/70',
[195854] = '1/40/55/70',
[195855] = '1/40/55/70',
[195095] = '1/1/1/1',
[195127] = '1/1/1/1',
[195097] = '1/1/1/1',
[195096] = '1/1/1/1',
[195112] = '1/1/1/1',
[195114] = '1/1/1/1',
[195115] = '1/1/1/1',
[195116] = '1/1/1/1',
[195119] = '1/1/1/1',
[195122] = '1/1/1/1',
[195126] = '1/1/1/1',
[195128] = '1/1/1/1',
[196375] = '1/1/1/1',
[196379] = '1/1/1/1',
[196382] = '1/1/1/1',
[196383] = '1/1/1/1',
[196384] = '1/1/1/1',
[196385] = '1/1/1/1',
[196387] = '1/1/1/1',
[196388] = '1/1/1/1',
[196395] = '1/1/1/1',
[196397] = '1/1/1/1',
[196425] = '1/1/1/1',
[196427] = '1/1/1/1',
[196428] = '1/1/1/1',
[196442] = '1/1/1/1',
[196456] = '1/1/1/1',
[196457] = '1/1/1/1',
[196467] = '1/1/1/1',
[196468] = '1/1/1/1',
[196469] = '1/1/1/1',
[196648] = '1/20/32/45',
[196470] = '1/800/800/800',
[196471] = '1/800/800/800',
[196472] = '1/800/800/800',
[196473] = '1/800/800/800',
[196474] = '1/800/800/800',
[196475] = '1/800/800/800',
[196476] = '1/800/800/800',
[196477] = '1/800/800/800',
[196478] = '1/800/800/800',
[196479] = '1/800/800/800',
[196480] = '1/800/800/800',
[196481] = '1/800/800/800',
[196482] = '1/800/800/800',
[196483] = '1/800/800/800',
[196484] = '1/800/800/800',
[198939] = '1/20/30/40',
[198965] = '1/20/30/40',
[198966] = '1/20/30/40',
[198967] = '1/20/30/40',
[198968] = '1/60/70/80',
[198969] = '1/60/70/80',
[198970] = '1/60/70/80',
[198971] = '1/60/70/80',
[198972] = '1/40/50/60',
[198973] = '1/40/50/60',
[198974] = '1/40/50/60',
[198975] = '1/40/50/60',
[198976] = '1/40/50/60',
[198977] = '1/40/50/60',
[198978] = '1/20/40/60',
[198979] = '1/20/40/60',
[198980] = '1/80/90/100',
[198981] = '1/90/95/100',
[198982] = '1/20/30/40',
[198983] = '1/20/40/60',
[198984] = '1/20/40/60',
[198987] = '1/20/40/60',
[198988] = '1/20/40/60',
[198989] = '1/20/40/60',
[198990] = '1/20/40/60',
[198991] = '1/40/50/60',
[198992] = '1/40/50/60',
[198993] = '1/40/50/60',
[198994] = '1/40/50/60',
[198995] = '1/100/100/100',
[198996] = '1/100/100/100',
[198997] = '1/100/100/100',
[198998] = '1/100/100/100',
[198999] = '1/60/70/80',
[199000] = '1/60/70/80',
[199001] = '1/60/70/80',
[199002] = '1/60/70/80',
[199003] = '1/60/70/80',
[199004] = '1/60/70/80',
[199005] = '1/60/70/80',
[199006] = '1/60/70/80',
[199007] = '1/60/70/80',
[199008] = '1/60/70/80',
[199009] = '1/90/95/100',
[199010] = '1/90/95/100',
[199011] = '1/90/95/100',
[199012] = '1/90/95/100',
[199013] = '1/80/90/100',
[199014] = '1/80/90/100',
[199015] = '1/80/90/100',
[199016] = '1/80/90/100',
[199017] = '1/80/90/100',
[199018] = '1/80/90/100',
[200466] = '1/20/40/60',
[201413] = '1/20/30/40',
[201496] = '1/20/30/40',
[201497] = '1/20/30/40',
[201498] = '1/20/30/40',
[201499] = '1/20/30/40',
[201500] = '1/40/50/60',
[201501] = '1/40/50/60',
[201502] = '1/40/50/60',
[201503] = '1/40/50/60',
[201504] = '1/40/50/60',
[201505] = '1/60/70/80',
[201506] = '1/60/70/80',
[201507] = '1/60/70/80',
[201508] = '1/60/70/80',
[201511] = '1/60/70/80',
[201512] = '1/20/30/40',
[201513] = '1/20/30/40',
[201514] = '1/20/30/40',
[201515] = '1/40/50/60',
[201516] = '1/60/70/80',
[201524] = '1/40/50/60',
[201525] = '1/40/50/60',
[201526] = '1/40/50/60',
[201527] = '1/40/50/60',
[201528] = '1/40/50/60',
[201529] = '1/60/70/80',
[201530] = '1/60/70/80',
[201531] = '1/60/70/80',
[201532] = '1/60/70/80',
[201533] = '1/60/70/80',
[201534] = '1/80/90/100',
[201535] = '1/80/90/100',
[201536] = '1/80/90/100',
[201537] = '1/80/90/100',
[201538] = '1/80/90/100',
[201539] = '1/40/50/60',
[201540] = '1/40/50/60',
[201541] = '1/40/50/60',
[201542] = '1/60/70/80',
[201543] = '1/80/90/100',
[201544] = '1/60/70/80',
[201545] = '1/60/70/80',
[201546] = '1/60/70/80',
[201547] = '1/60/70/80',
[201548] = '1/60/70/80',
[201549] = '1/80/90/100',
[201550] = '1/80/90/100',
[201551] = '1/80/90/100',
[201552] = '1/80/90/100',
[201553] = '1/80/90/100',
[201554] = '1/100/100/100',
[201555] = '1/100/100/100',
[201556] = '1/100/100/100',
[201557] = '1/100/100/100',
[201558] = '1/100/100/100',
[201559] = '1/60/70/80',
[201560] = '1/60/70/80',
[201561] = '1/60/70/80',
[201562] = '1/80/90/100',
[201563] = '1/100/100/100',
[201683] = '1/60/70/80',
[201684] = '1/80/90/100',
[201685] = '1/100/100/100',
[205243] = '1/1/1/1',
[208350] = '1/60/70/80',
[208351] = '1/60/70/80',
[208352] = '1/60/70/80',
[208353] = '1/60/70/80',
[208596] = '1/1/1/1',
[208615] = '1/1/1/1',
[209496] = '1/20/45/70',
[209497] = '1/20/45/70',
[209498] = '1/20/45/70',
[209499] = '1/20/45/70',
[209501] = '1/20/45/70',
[209502] = '1/20/45/70',
[209507] = '1/20/45/70',
[209509] = '1/20/45/70',
[209510] = '1/20/45/70',
[209511] = '1/20/45/70',
[209564] = '1/20/32/45',
[209603] = '1/20/30/40',
[209604] = '1/40/50/60',
[209605] = '1/40/50/60',
[209606] = '1/40/50/60',
[209607] = '1/60/70/80',
[209608] = '1/60/70/80',
[209609] = '1/60/70/80',
[209610] = '1/80/90/100',
[209611] = '1/80/90/100',
[209645] = '1/20/40/60',
[209646] = '1/20/40/60',
[209658] = '1/1/8/15',
[209659] = '1/1/8/15',
[209660] = '1/1/8/15',
[209661] = '1/1/8/15',
[209662] = '1/1/8/15',
[209664] = '1/1/8/15',
[210116] = '1/1/8/15',
[210653] = '1/50/70/90',
[210654] = '1/50/70/90',
[210656] = '1/50/70/90',
[213035] = '1/20/40/60',
[213036] = '1/20/40/60',
[213037] = '1/20/40/60',
[213248] = '1/20/50/80',
[213249] = '1/20/50/80',
[213250] = '1/20/50/80',
[213251] = '1/20/50/80',
[213252] = '1/20/50/80',
[213253] = '1/20/50/80',
[213254] = '1/20/50/80',
[213255] = '1/20/50/80',
[213256] = '1/20/50/80',
[213257] = '1/20/50/80',
[217651] = '1/70/72/75',
[217637] = '1/290/295/300',
[217641] = '1/70/72/75',
[217644] = '1/70/72/75',
[217645] = '1/70/72/75',
[217649] = '1/70/72/75',
[217650] = '1/70/72/75',
[217655] = '1/90/95/100',
[213916] = '1/100/105/110',
[223940] = '1/50/70/90',
[223941] = '1/50/70/90',
[220511] = '1/20/40/60',
[224199] = '1/1/3/5',
[225522] = '1/20/45/70',
[225524] = '1/20/45/70',
[225525] = '1/20/45/70',
[225527] = '1/20/45/70',
[225528] = '1/20/45/70',
[225529] = '1/20/45/70',
[225530] = '1/20/45/70',
[225531] = '1/20/45/70',
[225532] = '1/20/45/70',
[225533] = '1/20/45/70',
[225534] = '1/20/45/70',
[225535] = '1/20/45/70',
[225536] = '1/20/45/70',
[225538] = '1/20/45/70',
[225539] = '1/20/45/70',
[225541] = '1/20/45/70',
[225543] = '1/20/45/70',
[225545] = '1/20/45/70',
[225546] = '1/20/45/70',
[225547] = '1/20/45/70',
[225548] = '1/20/45/70',
[225549] = '1/20/45/70',
[225550] = '1/20/45/70',
[225551] = '1/20/45/70',
[225552] = '1/20/45/70',
[225554] = '1/20/45/70',
[225556] = '1/20/45/70',
[225558] = '1/20/45/70',
[225560] = '1/20/45/70',
[225902] = '1/1/1/1',
[225904] = '1/1/1/1',
[226137] = '1/220/230/240',
[226136] = '1/220/230/240',
[226135] = '1/220/230/240',
[226134] = '1/220/230/240',
[226133] = '1/215/225/235',
[226132] = '1/215/225/235',
[226131] = '1/210/220/230',
[226130] = '1/195/205/215',
[226129] = '1/195/205/215',
[226128] = '1/195/205/215',
[226127] = '1/190/200/210',
[226126] = '1/185/195/205',
[226125] = '1/180/190/200',
[226124] = '1/180/190/200',
[226123] = '1/170/180/190',
[226121] = '1/160/172/185',
[226120] = '1/155/167/180',
[226119] = '1/150/162/175',
[226118] = '1/145/157/170',
[226117] = '1/140/152/165',
[226116] = '1/135/147/160',
[226113] = '1/125/137/150',
[226112] = '1/125/137/150',
[226111] = '1/125/140/155',
[226109] = '1/120/135/150',
[226108] = '1/115/130/145',
[226107] = '1/110/125/140',
[226106] = '1/100/115/130',
[226105] = '1/85/100/115',
[226248] = '1/50/60/70',
[227043] = '1/20/40/60',
[227239] = '1/50/60/70',
[227240] = '1/50/60/70',
[227561] = '1/1/20/40',
[227562] = '1/1/35/70',
[226110] = '1/120/135/150',
[226114] = '1/125/137/150',
[226115] = '1/130/142/155',
[226122] = '1/165/175/185',
[228402] = '1/40/50/60',
[228403] = '1/60/70/80',
[228404] = '1/80/90/100',
[228405] = '1/40/50/60',
[228406] = '1/60/70/80',
[228407] = '1/80/90/100',
[228408] = '1/40/50/60',
[228409] = '1/60/70/80',
[228410] = '1/80/90/100',
[198985] = '1/20/40/60',
[229177] = '1/60/70/80',
[229178] = '1/60/70/80',
[229179] = '1/60/70/80',
[229180] = '1/60/70/80',
[229181] = '1/60/70/80',
[229182] = '1/60/70/80',
[229183] = '1/80/90/100',
[229184] = '1/80/90/100',
[229185] = '1/80/90/100',
[229217] = '1/60/70/80',
[229218] = '1/80/90/100',
[229220] = '1/100/100/100',
[230046] = '1/80/90/100',
[230936] = '1/20/40/60',
[230954] = '1/40/50/60',
[230955] = '1/60/70/80',
[232274] = '1/20/45/70',
[232275] = '1/20/45/70',
[229041] = '1/100/100/100',
[229043] = '1/100/100/100',
[229045] = '1/100/100/100',
[233278] = '1/20/45/70',
[235695] = '1/40/50/60',
[235696] = '1/40/50/60',
[235697] = '1/40/50/60',
[235698] = '1/40/50/60',
[235699] = '1/50/60/70',
[235700] = '1/50/60/70',
[235701] = '1/50/60/70',
[235702] = '1/50/60/70',
[235703] = '1/60/70/80',
[235704] = '1/60/70/80',
[235705] = '1/60/70/80',
[235706] = '1/60/70/80',
[235753] = '1/100/100/100',
[235754] = '1/100/100/100',
[235755] = '1/100/100/100',
[235756] = '1/100/100/100',
[235775] = '1/60/70/80',
[238577] = '1/40/50/60',
[238578] = '1/60/70/80',
[238579] = '1/80/90/100',
[240272] = '1/20/45/70',
[239412] = '1/100/105/110',
[239414] = '1/100/100/100',
[239413] = '1/100/100/100',
[239415] = '1/100/100/100',
[225559] = '1/20/45/70',
[148275] = '1/1/10/20',
[246984] = '1/20/45/70',
[246982] = '1/20/45/70',
[247619] = '1/80/90/100',
[247620] = '1/80/90/100',
[247622] = '1/80/90/100',
[247688] = '1/80/90/100',
[247690] = '1/80/90/100',
[247691] = '1/80/90/100',
[247694] = '1/90/95/100',
[247695] = '1/90/95/100',
[247696] = '1/90/95/100',
[247710] = '1/90/95/100',
[247713] = '1/90/95/100',
[247714] = '1/90/95/100',
[247700] = '1/20/32/45',
[247717] = '1/20/40/60',
[247744] = '1/75/87/100',
[247861] = '1/1/8/15',
[247751] = '1/90/95/100',
[247754] = '1/90/95/100',
[247755] = '1/90/95/100',
[247771] = '1/80/90/100',
[247773] = '1/80/90/100',
[247772] = '1/80/90/100',
[247774] = '1/80/90/100',
[247756] = '1/90/95/100',
[247757] = '1/90/95/100',
[247758] = '1/90/95/100',
[247762] = '1/90/95/100',
[247763] = '1/90/95/100',
[247764] = '1/90/95/100',
[247761] = '1/1/1/1',
[247765] = '1/90/95/100',
[247766] = '1/90/95/100',
[247767] = '1/90/95/100',
[247800] = '1/90/95/100',
[247801] = '1/90/95/100',
[247802] = '1/90/95/100',
[247803] = '1/90/95/100',
[247804] = '1/90/95/100',
[247805] = '1/90/95/100',
[247848] = '1/1/1/1',
[247849] = '1/1/1/1',
[247850] = '1/1/1/1',
[247851] = '1/1/1/1',
[247852] = '1/1/1/1',
[247853] = '1/1/1/1',
[247807] = '1/90/95/100',
[247808] = '1/90/95/100',
[247809] = '1/90/95/100',
[247701] = '1/20/50/80',
[248864] = '1/1/1/1',
[248870] = '1/1/1/1',
[248867] = '1/1/1/1',
[248869] = '1/1/1/1',
[251258] = '1/50/70/90',
[247614] = '1/80/90/100',
[247615] = '1/80/90/100',
[247616] = '1/80/90/100',
[251658] = '1/80/90/100',
[251651] = '1/60/70/80',
[251646] = '1/40/50/60',
[252106] = '1/60/70/80',
[254227] = '1/20/45/70',
[254231] = '1/20/45/70',
[254238] = '1/20/45/70',
[256123] = '1/170/172/175',
[246999] = '1/20/45/70',
[253165] = '1/25/37/50',
[253162] = '1/80/90/100',
[253168] = '1/15/32/50',
[253171] = '1/30/47/65',
[253174] = '1/45/72/100',
[253113] = '1/30/47/65',
[253177] = '1/50/70/90',
[253180] = '1/25/37/50',
[253183] = '1/10/17/25',
[253186] = '1/150/150/150',
[253187] = '1/150/150/150',
[253188] = '1/150/150/150',
[253116] = '1/110/130/150',
[253117] = '1/125/137/150',
[253118] = '1/135/142/150',
[253190] = '1/150/150/150',
[253191] = '1/150/150/150',
[253192] = '1/150/150/150',
[253110] = '1/80/90/100',
[253112] = '1/80/90/100',
[253125] = '1/15/32/50',
[253132] = '1/45/72/100',
[253135] = '1/45/72/100',
[253138] = '1/15/32/50',
[253141] = '1/45/72/100',
[253156] = '1/110/130/150',
[253157] = '1/125/137/150',
[253158] = '1/135/142/150',
[253159] = '1/110/130/150',
[253160] = '1/125/137/150',
[253161] = '1/135/142/150',
[252334] = '1/60/72/85',
[252335] = '1/75/95/115',
[252336] = '1/100/117/135',
[252337] = '1/60/72/85',
[252339] = '1/75/95/115',
[252340] = '1/100/117/135',
[252341] = '1/60/72/85',
[252342] = '1/75/95/115',
[252343] = '1/100/117/135',
[252344] = '1/60/72/85',
[252345] = '1/75/95/115',
[252346] = '1/100/117/135',
[252348] = '1/105/115/125',
[252349] = '1/140/145/150',
[252350] = '1/150/150/150',
[252351] = '1/105/115/125',
[252352] = '1/140/145/150',
[252353] = '1/150/150/150',
[252354] = '1/105/115/125',
[252355] = '1/140/145/150',
[252356] = '1/150/150/150',
[252357] = '1/105/115/125',
[252358] = '1/140/145/150',
[252359] = '1/150/150/150',
[252361] = '1/50/62/75',
[252362] = '1/80/102/125',
[252363] = '1/90/110/130',
[252368] = '1/50/62/75',
[252369] = '1/80/102/125',
[252370] = '1/90/110/130',
[252376] = '1/95/110/125',
[252377] = '1/110/130/150',
[252378] = '1/150/150/150',
[252379] = '1/95/110/125',
[252380] = '1/110/130/150',
[252381] = '1/150/150/150',
[252382] = '1/25/37/50',
[252383] = '1/50/62/75',
[252384] = '1/75/87/100',
[252385] = '1/25/37/50',
[252386] = '1/50/62/75',
[252387] = '1/75/87/100',
[252388] = '1/25/37/50',
[252389] = '1/50/62/75',
[252390] = '1/75/87/100',
[252391] = '1/50/62/75',
[252392] = '1/65/82/100',
[252393] = '1/85/105/125',
[251305] = '1/30/90/150',
[251306] = '1/30/90/150',
[251309] = '1/30/90/150',
[251310] = '1/30/90/150',
[251311] = '1/30/90/150',
[251314] = '1/30/90/150',
[251808] = '1/30/90/150',
[251822] = '1/30/90/150',
[251832] = '1/90/120/150',
[252394] = '1/50/62/75',
[252395] = '1/65/82/100',
[252396] = '1/85/105/125',
[252397] = '1/50/62/75',
[252398] = '1/65/82/100',
[252399] = '1/85/105/125',
[252400] = '1/50/62/75',
[252401] = '1/65/82/100',
[252402] = '1/85/105/125',
[255070] = '1/10/30/50',
[255068] = '1/35/55/75',
[255035] = '1/10/30/50',
[255040] = '1/10/30/50',
[255065] = '1/10/30/50',
[255066] = '1/10/30/50',
[255071] = '1/25/37/50',
[255086] = '1/40/57/75',
[255094] = '1/75/87/100',
[255072] = '1/25/37/50',
[255087] = '1/40/57/75',
[255095] = '1/75/87/100',
[255073] = '1/25/37/50',
[255088] = '1/40/57/75',
[255096] = '1/75/87/100',
[255074] = '1/25/37/50',
[255089] = '1/40/57/75',
[255097] = '1/75/87/100',
[255075] = '1/100/117/135',
[255090] = '1/120/135/150',
[255098] = '1/115/132/150',
[255076] = '1/100/117/135',
[255091] = '1/120/135/150',
[255099] = '1/115/132/150',
[255077] = '1/100/117/135',
[255092] = '1/120/135/150',
[255100] = '1/115/132/150',
[255078] = '1/100/117/135',
[255093] = '1/120/135/150',
[255101] = '1/115/132/150',
[255103] = '1/75/87/100',
[255104] = '1/105/120/135',
[255105] = '1/115/130/145',
[255110] = '1/75/87/100',
[255111] = '1/105/120/135',
[255112] = '1/115/130/145',
[255141] = '1/75/87/100',
[255142] = '1/105/120/135',
[255143] = '1/115/130/145',
[255129] = '1/75/87/100',
[255130] = '1/105/120/135',
[255131] = '1/115/130/145',
[255392] = '1/25/37/50',
[255393] = '1/50/67/85',
[255394] = '1/75/87/100',
[255395] = '1/25/37/50',
[255396] = '1/50/67/85',
[255397] = '1/75/87/100',
[255407] = '1/25/37/50',
[255408] = '1/50/67/85',
[255409] = '1/75/87/100',
[256073] = '1/35/67/100',
[256074] = '1/80/97/115',
[256075] = '1/95/110/125',
[256070] = '1/35/67/100',
[256071] = '1/80/97/115',
[256072] = '1/95/110/125',
[256080] = '1/35/67/100',
[256082] = '1/80/97/115',
[256084] = '1/95/110/125',
[256154] = '1/35/67/100',
[256155] = '1/80/97/115',
[256156] = '1/95/110/125',
[255457] = '1/125/137/150',
[255458] = '1/135/142/150',
[255459] = '1/145/147/150',
[256232] = '1/95/110/125',
[256233] = '1/110/130/150',
[256234] = '1/125/137/150',
[256275] = '1/95/115/135',
[256276] = '1/105/125/145',
[256277] = '1/115/132/150',
[256278] = '1/95/115/135',
[256279] = '1/105/125/145',
[256280] = '1/115/132/150',
[256281] = '1/95/115/135',
[256282] = '1/105/125/145',
[256283] = '1/115/132/150',
[256284] = '1/95/115/135',
[256285] = '1/105/125/145',
[256286] = '1/115/132/150',
[256287] = '1/95/115/135',
[256288] = '1/105/125/145',
[256289] = '1/115/132/150',
[256290] = '1/95/115/135',
[256291] = '1/105/125/145',
[256293] = '1/115/132/150',
[256294] = '1/95/115/135',
[256295] = '1/105/125/145',
[256296] = '1/115/132/150',
[256297] = '1/95/115/135',
[256298] = '1/105/125/145',
[256299] = '1/115/132/150',
[256217] = '1/70/75/80',
[256218] = '1/70/75/80',
[256219] = '1/70/75/80',
[256220] = '1/70/75/80',
[256221] = '1/70/75/80',
[256223] = '1/70/75/80',
[256308] = '1/70/75/80',
[256247] = '1/110/122/135',
[256248] = '1/150/150/150',
[256249] = '1/150/150/150',
[256235] = '1/25/50/75',
[256236] = '1/80/95/110',
[256237] = '1/75/92/110',
[256245] = '1/150/150/150',
[256246] = '1/150/150/150',
[256303] = '1/150/150/150',
[256304] = '1/150/150/150',
[256305] = '1/150/150/150',
[256690] = '1/15/50/85',
[256691] = '1/15/50/85',
[256689] = '1/15/50/85',
[256692] = '1/15/50/85',
[256693] = '1/15/50/85',
[256694] = '1/15/50/85',
[256695] = '1/105/125/145',
[256696] = '1/105/125/145',
[256698] = '1/105/125/145',
[256699] = '1/105/125/145',
[256700] = '1/150/150/150',
[256701] = '1/150/150/150',
[256702] = '1/150/150/150',
[256611] = '1/80/85/90',
[256613] = '1/80/85/90',
[256622] = '1/80/85/90',
[256510] = '1/75/105/135',
[256514] = '1/105/127/150',
[256515] = '1/125/137/150',
[256511] = '1/75/105/135',
[256516] = '1/105/127/150',
[256517] = '1/125/137/150',
[256512] = '1/75/105/135',
[256518] = '1/105/127/150',
[256519] = '1/125/137/150',
[256513] = '1/75/105/135',
[256520] = '1/105/127/150',
[256521] = '1/125/137/150',
[256255] = '1/105/120/135',
[256256] = '1/150/147/145',
[256257] = '1/150/150/150',
[256258] = '1/105/120/135',
[256259] = '1/150/147/145',
[256260] = '1/150/150/150',
[256791] = '1/150/150/150',
[256748] = '1/15/50/85',
[256749] = '1/50/75/100',
[256750] = '1/15/50/85',
[256751] = '1/50/75/100',
[256752] = '1/25/55/85',
[256754] = '1/50/75/100',
[256755] = '1/15/50/85',
[256756] = '1/10/47/85',
[256765] = '1/150/150/150',
[256766] = '1/150/150/150',
[256767] = '1/150/150/150',
[256768] = '1/150/150/150',
[256769] = '1/150/150/150',
[256770] = '1/150/150/150',
[256764] = '1/15/50/85',
[256763] = '1/50/75/100',
[256762] = '1/15/50/85',
[256761] = '1/50/75/100',
[256760] = '1/25/55/85',
[256759] = '1/50/75/100',
[256758] = '1/15/50/85',
[256757] = '1/10/47/85',
[256771] = '1/150/150/150',
[256772] = '1/150/150/150',
[256773] = '1/150/150/150',
[256774] = '1/150/150/150',
[256775] = '1/150/150/150',
[256776] = '1/150/150/150',
[256790] = '1/85/105/125',
[256792] = '1/85/105/125',
[256793] = '1/75/100/125',
[256777] = '1/25/55/85',
[256778] = '1/25/55/85',
[256787] = '1/100/117/135',
[256788] = '1/115/132/150',
[256789] = '1/120/135/150',
[256779] = '1/100/117/135',
[256780] = '1/115/132/150',
[256781] = '1/120/135/150',
[256782] = '1/100/117/135',
[256783] = '1/115/132/150',
[256784] = '1/120/135/150',
[257125] = '1/85/105/125',
[257126] = '1/110/127/145',
[257127] = '1/125/137/150',
[257128] = '1/150/150/150',
[257129] = '1/150/150/150',
[257130] = '1/150/150/150',
[257095] = '1/15/50/85',
[257104] = '1/75/87/100',
[257107] = '1/50/75/100',
[257096] = '1/15/50/85',
[257097] = '1/50/75/100',
[257099] = '1/25/55/85',
[257101] = '1/50/75/100',
[257102] = '1/15/50/85',
[257103] = '1/10/47/85',
[257114] = '1/100/117/135',
[257115] = '1/150/150/150',
[257116] = '1/150/150/150',
[257118] = '1/150/150/150',
[257120] = '1/150/150/150',
[257121] = '1/150/150/150',
[257122] = '1/150/150/150',
[257123] = '1/150/150/150',
[257124] = '1/150/150/150',
[257131] = '1/90/95/100',
[257132] = '1/150/150/150',
[257133] = '1/150/150/150',
[257134] = '1/90/95/100',
[257135] = '1/150/150/150',
[257136] = '1/150/150/150',
[257137] = '1/90/95/100',
[257138] = '1/150/150/150',
[257139] = '1/150/150/150',
[264769] = '1/50/75/100',
[264767] = '1/50/87/125',
[264766] = '1/50/75/100',
[264778] = '1/25/37/50',
[264777] = '1/25/37/50',
[264776] = '1/25/37/50',
[253152] = '1/145/147/150',
[253151] = '1/135/142/150',
[253150] = '1/125/137/150',
[253122] = '1/25/60/95',
[264960] = '1/50/82/115',
[264961] = '1/100/112/125',
[264962] = '1/115/125/135',
[264964] = '1/50/82/115',
[264966] = '1/100/112/125',
[264967] = '1/115/125/135',
[265097] = '1/50/75/100',
[265098] = '1/100/112/125',
[265099] = '1/115/125/135',
[265100] = '1/50/75/100',
[265101] = '1/100/112/125',
[265102] = '1/115/125/135',
[267201] = '1/10/42/75',
[267202] = '1/75/87/100',
[172539] = '1/1/25/50',
[88893] = '1/30/47/65',
[74556] = '1/25/30/35',
[230047] = '1/40/50/60',
[74558] = '1/30/47/65',
[45545] = '1/15/25/35',
[74557] = '1/50/62/75',
[45546] = '1/50/62/75',
[3276] = '1/80/90/100',
[10841] = '1/260/267/275',
[27033] = '1/50/62/75',
[18630] = '1/300/300/300',
[7929] = '1/210/225/240',
[102698] = '1/30/47/65',
[3278] = '1/150/167/185',
[3275] = '1/40/50/60',
[10840] = '1/240/245/250',
[27032] = '1/30/47/65',
[18629] = '1/290/295/300',
[7928] = '1/180/195/210',
[202853] = '1/10/20/30',
[202854] = '1/70/80/90',
[102697] = '1/25/27/30',
[3277] = '1/115/132/150',
[267458] = '1/10/30/50',
[267482] = '1/10/30/50',
[267486] = '1/10/30/50',
[267490] = '1/10/30/50',
[267495] = '1/35/55/75',
[267498] = '1/10/30/50',
[268852] = '1/75/95/115',
[268878] = '1/150/150/150',
[268879] = '1/150/150/150',
[268894] = '1/75/95/115',
[268895] = '1/150/150/150',
[268897] = '1/150/150/150',
[268901] = '1/75/95/115',
[268902] = '1/150/150/150',
[268903] = '1/150/150/150',
[268907] = '1/75/95/115',
[268908] = '1/150/150/150',
[268909] = '1/150/150/150',
[268913] = '1/75/95/115',
[268914] = '1/150/150/150',
[268915] = '1/150/150/150',
[268982] = '1/10/42/75',
[268983] = '1/85/105/125',
[269065] = '1/45/60/75',
[269064] = '1/20/60/100',
[255940] = '1/100/122/145',
[255936] = '1/100/122/145',
[269123] = '1/100/122/145',
[269424] = '1/110/130/150',
[269425] = '1/120/135/150',
[269426] = '1/130/140/150',
[269421] = '1/100/110/120',
[269422] = '1/110/122/135',
[269423] = '1/120/132/145',
[269444] = '1/115/132/150',
[269446] = '1/125/137/150',
[269447] = '1/135/142/150',
[269448] = '1/110/130/150',
[269449] = '1/120/135/150',
[269450] = '1/130/140/150',
[269451] = '1/100/110/120',
[269452] = '1/110/122/135',
[269453] = '1/120/132/145',
[269458] = '1/110/130/150',
[269459] = '1/120/135/150',
[269460] = '1/130/140/150',
[269464] = '1/100/110/120',
[269465] = '1/110/122/135',
[269466] = '1/120/132/145',
[269470] = '1/115/132/150',
[269471] = '1/125/137/150',
[269472] = '1/135/142/150',
[269476] = '1/100/110/120',
[269477] = '1/110/122/135',
[269478] = '1/120/132/145',
[269479] = '1/115/132/150',
[269480] = '1/125/137/150',
[269481] = '1/135/142/150',
[269516] = '1/100/117/135',
[269519] = '1/100/117/135',
[269522] = '1/100/117/135',
[269525] = '1/100/117/135',
[269528] = '1/100/117/135',
[269531] = '1/100/117/135',
[269534] = '1/100/117/135',
[269537] = '1/100/117/135',
[269540] = '1/100/117/135',
[269543] = '1/100/117/135',
[269552] = '1/100/117/135',
[269517] = '1/110/127/145',
[269518] = '1/120/135/150',
[269520] = '1/110/127/145',
[269521] = '1/120/135/150',
[269523] = '1/110/127/145',
[269524] = '1/120/135/150',
[269526] = '1/110/127/145',
[269527] = '1/120/135/150',
[269529] = '1/110/127/145',
[269530] = '1/120/135/150',
[269532] = '1/110/127/145',
[269533] = '1/120/135/150',
[269535] = '1/110/127/145',
[269536] = '1/120/135/150',
[269538] = '1/110/127/145',
[269539] = '1/120/135/150',
[269541] = '1/110/127/145',
[269542] = '1/120/135/150',
[269544] = '1/110/127/145',
[269545] = '1/120/135/150',
[269553] = '1/110/127/145',
[269554] = '1/120/135/150',
[269596] = '1/100/117/135',
[269597] = '1/110/127/145',
[269598] = '1/125/137/150',
[269599] = '1/100/117/135',
[269600] = '1/110/127/145',
[269601] = '1/125/137/150',
[269602] = '1/100/117/135',
[269603] = '1/110/127/145',
[269604] = '1/125/137/150',
[269605] = '1/100/117/135',
[269606] = '1/110/127/145',
[269607] = '1/125/137/150',
[269608] = '1/100/117/135',
[269609] = '1/110/127/145',
[269610] = '1/125/137/150',
[269611] = '1/100/117/135',
[269612] = '1/110/127/145',
[269613] = '1/125/137/150',
[265106] = '1/50/75/100',
[265110] = '1/100/125/150',
[265111] = '1/125/137/150',
[265112] = '1/125/137/150',
[269715] = '1/100/117/135',
[269716] = '1/110/127/145',
[269719] = '1/115/132/150',
[269724] = '1/125/137/150',
[269725] = '1/125/137/150',
[269726] = '1/135/142/150',
[269727] = '1/125/137/150',
[269728] = '1/125/137/150',
[269729] = '1/135/142/150',
[269734] = '1/105/120/135',
[269735] = '1/115/130/145',
[269736] = '1/125/137/150',
[269740] = '1/110/122/135',
[269741] = '1/115/130/145',
[269742] = '1/125/137/150',
[271366] = '1/35/55/75',
[271433] = '1/35/55/75',
[256253] = '1/50/75/100',
[256254] = '1/50/75/100',
[272056] = '1/130/140/150',
[272057] = '1/140/145/150',
[272058] = '1/150/150/150',
[272059] = '1/130/140/150',
[272060] = '1/140/145/150',
[272061] = '1/150/150/150',
[272062] = '1/130/140/150',
[272063] = '1/140/145/150',
[272064] = '1/150/150/150',
[272065] = '1/130/140/150',
[272066] = '1/140/145/150',
[272067] = '1/150/150/150',
[272226] = '1/25/50/75',
[272227] = '1/25/50/75',
[272228] = '1/25/50/75',
[272230] = '1/25/50/75',
[272278] = '1/60/65/70',
[272440] = '1/100/125/150',
[259411] = '1/35/67/100',
[259412] = '1/50/80/110',
[259413] = '1/60/90/120',
[259424] = '1/35/67/100',
[259425] = '1/50/80/110',
[259426] = '1/60/90/120',
[259430] = '1/15/45/75',
[259431] = '1/35/67/100',
[259432] = '1/50/80/110',
[259436] = '1/35/67/100',
[259437] = '1/50/80/110',
[259438] = '1/60/90/120',
[259442] = '1/35/67/100',
[259443] = '1/50/80/110',
[259444] = '1/60/90/120',
[259418] = '1/110/125/140',
[259419] = '1/150/150/150',
[259420] = '1/150/150/150',
[259421] = '1/150/150/150',
[259422] = '1/150/150/150',
[259423] = '1/150/150/150',
[259414] = '1/90/105/120',
[259415] = '1/110/130/150',
[259416] = '1/150/150/150',
[259427] = '1/90/105/120',
[259428] = '1/110/130/150',
[259429] = '1/150/150/150',
[259433] = '1/85/102/120',
[259434] = '1/110/130/150',
[259435] = '1/150/150/150',
[259439] = '1/90/105/120',
[259440] = '1/110/130/150',
[259441] = '1/150/150/150',
[259445] = '1/90/105/120',
[259446] = '1/110/130/150',
[259447] = '1/150/150/150',
[172542] = '1/75/87/100',
[172541] = '1/50/75/100',
[172540] = '1/1/25/50',
[221690] = '1/40/50/60',
[7934] = '1/80/115/150',
[7935] = '1/130/165/200',
[23787] = '1/300/300/300',
[274621] = '1/150/150/150',
[276088] = '1/75/100/125',
[276059] = '1/75/100/125',
[276121] = '1/150/150/150',
[276975] = '1/150/150/150',
[276976] = '1/150/150/150',
[276977] = '1/150/150/150',
[256786] = '1/100/110/120',
[253149] = '1/110/122/135',
[253144] = '1/120/132/145',
[278131] = '1/110/130/150',
[278132] = '1/125/137/150',
[278133] = '1/135/142/150',
[278411] = '1/95/110/125',
[278413] = '1/95/110/125',
[278414] = '1/95/110/125',
[278416] = '1/95/110/125',
[278415] = '1/95/110/125',
[278417] = '1/95/110/125',
[278418] = '1/95/110/125',
[278419] = '1/100/112/125',
[278420] = '1/95/110/125',
[278422] = '1/95/110/125',
[278423] = '1/95/110/125',
[276256] = '1/95/110/125',
[278527] = '1/110/130/150',
[278910] = '1/1/1/1',
[279159] = '1/75/100/125',
[279160] = '1/95/112/130',
[279161] = '1/100/117/135',
[279162] = '1/75/100/125',
[279163] = '1/95/112/130',
[279164] = '1/100/117/135',
[279165] = '1/75/100/125',
[279166] = '1/95/112/130',
[279167] = '1/100/117/135',
[279168] = '1/75/100/125',
[279169] = '1/95/112/130',
[279170] = '1/100/117/135',
[279183] = '1/85/117/150',
[279184] = '1/85/117/150',
[279182] = '1/85/117/150',
[280671] = '1/185/197/210',
[280732] = '1/35/67/100',
[280733] = '1/65/90/115',
[280734] = '1/95/110/125',
[280282] = '1/50/75/100',
[283249] = '1/135/142/150',
[283250] = '1/140/145/150',
[283251] = '1/145/147/150',
[283245] = '1/135/142/150',
[283247] = '1/140/145/150',
[283248] = '1/145/147/150',
[283242] = '1/135/142/150',
[283243] = '1/140/145/150',
[283244] = '1/145/147/150',
[282876] = '1/135/142/150',
[282878] = '1/140/145/150',
[282879] = '1/145/147/150',
[283239] = '1/135/142/150',
[283240] = '1/140/145/150',
[283241] = '1/145/147/150',
[282889] = '1/135/142/150',
[283237] = '1/140/145/150',
[283238] = '1/145/147/150',
[282871] = '1/135/142/150',
[282872] = '1/140/145/150',
[282873] = '1/145/147/150',
[282868] = '1/135/142/150',
[282869] = '1/140/145/150',
[282870] = '1/145/147/150',
[282865] = '1/135/142/150',
[282866] = '1/140/145/150',
[282867] = '1/145/147/150',
[282862] = '1/135/142/150',
[282863] = '1/140/145/150',
[282864] = '1/145/147/150',
[282859] = '1/135/142/150',
[282860] = '1/140/145/150',
[282861] = '1/145/147/150',
[282851] = '1/135/142/150',
[282855] = '1/140/145/150',
[282857] = '1/145/147/150',
[282806] = '1/135/142/150',
[282807] = '1/140/145/150',
[282808] = '1/145/147/150',
[282809] = '1/135/142/150',
[282810] = '1/140/145/150',
[282811] = '1/145/147/150',
[282803] = '1/135/142/150',
[282804] = '1/140/145/150',
[282805] = '1/145/147/150',
[282343] = '1/135/142/150',
[282344] = '1/140/145/150',
[282345] = '1/145/147/150',
[282327] = '1/135/142/150',
[282328] = '1/140/145/150',
[282329] = '1/145/147/150',
[282324] = '1/135/142/150',
[282325] = '1/140/145/150',
[282326] = '1/145/147/150',
[282321] = '1/135/142/150',
[282322] = '1/140/145/150',
[282323] = '1/145/147/150',
[282318] = '1/135/142/150',
[282319] = '1/140/145/150',
[282320] = '1/145/147/150',
[282312] = '1/135/142/150',
[282313] = '1/140/145/150',
[282314] = '1/145/147/150',
[282309] = '1/135/142/150',
[282310] = '1/140/145/150',
[282311] = '1/145/147/150',
[282306] = '1/135/142/150',
[282307] = '1/140/145/150',
[282308] = '1/145/147/150',
[282302] = '1/135/142/150',
[282303] = '1/140/145/150',
[282305] = '1/145/147/150',
[282290] = '1/135/142/150',
[282291] = '1/140/145/150',
[282292] = '1/145/147/150',
[282287] = '1/135/142/150',
[282288] = '1/140/145/150',
[282289] = '1/145/147/150',
[282277] = '1/135/142/150',
[282278] = '1/140/145/150',
[282281] = '1/145/147/150',
[282204] = '1/135/142/150',
[282275] = '1/140/145/150',
[282276] = '1/145/147/150',
[282194] = '1/135/142/150',
[282195] = '1/140/145/150',
[282196] = '1/145/147/150',
[282191] = '1/135/142/150',
[282192] = '1/140/145/150',
[282193] = '1/145/147/150',
[282175] = '1/135/142/150',
[282176] = '1/140/145/150',
[282177] = '1/145/147/150',
[282168] = '1/135/142/150',
[282169] = '1/140/145/150',
[282170] = '1/145/147/150',
[282164] = '1/135/142/150',
[282165] = '1/140/145/150',
[282166] = '1/145/147/150',
[283914] = '1/100/125/150',
[283915] = '1/125/137/150',
[283916] = '1/145/147/150',
[285639] = '1/150/150/150',
[285640] = '1/150/150/150',
[285641] = '1/150/150/150',
[285644] = '1/140/145/150',
[284292] = '1/125/137/150',
[284293] = '1/135/142/150',
[284294] = '1/145/147/150',
[284295] = '1/125/137/150',
[284296] = '1/135/142/150',
[284297] = '1/145/147/150',
[285895] = '1/100/112/125',
[286381] = '1/100/117/135',
[286478] = '1/135/140/145',
[286547] = '1/30/90/150',
[286630] = '1/1/25/50',
[286631] = '1/1/25/50',
[286644] = '1/1/25/50',
[286647] = '1/1/25/50',
[286649] = '1/1/25/50',
[286651] = '1/1/25/50',
[286652] = '1/1/25/50',
[286654] = '1/1/25/50',
[286665] = '1/100/100/100',
[285079] = '1/150/150/150',
[285087] = '1/150/150/150',
[285095] = '1/150/150/150',
[285080] = '1/150/150/150',
[285088] = '1/150/150/150',
[285096] = '1/150/150/150',
[285083] = '1/150/150/150',
[285091] = '1/150/150/150',
[285099] = '1/150/150/150',
[285084] = '1/150/150/150',
[285092] = '1/150/150/150',
[285100] = '1/150/150/150',
[285082] = '1/150/150/150',
[285090] = '1/150/150/150',
[285098] = '1/150/150/150',
[285081] = '1/150/150/150',
[285089] = '1/150/150/150',
[285097] = '1/150/150/150',
[285078] = '1/150/150/150',
[285086] = '1/150/150/150',
[285094] = '1/150/150/150',
[285077] = '1/150/150/150',
[285085] = '1/150/150/150',
[285093] = '1/150/150/150',
[286873] = '1/150/150/150',
[286874] = '1/150/150/150',
[286875] = '1/150/150/150',
[286867] = '1/150/150/150',
[286868] = '1/150/150/150',
[286869] = '1/150/150/150',
[286864] = '1/150/150/150',
[286865] = '1/150/150/150',
[286866] = '1/150/150/150',
[286870] = '1/150/150/150',
[286871] = '1/150/150/150',
[286872] = '1/150/150/150',
[286921] = '1/150/150/150',
[286922] = '1/150/150/150',
[286923] = '1/150/150/150',
[287108] = '1/150/150/150',
[287110] = '1/150/150/150',
[287112] = '1/150/150/150',
[286015] = '1/100/105/110',
[286016] = '1/110/115/120',
[286019] = '1/110/120/130',
[286021] = '1/115/125/135',
[287234] = '1/1/25/50',
[287235] = '1/1/25/50',
[287270] = '1/1/25/50',
[287279] = '1/1/25/50',
[287271] = '1/1/25/50',
[287272] = '1/1/25/50',
[287273] = '1/1/25/50',
[287274] = '1/1/25/50',
[287288] = '1/95/110/125',
[287447] = '1/50/62/75',
[287448] = '1/65/82/100',
[287449] = '1/85/105/125',
[287494] = '1/150/150/150',
[288027] = '1/35/67/100',
[288028] = '1/50/80/110',
[288029] = '1/60/90/120',
[288030] = '1/90/105/120',
[288032] = '1/110/130/150',
[288033] = '1/150/150/150',
[288182] = '1/1/1/1',
[288176] = '1/1/1/1',
[260403] = '1/150/150/150',
[289105] = '1/140/145/150',
[289174] = '1/145/147/150',
[289175] = '1/150/150/150',
[289179] = '1/145/147/150',
[289180] = '1/150/150/150',
[289181] = '1/150/150/150',
[289356] = '1/150/150/150',
[289313] = '1/150/150/150',
[253145] = '1/150/150/150',
[290360] = '1/1/50/100',
[290361] = '1/1/75/150',
[290471] = '1/120/125/130',
[290472] = '1/125/127/130',
[290473] = '1/130/132/135',
[291084] = '1/125/137/150',
[291085] = '1/130/140/150',
[291086] = '1/135/142/150',
[291089] = '1/125/137/150',
[291090] = '1/130/140/150',
[291091] = '1/125/137/150',
[291092] = '1/130/140/150',
[291093] = '1/125/137/150',
[291094] = '1/130/140/150',
[291095] = '1/125/137/150',
[291096] = '1/130/140/150',
[282975] = '1/150/150/150',
[259665] = '1/150/150/150',
[292320] = '1/150/150/150',
[292012] = '1/150/150/150',
[292322] = '1/150/150/150',
[256301] = '1/150/150/150',
[292946] = '1/150/150/150',
[293076] = '1/150/150/150',
[293801] = '1/1/10/20',
[283403] = '1/150/150/150',
[283401] = '1/150/150/150',
[283399] = '1/150/150/150',
[256703] = '1/150/150/150',
[285925] = '1/150/150/150',
[285926] = '1/150/150/150',
[285927] = '1/150/150/150',
[294748] = '1/165/170/175',
[294749] = '1/170/172/175',
[294750] = '1/175/175/175',
[294751] = '1/165/170/175',
[294752] = '1/170/172/175',
[294753] = '1/175/175/175',
[294754] = '1/165/170/175',
[294755] = '1/170/172/175',
[294756] = '1/175/175/175',
[294757] = '1/165/170/175',
[294758] = '1/170/172/175',
[294759] = '1/175/175/175',
[294760] = '1/165/170/175',
[294761] = '1/170/172/175',
[294762] = '1/175/175/175',
[294763] = '1/165/170/175',
[294764] = '1/170/172/175',
[294765] = '1/175/175/175',
[265937] = '1/165/170/175',
[294766] = '1/165/170/175',
[294767] = '1/170/172/175',
[294768] = '1/175/175/175',
[294769] = '1/165/170/175',
[294770] = '1/170/172/175',
[294771] = '1/175/175/175',
[294772] = '1/165/170/175',
[294773] = '1/170/172/175',
[294774] = '1/175/175/175',
[294775] = '1/165/170/175',
[294776] = '1/170/172/175',
[294777] = '1/175/175/175',
[294778] = '1/165/170/175',
[294779] = '1/170/172/175',
[294780] = '1/175/175/175',
[294781] = '1/165/170/175',
[294782] = '1/170/172/175',
[294783] = '1/175/175/175',
[256132] = '1/170/172/175',
[294784] = '1/165/170/175',
[294785] = '1/170/172/175',
[294786] = '1/175/175/175',
[294787] = '1/165/170/175',
[294788] = '1/170/172/175',
[294789] = '1/175/175/175',
[294790] = '1/165/170/175',
[294791] = '1/170/172/175',
[294792] = '1/175/175/175',
[294793] = '1/165/170/175',
[294794] = '1/170/172/175',
[294795] = '1/175/175/175',
[294796] = '1/165/170/175',
[294797] = '1/170/172/175',
[294798] = '1/175/175/175',
[294799] = '1/165/170/175',
[294800] = '1/170/172/175',
[294801] = '1/175/175/175',
[294802] = '1/165/170/175',
[294803] = '1/170/172/175',
[294804] = '1/175/175/175',
[294805] = '1/165/170/175',
[294806] = '1/170/172/175',
[294807] = '1/175/175/175',
[294808] = '1/165/170/175',
[294809] = '1/170/172/175',
[294810] = '1/175/175/175',
[294811] = '1/165/170/175',
[294812] = '1/170/172/175',
[294813] = '1/175/175/175',
[294814] = '1/165/170/175',
[294815] = '1/170/172/175',
[294816] = '1/175/175/175',
[294817] = '1/165/170/175',
[294818] = '1/170/172/175',
[294819] = '1/175/175/175',
[294820] = '1/165/170/175',
[294821] = '1/170/172/175',
[294822] = '1/175/175/175',
[294823] = '1/165/170/175',
[294824] = '1/170/172/175',
[294825] = '1/175/175/175',
[294826] = '1/165/170/175',
[294827] = '1/170/172/175',
[294828] = '1/175/175/175',
[294829] = '1/165/170/175',
[294830] = '1/170/172/175',
[294831] = '1/175/175/175',
[294832] = '1/165/170/175',
[294833] = '1/170/172/175',
[294834] = '1/175/175/175',
[294835] = '1/165/170/175',
[294836] = '1/170/172/175',
[294837] = '1/175/175/175',
[294838] = '1/165/170/175',
[294839] = '1/170/172/175',
[294840] = '1/175/175/175',
[294841] = '1/165/170/175',
[294842] = '1/170/172/175',
[294843] = '1/175/175/175',
[294844] = '1/165/170/175',
[294845] = '1/170/172/175',
[294846] = '1/175/175/175',
[296149] = '1/0/87/175',
[296148] = '1/0/87/175',
[296147] = '1/0/87/175',
[296145] = '1/0/87/175',
[296144] = '1/0/87/175',
[296143] = '1/0/87/175',
[297078] = '1/165/170/175',
[297079] = '1/170/172/175',
[297080] = '1/175/175/175',
[297081] = '1/165/170/175',
[297082] = '1/170/172/175',
[297083] = '1/175/175/175',
[297084] = '1/165/170/175',
[297085] = '1/170/172/175',
[297086] = '1/175/175/175',
[297077] = '1/165/170/175',
[297075] = '1/170/172/175',
[297074] = '1/175/175/175',
[297087] = '1/165/170/175',
[297088] = '1/170/172/175',
[297089] = '1/175/175/175',
[297105] = '1/165/170/175',
[297106] = '1/170/172/175',
[297107] = '1/175/175/175',
[297989] = '1/165/170/175',
[297995] = '1/165/170/175',
[298001] = '1/170/172/175',
[298002] = '1/175/175/175',
[297993] = '1/165/170/175',
[297991] = '1/170/172/175',
[297999] = '1/175/175/175',
[297994] = '1/170/172/175',
[298016] = '1/175/175/175',
[298142] = '1/0/87/175',
[298143] = '1/0/87/175',
[298144] = '1/0/87/175',
[298255] = '1/150/162/175',
[298256] = '1/150/162/175',
[298257] = '1/150/162/175',
[298011] = '1/175/175/175',
[298010] = '1/170/172/175',
[298009] = '1/165/170/175',
[298433] = '1/175/175/175',
[300769] = '1/175/175/175',
[298438] = '1/175/175/175',
[298437] = '1/175/175/175',
[298440] = '1/175/175/175',
[298439] = '1/175/175/175',
[298442] = '1/175/175/175',
[298441] = '1/175/175/175',
[298625] = '1/165/170/175',
[298647] = '1/170/172/175',
[298648] = '1/175/175/175',
[298729] = '1/165/170/175',
[298730] = '1/170/172/175',
[298731] = '1/175/175/175',
[298726] = '1/165/170/175',
[298727] = '1/170/172/175',
[298728] = '1/175/175/175',
[298734] = '1/165/170/175',
[298735] = '1/170/172/175',
[298736] = '1/175/175/175',
[298741] = '1/165/170/175',
[298742] = '1/170/172/175',
[298743] = '1/175/175/175',
[298744] = '1/165/170/175',
[298745] = '1/170/172/175',
[298746] = '1/175/175/175',
[298747] = '1/165/170/175',
[298748] = '1/170/172/175',
[298749] = '1/175/175/175',
[298750] = '1/165/170/175',
[298751] = '1/170/172/175',
[298752] = '1/175/175/175',
[298800] = '1/175/175/175',
[298794] = '1/165/170/175',
[298801] = '1/175/175/175',
[298798] = '1/165/170/175',
[298797] = '1/165/170/175',
[298799] = '1/175/175/175',
[298796] = '1/165/170/175',
[298842] = '1/170/172/175',
[298843] = '1/175/175/175',
[298845] = '1/175/175/175',
[298846] = '1/170/172/175',
[298847] = '1/175/175/175',
[298848] = '1/175/175/175',
[298850] = '1/170/172/175',
[298851] = '1/175/175/175',
[298852] = '1/175/175/175',
[298853] = '1/170/172/175',
[298854] = '1/175/175/175',
[298855] = '1/175/175/175',
[298862] = '1/175/175/175',
[298863] = '1/175/175/175',
[298864] = '1/175/175/175',
[298930] = '1/175/175/175',
[298927] = '1/150/162/175',
[298929] = '1/125/150/175',
[298995] = '1/175/175/175',
[298996] = '1/175/175/175',
[298997] = '1/175/175/175',
[298998] = '1/175/175/175',
[298999] = '1/175/175/175',
[299000] = '1/175/175/175',
[299001] = '1/175/175/175',
[299002] = '1/175/175/175',
[299003] = '1/175/175/175',
[299004] = '1/175/175/175',
[299005] = '1/175/175/175',
[299006] = '1/175/175/175',
[299007] = '1/175/175/175',
[299008] = '1/175/175/175',
[299009] = '1/175/175/175',
[299010] = '1/175/175/175',
[299011] = '1/175/175/175',
[299012] = '1/175/175/175',
[299013] = '1/175/175/175',
[299014] = '1/175/175/175',
[299015] = '1/175/175/175',
[299016] = '1/175/175/175',
[299017] = '1/175/175/175',
[299018] = '1/175/175/175',
[299019] = '1/175/175/175',
[299020] = '1/175/175/175',
[299021] = '1/175/175/175',
[299022] = '1/175/175/175',
[299023] = '1/175/175/175',
[299024] = '1/175/175/175',
[299025] = '1/175/175/175',
[299026] = '1/175/175/175',
[299027] = '1/175/175/175',
[299028] = '1/175/175/175',
[299029] = '1/175/175/175',
[299030] = '1/175/175/175',
[299031] = '1/175/175/175',
[299032] = '1/175/175/175',
[299033] = '1/175/175/175',
[299034] = '1/175/175/175',
[299035] = '1/175/175/175',
[299036] = '1/175/175/175',
[299106] = '1/155/157/160',
[299105] = '1/155/157/160',
[299665] = '1/165/170/175',
[299668] = '1/165/170/175',
[299671] = '1/165/170/175',
[300381] = '1/1/13/25',
[300382] = '1/1/13/25',
[300619] = '1/150/162/175',
[300749] = '1/165/170/175',
[300750] = '1/170/172/175',
[300751] = '1/175/175/175',
[300752] = '1/165/170/175',
[300753] = '1/170/172/175',
[300754] = '1/175/175/175',
[300756] = '1/165/170/175',
[300770] = '1/175/175/175',
[300788] = '1/175/175/175',
[300789] = '1/175/175/175',
[301310] = '1/165/170/175',
[301311] = '1/170/172/175',
[301312] = '1/175/175/175',
[301392] = '1/165/170/175',
[301413] = '1/165/170/175',
[301412] = '1/165/170/175',
[301403] = '1/150/162/175',
[301409] = '1/165/170/175',
[301405] = '1/165/170/175',
[301411] = '1/165/170/175',
[382995] = '1/1/13/25',
[382980] = '1/1/13/25',
[382994] = '1/1/13/25',
[382991] = '1/1/13/25',
[302007] = '1/0/87/175',
[302010] = '1/0/87/175',
[302011] = '1/0/87/175',
[302014] = '1/0/87/175',
[302015] = '1/0/87/175',
[302016] = '1/0/87/175',
[302187] = '1/175/175/175',
[302188] = '1/175/175/175',
[302189] = '1/175/175/175',
[302190] = '1/175/175/175',
[302690] = '1/1/13/25',
[302691] = '1/1/13/25',
[302692] = '1/1/13/25',
[302693] = '1/1/13/25',
[302694] = '1/1/13/25',
[302695] = '1/1/13/25',
[382990] = '1/1/13/25',
[382989] = '1/1/13/25',
[382988] = '1/1/13/25',
[382987] = '1/1/13/25',
[382986] = '1/1/13/25',
[382984] = '1/1/13/25',
[382979] = '1/1/13/25',
[382978] = '1/1/13/25',
[382977] = '1/1/13/25',
[382975] = '1/1/13/25',
[382973] = '1/1/13/25',
[304033] = '1/150/162/175',
[304036] = '1/150/162/175',
[304030] = '1/150/162/175',
[304042] = '1/150/162/175',
[304307] = '1/165/170/175',
[304308] = '1/165/170/175',
[304312] = '1/165/170/175',
[304314] = '1/165/170/175',
[304315] = '1/165/170/175',
[304317] = '1/165/170/175',
[304318] = '1/165/170/175',
[304320] = '1/165/170/175',
[304322] = '1/165/170/175',
[304323] = '1/165/170/175',
[304324] = '1/165/170/175',
[304412] = '1/165/170/175',
[304413] = '1/165/170/175',
[304414] = '1/165/170/175',
[304415] = '1/165/170/175',
[304416] = '1/165/170/175',
[304417] = '1/165/170/175',
[304418] = '1/165/170/175',
[304419] = '1/165/170/175',
[304420] = '1/165/170/175',
[304421] = '1/165/170/175',
[304422] = '1/165/170/175',
[304423] = '1/165/170/175',
[304424] = '1/165/170/175',
[304425] = '1/165/170/175',
[304426] = '1/165/170/175',
[304427] = '1/165/170/175',
[304428] = '1/165/170/175',
[304429] = '1/165/170/175',
[304430] = '1/165/170/175',
[304431] = '1/165/170/175',
[304432] = '1/165/170/175',
[304433] = '1/165/170/175',
[304434] = '1/165/170/175',
[304435] = '1/165/170/175',
[304436] = '1/165/170/175',
[304437] = '1/165/170/175',
[304438] = '1/165/170/175',
[304439] = '1/165/170/175',
[304440] = '1/165/170/175',
[304441] = '1/165/170/175',
[298515] = '1/175/175/175',
[304559] = '1/175/175/175',
[304560] = '1/175/175/175',
[304561] = '1/175/175/175',
[304562] = '1/175/175/175',
[304563] = '1/175/175/175',
[304564] = '1/175/175/175',
[304565] = '1/165/170/175',
[304566] = '1/165/170/175',
[304567] = '1/165/170/175',
[304568] = '1/165/170/175',
[304569] = '1/165/170/175',
[304570] = '1/165/170/175',
[304571] = '1/165/170/175',
[304572] = '1/165/170/175',
[304573] = '1/165/170/175',
[304574] = '1/165/170/175',
[304575] = '1/165/170/175',
[304576] = '1/165/170/175',
[304577] = '1/165/170/175',
[304578] = '1/165/170/175',
[304579] = '1/165/170/175',
[304580] = '1/165/170/175',
[304581] = '1/165/170/175',
[304582] = '1/165/170/175',
[303788] = '1/175/175/175',
[305796] = '1/175/175/175',
[305803] = '1/175/175/175',
[305802] = '1/175/175/175',
[305801] = '1/175/175/175',
[305800] = '1/175/175/175',
[305806] = '1/175/175/175',
[305807] = '1/175/175/175',
[305843] = '1/175/175/175',
[305842] = '1/175/175/175',
[305841] = '1/175/175/175',
[305840] = '1/175/175/175',
[305839] = '1/175/175/175',
[305838] = '1/175/175/175',
[305863] = '1/165/170/175',
[305862] = '1/165/170/175',
[305861] = '1/165/170/175',
[305860] = '1/165/170/175',
[305859] = '1/165/170/175',
[305858] = '1/165/170/175',
[305936] = '1/165/170/175',
[305937] = '1/165/170/175',
[305938] = '1/165/170/175',
[305945] = '1/175/175/175',
[305944] = '1/175/175/175',
[305943] = '1/175/175/175',
[305942] = '1/175/175/175',
[305941] = '1/175/175/175',
[305940] = '1/175/175/175',
[305951] = '1/175/175/175',
[305950] = '1/175/175/175',
[305949] = '1/175/175/175',
[305948] = '1/175/175/175',
[305947] = '1/175/175/175',
[305946] = '1/175/175/175',
[305952] = '1/165/170/175',
[305953] = '1/165/170/175',
[305954] = '1/165/170/175',
[305168] = '1/165/170/175',
[305170] = '1/165/170/175',
[305171] = '1/165/170/175',
[305982] = '1/175/175/175',
[305981] = '1/175/175/175',
[305980] = '1/175/175/175',
[305994] = '1/175/175/175',
[305993] = '1/175/175/175',
[305992] = '1/175/175/175',
[305795] = '1/175/175/175',
[305805] = '1/175/175/175',
[305804] = '1/175/175/175',
[305798] = '1/175/175/175',
[305799] = '1/175/175/175',
[304442] = '1/165/167/170',
[304443] = '1/165/167/170',
[304444] = '1/165/167/170',
[307118] = '1/20/35/50',
[307119] = '1/20/35/50',
[307120] = '1/25/32/40',
[307121] = '1/90/97/105',
[307122] = '1/115/122/130',
[307123] = '1/55/62/70',
[307124] = '1/25/37/50',
[307125] = '1/70/77/85',
[307100] = '1/15/22/30',
[307087] = '1/175/175/175',
[307101] = '1/170/172/175',
[307103] = '1/170/172/175',
[301578] = '1/10/15/20',
[256134] = '1/60/77/95',
[261424] = '1/45/57/70',
[301683] = '1/10/15/20',
[307093] = '1/165/170/175',
[307094] = '1/110/127/145',
[307095] = '1/110/127/145',
[307096] = '1/165/170/175',
[307097] = '1/165/170/175',
[307098] = '1/165/170/175',
[261423] = '1/15/22/30',
[295084] = '1/55/67/80',
[256133] = '1/70/87/105',
[307142] = '1/175/175/175',
[307143] = '1/175/175/175',
[307200] = '1/175/175/175',
[307172] = '1/200/200/200',
[307221] = '1/200/200/200',
[307220] = '1/200/200/200',
[307219] = '1/200/200/200',
[307176] = '1/200/200/200',
[307175] = '1/200/200/200',
[307381] = '1/145/160/175',
[307382] = '1/135/152/170',
[307383] = '1/135/152/170',
[307384] = '1/145/160/175',
[307663] = '1/25/30/35',
[307664] = '1/5/10/15',
[307665] = '1/15/20/25',
[307666] = '1/30/35/40',
[307667] = '1/35/40/45',
[307671] = '1/20/25/30',
[307668] = '1/40/45/50',
[307669] = '1/10/15/20',
[307670] = '1/5/10/15',
[307712] = '1/100/100/100',
[307711] = '1/100/100/100',
[307710] = '1/100/100/100',
[307709] = '1/100/100/100',
[307708] = '1/100/100/100',
[307707] = '1/100/100/100',
[307706] = '1/100/100/100',
[307705] = '1/100/100/100',
[307611] = '1/57/58/60',
[307721] = '1/17/18/20',
[307672] = '1/30/35/40',
[307674] = '1/25/30/35',
[307675] = '1/15/20/25',
[307676] = '1/20/25/30',
[307677] = '1/10/15/20',
[307678] = '1/30/35/40',
[307679] = '1/40/45/50',
[307680] = '1/5/10/15',
[307681] = '1/20/25/30',
[307682] = '1/35/40/45',
[307717] = '1/5/7/10',
[307718] = '1/55/57/60',
[307719] = '1/5/7/10',
[307720] = '1/60/62/65',
[299672] = '1/175/175/175',
[299673] = '1/175/175/175',
[308397] = '1/30/32/35',
[308400] = '1/70/72/75',
[308402] = '1/75/75/75',
[308403] = '1/75/75/75',
[308404] = '1/40/42/45',
[308405] = '1/60/62/65',
[308410] = '1/20/22/25',
[308411] = '1/50/52/55',
[308412] = '1/35/37/40',
[308413] = '1/65/67/70',
[308414] = '1/20/22/25',
[308415] = '1/50/52/55',
[308417] = '1/75/75/75',
[308419] = '1/75/75/75',
[308420] = '1/75/75/75',
[308425] = '1/30/32/35',
[308426] = '1/60/62/65',
[309173] = '1/110/112/115',
[309174] = '1/10/15/20',
[309175] = '1/40/45/50',
[309176] = '1/25/30/35',
[309177] = '1/35/40/45',
[309178] = '1/45/50/55',
[309179] = '1/50/55/60',
[309180] = '1/20/25/30',
[309181] = '1/10/15/20',
[309182] = '1/10/15/20',
[309183] = '1/40/45/50',
[309184] = '1/25/30/35',
[309185] = '1/35/40/45',
[309186] = '1/45/50/55',
[309187] = '1/50/55/60',
[309188] = '1/20/25/30',
[309189] = '1/10/15/20',
[309190] = '1/45/47/50',
[309191] = '1/25/27/30',
[309192] = '1/40/42/45',
[309193] = '1/55/57/60',
[309198] = '1/110/112/115',
[309199] = '1/110/112/115',
[309200] = '1/110/112/115',
[309201] = '1/110/112/115',
[309202] = '1/110/112/115',
[309203] = '1/110/112/115',
[309204] = '1/110/112/115',
[309205] = '1/110/112/115',
[309206] = '1/110/112/115',
[309207] = '1/110/112/115',
[309208] = '1/110/112/115',
[309209] = '1/110/112/115',
[309210] = '1/110/112/115',
[309211] = '1/110/112/115',
[309212] = '1/110/112/115',
[309213] = '1/110/112/115',
[309230] = '1/65/70/75',
[309231] = '1/90/95/100',
[309232] = '1/75/80/85',
[309233] = '1/85/90/95',
[309234] = '1/100/100/100',
[309235] = '1/100/100/100',
[309236] = '1/70/75/80',
[309237] = '1/60/65/70',
[309238] = '1/65/70/75',
[309239] = '1/90/95/100',
[309240] = '1/75/80/85',
[309241] = '1/85/90/95',
[309242] = '1/100/100/100',
[309243] = '1/100/100/100',
[309244] = '1/70/75/80',
[309245] = '1/60/65/70',
[309443] = '1/175/175/175',
[309534] = '1/85/90/95',
[309535] = '1/70/75/80',
[309528] = '1/35/42/50',
[309530] = '1/35/42/50',
[309531] = '1/35/42/50',
[309532] = '1/20/25/30',
[309524] = '1/10/17/25',
[309525] = '1/20/25/30',
[309526] = '1/85/90/95',
[309608] = '1/20/25/30',
[309609] = '1/85/90/95',
[309610] = '1/10/17/25',
[309636] = '1/115/132/150',
[309637] = '1/115/132/150',
[309638] = '1/115/132/150',
[309612] = '1/45/55/65',
[309616] = '1/90/95/100',
[309613] = '1/50/60/70',
[309617] = '1/90/95/100',
[309614] = '1/55/65/75',
[309618] = '1/90/95/100',
[309615] = '1/60/65/70',
[309619] = '1/90/95/100',
[309645] = '1/1/1/1',
[309644] = '1/1/1/1',
[309620] = '1/110/130/150',
[309621] = '1/110/130/150',
[309622] = '1/110/130/150',
[309623] = '1/110/130/150',
[309627] = '1/35/42/50',
[265105] = '1/30/40/50',
[310495] = '1/60/65/70',
[310496] = '1/60/65/70',
[310497] = '1/60/65/70',
[310484] = '1/20/27/35',
[310485] = '1/25/32/40',
[310486] = '1/30/37/45',
[310490] = '1/75/77/80',
[310492] = '1/70/75/80',
[310493] = '1/55/60/65',
[310501] = '1/95/97/100',
[310504] = '1/95/97/100',
[310507] = '1/95/97/100',
[310509] = '1/95/97/100',
[310522] = '1/10/17/25',
[310524] = '1/10/17/25',
[310525] = '1/45/47/50',
[310526] = '1/75/77/80',
[310533] = '1/90/92/95',
[310534] = '1/90/92/95',
[310536] = '1/40/45/50',
[310535] = '1/85/90/95',
[310870] = '1/40/45/50',
[310871] = '1/30/35/40',
[310872] = '1/25/30/35',
[310873] = '1/35/40/45',
[310874] = '1/45/50/55',
[310875] = '1/50/55/60',
[310876] = '1/20/25/30',
[310877] = '1/10/15/20',
[310869] = '1/10/15/20',
[310896] = '1/65/70/75',
[310904] = '1/60/65/70',
[310903] = '1/70/75/80',
[310902] = '1/100/100/100',
[310901] = '1/100/100/100',
[310900] = '1/85/90/95',
[310899] = '1/75/80/85',
[310898] = '1/80/85/90',
[310897] = '1/90/95/100',
[310878] = '1/100/100/100',
[310886] = '1/100/100/100',
[310885] = '1/100/100/100',
[310884] = '1/100/100/100',
[310883] = '1/100/100/100',
[310882] = '1/100/100/100',
[310881] = '1/100/100/100',
[310880] = '1/100/100/100',
[310879] = '1/100/100/100',
[310923] = '1/55/65/75',
[310924] = '1/10/15/20',
[311408] = '1/30/35/40',
[311405] = '1/15/20/25',
[311406] = '1/15/20/25',
[311424] = '1/70/72/75',
[311413] = '1/55/60/65',
[311414] = '1/55/60/65',
[311415] = '1/55/60/65',
[311416] = '1/55/60/65',
[311417] = '1/55/60/65',
[311418] = '1/55/60/65',
[311441] = '1/95/110/125',
[311423] = '1/25/30/35',
[311425] = '1/30/32/35',
[311688] = '1/40/45/50',
[311689] = '1/40/45/50',
[311453] = '1/115/120/125',
[311866] = '1/15/37/60',
[311867] = '1/15/37/60',
[311868] = '1/25/42/60',
[311869] = '1/25/42/60',
[311870] = '1/30/45/60',
[311871] = '1/30/45/60',
[311859] = '1/65/82/100',
[311863] = '1/65/82/100',
[311864] = '1/70/85/100',
[311865] = '1/70/85/100',
[311949] = '1/40/50/60',
[311953] = '1/50/60/70',
[311952] = '1/40/50/60',
[311948] = '1/30/45/60',
[311951] = '1/40/50/60',
[311950] = '1/40/50/60',
[311902] = '1/40/52/65',
[311906] = '1/100/100/100',
[311903] = '1/50/62/75',
[311907] = '1/100/100/100',
[311904] = '1/40/52/65',
[311908] = '1/100/100/100',
[311905] = '1/50/62/75',
[311909] = '1/100/100/100',
[311880] = '1/25/42/60',
[311884] = '1/100/100/100',
[311881] = '1/35/47/60',
[311885] = '1/100/100/100',
[311882] = '1/30/45/60',
[311886] = '1/100/100/100',
[311883] = '1/40/50/60',
[311887] = '1/100/100/100',
[306087] = '1/165/170/175',
[306086] = '1/165/170/175',
[306085] = '1/165/170/175',
[306084] = '1/165/170/175',
[306083] = '1/165/170/175',
[306082] = '1/165/170/175',
[306081] = '1/165/170/175',
[306080] = '1/165/170/175',
[306079] = '1/165/170/175',
[306078] = '1/165/170/175',
[305853] = '1/165/170/175',
[305852] = '1/165/170/175',
[305851] = '1/165/170/175',
[305850] = '1/165/170/175',
[305849] = '1/165/170/175',
[305848] = '1/165/170/175',
[305847] = '1/165/170/175',
[305846] = '1/165/170/175',
[305845] = '1/165/170/175',
[305844] = '1/165/170/175',
[306312] = '1/165/170/175',
[306310] = '1/165/170/175',
[306482] = '1/175/175/175',
[306483] = '1/175/175/175',
[306481] = '1/175/175/175',
[314963] = '1/165/170/175',
[314961] = '1/165/170/175',
[314962] = '1/165/170/175',
[314959] = '1/165/170/175',
[314960] = '1/165/170/175',
[321029] = '1/65/70/75',
[322301] = '1/120/137/155',
[322587] = '1/90/95/100',
[322588] = '1/65/70/75',
[322589] = '1/75/80/85',
[322590] = '1/85/90/95',
[322591] = '1/100/100/100',
[322593] = '1/100/100/100',
[322594] = '1/70/75/80',
[322595] = '1/60/65/70',
[323609] = '1/10/17/25',
[323760] = '1/105/127/150',
[323761] = '1/105/127/150',
[323762] = '1/40/50/60',
[323755] = '1/65/70/75',
[324039] = '1/95/110/125',
[324036] = '1/95/110/125',
[324035] = '1/95/110/125',
[324037] = '1/95/110/125',
[324087] = '1/10/12/15',
[324088] = '1/60/62/65',
[324198] = '1/85/92/100',
[324735] = '1/90/92/95',
[308897] = '1/90/92/95',
[308899] = '1/80/82/85',
[324750] = '1/1/13/25',
[324773] = '1/100/125/150',
[325248] = '1/1/13/25',
[326805] = '1/500/505/510',
[326855] = '1/500/505/510',
[326911] = '1/500/505/510',
[326977] = '1/500/505/510',
[327082] = '1/500/505/510',
[327920] = '1/100/100/100',
[327921] = '1/100/100/100',
[311410] = '1/80/85/90',
[311409] = '1/80/85/90',
[311411] = '1/80/85/90',
[311412] = '1/80/85/90',
[330134] = '1/1/10/20',
[330140] = '1/1/10/20',
[330141] = '1/1/10/20',
[330142] = '1/1/10/20',
[330143] = '1/1/10/20',
[330144] = '1/1/10/20',
[330145] = '1/1/10/20',
[330146] = '1/1/10/20',
[330147] = '1/1/10/20',
[330148] = '1/1/10/20',
[330149] = '1/1/10/20',
[330150] = '1/1/10/20',
[330151] = '1/1/10/20',
[330152] = '1/1/10/20',
[330153] = '1/1/10/20',
[330154] = '1/1/10/20',
[330155] = '1/1/10/20',
[330156] = '1/1/10/20',
[330157] = '1/1/10/20',
[330158] = '1/1/10/20',
[330159] = '1/1/10/20',
[330160] = '1/1/10/20',
[330161] = '1/1/10/20',
[330162] = '1/1/10/20',
[330163] = '1/1/10/20',
[330164] = '1/1/10/20',
[330165] = '1/1/10/20',
[330166] = '1/1/10/20',
[330167] = '1/1/10/20',
[330168] = '1/1/10/20',
[330169] = '1/1/10/20',
[330170] = '1/1/10/20',
[330171] = '1/1/10/20',
[330172] = '1/1/10/20',
[330173] = '1/1/10/20',
[330174] = '1/1/10/20',
[330175] = '1/1/10/20',
[330176] = '1/1/10/20',
[330177] = '1/1/10/20',
[330178] = '1/1/10/20',
[330180] = '1/1/10/20',
[330181] = '1/1/10/20',
[330183] = '1/1/10/20',
[330184] = '1/1/10/20',
[330185] = '1/1/10/20',
[330186] = '1/1/10/20',
[330187] = '1/1/10/20',
[330188] = '1/1/10/20',
[330189] = '1/1/10/20',
[330190] = '1/1/10/20',
[330191] = '1/1/10/20',
[330192] = '1/1/10/20',
[330193] = '1/1/10/20',
[330194] = '1/1/10/20',
[330195] = '1/1/10/20',
[330196] = '1/1/10/20',
[330197] = '1/1/10/20',
[330198] = '1/1/10/20',
[330199] = '1/1/10/20',
[330200] = '1/1/10/20',
[330201] = '1/1/10/20',
[330202] = '1/1/10/20',
[330203] = '1/1/10/20',
[330204] = '1/1/10/20',
[330205] = '1/1/10/20',
[330206] = '1/1/10/20',
[330207] = '1/1/10/20',
[330208] = '1/1/10/20',
[330209] = '1/1/10/20',
[330210] = '1/1/10/20',
[330211] = '1/1/10/20',
[330212] = '1/1/10/20',
[330213] = '1/1/10/20',
[330214] = '1/1/10/20',
[330215] = '1/1/10/20',
[330216] = '1/1/10/20',
[330218] = '1/1/10/20',
[330219] = '1/1/10/20',
[330220] = '1/1/10/20',
[330221] = '1/1/10/20',
[330222] = '1/1/10/20',
[330223] = '1/1/10/20',
[330224] = '1/1/10/20',
[330225] = '1/1/10/20',
[330226] = '1/1/10/20',
[330227] = '1/1/10/20',
[330228] = '1/1/10/20',
[330229] = '1/1/10/20',
[330230] = '1/1/10/20',
[330231] = '1/1/10/20',
[330232] = '1/1/10/20',
[330233] = '1/1/10/20',
[330234] = '1/1/10/20',
[330235] = '1/1/10/20',
[330236] = '1/1/10/20',
[330237] = '1/1/10/20',
[330238] = '1/1/10/20',
[330239] = '1/1/10/20',
[330240] = '1/1/10/20',
[330241] = '1/1/10/20',
[330242] = '1/1/10/20',
[330243] = '1/1/10/20',
[330244] = '1/1/10/20',
[330245] = '1/1/10/20',
[330246] = '1/1/10/20',
[330247] = '1/1/10/20',
[330248] = '1/1/10/20',
[330249] = '1/1/10/20',
[330250] = '1/1/10/20',
[330251] = '1/1/10/20',
[330252] = '1/1/10/20',
[330253] = '1/1/10/20',
[330254] = '1/1/10/20',
[330255] = '1/1/10/20',
[330256] = '1/1/10/20',
[330257] = '1/1/10/20',
[330258] = '1/1/10/20',
[330259] = '1/1/10/20',
[330260] = '1/1/10/20',
[330261] = '1/1/10/20',
[331007] = '1/115/117/120',
[332006] = '1/100/100/100',
[332007] = '1/100/100/100',
[332008] = '1/100/100/100',
[332009] = '1/100/100/100',
[332010] = '1/100/100/100',
[332011] = '1/100/100/100',
[332012] = '1/100/100/100',
[332013] = '1/100/100/100',
[332041] = '1/100/100/100',
[332042] = '1/100/100/100',
[332043] = '1/100/100/100',
[332044] = '1/100/100/100',
[332045] = '1/100/100/100',
[332046] = '1/100/100/100',
[332047] = '1/100/100/100',
[332048] = '1/100/100/100',
[332014] = '1/110/112/115',
[332015] = '1/110/112/115',
[332016] = '1/110/112/115',
[332017] = '1/110/112/115',
[332018] = '1/110/112/115',
[332019] = '1/110/112/115',
[332020] = '1/110/112/115',
[332021] = '1/110/112/115',
[332022] = '1/110/112/115',
[332023] = '1/110/112/115',
[332024] = '1/110/112/115',
[332025] = '1/110/112/115',
[332026] = '1/110/112/115',
[332027] = '1/110/112/115',
[332028] = '1/110/112/115',
[332029] = '1/110/112/115',
[332049] = '1/110/112/115',
[332050] = '1/110/112/115',
[332051] = '1/110/112/115',
[332052] = '1/110/112/115',
[332053] = '1/110/112/115',
[332054] = '1/110/112/115',
[332055] = '1/110/112/115',
[332056] = '1/110/112/115',
[332057] = '1/110/112/115',
[332058] = '1/110/112/115',
[332059] = '1/110/112/115',
[332060] = '1/110/112/115',
[332061] = '1/110/112/115',
[332062] = '1/110/112/115',
[332063] = '1/110/112/115',
[332064] = '1/110/112/115',
[332039] = '1/100/100/100',
[332040] = '1/100/100/100',
[332074] = '1/100/100/100',
[332075] = '1/100/100/100',
[332030] = '1/100/100/100',
[332031] = '1/100/100/100',
[332032] = '1/100/100/100',
[332033] = '1/100/100/100',
[332034] = '1/100/100/100',
[332035] = '1/100/100/100',
[332036] = '1/100/100/100',
[332037] = '1/100/100/100',
[332038] = '1/100/100/100',
[332065] = '1/100/100/100',
[332066] = '1/100/100/100',
[332067] = '1/100/100/100',
[332068] = '1/100/100/100',
[332069] = '1/100/100/100',
[332070] = '1/100/100/100',
[332071] = '1/100/100/100',
[332072] = '1/100/100/100',
[332073] = '1/100/100/100',
[324197] = '1/85/92/100',
[324196] = '1/85/92/100',
[324195] = '1/85/92/100',
[334413] = '1/10/15/20',
[334499] = '1/15/20/25',
[334537] = '1/100/105/110',
[334548] = '1/10/15/20',
[337374] = '1/1/1/1',
[337426] = '1/1/1/1',
[337427] = '1/1/1/1',
[337626] = '1/1/1/1',
[337621] = '1/1/1/1',
[337619] = '1/1/1/1',
[338091] = '1/1/1/1',
[338090] = '1/1/1/1',
[338088] = '1/1/1/1',
[338097] = '1/1/1/1',
[338096] = '1/1/1/1',
[338095] = '1/1/1/1',
[338094] = '1/1/1/1',
[338968] = '1/100/100/100',
[338969] = '1/100/100/100',
[338970] = '1/100/100/100',
[338971] = '1/100/100/100',
[338972] = '1/100/100/100',
[338974] = '1/100/100/100',
[338975] = '1/100/100/100',
[338976] = '1/100/100/100',
[338977] = '1/100/100/100',
[338978] = '1/100/100/100',
[338979] = '1/110/112/115',
[338980] = '1/110/112/115',
[338981] = '1/110/112/115',
[338982] = '1/110/112/115',
[338983] = '1/110/112/115',
[338984] = '1/110/112/115',
[338985] = '1/110/112/115',
[338986] = '1/110/112/115',
[338987] = '1/110/112/115',
[338988] = '1/110/112/115',
[338989] = '1/110/112/115',
[338990] = '1/110/112/115',
[338991] = '1/110/112/115',
[338992] = '1/110/112/115',
[338993] = '1/110/112/115',
[338994] = '1/110/112/115',
[338995] = '1/100/100/100',
[338996] = '1/100/100/100',
[338997] = '1/100/100/100',
[338998] = '1/100/100/100',
[339000] = '1/100/100/100',
[339001] = '1/100/100/100',
[339002] = '1/100/100/100',
[339003] = '1/100/100/100',
[339004] = '1/100/100/100',
[342316] = '1/70/75/80',
[342887] = '1/60/77/95',
[343184] = '1/55/60/65',
[343185] = '1/75/80/85',
[343099] = '1/55/60/65',
[343100] = '1/75/80/85',
[343195] = '1/55/60/65',
[343193] = '1/75/80/85',
[343204] = '1/55/60/65',
[343202] = '1/75/80/85',
[343634] = '1/1/1/1',
[343662] = '1/50/55/60',
[343661] = '1/35/37/40',
[343660] = '1/50/55/60',
[343659] = '1/55/60/65',
[343675] = '1/130/132/135',
[343679] = '1/155/157/160',
[343678] = '1/175/177/180',
[343680] = '1/45/47/50',
[343684] = '1/50/52/55',
[343683] = '1/70/72/75',
[343686] = '1/45/47/50',
[343691] = '1/50/52/55',
[343689] = '1/70/72/75',
[344316] = '1/100/117/135',
[344335] = '1/150/150/150',
[344340] = '1/150/150/150',
[344341] = '1/150/150/150',
[345179] = '1/55/62/70',
[343693] = '1/45/47/50',
[343697] = '1/50/52/55',
[343696] = '1/95/95/95',
[345985] = '1/25/32/40',
[345986] = '1/75/80/85',
[347176] = '1/125/150/175',
[347457] = '1/10/15/20',
[347509] = '1/15/20/25',
[352439] = '1/202/202/202',
[352443] = '1/202/202/202',
[352444] = '1/202/202/202',
[352445] = '1/202/202/202',
[343201] = '1/90/92/95',
[343192] = '1/90/92/95',
[343695] = '1/100/100/100',
[343102] = '1/90/92/95',
[343186] = '1/90/92/95',
[343677] = '1/190/192/195',
[343676] = '1/200/200/200',
[343188] = '1/101/101/101',
[343681] = '1/100/100/100',
[343103] = '1/101/101/101',
[343687] = '1/100/100/100',
[343694] = '1/101/101/101',
[343189] = '1/100/100/100',
[343200] = '1/100/100/100',
[354764] = '1/75/75/75',
[354766] = '1/50/52/55',
[354768] = '1/30/32/35',
[354797] = '1/55/60/65',
[354800] = '1/80/82/85',
[354885] = '1/100/112/125',
[354880] = '1/100/112/125',
[354881] = '1/100/112/125',
[354884] = '1/100/112/125',
[354882] = '1/100/112/125',
[307144] = '1/175/175/175',
[355184] = '1/50/62/75',
[355189] = '1/100/100/100',
[355187] = '1/60/65/70',
[355183] = '1/15/20/25',
[355354] = '1/100/100/100',
[354000] = '1/100/100/100',
[354394] = '1/115/120/125',
[359333] = '1/75/75/75',
[359490] = '1/55/60/65',
[359492] = '1/50/60/70',
[359661] = '1/200/200/200',
[359662] = '1/200/200/200',
[359663] = '1/200/200/200',
[359664] = '1/200/200/200',
[359665] = '1/200/200/200',
[359666] = '1/201/201/201',
[359673] = '1/203/203/203',
[359671] = '1/201/201/201',
[359674] = '1/201/201/201',
[359672] = '1/201/201/201',
[359669] = '1/201/201/201',
[359670] = '1/201/201/201',
[359700] = '1/203/203/203',
[359701] = '1/203/203/203',
[359702] = '1/203/203/203',
[359703] = '1/203/203/203',
[359786] = '1/101/101/101',
[359870] = '1/170/172/175',
[359890] = '1/130/130/130',
[360007] = '1/100/110/120',
[360013] = '1/100/110/120',
[360014] = '1/100/110/120',
[360016] = '1/100/110/120',
[360088] = '1/100/110/120',
[360126] = '1/100/110/120',
[360317] = '1/100/110/120',
[360318] = '1/100/110/120',
[360539] = '1/100/100/100',
[360885] = '1/100/100/100',
[360542] = '1/100/100/100',
[360880] = '1/100/100/100',
[360545] = '1/100/100/100',
[360899] = '1/100/100/100',
[360882] = '1/20/45/70',
[362412] = '1/100/100/100',
[365729] = '1/100/100/100',
[365730] = '1/100/100/100',
[365731] = '1/100/100/100',
[365734] = '1/100/100/100',
[365735] = '1/50/55/60',
[367389] = '1/100/100/100',
[367393] = '1/100/100/100',
[367623] = '1/100/100/100',
[367622] = '1/100/100/100',
[367619] = '1/100/100/100',
[367618] = '1/100/100/100',
[367617] = '1/100/100/100',
[367616] = '1/100/100/100',
[367615] = '1/100/100/100',
[367614] = '1/100/100/100',
[395886] = '1/15/20/25',
[367610] = '1/10/15/20',
[367609] = '1/5/10/15',
[367608] = '1/100/100/100',
[367607] = '1/100/100/100',
[367606] = '1/100/100/100',
[367605] = '1/100/100/100',
[367604] = '1/100/100/100',
[367603] = '1/100/100/100',
[367602] = '1/100/100/100',
[367601] = '1/100/100/100',
[367600] = '1/30/35/40',
[367599] = '1/35/40/45',
[367598] = '1/55/60/65',
[367597] = '1/50/55/60',
[367596] = '1/25/30/35',
[367595] = '1/35/40/45',
[367594] = '1/100/100/100',
[367593] = '1/100/100/100',
[367592] = '1/100/100/100',
[367591] = '1/100/100/100',
[367590] = '1/100/100/100',
[367589] = '1/100/100/100',
[367588] = '1/100/100/100',
[367587] = '1/100/100/100',
[367586] = '1/100/100/100',
[367585] = '1/100/100/100',
[370438] = '1/55/60/65',
[370453] = '1/55/60/65',
[370456] = '1/60/65/70',
[370457] = '1/60/65/70',
[370460] = '1/55/60/65',
[370462] = '1/55/60/65',
[370463] = '1/55/60/65',
[370465] = '1/30/35/40',
[370472] = '1/40/50/60',
[370473] = '1/40/50/60',
[370476] = '1/40/45/50',
[370478] = '1/30/35/40',
[370483] = '1/40/50/60',
[370504] = '1/55/60/65',
[370521] = '1/40/45/50',
[370524] = '1/55/60/65',
[370525] = '1/55/60/65',
[370528] = '1/55/60/65',
[370533] = '1/55/60/65',
[370536] = '1/55/60/65',
[370539] = '1/5/10/15',
[370543] = '1/70/75/80',
[370547] = '1/10/15/20',
[370551] = '1/55/60/65',
[370556] = '1/40/45/50',
[370558] = '1/40/45/50',
[370561] = '1/40/45/50',
[370668] = '1/65/70/75',
[370672] = '1/70/75/80',
[370673] = '1/50/55/60',
[370676] = '1/100/100/100',
[370677] = '1/100/100/100',
[370707] = '1/15/20/25',
[370708] = '1/15/20/25',
[370710] = '1/15/20/25',
[370711] = '1/15/20/25',
[370714] = '1/20/30/40',
[370715] = '1/20/30/40',
[370717] = '1/25/30/35',
[370722] = '1/20/25/30',
[370723] = '1/60/65/70',
[370724] = '1/50/55/60',
[370725] = '1/50/55/60',
[370728] = '1/50/55/60',
[370729] = '1/25/30/35',
[370730] = '1/25/30/35',
[370731] = '1/40/45/50',
[370732] = '1/20/25/30',
[370733] = '1/20/25/30',
[370735] = '1/40/50/60',
[370738] = '1/50/55/60',
[370743] = '1/80/90/100',
[370745] = '1/85/100/115',
[370746] = '1/80/90/100',
[370747] = '1/85/100/115',
[370771] = '1/1/60/120',
[367712] = '1/50/55/60',
[367713] = '1/55/60/65',
[367714] = '1/50/55/60',
[371395] = '1/20/25/30',
[371349] = '1/30/35/40',
[371372] = '1/100/100/100',
[371344] = '1/5/10/15',
[371412] = '1/90/95/100',
[371365] = '1/90/95/100',
[371343] = '1/15/20/25',
[371369] = '1/90/95/100',
[371338] = '1/25/30/35',
[371366] = '1/90/95/100',
[371309] = '1/10/15/20',
[371367] = '1/90/95/100',
[371304] = '1/20/25/30',
[371368] = '1/90/95/100',
[371302] = '1/35/40/45',
[371364] = '1/20/25/30',
[371374] = '1/90/95/100',
[371371] = '1/90/95/100',
[371360] = '1/30/35/40',
[376700] = '1/40/50/60',
[371394] = '1/10/15/20',
[371403] = '1/50/55/60',
[371635] = '1/1/5/10',
[371650] = '1/40/45/50',
[371674] = '1/35/40/45',
[371682] = '1/45/50/55',
[383536] = '1/50/57/65',
[374437] = '1/15/17/20',
[374438] = '1/15/17/20',
[374439] = '1/15/17/20',
[374440] = '1/15/17/20',
[374441] = '1/15/15/15',
[374442] = '1/70/75/80',
[374443] = '1/70/75/80',
[374444] = '1/70/75/80',
[374445] = '1/70/75/80',
[374446] = '1/70/75/80',
[374447] = '1/70/75/80',
[374448] = '1/70/75/80',
[374449] = '1/70/75/80',
[374450] = '1/70/75/80',
[374453] = '1/70/75/80',
[374454] = '1/70/75/80',
[374455] = '1/70/75/80',
[374456] = '1/70/75/80',
[374457] = '1/70/75/80',
[374458] = '1/70/75/80',
[374459] = '1/70/75/80',
[374460] = '1/70/75/80',
[374461] = '1/70/75/80',
[374462] = '1/70/75/80',
[374463] = '1/70/75/80',
[374465] = '1/90/95/100',
[374467] = '1/90/95/100',
[374468] = '1/90/95/100',
[374470] = '1/90/95/100',
[374472] = '1/50/55/60',
[374477] = '1/20/25/30',
[374478] = '1/20/25/30',
[374480] = '1/10/12/15',
[374475] = '1/10/12/15',
[374483] = '1/45/50/55',
[374484] = '1/45/50/55',
[374486] = '1/100/100/100',
[374488] = '1/100/100/100',
[374490] = '1/100/100/100',
[374493] = '1/100/100/100',
[374494] = '1/20/25/30',
[374495] = '1/40/45/50',
[374496] = '1/40/45/50',
[374497] = '1/100/100/100',
[374498] = '1/100/100/100',
[374499] = '1/100/100/100',
[374501] = '1/100/100/100',
[374502] = '1/50/55/60',
[374506] = '1/30/35/40',
[374508] = '1/40/45/50',
[374509] = '1/70/72/75',
[374510] = '1/70/75/80',
[374511] = '1/70/75/80',
[374512] = '1/70/75/80',
[374514] = '1/70/75/80',
[374516] = '1/70/75/80',
[374518] = '1/45/47/50',
[374522] = '1/70/72/75',
[374525] = '1/70/72/75',
[374531] = '1/25/27/30',
[374532] = '1/25/27/30',
[374537] = '1/25/27/30',
[374538] = '1/90/95/100',
[374540] = '1/90/95/100',
[374542] = '1/90/95/100',
[374543] = '1/90/95/100',
[374546] = '1/60/62/65',
[374547] = '1/60/62/65',
[374548] = '1/60/62/65',
[374549] = '1/60/62/65',
[374550] = '1/60/62/65',
[374551] = '1/100/100/100',
[374553] = '1/70/72/75',
[374627] = '1/10/12/15',
[375063] = '1/45/47/50',
[375188] = '1/40/45/50',
[375196] = '1/90/95/100',
[375199] = '1/100/100/100',
[375142] = '1/100/100/100',
[375143] = '1/100/100/100',
[375149] = '1/100/100/100',
[375148] = '1/100/100/100',
[375147] = '1/100/100/100',
[375145] = '1/100/100/100',
[375144] = '1/100/100/100',
[375146] = '1/100/100/100',
[375127] = '1/50/55/60',
[375131] = '1/50/55/60',
[375130] = '1/50/55/60',
[375126] = '1/50/55/60',
[375128] = '1/50/55/60',
[375129] = '1/50/55/60',
[375133] = '1/50/55/60',
[375132] = '1/50/55/60',
[375197] = '1/100/100/100',
[375103] = '1/10/15/20',
[375105] = '1/15/20/25',
[375104] = '1/5/10/15',
[375109] = '1/100/100/100',
[375110] = '1/100/100/100',
[375111] = '1/100/100/100',
[375112] = '1/100/100/100',
[375113] = '1/100/100/100',
[375114] = '1/100/100/100',
[375115] = '1/100/100/100',
[375116] = '1/100/100/100',
[375150] = '1/100/100/100',
[375151] = '1/100/100/100',
[375155] = '1/100/100/100',
[375156] = '1/100/100/100',
[375154] = '1/100/100/100',
[375152] = '1/100/100/100',
[375153] = '1/100/100/100',
[375135] = '1/50/55/60',
[375139] = '1/50/55/60',
[375138] = '1/50/55/60',
[375134] = '1/50/55/60',
[375136] = '1/50/55/60',
[375137] = '1/50/55/60',
[375141] = '1/50/55/60',
[375140] = '1/50/55/60',
[375106] = '1/10/15/20',
[375108] = '1/15/20/25',
[375107] = '1/5/10/15',
[375117] = '1/100/100/100',
[375118] = '1/100/100/100',
[375119] = '1/100/100/100',
[375120] = '1/100/100/100',
[375121] = '1/100/100/100',
[375122] = '1/100/100/100',
[375123] = '1/100/100/100',
[375124] = '1/100/100/100',
[375157] = '1/100/100/100',
[375162] = '1/65/70/75',
[375161] = '1/65/70/75',
[375164] = '1/15/20/25',
[375187] = '1/40/45/50',
[375195] = '1/90/95/100',
[375168] = '1/20/25/30',
[375185] = '1/35/40/45',
[375193] = '1/90/95/100',
[375166] = '1/40/50/60',
[375181] = '1/15/20/25',
[375189] = '1/90/95/100',
[375184] = '1/35/40/45',
[375192] = '1/90/95/100',
[375186] = '1/5/10/15',
[375194] = '1/90/95/100',
[375173] = '1/30/35/40',
[375174] = '1/30/35/40',
[375176] = '1/30/35/40',
[375178] = '1/30/35/40',
[375179] = '1/30/35/40',
[375180] = '1/30/35/40',
[375182] = '1/20/25/30',
[375190] = '1/90/95/100',
[375183] = '1/10/15/20',
[375191] = '1/90/95/100',
[375159] = '1/70/75/80',
[375160] = '1/70/75/80',
[375171] = '1/65/70/75',
[375172] = '1/65/70/75',
[375125] = '1/100/100/100',
[375102] = '1/40/45/50',
[376233] = '1/20/25/30',
[376618] = '1/40/45/50',
[376623] = '1/40/45/50',
[376619] = '1/40/45/50',
[376621] = '1/40/45/50',
[376620] = '1/40/45/50',
[376622] = '1/40/45/50',
[376624] = '1/40/45/50',
[376617] = '1/40/45/50',
[376492] = '1/100/100/100',
[376493] = '1/100/100/100',
[376494] = '1/100/100/100',
[376495] = '1/100/100/100',
[376496] = '1/100/100/100',
[376497] = '1/100/100/100',
[376500] = '1/100/100/100',
[376501] = '1/100/100/100',
[376502] = '1/100/100/100',
[376503] = '1/100/100/100',
[376504] = '1/100/100/100',
[376505] = '1/100/100/100',
[376506] = '1/25/30/35',
[376507] = '1/20/25/30',
[376508] = '1/15/20/25',
[376509] = '1/10/15/20',
[376510] = '1/100/100/100',
[376511] = '1/100/100/100',
[376512] = '1/100/100/100',
[376513] = '1/100/100/100',
[376514] = '1/100/100/100',
[376515] = '1/100/100/100',
[376516] = '1/100/100/100',
[376517] = '1/100/100/100',
[376518] = '1/100/100/100',
[376519] = '1/40/45/50',
[376520] = '1/40/45/50',
[376521] = '1/40/45/50',
[376522] = '1/40/45/50',
[376523] = '1/40/45/50',
[376524] = '1/40/45/50',
[376525] = '1/40/45/50',
[376526] = '1/40/45/50',
[376527] = '1/40/45/50',
[376528] = '1/45/50/55',
[376529] = '1/65/70/75',
[376530] = '1/5/10/15',
[376531] = '1/55/60/65',
[376532] = '1/55/60/65',
[376533] = '1/50/55/60',
[376534] = '1/40/45/50',
[376535] = '1/30/35/40',
[376536] = '1/35/40/45',
[376537] = '1/35/40/45',
[376538] = '1/55/60/65',
[376539] = '1/75/80/85',
[376540] = '1/75/80/85',
[376541] = '1/65/70/75',
[376542] = '1/65/70/75',
[376543] = '1/35/40/45',
[376544] = '1/90/95/100',
[376545] = '1/10/15/20',
[376546] = '1/100/100/100',
[376547] = '1/25/30/35',
[376548] = '1/90/95/100',
[376549] = '1/40/45/50',
[376550] = '1/90/95/100',
[376551] = '1/30/35/40',
[376552] = '1/90/95/100',
[376553] = '1/20/25/30',
[376554] = '1/90/95/100',
[376555] = '1/20/25/30',
[376556] = '1/50/62/75',
[376557] = '1/50/62/75',
[376558] = '1/40/45/50',
[376559] = '1/30/35/40',
[376560] = '1/15/20/25',
[376561] = '1/65/70/75',
[376562] = '1/5/10/15',
[376563] = '100/40/45/50',
[376564] = '100/40/45/50',
[376565] = '1/50/55/60',
[376566] = '1/50/55/60',
[376567] = '1/30/35/40',
[376568] = '1/30/35/40',
[376569] = '1/30/35/40',
[376570] = '1/40/45/50',
[376699] = '1/40/50/60',
[377280] = '1/50/55/60',
[377281] = '1/50/55/60',
[370748] = '1/15/20/25',
[377804] = '1/45/47/50',
[377915] = '1/10/17/25',
[377960] = '1/45/47/50',
[377978] = '1/1/1/1',
[377981] = '1/10/17/25',
[377984] = '1/10/17/25',
[377982] = '1/10/17/25',
[377983] = '1/10/17/25',
[377985] = '1/10/17/25',
[377989] = '1/10/15/20',
[377987] = '1/10/17/25',
[377988] = '1/10/17/25',
[377986] = '1/10/17/25',
[378302] = '1/100/100/100',
[381363] = '1/20/22/25',
[381364] = '1/20/22/25',
[381373] = '1/55/57/60',
[381375] = '1/55/57/60',
[381367] = '1/20/22/25',
[381368] = '1/25/27/30',
[381365] = '1/5/5/5',
[381369] = '1/20/22/25',
[381370] = '1/15/17/20',
[381371] = '1/50/50/50',
[381376] = '1/35/37/40',
[381377] = '1/35/37/40',
[381378] = '1/35/37/40',
[381380] = '1/35/37/40',
[381381] = '1/25/27/30',
[381382] = '1/45/47/50',
[381383] = '1/45/47/50',
[381385] = '1/45/47/50',
[381386] = '1/45/47/50',
[381388] = '1/45/47/50',
[381389] = '1/35/37/40',
[381403] = '1/45/47/50',
[381404] = '1/45/47/50',
[381407] = '1/45/47/50',
[381411] = '1/45/47/50',
[381391] = '1/70/72/75',
[381392] = '1/70/72/75',
[381393] = '1/70/72/75',
[381395] = '1/70/72/75',
[381396] = '1/90/95/100',
[381397] = '1/90/95/100',
[381398] = '1/90/95/100',
[381399] = '1/90/95/100',
[381400] = '1/90/95/100',
[381402] = '1/90/95/100',
[381412] = '1/80/85/90',
[381413] = '1/60/65/70',
[381415] = '1/90/95/100',
[381417] = '1/90/95/100',
[381418] = '1/90/95/100',
[381420] = '1/100/100/100',
[381270] = '1/20/25/30',
[385197] = '1/15/20/25',
[382408] = '1/65/70/75',
[382407] = '1/20/22/25',
[382404] = '1/35/37/40',
[382403] = '1/35/37/40',
[382402] = '1/35/37/40',
[382401] = '1/30/32/35',
[382400] = '1/90/95/100',
[382399] = '1/90/95/100',
[382398] = '1/40/42/45',
[382397] = '1/40/42/45',
[382396] = '1/40/42/45',
[382395] = '1/40/42/45',
[382394] = '1/40/42/45',
[382393] = '1/40/42/45',
[382392] = '1/40/42/45',
[382391] = '1/100/100/100',
[382390] = '1/100/100/100',
[382389] = '1/100/100/100',
[382388] = '1/100/100/100',
[382387] = '1/45/47/50',
[382386] = '1/20/22/25',
[382385] = '1/20/22/25',
[382384] = '1/20/22/25',
[382383] = '1/20/22/25',
[382381] = '1/40/50/60',
[382380] = '1/45/47/50',
[382379] = '1/45/50/55',
[382378] = '1/20/22/25',
[382377] = '1/20/22/25',
[382376] = '1/20/22/25',
[382375] = '1/10/12/15',
[382371] = '1/65/70/75',
[382370] = '1/65/70/75',
[382369] = '1/65/70/75',
[382368] = '1/65/70/75',
[382367] = '1/50/50/50',
[382366] = '1/30/35/40',
[382365] = '1/30/35/40',
[382364] = '1/30/32/35',
[382363] = '1/30/32/35',
[382362] = '1/30/32/35',
[382361] = '1/30/32/35',
[382359] = '1/65/70/75',
[382358] = '1/100/100/100',
[382357] = '1/50/50/50',
[382356] = '1/50/50/50',
[382355] = '1/50/50/50',
[382354] = '1/100/100/100',
[382353] = '1/65/70/75',
[382351] = '1/65/70/75',
[382350] = '1/65/70/75',
[382349] = '1/65/70/75',
[382348] = '1/50/57/65',
[382346] = '1/30/35/40',
[382345] = '1/35/37/40',
[382344] = '1/50/50/50',
[382343] = '1/30/35/40',
[382342] = '1/90/95/100',
[382341] = '1/90/95/100',
[382340] = '1/90/95/100',
[382339] = '1/40/45/50',
[382338] = '1/30/35/40',
[382337] = '1/30/35/40',
[382336] = '1/50/50/50',
[382335] = '1/35/37/40',
[382334] = '1/65/70/75',
[382333] = '1/30/35/40',
[382332] = '1/50/50/50',
[382331] = '1/35/37/40',
[382330] = '1/15/17/20',
[382329] = '1/90/95/100',
[382328] = '1/65/70/75',
[382327] = '1/35/37/40',
[382326] = '1/50/55/60',
[382325] = '1/50/55/60',
[382324] = '1/50/50/50',
[382323] = '1/30/35/40',
[382322] = '1/25/27/30',
[382321] = '1/100/100/100',
[382320] = '1/100/100/100',
[382319] = '1/100/100/100',
[382318] = '1/100/100/100',
[382317] = '1/100/100/100',
[382982] = '1/1/5/10',
[382981] = '1/10/12/15',
[383649] = '1/1/1/1',
[383792] = '1/1/1/1',
[383793] = '1/1/1/1',
[383795] = '1/1/1/1',
[383796] = '1/1/1/1',
[383797] = '1/1/1/1',
[383787] = '1/10/15/20',
[383585] = '1/25/37/50',
[383584] = '1/25/37/50',
[383583] = '1/25/37/50',
[383582] = '1/25/37/50',
[383580] = '1/25/37/50',
[383579] = '1/25/37/50',
[383578] = '1/25/37/50',
[383545] = '1/100/100/100',
[383575] = '1/35/42/50',
[383574] = '1/35/42/50',
[383576] = '1/25/37/50',
[383531] = '1/10/15/20',
[383546] = '1/60/72/85',
[383788] = '1/10/15/20',
[383548] = '1/90/95/100',
[383547] = '1/35/40/45',
[383534] = '1/50/62/75',
[383533] = '1/50/57/65',
[383550] = '1/90/95/100',
[383549] = '1/35/40/45',
[383791] = '1/30/35/40',
[383530] = '1/20/25/30',
[383586] = '1/50/62/75',
[383544] = '1/25/30/35',
[383543] = '1/25/30/35',
[383529] = '1/35/40/45',
[383542] = '1/100/100/100',
[383538] = '1/50/62/75',
[383569] = '1/15/25/35',
[383572] = '1/20/22/25',
[383573] = '1/20/22/25',
[383565] = '1/20/22/25',
[383570] = '1/20/22/25',
[383571] = '1/20/22/25',
[383567] = '1/20/22/25',
[383786] = '1/10/15/20',
[383587] = '1/50/62/75',
[383535] = '1/50/62/75',
[383520] = '1/35/42/50',
[383516] = '1/35/42/50',
[383519] = '1/35/42/50',
[383524] = '1/35/42/50',
[383759] = '1/35/42/50',
[383515] = '1/35/42/50',
[383523] = '1/35/42/50',
[383517] = '1/35/42/50',
[383522] = '1/35/42/50',
[383844] = '1/35/42/50',
[383562] = '1/55/60/65',
[383561] = '1/55/60/65',
[383560] = '1/55/60/65',
[383556] = '1/55/60/65',
[383555] = '1/55/60/65',
[383554] = '1/55/60/65',
[383563] = '1/20/25/30',
[383512] = '1/40/57/75',
[383540] = '1/100/100/100',
[383790] = '1/45/50/55',
[383539] = '1/25/30/35',
[383590] = '1/50/55/60',
[383588] = '1/50/55/60',
[383593] = '1/50/55/60',
[383592] = '1/50/55/60',
[383591] = '1/50/55/60',
[384313] = '1/35/37/40',
[384314] = '1/15/17/20',
[374530] = '1/25/27/30',
[383527] = '1/35/40/45',
[383525] = '1/35/40/45',
[381547] = '1/65/70/75',
[384491] = '1/65/70/75',
[384688] = '1/30/45/60',
[384690] = '1/100/100/100',
[384692] = '1/15/22/30',
[384693] = '1/100/100/100',
[382374] = '1/1/1/1',
[384869] = '1/20/22/25',
[383552] = '1/90/95/100',
[383551] = '1/35/40/45',
[384948] = '1/20/25/30',
[384949] = '1/20/25/30',
[381848] = '1/65/70/75',
[381849] = '1/65/70/75',
[383577] = '1/25/37/50',
[383541] = '1/100/100/100',
[383767] = '1/100/100/100',
[383325] = '1/100/100/100',
[383770] = '1/100/100/100',
[383772] = '1/100/100/100',
[386667] = '1/65/70/75',
[386670] = '1/50/50/50',
[387246] = '1/65/70/75',
[388274] = '1/5/7/10',
[388280] = '1/5/7/10',
[388282] = '1/5/7/10',
[388281] = '1/5/7/10',
[388930] = '1/10/15/20',
[389135] = '1/10/15/20',
[389136] = '1/10/15/20',
[389151] = '1/5/10/15',
[389292] = '1/40/45/50',
[389293] = '1/40/45/50',
[389294] = '1/40/45/50',
[389295] = '1/40/45/50',
[389297] = '1/20/25/30',
[389298] = '1/20/25/30',
[389300] = '1/20/25/30',
[389301] = '1/55/60/65',
[389303] = '1/55/60/65',
[389304] = '1/55/60/65',
[388279] = '1/45/47/50',
[389397] = '1/30/35/40',
[389398] = '1/30/35/40',
[389400] = '1/30/35/40',
[389403] = '1/60/67/75',
[389404] = '1/60/67/75',
[389405] = '1/60/67/75',
[389410] = '1/40/45/50',
[389416] = '1/65/75/85',
[389417] = '1/65/75/85',
[389419] = '1/65/75/85',
[389458] = '1/90/95/100',
[389406] = '1/100/100/100',
[389409] = '1/100/100/100',
[389413] = '1/100/100/100',
[389420] = '1/60/80/100',
[389459] = '1/60/80/100',
[389460] = '1/60/80/100',
[389461] = '1/60/80/100',
[389462] = '1/60/80/100',
[389463] = '1/60/80/100',
[389464] = '1/60/80/100',
[389465] = '1/90/95/100',
[389479] = '1/70/80/90',
[389480] = '1/70/80/90',
[389484] = '1/70/80/90',
[389508] = '1/65/77/90',
[389513] = '1/65/77/90',
[389519] = '1/65/77/90',
[389525] = '1/65/77/90',
[389530] = '1/65/77/90',
[389537] = '1/60/65/70',
[389540] = '1/60/65/70',
[389542] = '1/60/65/70',
[389543] = '1/60/65/70',
[389546] = '1/60/65/70',
[389547] = '1/85/92/100',
[389549] = '1/85/92/100',
[389550] = '1/85/92/100',
[389551] = '1/85/92/100',
[389558] = '1/85/92/100',
[389700] = '1/1/1/1',
[389701] = '1/1/1/1',
[389702] = '1/1/1/1',
[389703] = '1/1/1/1',
[389704] = '1/1/1/1',
[390823] = '1/20/25/30',
[390825] = '1/90/95/100',
[390831] = '1/50/62/75',
[390839] = '1/90/95/100',
[390855] = '1/50/62/75',
[390847] = '1/45/50/55',
[390848] = '1/45/50/55',
[390849] = '1/45/50/55',
[390850] = '1/45/50/55',
[390851] = '1/45/50/55',
[390852] = '1/45/50/55',
[390853] = '1/45/50/55',
[390951] = '1/45/50/55',
[391176] = '1/5/10/15',
[391179] = '1/100/100/100',
[391185] = '1/50/65/80',
[391196] = '1/5/10/15',
[391197] = '1/25/30/35',
[391202] = '1/40/50/60',
[391302] = '1/1/1/1',
[391304] = '1/1/1/1',
[391406] = '1/15/22/30',
[391441] = '1/30/45/60',
[391447] = '1/30/45/60',
[391444] = '1/30/45/60',
[391505] = '1/100/100/100',
[391498] = '1/60/80/100',
[391499] = '1/100/100/100',
[391506] = '1/100/100/100',
[391507] = '1/100/100/100',
[391509] = '1/100/100/100',
[391511] = '1/100/100/100',
[391513] = '1/100/100/100',
[391515] = '1/100/100/100',
[391492] = '1/60/80/100',
[391460] = '1/60/80/100',
[391415] = '1/60/80/100',
[391496] = '1/60/80/100',
[391431] = '1/60/80/100',
[391500] = '1/100/100/100',
[391501] = '1/100/100/100',
[391502] = '1/100/100/100',
[391503] = '1/100/100/100',
[391504] = '1/100/100/100',
[391508] = '1/100/100/100',
[391510] = '1/100/100/100',
[391512] = '1/100/100/100',
[391514] = '1/100/100/100',
[391516] = '1/100/100/100',
[391558] = '1/1/1/1',
[391564] = '1/1/1/1',
[391562] = '1/1/1/1',
[391557] = '1/1/1/1',
[391560] = '1/1/1/1',
[391781] = '1/40/50/60',
[391782] = '1/40/50/60',
[391846] = '1/65/70/75',
[391845] = '1/50/62/75',
[391848] = '1/50/62/75',
[391836] = '1/65/70/75',
[391832] = '1/50/62/75',
[391834] = '1/50/62/75',
[383581] = '1/25/37/50',
[392396] = '1/1/1/1',
[391813] = '1/90/95/100',
[392440] = '1/50/50/50',
[392445] = '1/49/49/49',
[391814] = '1/90/95/100',
[391815] = '1/90/95/100',
[391816] = '1/90/95/100',
[392697] = '1/40/45/50',
[392888] = '1/1/13/25',
[393059] = '1/10/30/50',
[393060] = '1/10/30/50',
[393061] = '1/10/30/50',
[393062] = '1/10/30/50',
[393065] = '1/10/30/50',
[393064] = '1/10/30/50',
[393063] = '1/10/30/50',
[393066] = '1/10/30/50',
[393067] = '1/10/30/50',
[393068] = '1/10/30/50',
[392944] = '1/35/42/50',
[391807] = '1/5/10/15',
[391806] = '1/25/30/35',
[391808] = '1/40/45/50',
[391809] = '1/45/50/55',
[391810] = '1/45/50/55',
[391811] = '1/45/50/55',
[391812] = '1/50/60/70',
[393404] = '1/25/30/35',
[393416] = '1/45/50/55',
[393796] = '1/65/70/75',
[393853] = '1/100/100/100',
[394189] = '1/5/7/10',
[394621] = '1/100/100/100',
[395269] = '1/1/1/1',
[395275] = '1/1/1/1',
[395282] = '1/1/1/1',
[395696] = '5/15/17/20',
[395706] = '1/20/20/20',
[395700] = '1/19/19/19',
[367611] = '1/35/40/45',
[395879] = '1/45/50/55',
[395881] = '1/40/45/50',
[395883] = '1/55/60/65',
[395880] = '1/50/55/60',
[395844] = '1/25/30/35',
[395839] = '1/55/60/65',
[395851] = '1/45/50/55',
[395863] = '1/25/30/35',
[395864] = '1/55/60/65',
[395865] = '1/30/35/40',
[395867] = '1/50/55/60',
[395868] = '1/45/50/55',
[395809] = '1/35/40/45',
[395813] = '1/40/45/50',
[395807] = '1/55/60/65',
[395814] = '1/50/55/60',
[395815] = '1/45/50/55',
[395845] = '1/30/35/40',
[395847] = '1/50/55/60',
[396162] = '1/1/1/1',
[396169] = '1/1/1/1',
[396171] = '1/1/1/1',
[396173] = '1/1/1/1',
[396777] = '1/45/47/50',
[397856] = '1/100/100/100',
[397857] = '1/100/100/100',
[397853] = '1/100/100/100',
[397855] = '1/100/100/100',
[397858] = '1/100/100/100',
[397859] = '1/100/100/100',
[397860] = '1/100/100/100',
[397861] = '1/100/100/100',
[397862] = '1/100/100/100',
[397863] = '1/100/100/100',
[397864] = '1/100/100/100',
[397865] = '1/100/100/100',
[397866] = '1/100/100/100',
[397867] = '1/100/100/100',
[398438] = '1/5/5/5',
[400026] = '1/40/45/50',
[400027] = '1/40/45/50',
[400028] = '1/40/45/50',
[400270] = '1/50/55/60',
[388213] = '1/1/1/1',
[390392] = '1/1/1/1',
[400808] = '1/50/55/60',
[400807] = '1/40/45/50',
[400809] = '1/50/55/60',
[400810] = '1/50/55/60',
[400811] = '1/50/55/60',
[400812] = '1/50/55/60',
[400814] = '1/50/55/60',
[400815] = '1/50/55/60',
[402118] = '1/300/300/300',
[402151] = '1/300/300/300',
[402139] = '1/300/300/300',
[402140] = '1/300/300/300',
[402143] = '1/300/300/300',
[402123] = '1/300/300/300',
[402124] = '1/300/300/300',
[402125] = '1/300/300/300',
[402126] = '1/300/300/300',
[402128] = '1/300/300/300',
[402129] = '1/300/300/300',
[402130] = '1/300/300/300',
[402131] = '1/300/300/300',
[402133] = '1/300/300/300',
[402134] = '1/300/300/300',
[402135] = '1/300/300/300',
[402136] = '1/300/300/300',
[402137] = '1/300/300/300',
[402138] = '1/300/300/300',
[402141] = '1/300/300/300',
[402142] = '1/300/300/300',
[402144] = '1/300/300/300',
[402146] = '1/300/300/300',
[402147] = '1/300/300/300',
[402148] = '1/300/300/300',
[402150] = '1/300/300/300',
[402152] = '1/300/300/300',
[402155] = '1/300/300/300',
[402156] = '1/300/300/300',
[402615] = '1/300/300/300',
[403018] = '1/80/85/90',
[403159] = '1/50/55/60',
[403164] = '1/50/55/60',
[403160] = '1/50/55/60',
[403162] = '1/50/55/60',
[403161] = '1/50/55/60',
[403163] = '1/50/55/60',
[403165] = '1/50/55/60',
[403158] = '1/50/55/60',
[403166] = '1/50/55/60',
[403167] = '1/50/55/60',
[403168] = '1/50/55/60',
[403131] = '1/50/55/60',
[403132] = '1/50/55/60',
[403134] = '1/50/55/60',
[403138] = '1/50/55/60',
[403137] = '1/50/55/60',
[403133] = '1/50/55/60',
[403135] = '1/50/55/60',
[403136] = '1/50/55/60',
[403140] = '1/50/55/60',
[403139] = '1/50/55/60',
[403142] = '1/50/55/60',
[403146] = '1/50/55/60',
[403145] = '1/50/55/60',
[403141] = '1/50/55/60',
[403143] = '1/50/55/60',
[403144] = '1/50/55/60',
[403148] = '1/50/55/60',
[403147] = '1/50/55/60',
[403149] = '1/50/55/60',
[403150] = '1/50/55/60',
[403151] = '1/50/55/60',
[403152] = '1/50/55/60',
[403153] = '1/50/55/60',
[403154] = '1/50/55/60',
[403155] = '1/50/55/60',
[403156] = '1/50/55/60',
[403157] = '1/50/55/60',
[403483] = '1/1/1/1',
[404740] = '1/100/100/100',
[405076] = '1/85/92/100',
[404859] = '1/85/92/100',
[405131] = '1/1/1/1',
[405120] = '1/60/80/100',
[405121] = '1/100/100/100',
[405134] = '1/1/1/1',
[405123] = '1/60/80/100',
[405124] = '1/100/100/100',
[405126] = '1/100/100/100',
[405127] = '1/100/100/100',
[405205] = '1/1/1/1',
[405650] = '1/45/50/55',
[405803] = '1/100/100/100',
[405832] = '1/55/60/65',
[405847] = '1/50/55/60',
[405879] = '1/100/100/100',
[405937] = '1/60/65/70',
[405974] = '1/45/50/55',
[406106] = '1/100/100/100',
[406267] = '1/100/100/100',
[406266] = '1/100/100/100',
[406275] = '1/70/75/80',
[406214] = '1/65/70/75',
[406108] = '1/60/75/90',
[406413] = '1/80/90/100',
[406418] = '1/95/97/100',
[407006] = '1/50/57/65',
[407005] = '1/50/57/65',
[409224] = '1/100/100/100',
[407066] = '1/50/57/65',
[407100] = '1/50/57/65',
[407161] = '1/100/100/100',
[407170] = '1/100/100/100',
[408052] = '1/65/70/75',
[408230] = '1/65/70/75',
[408231] = '1/70/72/75',
[408282] = '1/45/55/65',
[408283] = '1/100/100/100',
[408288] = '1/45/55/65',
[408299] = '1/45/55/65',
[408326] = '1/100/100/100',
[408304] = '1/65/70/75',
[408318] = '1/100/100/100',
[408218] = '1/35/42/50',
[408220] = '1/35/42/50',
[408221] = '1/35/42/50',
[408222] = '1/35/42/50',
[408223] = '1/35/42/50',
[408271] = '1/35/40/45',
[408272] = '1/60/72/85',
[408273] = '1/60/62/65',
[408277] = '1/60/62/65',
[408278] = '1/50/55/60',
[408397] = '1/70/72/75',
[408398] = '1/70/72/75',
[409351] = '1/50/55/60',
[409353] = '1/50/55/60',
[409355] = '1/50/55/60',
[409356] = '1/50/55/60',
[409555] = '1/40/45/50',
[409557] = '1/40/45/50',
[409839] = '1/65/70/75',
[413490] = '1/320/330/340',
[413491] = '1/320/330/340',
[413492] = '1/320/330/340',
[413494] = '1/320/330/340',
[413495] = '1/320/330/340',
[413496] = '1/320/330/340',
[413497] = '1/320/330/340',
[413498] = '1/320/330/340',
[413499] = '1/320/330/340',
[413500] = '1/320/330/340',
[413501] = '1/320/330/340',
[413502] = '1/320/330/340',
[413503] = '1/320/330/340',
[413504] = '1/320/330/340',
[413505] = '1/320/330/340',
[413506] = '1/320/330/340',
[413507] = '1/320/330/340',
[413508] = '1/320/330/340',
[413509] = '1/320/330/340',
[413510] = '1/320/330/340',
[413511] = '1/300/300/300',
[413512] = '1/300/300/300',
[413513] = '1/300/300/300',
[413514] = '1/300/300/300',
[413518] = '1/300/300/300',
[413520] = '1/300/300/300',
[413521] = '1/300/300/300',
[413522] = '1/300/300/300',
[413523] = '1/300/300/300',
[413524] = '1/300/300/300',
[413739] = '1/300/300/300',
[413740] = '1/300/300/300',
[413741] = '1/300/300/300',
[413742] = '1/300/300/300',
[413744] = '1/300/300/300',
[413745] = '1/300/300/300',
[413746] = '1/300/300/300',
[413749] = '1/300/300/300',
[413750] = '1/300/300/300',
[413753] = '1/300/300/300',
[413755] = '1/300/300/300',
[413757] = '1/300/300/300',
[413758] = '1/300/300/300',
[413760] = '1/300/300/300',
[413516] = '1/300/300/300',
[413517] = '1/300/300/300',
[413738] = '1/300/300/300',
[413756] = '1/300/300/300',
[413761] = '1/300/300/300',
[413747] = '1/300/300/300',
[413754] = '1/300/300/300',
[413515] = '1/300/300/300',
[413519] = '1/300/300/300',
[413748] = '1/300/300/300',
[413743] = '1/300/300/300',
[413751] = '1/300/300/300',
[413752] = '1/300/300/300',
[413759] = '1/300/300/300',
[413788] = '1/300/300/300',
[413903] = '1/300/300/300',
[414590] = '1/300/300/300',
[414946] = '1/45/50/55',
[414985] = '1/60/75/90',
[414988] = '1/80/90/100',
[414989] = '1/95/97/100',
[415628] = '1/55/60/65',
[415810] = '1/55/60/65',
[416001] = '1/25/27/30',
[416047] = '1/85/92/100',
[416137] = '1/60/62/65',
[416149] = '1/65/70/75',
[416682] = '1/300/300/300',
[416683] = '1/300/300/300',
[416687] = '1/300/300/300',
[416688] = '1/300/300/300',
[416690] = '1/300/300/300',
[416689] = '1/300/300/300',
[416691] = '1/300/300/300',
[416692] = '1/300/300/300',
[416684] = '1/300/300/300',
[416685] = '1/300/300/300',
[416686] = '1/300/300/300',
[225553] = '1/20/45/70',
[414565] = '1/300/305/310',
[414566] = '1/300/305/310',
[414567] = '1/300/305/310',
[414564] = '1/300/305/310',
[418579] = '1/70/75/80',
[419032] = '1/50/55/60',
[419037] = '1/50/55/60',
[419033] = '1/50/55/60',
[419035] = '1/50/55/60',
[419034] = '1/50/55/60',
[419036] = '1/50/55/60',
[419038] = '1/50/55/60',
[419031] = '1/50/55/60',
[419004] = '1/50/55/60',
[419005] = '1/50/55/60',
[419039] = '1/50/55/60',
[419040] = '1/50/55/60',
[419041] = '1/50/55/60',
[419045] = '1/50/55/60',
[419044] = '1/50/55/60',
[419043] = '1/50/55/60',
[419042] = '1/50/55/60',
[419007] = '1/50/55/60',
[419011] = '1/50/55/60',
[419010] = '1/50/55/60',
[419006] = '1/50/55/60',
[419008] = '1/50/55/60',
[419009] = '1/50/55/60',
[419013] = '1/50/55/60',
[419012] = '1/50/55/60',
[419015] = '1/50/55/60',
[419019] = '1/50/55/60',
[419018] = '1/50/55/60',
[419014] = '1/50/55/60',
[419016] = '1/50/55/60',
[419017] = '1/50/55/60',
[419021] = '1/50/55/60',
[419020] = '1/50/55/60',
[419030] = '1/50/55/60',
[419029] = '1/50/55/60',
[419028] = '1/50/55/60',
[419027] = '1/50/55/60',
[419026] = '1/50/55/60',
[419025] = '1/50/55/60',
[419024] = '1/50/55/60',
[419023] = '1/50/55/60',
[419022] = '1/50/55/60',
[420740] = '1/50/65/80',
[421176] = '1/100/100/100',
[421224] = '1/60/80/100',
[421226] = '1/100/100/100',
[421227] = '1/100/100/100',
[421247] = '1/100/100/100',
[421244] = '1/60/80/100',
[422293] = '1/1/1/1',
[422809] = '1/1/1/1',
[425263] = '1/50/55/60',
[425954] = '1/60/72/85',
[425958] = '1/35/42/50',
[425961] = '1/35/42/50',
[425959] = '1/35/42/50',
[426332] = '1/100/100/100',
[426434] = '1/65/70/75',
[427956] = '1/60/62/65',
[429149] = '1/60/62/65',
[430066] = '1/50/55/60',
[430065] = '1/50/55/60',
[430071] = '1/50/55/60',
[430068] = '1/50/55/60',
[430069] = '1/50/55/60',
[430072] = '1/50/55/60',
[430067] = '1/50/55/60',
[430070] = '1/50/55/60',
[430093] = '1/50/55/60',
[430082] = '1/50/55/60',
[430083] = '1/50/55/60',
[430084] = '1/50/55/60',
[430085] = '1/50/55/60',
[430086] = '1/50/55/60',
[430087] = '1/50/55/60',
[430088] = '1/50/55/60',
[430089] = '1/50/55/60',
[430092] = '1/50/55/60',
[430091] = '1/50/55/60',
[430055] = '1/50/55/60',
[430056] = '1/50/55/60',
[430094] = '1/50/55/60',
[430095] = '1/50/55/60',
[430090] = '1/50/55/60',
[430096] = '1/50/55/60',
[430064] = '1/50/55/60',
[430062] = '1/50/55/60',
[430058] = '1/50/55/60',
[430061] = '1/50/55/60',
[430057] = '1/50/55/60',
[430060] = '1/50/55/60',
[430059] = '1/50/55/60',
[430063] = '1/50/55/60',
[430081] = '1/50/55/60',
[430073] = '1/50/55/60',
[430076] = '1/50/55/60',
[430077] = '1/50/55/60',
[430078] = '1/50/55/60',
[430080] = '1/50/55/60',
[430079] = '1/50/55/60',
[430075] = '1/50/55/60',
[430074] = '1/50/55/60',
[429948] = '1/60/75/90',
[429945] = '1/80/90/100',
[429947] = '1/95/97/100',
[422337] = '1/100/100/100',
[422338] = '1/100/100/100',
[422330] = '1/100/100/100',
--@end-version-retail@
}
end
